""" Cisco_IOS_XR_pmengine_oper 

This module contains a collection of YANG definitions
for Cisco IOS\-XR pmengine package operational data.

This module contains definitions
for the following management objects\:
  performance\-management\: performace data
  performance\-management\-history\: performance management history

Copyright (c) 2013\-2018 by Cisco Systems, Inc.
All rights reserved.

"""
from collections import OrderedDict

from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YError, YModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error



class PmPrbsPatternEt(Enum):
    """
    PmPrbsPatternEt (Enum Class)

    PM PRBS Pattern Mode Enum

    .. data:: prbs_none = 0

    	pn none

    .. data:: pn31 = 1

    	pn31

    .. data:: pn23 = 2

    	pn23

    .. data:: pn11 = 4

    	pn11

    .. data:: inv_pn31 = 8

    	inv pn31

    .. data:: inv_pn11 = 16

    	inv pn11

    .. data:: pn15 = 32

    	pn15

    """

    prbs_none = Enum.YLeaf(0, "prbs-none")

    pn31 = Enum.YLeaf(1, "pn31")

    pn23 = Enum.YLeaf(2, "pn23")

    pn11 = Enum.YLeaf(4, "pn11")

    inv_pn31 = Enum.YLeaf(8, "inv-pn31")

    inv_pn11 = Enum.YLeaf(16, "inv-pn11")

    pn15 = Enum.YLeaf(32, "pn15")


class PmPrbsStatusEt(Enum):
    """
    PmPrbsStatusEt (Enum Class)

    PM PRBS Status Mode Enum

    .. data:: not_applicable = 0

    	not applicable

    .. data:: locked = 1

    	locked

    .. data:: un_locked = 2

    	unlocked

    """

    not_applicable = Enum.YLeaf(0, "not-applicable")

    locked = Enum.YLeaf(1, "locked")

    un_locked = Enum.YLeaf(2, "un-locked")


class PmSonetPathWidthEnum(Enum):
    """
    PmSonetPathWidthEnum (Enum Class)

    Sonet Path Width Enum

    .. data:: none = 0

    	Sonet Path Width NONE 

    .. data:: sts1 = 1

    	Sonet Path Width STS1 

    .. data:: sts3c_stm1 = 2

    	Sonet Path Width sts3cSTM1 

    .. data:: sts12c_stm4 = 3

    	Sonet Path Width sts12cSTM4 

    .. data:: sts24c = 4

    	Sonet Path Width sts24 

    .. data:: sts48c_stm16 = 5

    	Sonet Path Width sts48cSTM16 

    .. data:: sts192c_stm64 = 6

    	Sonet Path Width sts192cSTM64 

    .. data:: sts768c_stm256 = 7

    	Sonet Path Width sts768cSTM256 

    """

    none = Enum.YLeaf(0, "none")

    sts1 = Enum.YLeaf(1, "sts1")

    sts3c_stm1 = Enum.YLeaf(2, "sts3c-stm1")

    sts12c_stm4 = Enum.YLeaf(3, "sts12c-stm4")

    sts24c = Enum.YLeaf(4, "sts24c")

    sts48c_stm16 = Enum.YLeaf(5, "sts48c-stm16")

    sts192c_stm64 = Enum.YLeaf(6, "sts192c-stm64")

    sts768c_stm256 = Enum.YLeaf(7, "sts768c-stm256")



class PerformanceManagement(Entity):
    """
    performace data
    
    .. attribute:: macsec
    
    	MACSEC controller performance data
    	**type**\:  :py:class:`Macsec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec>`
    
    .. attribute:: ho_vc
    
    	HO\_VC controller performance data
    	**type**\:  :py:class:`HoVc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc>`
    
    .. attribute:: odu
    
    	ODU controller performance data
    	**type**\:  :py:class:`Odu <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu>`
    
    .. attribute:: otu
    
    	OTU controller performance data
    	**type**\:  :py:class:`Otu <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu>`
    
    .. attribute:: stm
    
    	STM controller performance data
    	**type**\:  :py:class:`Stm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm>`
    
    .. attribute:: sonet
    
    	SONET controller performance data
    	**type**\:  :py:class:`Sonet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet>`
    
    .. attribute:: optics
    
    	OPTICS controller performance data
    	**type**\:  :py:class:`Optics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics>`
    
    .. attribute:: sts
    
    	STS controller performance data
    	**type**\:  :py:class:`Sts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts>`
    
    .. attribute:: dwdm
    
    	DWDM controller performance data
    	**type**\:  :py:class:`Dwdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm>`
    
    .. attribute:: oc
    
    	OC controller performance data
    	**type**\:  :py:class:`Oc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc>`
    
    .. attribute:: ethernet
    
    	EHERNET controller performance data
    	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet>`
    
    

    """

    _prefix = 'pmengine-oper'
    _revision = '2017-09-07'

    def __init__(self):
        super(PerformanceManagement, self).__init__()
        self._top_entity = None

        self.yang_name = "performance-management"
        self.yang_parent_name = "Cisco-IOS-XR-pmengine-oper"
        self.is_top_level_class = True
        self.has_list_ancestor = False
        self.ylist_key_names = []
        self._child_classes = OrderedDict([("macsec", ("macsec", PerformanceManagement.Macsec)), ("ho-vc", ("ho_vc", PerformanceManagement.HoVc)), ("odu", ("odu", PerformanceManagement.Odu)), ("otu", ("otu", PerformanceManagement.Otu)), ("stm", ("stm", PerformanceManagement.Stm)), ("sonet", ("sonet", PerformanceManagement.Sonet)), ("optics", ("optics", PerformanceManagement.Optics)), ("sts", ("sts", PerformanceManagement.Sts)), ("dwdm", ("dwdm", PerformanceManagement.Dwdm)), ("oc", ("oc", PerformanceManagement.Oc)), ("ethernet", ("ethernet", PerformanceManagement.Ethernet))])
        self._leafs = OrderedDict()

        self.macsec = PerformanceManagement.Macsec()
        self.macsec.parent = self
        self._children_name_map["macsec"] = "macsec"

        self.ho_vc = PerformanceManagement.HoVc()
        self.ho_vc.parent = self
        self._children_name_map["ho_vc"] = "ho-vc"

        self.odu = PerformanceManagement.Odu()
        self.odu.parent = self
        self._children_name_map["odu"] = "odu"

        self.otu = PerformanceManagement.Otu()
        self.otu.parent = self
        self._children_name_map["otu"] = "otu"

        self.stm = PerformanceManagement.Stm()
        self.stm.parent = self
        self._children_name_map["stm"] = "stm"

        self.sonet = PerformanceManagement.Sonet()
        self.sonet.parent = self
        self._children_name_map["sonet"] = "sonet"

        self.optics = PerformanceManagement.Optics()
        self.optics.parent = self
        self._children_name_map["optics"] = "optics"

        self.sts = PerformanceManagement.Sts()
        self.sts.parent = self
        self._children_name_map["sts"] = "sts"

        self.dwdm = PerformanceManagement.Dwdm()
        self.dwdm.parent = self
        self._children_name_map["dwdm"] = "dwdm"

        self.oc = PerformanceManagement.Oc()
        self.oc.parent = self
        self._children_name_map["oc"] = "oc"

        self.ethernet = PerformanceManagement.Ethernet()
        self.ethernet.parent = self
        self._children_name_map["ethernet"] = "ethernet"
        self._segment_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management"
        self._is_frozen = True

    def __setattr__(self, name, value):
        self._perform_setattr(PerformanceManagement, [], name, value)


    class Macsec(Entity):
        """
        MACSEC controller performance data
        
        .. attribute:: macsec_ports
        
        	Port performance data
        	**type**\:  :py:class:`MacsecPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts>`
        
        

        """

        _prefix = 'pmengine-oper'
        _revision = '2017-09-07'

        def __init__(self):
            super(PerformanceManagement.Macsec, self).__init__()

            self.yang_name = "macsec"
            self.yang_parent_name = "performance-management"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("macsec-ports", ("macsec_ports", PerformanceManagement.Macsec.MacsecPorts))])
            self._leafs = OrderedDict()

            self.macsec_ports = PerformanceManagement.Macsec.MacsecPorts()
            self.macsec_ports.parent = self
            self._children_name_map["macsec_ports"] = "macsec-ports"
            self._segment_path = lambda: "macsec"
            self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(PerformanceManagement.Macsec, [], name, value)


        class MacsecPorts(Entity):
            """
            Port performance data
            
            .. attribute:: macsec_port
            
            	Port performance data
            	**type**\: list of  		 :py:class:`MacsecPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort>`
            
            

            """

            _prefix = 'pmengine-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(PerformanceManagement.Macsec.MacsecPorts, self).__init__()

                self.yang_name = "macsec-ports"
                self.yang_parent_name = "macsec"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("macsec-port", ("macsec_port", PerformanceManagement.Macsec.MacsecPorts.MacsecPort))])
                self._leafs = OrderedDict()

                self.macsec_port = YList(self)
                self._segment_path = lambda: "macsec-ports"
                self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management/macsec/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts, [], name, value)


            class MacsecPort(Entity):
                """
                Port performance data
                
                .. attribute:: name  (key)
                
                	Port name
                	**type**\: str
                
                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                
                .. attribute:: macsec_current
                
                	port current performance data
                	**type**\:  :py:class:`MacsecCurrent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort, self).__init__()

                    self.yang_name = "macsec-port"
                    self.yang_parent_name = "macsec-ports"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("macsec-current", ("macsec_current", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ])
                    self.name = None

                    self.macsec_current = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent()
                    self.macsec_current.parent = self
                    self._children_name_map["macsec_current"] = "macsec-current"
                    self._segment_path = lambda: "macsec-port" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management/macsec/macsec-ports/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort, ['name'], name, value)


                class MacsecCurrent(Entity):
                    """
                    port current performance data
                    
                    .. attribute:: macsec_minute15
                    
                    	port current performance data
                    	**type**\:  :py:class:`MacsecMinute15 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15>`
                    
                    .. attribute:: macsec_second30
                    
                    	port current performance data
                    	**type**\:  :py:class:`MacsecSecond30 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30>`
                    
                    .. attribute:: macsec_hour24
                    
                    	port current performance data
                    	**type**\:  :py:class:`MacsecHour24 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent, self).__init__()

                        self.yang_name = "macsec-current"
                        self.yang_parent_name = "macsec-port"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("macsec-minute15", ("macsec_minute15", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15)), ("macsec-second30", ("macsec_second30", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30)), ("macsec-hour24", ("macsec_hour24", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24))])
                        self._leafs = OrderedDict()

                        self.macsec_minute15 = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15()
                        self.macsec_minute15.parent = self
                        self._children_name_map["macsec_minute15"] = "macsec-minute15"

                        self.macsec_second30 = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30()
                        self.macsec_second30.parent = self
                        self._children_name_map["macsec_second30"] = "macsec-second30"

                        self.macsec_hour24 = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24()
                        self.macsec_hour24.parent = self
                        self._children_name_map["macsec_hour24"] = "macsec-hour24"
                        self._segment_path = lambda: "macsec-current"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent, [], name, value)


                    class MacsecMinute15(Entity):
                        """
                        port current performance data
                        
                        .. attribute:: macsec_minute15secyifs
                        
                        	port current performance data
                        	**type**\:  :py:class:`MacsecMinute15secyifs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs>`
                        
                        .. attribute:: macsec_minute15secyrxes
                        
                        	port current performance data
                        	**type**\:  :py:class:`MacsecMinute15secyrxes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes>`
                        
                        .. attribute:: macsec_minute15secytxes
                        
                        	port current performance data
                        	**type**\:  :py:class:`MacsecMinute15secytxes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secytxes>`
                        
                        .. attribute:: macsec_minute15_ether_s
                        
                        	port current performance data
                        	**type**\:  :py:class:`MacsecMinute15EtherS <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15, self).__init__()

                            self.yang_name = "macsec-minute15"
                            self.yang_parent_name = "macsec-current"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("macsec-minute15secyifs", ("macsec_minute15secyifs", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs)), ("macsec-minute15secyrxes", ("macsec_minute15secyrxes", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes)), ("macsec-minute15secytxes", ("macsec_minute15secytxes", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secytxes)), ("macsec-minute15-ether-s", ("macsec_minute15_ether_s", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS))])
                            self._leafs = OrderedDict()

                            self.macsec_minute15secyifs = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs()
                            self.macsec_minute15secyifs.parent = self
                            self._children_name_map["macsec_minute15secyifs"] = "macsec-minute15secyifs"

                            self.macsec_minute15secyrxes = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes()
                            self.macsec_minute15secyrxes.parent = self
                            self._children_name_map["macsec_minute15secyrxes"] = "macsec-minute15secyrxes"

                            self.macsec_minute15secytxes = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secytxes()
                            self.macsec_minute15secytxes.parent = self
                            self._children_name_map["macsec_minute15secytxes"] = "macsec-minute15secytxes"

                            self.macsec_minute15_ether_s = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS()
                            self.macsec_minute15_ether_s.parent = self
                            self._children_name_map["macsec_minute15_ether_s"] = "macsec-minute15-ether-s"
                            self._segment_path = lambda: "macsec-minute15"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15, [], name, value)


                        class MacsecMinute15secyifs(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: macsec_minute15secyif
                            
                            	port 15\-minute secy\-if performance data
                            	**type**\: list of  		 :py:class:`MacsecMinute15secyif <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs, self).__init__()

                                self.yang_name = "macsec-minute15secyifs"
                                self.yang_parent_name = "macsec-minute15"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("macsec-minute15secyif", ("macsec_minute15secyif", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif))])
                                self._leafs = OrderedDict()

                                self.macsec_minute15secyif = YList(self)
                                self._segment_path = lambda: "macsec-minute15secyifs"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs, [], name, value)


                            class MacsecMinute15secyif(Entity):
                                """
                                port 15\-minute secy\-if performance data
                                
                                .. attribute:: number  (key)
                                
                                	channel number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: in_pkts_untagged
                                
                                	In Packet Untagged
                                	**type**\:  :py:class:`InPktsUntagged <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.InPktsUntagged>`
                                
                                .. attribute:: in_pkts_no_tag
                                
                                	In Packet No tag
                                	**type**\:  :py:class:`InPktsNoTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.InPktsNoTag>`
                                
                                .. attribute:: in_pkts_bad_tag
                                
                                	In Packet Bad tag
                                	**type**\:  :py:class:`InPktsBadTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.InPktsBadTag>`
                                
                                .. attribute:: in_pkts_unknown_sci
                                
                                	In Packet Unknown sci
                                	**type**\:  :py:class:`InPktsUnknownSci <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.InPktsUnknownSci>`
                                
                                .. attribute:: in_pkts_no_sci
                                
                                	In Packet No sci
                                	**type**\:  :py:class:`InPktsNoSci <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.InPktsNoSci>`
                                
                                .. attribute:: in_pkts_overrun
                                
                                	In Packet Overrun
                                	**type**\:  :py:class:`InPktsOverrun <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.InPktsOverrun>`
                                
                                .. attribute:: in_octets_validated
                                
                                	In Octet Validated
                                	**type**\:  :py:class:`InOctetsValidated <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.InOctetsValidated>`
                                
                                .. attribute:: in_octets_decrypted
                                
                                	In Octet Decrypted
                                	**type**\:  :py:class:`InOctetsDecrypted <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.InOctetsDecrypted>`
                                
                                .. attribute:: out_pkts_untagged
                                
                                	Out Packet Untagged
                                	**type**\:  :py:class:`OutPktsUntagged <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.OutPktsUntagged>`
                                
                                .. attribute:: out_pkts_too_long
                                
                                	Out Packet Too Long
                                	**type**\:  :py:class:`OutPktsTooLong <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.OutPktsTooLong>`
                                
                                .. attribute:: out_octets_protected
                                
                                	Out Octet Protected
                                	**type**\:  :py:class:`OutOctetsProtected <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.OutOctetsProtected>`
                                
                                .. attribute:: out_octets_encrypted
                                
                                	Out Octet encrypted
                                	**type**\:  :py:class:`OutOctetsEncrypted <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.OutOctetsEncrypted>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\: bool
                                
                                .. attribute:: sample_count
                                
                                	Running Sample Count
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif, self).__init__()

                                    self.yang_name = "macsec-minute15secyif"
                                    self.yang_parent_name = "macsec-minute15secyifs"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("in-pkts-untagged", ("in_pkts_untagged", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.InPktsUntagged)), ("in-pkts-no-tag", ("in_pkts_no_tag", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.InPktsNoTag)), ("in-pkts-bad-tag", ("in_pkts_bad_tag", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.InPktsBadTag)), ("in-pkts-unknown-sci", ("in_pkts_unknown_sci", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.InPktsUnknownSci)), ("in-pkts-no-sci", ("in_pkts_no_sci", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.InPktsNoSci)), ("in-pkts-overrun", ("in_pkts_overrun", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.InPktsOverrun)), ("in-octets-validated", ("in_octets_validated", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.InOctetsValidated)), ("in-octets-decrypted", ("in_octets_decrypted", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.InOctetsDecrypted)), ("out-pkts-untagged", ("out_pkts_untagged", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.OutPktsUntagged)), ("out-pkts-too-long", ("out_pkts_too_long", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.OutPktsTooLong)), ("out-octets-protected", ("out_octets_protected", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.OutOctetsProtected)), ("out-octets-encrypted", ("out_octets_encrypted", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.OutOctetsEncrypted))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                        ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                        ('sample_count', (YLeaf(YType.uint64, 'sample-count'), ['int'])),
                                    ])
                                    self.number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear24_hr_time = None
                                    self.sec30_support = None
                                    self.sample_count = None

                                    self.in_pkts_untagged = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.InPktsUntagged()
                                    self.in_pkts_untagged.parent = self
                                    self._children_name_map["in_pkts_untagged"] = "in-pkts-untagged"

                                    self.in_pkts_no_tag = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.InPktsNoTag()
                                    self.in_pkts_no_tag.parent = self
                                    self._children_name_map["in_pkts_no_tag"] = "in-pkts-no-tag"

                                    self.in_pkts_bad_tag = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.InPktsBadTag()
                                    self.in_pkts_bad_tag.parent = self
                                    self._children_name_map["in_pkts_bad_tag"] = "in-pkts-bad-tag"

                                    self.in_pkts_unknown_sci = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.InPktsUnknownSci()
                                    self.in_pkts_unknown_sci.parent = self
                                    self._children_name_map["in_pkts_unknown_sci"] = "in-pkts-unknown-sci"

                                    self.in_pkts_no_sci = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.InPktsNoSci()
                                    self.in_pkts_no_sci.parent = self
                                    self._children_name_map["in_pkts_no_sci"] = "in-pkts-no-sci"

                                    self.in_pkts_overrun = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.InPktsOverrun()
                                    self.in_pkts_overrun.parent = self
                                    self._children_name_map["in_pkts_overrun"] = "in-pkts-overrun"

                                    self.in_octets_validated = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.InOctetsValidated()
                                    self.in_octets_validated.parent = self
                                    self._children_name_map["in_octets_validated"] = "in-octets-validated"

                                    self.in_octets_decrypted = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.InOctetsDecrypted()
                                    self.in_octets_decrypted.parent = self
                                    self._children_name_map["in_octets_decrypted"] = "in-octets-decrypted"

                                    self.out_pkts_untagged = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.OutPktsUntagged()
                                    self.out_pkts_untagged.parent = self
                                    self._children_name_map["out_pkts_untagged"] = "out-pkts-untagged"

                                    self.out_pkts_too_long = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.OutPktsTooLong()
                                    self.out_pkts_too_long.parent = self
                                    self._children_name_map["out_pkts_too_long"] = "out-pkts-too-long"

                                    self.out_octets_protected = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.OutOctetsProtected()
                                    self.out_octets_protected.parent = self
                                    self._children_name_map["out_octets_protected"] = "out-octets-protected"

                                    self.out_octets_encrypted = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.OutOctetsEncrypted()
                                    self.out_octets_encrypted.parent = self
                                    self._children_name_map["out_octets_encrypted"] = "out-octets-encrypted"
                                    self._segment_path = lambda: "macsec-minute15secyif" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support', 'sample_count'], name, value)


                                class InPktsUntagged(Entity):
                                    """
                                    In Packet Untagged
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.InPktsUntagged, self).__init__()

                                        self.yang_name = "in-pkts-untagged"
                                        self.yang_parent_name = "macsec-minute15secyif"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts-untagged"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.InPktsUntagged, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPktsNoTag(Entity):
                                    """
                                    In Packet No tag
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.InPktsNoTag, self).__init__()

                                        self.yang_name = "in-pkts-no-tag"
                                        self.yang_parent_name = "macsec-minute15secyif"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts-no-tag"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.InPktsNoTag, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPktsBadTag(Entity):
                                    """
                                    In Packet Bad tag
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.InPktsBadTag, self).__init__()

                                        self.yang_name = "in-pkts-bad-tag"
                                        self.yang_parent_name = "macsec-minute15secyif"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts-bad-tag"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.InPktsBadTag, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPktsUnknownSci(Entity):
                                    """
                                    In Packet Unknown sci
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.InPktsUnknownSci, self).__init__()

                                        self.yang_name = "in-pkts-unknown-sci"
                                        self.yang_parent_name = "macsec-minute15secyif"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts-unknown-sci"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.InPktsUnknownSci, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPktsNoSci(Entity):
                                    """
                                    In Packet No sci
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.InPktsNoSci, self).__init__()

                                        self.yang_name = "in-pkts-no-sci"
                                        self.yang_parent_name = "macsec-minute15secyif"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts-no-sci"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.InPktsNoSci, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPktsOverrun(Entity):
                                    """
                                    In Packet Overrun
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.InPktsOverrun, self).__init__()

                                        self.yang_name = "in-pkts-overrun"
                                        self.yang_parent_name = "macsec-minute15secyif"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts-overrun"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.InPktsOverrun, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InOctetsValidated(Entity):
                                    """
                                    In Octet Validated
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.InOctetsValidated, self).__init__()

                                        self.yang_name = "in-octets-validated"
                                        self.yang_parent_name = "macsec-minute15secyif"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-octets-validated"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.InOctetsValidated, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InOctetsDecrypted(Entity):
                                    """
                                    In Octet Decrypted
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.InOctetsDecrypted, self).__init__()

                                        self.yang_name = "in-octets-decrypted"
                                        self.yang_parent_name = "macsec-minute15secyif"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-octets-decrypted"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.InOctetsDecrypted, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutPktsUntagged(Entity):
                                    """
                                    Out Packet Untagged
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.OutPktsUntagged, self).__init__()

                                        self.yang_name = "out-pkts-untagged"
                                        self.yang_parent_name = "macsec-minute15secyif"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-pkts-untagged"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.OutPktsUntagged, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutPktsTooLong(Entity):
                                    """
                                    Out Packet Too Long
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.OutPktsTooLong, self).__init__()

                                        self.yang_name = "out-pkts-too-long"
                                        self.yang_parent_name = "macsec-minute15secyif"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-pkts-too-long"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.OutPktsTooLong, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutOctetsProtected(Entity):
                                    """
                                    Out Octet Protected
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.OutOctetsProtected, self).__init__()

                                        self.yang_name = "out-octets-protected"
                                        self.yang_parent_name = "macsec-minute15secyif"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-octets-protected"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.OutOctetsProtected, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutOctetsEncrypted(Entity):
                                    """
                                    Out Octet encrypted
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.OutOctetsEncrypted, self).__init__()

                                        self.yang_name = "out-octets-encrypted"
                                        self.yang_parent_name = "macsec-minute15secyif"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-octets-encrypted"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyifs.MacsecMinute15secyif.OutOctetsEncrypted, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                        class MacsecMinute15secyrxes(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: macsec_minute15secyrx
                            
                            	port 15\-minute secy\-rx performance data
                            	**type**\: list of  		 :py:class:`MacsecMinute15secyrx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes, self).__init__()

                                self.yang_name = "macsec-minute15secyrxes"
                                self.yang_parent_name = "macsec-minute15"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("macsec-minute15secyrx", ("macsec_minute15secyrx", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx))])
                                self._leafs = OrderedDict()

                                self.macsec_minute15secyrx = YList(self)
                                self._segment_path = lambda: "macsec-minute15secyrxes"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes, [], name, value)


                            class MacsecMinute15secyrx(Entity):
                                """
                                port 15\-minute secy\-rx performance data
                                
                                .. attribute:: number  (key)
                                
                                	channel number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: in_pkts_unchecked
                                
                                	In Packet Unchecked
                                	**type**\:  :py:class:`InPktsUnchecked <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx.InPktsUnchecked>`
                                
                                .. attribute:: in_pkts_delayed
                                
                                	In Packet Delay
                                	**type**\:  :py:class:`InPktsDelayed <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx.InPktsDelayed>`
                                
                                .. attribute:: in_pkts_late
                                
                                	In Packet Late
                                	**type**\:  :py:class:`InPktsLate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx.InPktsLate>`
                                
                                .. attribute:: in_pkts_ok
                                
                                	In Packet Ok
                                	**type**\:  :py:class:`InPktsOk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx.InPktsOk>`
                                
                                .. attribute:: in_pkts_invalid
                                
                                	In Packet Invalid
                                	**type**\:  :py:class:`InPktsInvalid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx.InPktsInvalid>`
                                
                                .. attribute:: in_pkts_not_valid
                                
                                	In Packet Not Valid
                                	**type**\:  :py:class:`InPktsNotValid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx.InPktsNotValid>`
                                
                                .. attribute:: in_pkts_not_using_sa
                                
                                	In Packet Not Using SA
                                	**type**\:  :py:class:`InPktsNotUsingSa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx.InPktsNotUsingSa>`
                                
                                .. attribute:: in_pkts_unused_sa
                                
                                	In Packet Unused SA
                                	**type**\:  :py:class:`InPktsUnusedSa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx.InPktsUnusedSa>`
                                
                                .. attribute:: in_pkts_untagged_hit
                                
                                	In Packet Untagged Hit
                                	**type**\:  :py:class:`InPktsUntaggedHit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx.InPktsUntaggedHit>`
                                
                                .. attribute:: in_octets_validated
                                
                                	In Octet Validated
                                	**type**\:  :py:class:`InOctetsValidated <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx.InOctetsValidated>`
                                
                                .. attribute:: in_octets_decrypted
                                
                                	In Octet Decrypted
                                	**type**\:  :py:class:`InOctetsDecrypted <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx.InOctetsDecrypted>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\: bool
                                
                                .. attribute:: sample_count
                                
                                	Running Sample Count
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx, self).__init__()

                                    self.yang_name = "macsec-minute15secyrx"
                                    self.yang_parent_name = "macsec-minute15secyrxes"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("in-pkts-unchecked", ("in_pkts_unchecked", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx.InPktsUnchecked)), ("in-pkts-delayed", ("in_pkts_delayed", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx.InPktsDelayed)), ("in-pkts-late", ("in_pkts_late", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx.InPktsLate)), ("in-pkts-ok", ("in_pkts_ok", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx.InPktsOk)), ("in-pkts-invalid", ("in_pkts_invalid", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx.InPktsInvalid)), ("in-pkts-not-valid", ("in_pkts_not_valid", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx.InPktsNotValid)), ("in-pkts-not-using-sa", ("in_pkts_not_using_sa", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx.InPktsNotUsingSa)), ("in-pkts-unused-sa", ("in_pkts_unused_sa", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx.InPktsUnusedSa)), ("in-pkts-untagged-hit", ("in_pkts_untagged_hit", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx.InPktsUntaggedHit)), ("in-octets-validated", ("in_octets_validated", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx.InOctetsValidated)), ("in-octets-decrypted", ("in_octets_decrypted", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx.InOctetsDecrypted))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                        ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                        ('sample_count', (YLeaf(YType.uint64, 'sample-count'), ['int'])),
                                    ])
                                    self.number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear24_hr_time = None
                                    self.sec30_support = None
                                    self.sample_count = None

                                    self.in_pkts_unchecked = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx.InPktsUnchecked()
                                    self.in_pkts_unchecked.parent = self
                                    self._children_name_map["in_pkts_unchecked"] = "in-pkts-unchecked"

                                    self.in_pkts_delayed = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx.InPktsDelayed()
                                    self.in_pkts_delayed.parent = self
                                    self._children_name_map["in_pkts_delayed"] = "in-pkts-delayed"

                                    self.in_pkts_late = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx.InPktsLate()
                                    self.in_pkts_late.parent = self
                                    self._children_name_map["in_pkts_late"] = "in-pkts-late"

                                    self.in_pkts_ok = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx.InPktsOk()
                                    self.in_pkts_ok.parent = self
                                    self._children_name_map["in_pkts_ok"] = "in-pkts-ok"

                                    self.in_pkts_invalid = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx.InPktsInvalid()
                                    self.in_pkts_invalid.parent = self
                                    self._children_name_map["in_pkts_invalid"] = "in-pkts-invalid"

                                    self.in_pkts_not_valid = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx.InPktsNotValid()
                                    self.in_pkts_not_valid.parent = self
                                    self._children_name_map["in_pkts_not_valid"] = "in-pkts-not-valid"

                                    self.in_pkts_not_using_sa = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx.InPktsNotUsingSa()
                                    self.in_pkts_not_using_sa.parent = self
                                    self._children_name_map["in_pkts_not_using_sa"] = "in-pkts-not-using-sa"

                                    self.in_pkts_unused_sa = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx.InPktsUnusedSa()
                                    self.in_pkts_unused_sa.parent = self
                                    self._children_name_map["in_pkts_unused_sa"] = "in-pkts-unused-sa"

                                    self.in_pkts_untagged_hit = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx.InPktsUntaggedHit()
                                    self.in_pkts_untagged_hit.parent = self
                                    self._children_name_map["in_pkts_untagged_hit"] = "in-pkts-untagged-hit"

                                    self.in_octets_validated = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx.InOctetsValidated()
                                    self.in_octets_validated.parent = self
                                    self._children_name_map["in_octets_validated"] = "in-octets-validated"

                                    self.in_octets_decrypted = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx.InOctetsDecrypted()
                                    self.in_octets_decrypted.parent = self
                                    self._children_name_map["in_octets_decrypted"] = "in-octets-decrypted"
                                    self._segment_path = lambda: "macsec-minute15secyrx" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support', 'sample_count'], name, value)


                                class InPktsUnchecked(Entity):
                                    """
                                    In Packet Unchecked
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx.InPktsUnchecked, self).__init__()

                                        self.yang_name = "in-pkts-unchecked"
                                        self.yang_parent_name = "macsec-minute15secyrx"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts-unchecked"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx.InPktsUnchecked, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPktsDelayed(Entity):
                                    """
                                    In Packet Delay
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx.InPktsDelayed, self).__init__()

                                        self.yang_name = "in-pkts-delayed"
                                        self.yang_parent_name = "macsec-minute15secyrx"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts-delayed"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx.InPktsDelayed, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPktsLate(Entity):
                                    """
                                    In Packet Late
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx.InPktsLate, self).__init__()

                                        self.yang_name = "in-pkts-late"
                                        self.yang_parent_name = "macsec-minute15secyrx"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts-late"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx.InPktsLate, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPktsOk(Entity):
                                    """
                                    In Packet Ok
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx.InPktsOk, self).__init__()

                                        self.yang_name = "in-pkts-ok"
                                        self.yang_parent_name = "macsec-minute15secyrx"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts-ok"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx.InPktsOk, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPktsInvalid(Entity):
                                    """
                                    In Packet Invalid
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx.InPktsInvalid, self).__init__()

                                        self.yang_name = "in-pkts-invalid"
                                        self.yang_parent_name = "macsec-minute15secyrx"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts-invalid"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx.InPktsInvalid, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPktsNotValid(Entity):
                                    """
                                    In Packet Not Valid
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx.InPktsNotValid, self).__init__()

                                        self.yang_name = "in-pkts-not-valid"
                                        self.yang_parent_name = "macsec-minute15secyrx"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts-not-valid"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx.InPktsNotValid, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPktsNotUsingSa(Entity):
                                    """
                                    In Packet Not Using SA
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx.InPktsNotUsingSa, self).__init__()

                                        self.yang_name = "in-pkts-not-using-sa"
                                        self.yang_parent_name = "macsec-minute15secyrx"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts-not-using-sa"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx.InPktsNotUsingSa, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPktsUnusedSa(Entity):
                                    """
                                    In Packet Unused SA
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx.InPktsUnusedSa, self).__init__()

                                        self.yang_name = "in-pkts-unused-sa"
                                        self.yang_parent_name = "macsec-minute15secyrx"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts-unused-sa"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx.InPktsUnusedSa, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPktsUntaggedHit(Entity):
                                    """
                                    In Packet Untagged Hit
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx.InPktsUntaggedHit, self).__init__()

                                        self.yang_name = "in-pkts-untagged-hit"
                                        self.yang_parent_name = "macsec-minute15secyrx"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts-untagged-hit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx.InPktsUntaggedHit, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InOctetsValidated(Entity):
                                    """
                                    In Octet Validated
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx.InOctetsValidated, self).__init__()

                                        self.yang_name = "in-octets-validated"
                                        self.yang_parent_name = "macsec-minute15secyrx"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-octets-validated"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx.InOctetsValidated, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InOctetsDecrypted(Entity):
                                    """
                                    In Octet Decrypted
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx.InOctetsDecrypted, self).__init__()

                                        self.yang_name = "in-octets-decrypted"
                                        self.yang_parent_name = "macsec-minute15secyrx"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-octets-decrypted"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secyrxes.MacsecMinute15secyrx.InOctetsDecrypted, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                        class MacsecMinute15secytxes(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: macsec_minute15secytx
                            
                            	port 15\-minute secy\-tx performance data
                            	**type**\: list of  		 :py:class:`MacsecMinute15secytx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secytxes.MacsecMinute15secytx>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secytxes, self).__init__()

                                self.yang_name = "macsec-minute15secytxes"
                                self.yang_parent_name = "macsec-minute15"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("macsec-minute15secytx", ("macsec_minute15secytx", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secytxes.MacsecMinute15secytx))])
                                self._leafs = OrderedDict()

                                self.macsec_minute15secytx = YList(self)
                                self._segment_path = lambda: "macsec-minute15secytxes"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secytxes, [], name, value)


                            class MacsecMinute15secytx(Entity):
                                """
                                port 15\-minute secy\-tx performance data
                                
                                .. attribute:: number  (key)
                                
                                	channel number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: out_pkts_protected
                                
                                	Out Packets Protected
                                	**type**\:  :py:class:`OutPktsProtected <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secytxes.MacsecMinute15secytx.OutPktsProtected>`
                                
                                .. attribute:: out_pkts_encrypted
                                
                                	Out Packets Encrypted
                                	**type**\:  :py:class:`OutPktsEncrypted <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secytxes.MacsecMinute15secytx.OutPktsEncrypted>`
                                
                                .. attribute:: out_octets_protected
                                
                                	Out Octets Protected 
                                	**type**\:  :py:class:`OutOctetsProtected <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secytxes.MacsecMinute15secytx.OutOctetsProtected>`
                                
                                .. attribute:: out_octets_encrypted
                                
                                	Out Octets Encrypted
                                	**type**\:  :py:class:`OutOctetsEncrypted <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secytxes.MacsecMinute15secytx.OutOctetsEncrypted>`
                                
                                .. attribute:: out_pkts_too_long
                                
                                	Out Packets Too Long
                                	**type**\:  :py:class:`OutPktsTooLong <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secytxes.MacsecMinute15secytx.OutPktsTooLong>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\: bool
                                
                                .. attribute:: sample_count
                                
                                	Running Sample Count
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secytxes.MacsecMinute15secytx, self).__init__()

                                    self.yang_name = "macsec-minute15secytx"
                                    self.yang_parent_name = "macsec-minute15secytxes"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("out-pkts-protected", ("out_pkts_protected", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secytxes.MacsecMinute15secytx.OutPktsProtected)), ("out-pkts-encrypted", ("out_pkts_encrypted", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secytxes.MacsecMinute15secytx.OutPktsEncrypted)), ("out-octets-protected", ("out_octets_protected", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secytxes.MacsecMinute15secytx.OutOctetsProtected)), ("out-octets-encrypted", ("out_octets_encrypted", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secytxes.MacsecMinute15secytx.OutOctetsEncrypted)), ("out-pkts-too-long", ("out_pkts_too_long", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secytxes.MacsecMinute15secytx.OutPktsTooLong))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                        ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                        ('sample_count', (YLeaf(YType.uint64, 'sample-count'), ['int'])),
                                    ])
                                    self.number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear24_hr_time = None
                                    self.sec30_support = None
                                    self.sample_count = None

                                    self.out_pkts_protected = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secytxes.MacsecMinute15secytx.OutPktsProtected()
                                    self.out_pkts_protected.parent = self
                                    self._children_name_map["out_pkts_protected"] = "out-pkts-protected"

                                    self.out_pkts_encrypted = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secytxes.MacsecMinute15secytx.OutPktsEncrypted()
                                    self.out_pkts_encrypted.parent = self
                                    self._children_name_map["out_pkts_encrypted"] = "out-pkts-encrypted"

                                    self.out_octets_protected = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secytxes.MacsecMinute15secytx.OutOctetsProtected()
                                    self.out_octets_protected.parent = self
                                    self._children_name_map["out_octets_protected"] = "out-octets-protected"

                                    self.out_octets_encrypted = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secytxes.MacsecMinute15secytx.OutOctetsEncrypted()
                                    self.out_octets_encrypted.parent = self
                                    self._children_name_map["out_octets_encrypted"] = "out-octets-encrypted"

                                    self.out_pkts_too_long = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secytxes.MacsecMinute15secytx.OutPktsTooLong()
                                    self.out_pkts_too_long.parent = self
                                    self._children_name_map["out_pkts_too_long"] = "out-pkts-too-long"
                                    self._segment_path = lambda: "macsec-minute15secytx" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secytxes.MacsecMinute15secytx, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support', 'sample_count'], name, value)


                                class OutPktsProtected(Entity):
                                    """
                                    Out Packets Protected
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secytxes.MacsecMinute15secytx.OutPktsProtected, self).__init__()

                                        self.yang_name = "out-pkts-protected"
                                        self.yang_parent_name = "macsec-minute15secytx"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-pkts-protected"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secytxes.MacsecMinute15secytx.OutPktsProtected, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutPktsEncrypted(Entity):
                                    """
                                    Out Packets Encrypted
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secytxes.MacsecMinute15secytx.OutPktsEncrypted, self).__init__()

                                        self.yang_name = "out-pkts-encrypted"
                                        self.yang_parent_name = "macsec-minute15secytx"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-pkts-encrypted"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secytxes.MacsecMinute15secytx.OutPktsEncrypted, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutOctetsProtected(Entity):
                                    """
                                    Out Octets Protected 
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secytxes.MacsecMinute15secytx.OutOctetsProtected, self).__init__()

                                        self.yang_name = "out-octets-protected"
                                        self.yang_parent_name = "macsec-minute15secytx"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-octets-protected"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secytxes.MacsecMinute15secytx.OutOctetsProtected, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutOctetsEncrypted(Entity):
                                    """
                                    Out Octets Encrypted
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secytxes.MacsecMinute15secytx.OutOctetsEncrypted, self).__init__()

                                        self.yang_name = "out-octets-encrypted"
                                        self.yang_parent_name = "macsec-minute15secytx"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-octets-encrypted"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secytxes.MacsecMinute15secytx.OutOctetsEncrypted, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutPktsTooLong(Entity):
                                    """
                                    Out Packets Too Long
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secytxes.MacsecMinute15secytx.OutPktsTooLong, self).__init__()

                                        self.yang_name = "out-pkts-too-long"
                                        self.yang_parent_name = "macsec-minute15secytx"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-pkts-too-long"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15secytxes.MacsecMinute15secytx.OutPktsTooLong, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                        class MacsecMinute15EtherS(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: macsec_minute15_ether
                            
                            	port 15\-minute ether performance data
                            	**type**\: list of  		 :py:class:`MacsecMinute15Ether <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS, self).__init__()

                                self.yang_name = "macsec-minute15-ether-s"
                                self.yang_parent_name = "macsec-minute15"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("macsec-minute15-ether", ("macsec_minute15_ether", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether))])
                                self._leafs = OrderedDict()

                                self.macsec_minute15_ether = YList(self)
                                self._segment_path = lambda: "macsec-minute15-ether-s"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS, [], name, value)


                            class MacsecMinute15Ether(Entity):
                                """
                                port 15\-minute ether performance data
                                
                                .. attribute:: number  (key)
                                
                                	channel number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rx_pkt
                                
                                	RX PKT
                                	**type**\:  :py:class:`RxPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.RxPkt>`
                                
                                .. attribute:: stat_pkt
                                
                                	STAT PKT
                                	**type**\:  :py:class:`StatPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.StatPkt>`
                                
                                .. attribute:: octet_stat
                                
                                	OCTET STAT
                                	**type**\:  :py:class:`OctetStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OctetStat>`
                                
                                .. attribute:: oversize_pkt_stat
                                
                                	OVERSIZE PKT
                                	**type**\:  :py:class:`OversizePktStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OversizePktStat>`
                                
                                .. attribute:: fcs_errors_stat
                                
                                	FCS ERR
                                	**type**\:  :py:class:`FcsErrorsStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.FcsErrorsStat>`
                                
                                .. attribute:: long_frames_stat
                                
                                	LONG FRAMES
                                	**type**\:  :py:class:`LongFramesStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.LongFramesStat>`
                                
                                .. attribute:: jabber_stat
                                
                                	JABBER STATS
                                	**type**\:  :py:class:`JabberStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.JabberStat>`
                                
                                .. attribute:: ether64_octets
                                
                                	SIXTY FOUR OCTET
                                	**type**\:  :py:class:`Ether64Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.Ether64Octets>`
                                
                                .. attribute:: ether65127_octet
                                
                                	OCTET
                                	**type**\:  :py:class:`Ether65127Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.Ether65127Octet>`
                                
                                .. attribute:: ether128255_octet
                                
                                	TFF OCTET
                                	**type**\:  :py:class:`Ether128255Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.Ether128255Octet>`
                                
                                .. attribute:: ether256511_octet
                                
                                	FOO OCTET
                                	**type**\:  :py:class:`Ether256511Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.Ether256511Octet>`
                                
                                .. attribute:: ether5121023_octet
                                
                                	OZTT OCTET
                                	**type**\:  :py:class:`Ether5121023Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.Ether5121023Octet>`
                                
                                .. attribute:: ether10241518_octet
                                
                                	OFO OCTET
                                	**type**\:  :py:class:`Ether10241518Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.Ether10241518Octet>`
                                
                                .. attribute:: in_ucast_pkt
                                
                                	IN UCAST
                                	**type**\:  :py:class:`InUcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InUcastPkt>`
                                
                                .. attribute:: in_mcast_pkt
                                
                                	IN MCAST
                                	**type**\:  :py:class:`InMcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InMcastPkt>`
                                
                                .. attribute:: in_bcast_pkt
                                
                                	IN BCAST
                                	**type**\:  :py:class:`InBcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InBcastPkt>`
                                
                                .. attribute:: out_ucast_pkt
                                
                                	OUT UCAST
                                	**type**\:  :py:class:`OutUcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutUcastPkt>`
                                
                                .. attribute:: out_bcast_pkt
                                
                                	OUT BCAST
                                	**type**\:  :py:class:`OutBcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutBcastPkt>`
                                
                                .. attribute:: out_mcast_pkt
                                
                                	OUT MCAST
                                	**type**\:  :py:class:`OutMcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutMcastPkt>`
                                
                                .. attribute:: tx_pkt
                                
                                	TX PKT
                                	**type**\:  :py:class:`TxPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.TxPkt>`
                                
                                .. attribute:: if_in_errors
                                
                                	IFIN ERRORS
                                	**type**\:  :py:class:`IfInErrors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.IfInErrors>`
                                
                                .. attribute:: if_in_octets
                                
                                	IFIN OCTETS
                                	**type**\:  :py:class:`IfInOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.IfInOctets>`
                                
                                .. attribute:: ether_stat_multicast_pkt
                                
                                	ETHER STAT MULTICAST PKT
                                	**type**\:  :py:class:`EtherStatMulticastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.EtherStatMulticastPkt>`
                                
                                .. attribute:: ether_stat_broadcast_pkt
                                
                                	ETHER STAT BROADCAST PKT
                                	**type**\:  :py:class:`EtherStatBroadcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.EtherStatBroadcastPkt>`
                                
                                .. attribute:: ether_stat_undersized_pkt
                                
                                	ETHER STAT UNDERSIZED PKT
                                	**type**\:  :py:class:`EtherStatUndersizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.EtherStatUndersizedPkt>`
                                
                                .. attribute:: out_octets
                                
                                	OUT OCTET
                                	**type**\:  :py:class:`OutOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutOctets>`
                                
                                .. attribute:: in_pause_frame
                                
                                	INPUT PAUSE FRAME
                                	**type**\:  :py:class:`InPauseFrame <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InPauseFrame>`
                                
                                .. attribute:: in_good_bytes
                                
                                	INPUT GOOD BYTES
                                	**type**\:  :py:class:`InGoodBytes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InGoodBytes>`
                                
                                .. attribute:: in8021q_frames
                                
                                	INPUT 802 1Q FRAMES
                                	**type**\:  :py:class:`In8021qFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.In8021qFrames>`
                                
                                .. attribute:: in_pkts1519_max_octets
                                
                                	INPUT PKTS 1519MAX OCTETS
                                	**type**\:  :py:class:`InPkts1519MaxOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InPkts1519MaxOctets>`
                                
                                .. attribute:: in_good_pkts
                                
                                	INPUT GOOD PKTS
                                	**type**\:  :py:class:`InGoodPkts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InGoodPkts>`
                                
                                .. attribute:: in_drop_overrun
                                
                                	INPUT DROP OVERRUN
                                	**type**\:  :py:class:`InDropOverrun <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InDropOverrun>`
                                
                                .. attribute:: in_drop_abort
                                
                                	INPUT DROP ABORT
                                	**type**\:  :py:class:`InDropAbort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InDropAbort>`
                                
                                .. attribute:: in_drop_invalid_vlan
                                
                                	INPUT DROP INVALID VLAN
                                	**type**\:  :py:class:`InDropInvalidVlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InDropInvalidVlan>`
                                
                                .. attribute:: in_drop_invalid_dmac
                                
                                	INPUT DROP INVALID DMAC
                                	**type**\:  :py:class:`InDropInvalidDmac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InDropInvalidDmac>`
                                
                                .. attribute:: in_drop_invalid_encap
                                
                                	INPUT DROP INVALID ENCAP
                                	**type**\:  :py:class:`InDropInvalidEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InDropInvalidEncap>`
                                
                                .. attribute:: in_drop_other
                                
                                	INPUT DROP OTHER
                                	**type**\:  :py:class:`InDropOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InDropOther>`
                                
                                .. attribute:: in_mib_giant
                                
                                	INPUT MIB GIANT
                                	**type**\:  :py:class:`InMibGiant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InMibGiant>`
                                
                                .. attribute:: in_mib_jabber
                                
                                	INPUT MIB JABBER
                                	**type**\:  :py:class:`InMibJabber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InMibJabber>`
                                
                                .. attribute:: in_mibcrc
                                
                                	IN MIB CRC
                                	**type**\:  :py:class:`InMibcrc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InMibcrc>`
                                
                                .. attribute:: in_error_collisions
                                
                                	IN ERROR COLLISIONS
                                	**type**\:  :py:class:`InErrorCollisions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InErrorCollisions>`
                                
                                .. attribute:: in_error_symbol
                                
                                	IN ERROR SYMBOL
                                	**type**\:  :py:class:`InErrorSymbol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InErrorSymbol>`
                                
                                .. attribute:: out_good_bytes
                                
                                	OUT GOOD BYTES
                                	**type**\:  :py:class:`OutGoodBytes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutGoodBytes>`
                                
                                .. attribute:: out8021q_frames
                                
                                	OUT 802 1Q FRAMES
                                	**type**\:  :py:class:`Out8021qFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.Out8021qFrames>`
                                
                                .. attribute:: out_pause_frames
                                
                                	OUT PAUSE FRAMES
                                	**type**\:  :py:class:`OutPauseFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutPauseFrames>`
                                
                                .. attribute:: out_pkts1519_max_octets
                                
                                	OUT PKTS 1519 MAX OCTETS
                                	**type**\:  :py:class:`OutPkts1519MaxOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutPkts1519MaxOctets>`
                                
                                .. attribute:: out_good_pkts
                                
                                	OUT GOOD PKTS
                                	**type**\:  :py:class:`OutGoodPkts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutGoodPkts>`
                                
                                .. attribute:: out_drop_underrun
                                
                                	OUT DROP UNDERRUN
                                	**type**\:  :py:class:`OutDropUnderrun <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutDropUnderrun>`
                                
                                .. attribute:: out_drop_abort
                                
                                	OUT DROP ABORT
                                	**type**\:  :py:class:`OutDropAbort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutDropAbort>`
                                
                                .. attribute:: out_drop_other
                                
                                	OUT DROP OTHER
                                	**type**\:  :py:class:`OutDropOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutDropOther>`
                                
                                .. attribute:: out_error_other
                                
                                	OUT ERROR OTHER
                                	**type**\:  :py:class:`OutErrorOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutErrorOther>`
                                
                                .. attribute:: in_error_giant
                                
                                	IN ERROR GIANT
                                	**type**\:  :py:class:`InErrorGiant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InErrorGiant>`
                                
                                .. attribute:: in_error_runt
                                
                                	IN ERROR RUNT
                                	**type**\:  :py:class:`InErrorRunt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InErrorRunt>`
                                
                                .. attribute:: in_error_jabbers
                                
                                	IN ERROR JABBERS
                                	**type**\:  :py:class:`InErrorJabbers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InErrorJabbers>`
                                
                                .. attribute:: in_error_fragments
                                
                                	IN ERROR FRAGMENTS
                                	**type**\:  :py:class:`InErrorFragments <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InErrorFragments>`
                                
                                .. attribute:: in_error_other
                                
                                	IN ERROR OTHER
                                	**type**\:  :py:class:`InErrorOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InErrorOther>`
                                
                                .. attribute:: in_pkt64_octet
                                
                                	IN PKT 64 OCTET
                                	**type**\:  :py:class:`InPkt64Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InPkt64Octet>`
                                
                                .. attribute:: in_pkts65_to127_octets
                                
                                	IN PKTS 65 127OCTETS
                                	**type**\:  :py:class:`InPkts65To127Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InPkts65To127Octets>`
                                
                                .. attribute:: in_pkts128_to255_octets
                                
                                	IN PKTS 128 255 OCTETS
                                	**type**\:  :py:class:`InPkts128To255Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InPkts128To255Octets>`
                                
                                .. attribute:: in_pkts256_to511_octets
                                
                                	IN PKTS 256 511 OCTETS
                                	**type**\:  :py:class:`InPkts256To511Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InPkts256To511Octets>`
                                
                                .. attribute:: in_pkts512_to1023_octets
                                
                                	IN PKTS 512 1023 OCTETS
                                	**type**\:  :py:class:`InPkts512To1023Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InPkts512To1023Octets>`
                                
                                .. attribute:: in_pkts1024_to1518_octets
                                
                                	IN PKTS 1024 1518 OCTETS
                                	**type**\:  :py:class:`InPkts1024To1518Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InPkts1024To1518Octets>`
                                
                                .. attribute:: outpkt64octet
                                
                                	OUT PKT 64 OCTET
                                	**type**\:  :py:class:`Outpkt64octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.Outpkt64octet>`
                                
                                .. attribute:: out_pkts65127_octets
                                
                                	OUT PKTS 65 127OCTETS
                                	**type**\:  :py:class:`OutPkts65127Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutPkts65127Octets>`
                                
                                .. attribute:: out_pkts128255_octets
                                
                                	OUT PKTS 128 255 OCTETS
                                	**type**\:  :py:class:`OutPkts128255Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutPkts128255Octets>`
                                
                                .. attribute:: out_pkts256511_octets
                                
                                	OUT PKTS 256 511 OCTETS
                                	**type**\:  :py:class:`OutPkts256511Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutPkts256511Octets>`
                                
                                .. attribute:: out_pkts5121023_octets
                                
                                	OUT PKTS 512 1023 OCTETS
                                	**type**\:  :py:class:`OutPkts5121023Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutPkts5121023Octets>`
                                
                                .. attribute:: out_pkts10241518_octets
                                
                                	OUT PKTS 1024 1518 OCTETS
                                	**type**\:  :py:class:`OutPkts10241518Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutPkts10241518Octets>`
                                
                                .. attribute:: rx_util
                                
                                	Rx Utilization in Percent
                                	**type**\:  :py:class:`RxUtil <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.RxUtil>`
                                
                                .. attribute:: tx_util
                                
                                	Tx Utilization in Percent
                                	**type**\:  :py:class:`TxUtil <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.TxUtil>`
                                
                                .. attribute:: tx_undersized_pkt
                                
                                	TX Undersized Pkt
                                	**type**\:  :py:class:`TxUndersizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.TxUndersizedPkt>`
                                
                                .. attribute:: tx_oversized_pkt
                                
                                	TX Oversized Pkt
                                	**type**\:  :py:class:`TxOversizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.TxOversizedPkt>`
                                
                                .. attribute:: tx_fragments
                                
                                	TX Fragments
                                	**type**\:  :py:class:`TxFragments <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.TxFragments>`
                                
                                .. attribute:: tx_jabber
                                
                                	TX Jabber
                                	**type**\:  :py:class:`TxJabber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.TxJabber>`
                                
                                .. attribute:: tx_bad_fcs
                                
                                	TX Bad Fcs
                                	**type**\:  :py:class:`TxBadFcs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.TxBadFcs>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether, self).__init__()

                                    self.yang_name = "macsec-minute15-ether"
                                    self.yang_parent_name = "macsec-minute15-ether-s"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("rx-pkt", ("rx_pkt", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.RxPkt)), ("stat-pkt", ("stat_pkt", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.StatPkt)), ("octet-stat", ("octet_stat", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OctetStat)), ("oversize-pkt-stat", ("oversize_pkt_stat", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OversizePktStat)), ("fcs-errors-stat", ("fcs_errors_stat", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.FcsErrorsStat)), ("long-frames-stat", ("long_frames_stat", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.LongFramesStat)), ("jabber-stat", ("jabber_stat", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.JabberStat)), ("ether64-octets", ("ether64_octets", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.Ether64Octets)), ("ether65127-octet", ("ether65127_octet", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.Ether65127Octet)), ("ether128255-octet", ("ether128255_octet", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.Ether128255Octet)), ("ether256511-octet", ("ether256511_octet", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.Ether256511Octet)), ("ether5121023-octet", ("ether5121023_octet", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.Ether5121023Octet)), ("ether10241518-octet", ("ether10241518_octet", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.Ether10241518Octet)), ("in-ucast-pkt", ("in_ucast_pkt", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InUcastPkt)), ("in-mcast-pkt", ("in_mcast_pkt", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InMcastPkt)), ("in-bcast-pkt", ("in_bcast_pkt", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InBcastPkt)), ("out-ucast-pkt", ("out_ucast_pkt", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutUcastPkt)), ("out-bcast-pkt", ("out_bcast_pkt", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutBcastPkt)), ("out-mcast-pkt", ("out_mcast_pkt", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutMcastPkt)), ("tx-pkt", ("tx_pkt", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.TxPkt)), ("if-in-errors", ("if_in_errors", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.IfInErrors)), ("if-in-octets", ("if_in_octets", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.IfInOctets)), ("ether-stat-multicast-pkt", ("ether_stat_multicast_pkt", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.EtherStatMulticastPkt)), ("ether-stat-broadcast-pkt", ("ether_stat_broadcast_pkt", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.EtherStatBroadcastPkt)), ("ether-stat-undersized-pkt", ("ether_stat_undersized_pkt", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.EtherStatUndersizedPkt)), ("out-octets", ("out_octets", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutOctets)), ("in-pause-frame", ("in_pause_frame", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InPauseFrame)), ("in-good-bytes", ("in_good_bytes", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InGoodBytes)), ("in8021q-frames", ("in8021q_frames", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.In8021qFrames)), ("in-pkts1519-max-octets", ("in_pkts1519_max_octets", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InPkts1519MaxOctets)), ("in-good-pkts", ("in_good_pkts", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InGoodPkts)), ("in-drop-overrun", ("in_drop_overrun", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InDropOverrun)), ("in-drop-abort", ("in_drop_abort", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InDropAbort)), ("in-drop-invalid-vlan", ("in_drop_invalid_vlan", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InDropInvalidVlan)), ("in-drop-invalid-dmac", ("in_drop_invalid_dmac", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InDropInvalidDmac)), ("in-drop-invalid-encap", ("in_drop_invalid_encap", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InDropInvalidEncap)), ("in-drop-other", ("in_drop_other", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InDropOther)), ("in-mib-giant", ("in_mib_giant", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InMibGiant)), ("in-mib-jabber", ("in_mib_jabber", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InMibJabber)), ("in-mibcrc", ("in_mibcrc", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InMibcrc)), ("in-error-collisions", ("in_error_collisions", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InErrorCollisions)), ("in-error-symbol", ("in_error_symbol", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InErrorSymbol)), ("out-good-bytes", ("out_good_bytes", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutGoodBytes)), ("out8021q-frames", ("out8021q_frames", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.Out8021qFrames)), ("out-pause-frames", ("out_pause_frames", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutPauseFrames)), ("out-pkts1519-max-octets", ("out_pkts1519_max_octets", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutPkts1519MaxOctets)), ("out-good-pkts", ("out_good_pkts", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutGoodPkts)), ("out-drop-underrun", ("out_drop_underrun", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutDropUnderrun)), ("out-drop-abort", ("out_drop_abort", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutDropAbort)), ("out-drop-other", ("out_drop_other", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutDropOther)), ("out-error-other", ("out_error_other", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutErrorOther)), ("in-error-giant", ("in_error_giant", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InErrorGiant)), ("in-error-runt", ("in_error_runt", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InErrorRunt)), ("in-error-jabbers", ("in_error_jabbers", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InErrorJabbers)), ("in-error-fragments", ("in_error_fragments", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InErrorFragments)), ("in-error-other", ("in_error_other", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InErrorOther)), ("in-pkt64-octet", ("in_pkt64_octet", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InPkt64Octet)), ("in-pkts65-to127-octets", ("in_pkts65_to127_octets", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InPkts65To127Octets)), ("in-pkts128-to255-octets", ("in_pkts128_to255_octets", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InPkts128To255Octets)), ("in-pkts256-to511-octets", ("in_pkts256_to511_octets", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InPkts256To511Octets)), ("in-pkts512-to1023-octets", ("in_pkts512_to1023_octets", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InPkts512To1023Octets)), ("in-pkts1024-to1518-octets", ("in_pkts1024_to1518_octets", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InPkts1024To1518Octets)), ("outpkt64octet", ("outpkt64octet", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.Outpkt64octet)), ("out-pkts65127-octets", ("out_pkts65127_octets", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutPkts65127Octets)), ("out-pkts128255-octets", ("out_pkts128255_octets", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutPkts128255Octets)), ("out-pkts256511-octets", ("out_pkts256511_octets", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutPkts256511Octets)), ("out-pkts5121023-octets", ("out_pkts5121023_octets", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutPkts5121023Octets)), ("out-pkts10241518-octets", ("out_pkts10241518_octets", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutPkts10241518Octets)), ("rx-util", ("rx_util", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.RxUtil)), ("tx-util", ("tx_util", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.TxUtil)), ("tx-undersized-pkt", ("tx_undersized_pkt", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.TxUndersizedPkt)), ("tx-oversized-pkt", ("tx_oversized_pkt", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.TxOversizedPkt)), ("tx-fragments", ("tx_fragments", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.TxFragments)), ("tx-jabber", ("tx_jabber", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.TxJabber)), ("tx-bad-fcs", ("tx_bad_fcs", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.TxBadFcs))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                        ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                    ])
                                    self.number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None
                                    self.sec30_support = None

                                    self.rx_pkt = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.RxPkt()
                                    self.rx_pkt.parent = self
                                    self._children_name_map["rx_pkt"] = "rx-pkt"

                                    self.stat_pkt = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.StatPkt()
                                    self.stat_pkt.parent = self
                                    self._children_name_map["stat_pkt"] = "stat-pkt"

                                    self.octet_stat = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OctetStat()
                                    self.octet_stat.parent = self
                                    self._children_name_map["octet_stat"] = "octet-stat"

                                    self.oversize_pkt_stat = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OversizePktStat()
                                    self.oversize_pkt_stat.parent = self
                                    self._children_name_map["oversize_pkt_stat"] = "oversize-pkt-stat"

                                    self.fcs_errors_stat = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.FcsErrorsStat()
                                    self.fcs_errors_stat.parent = self
                                    self._children_name_map["fcs_errors_stat"] = "fcs-errors-stat"

                                    self.long_frames_stat = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.LongFramesStat()
                                    self.long_frames_stat.parent = self
                                    self._children_name_map["long_frames_stat"] = "long-frames-stat"

                                    self.jabber_stat = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.JabberStat()
                                    self.jabber_stat.parent = self
                                    self._children_name_map["jabber_stat"] = "jabber-stat"

                                    self.ether64_octets = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.Ether64Octets()
                                    self.ether64_octets.parent = self
                                    self._children_name_map["ether64_octets"] = "ether64-octets"

                                    self.ether65127_octet = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.Ether65127Octet()
                                    self.ether65127_octet.parent = self
                                    self._children_name_map["ether65127_octet"] = "ether65127-octet"

                                    self.ether128255_octet = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.Ether128255Octet()
                                    self.ether128255_octet.parent = self
                                    self._children_name_map["ether128255_octet"] = "ether128255-octet"

                                    self.ether256511_octet = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.Ether256511Octet()
                                    self.ether256511_octet.parent = self
                                    self._children_name_map["ether256511_octet"] = "ether256511-octet"

                                    self.ether5121023_octet = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.Ether5121023Octet()
                                    self.ether5121023_octet.parent = self
                                    self._children_name_map["ether5121023_octet"] = "ether5121023-octet"

                                    self.ether10241518_octet = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.Ether10241518Octet()
                                    self.ether10241518_octet.parent = self
                                    self._children_name_map["ether10241518_octet"] = "ether10241518-octet"

                                    self.in_ucast_pkt = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InUcastPkt()
                                    self.in_ucast_pkt.parent = self
                                    self._children_name_map["in_ucast_pkt"] = "in-ucast-pkt"

                                    self.in_mcast_pkt = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InMcastPkt()
                                    self.in_mcast_pkt.parent = self
                                    self._children_name_map["in_mcast_pkt"] = "in-mcast-pkt"

                                    self.in_bcast_pkt = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InBcastPkt()
                                    self.in_bcast_pkt.parent = self
                                    self._children_name_map["in_bcast_pkt"] = "in-bcast-pkt"

                                    self.out_ucast_pkt = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutUcastPkt()
                                    self.out_ucast_pkt.parent = self
                                    self._children_name_map["out_ucast_pkt"] = "out-ucast-pkt"

                                    self.out_bcast_pkt = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutBcastPkt()
                                    self.out_bcast_pkt.parent = self
                                    self._children_name_map["out_bcast_pkt"] = "out-bcast-pkt"

                                    self.out_mcast_pkt = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutMcastPkt()
                                    self.out_mcast_pkt.parent = self
                                    self._children_name_map["out_mcast_pkt"] = "out-mcast-pkt"

                                    self.tx_pkt = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.TxPkt()
                                    self.tx_pkt.parent = self
                                    self._children_name_map["tx_pkt"] = "tx-pkt"

                                    self.if_in_errors = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.IfInErrors()
                                    self.if_in_errors.parent = self
                                    self._children_name_map["if_in_errors"] = "if-in-errors"

                                    self.if_in_octets = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.IfInOctets()
                                    self.if_in_octets.parent = self
                                    self._children_name_map["if_in_octets"] = "if-in-octets"

                                    self.ether_stat_multicast_pkt = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.EtherStatMulticastPkt()
                                    self.ether_stat_multicast_pkt.parent = self
                                    self._children_name_map["ether_stat_multicast_pkt"] = "ether-stat-multicast-pkt"

                                    self.ether_stat_broadcast_pkt = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.EtherStatBroadcastPkt()
                                    self.ether_stat_broadcast_pkt.parent = self
                                    self._children_name_map["ether_stat_broadcast_pkt"] = "ether-stat-broadcast-pkt"

                                    self.ether_stat_undersized_pkt = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.EtherStatUndersizedPkt()
                                    self.ether_stat_undersized_pkt.parent = self
                                    self._children_name_map["ether_stat_undersized_pkt"] = "ether-stat-undersized-pkt"

                                    self.out_octets = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutOctets()
                                    self.out_octets.parent = self
                                    self._children_name_map["out_octets"] = "out-octets"

                                    self.in_pause_frame = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InPauseFrame()
                                    self.in_pause_frame.parent = self
                                    self._children_name_map["in_pause_frame"] = "in-pause-frame"

                                    self.in_good_bytes = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InGoodBytes()
                                    self.in_good_bytes.parent = self
                                    self._children_name_map["in_good_bytes"] = "in-good-bytes"

                                    self.in8021q_frames = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.In8021qFrames()
                                    self.in8021q_frames.parent = self
                                    self._children_name_map["in8021q_frames"] = "in8021q-frames"

                                    self.in_pkts1519_max_octets = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InPkts1519MaxOctets()
                                    self.in_pkts1519_max_octets.parent = self
                                    self._children_name_map["in_pkts1519_max_octets"] = "in-pkts1519-max-octets"

                                    self.in_good_pkts = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InGoodPkts()
                                    self.in_good_pkts.parent = self
                                    self._children_name_map["in_good_pkts"] = "in-good-pkts"

                                    self.in_drop_overrun = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InDropOverrun()
                                    self.in_drop_overrun.parent = self
                                    self._children_name_map["in_drop_overrun"] = "in-drop-overrun"

                                    self.in_drop_abort = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InDropAbort()
                                    self.in_drop_abort.parent = self
                                    self._children_name_map["in_drop_abort"] = "in-drop-abort"

                                    self.in_drop_invalid_vlan = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InDropInvalidVlan()
                                    self.in_drop_invalid_vlan.parent = self
                                    self._children_name_map["in_drop_invalid_vlan"] = "in-drop-invalid-vlan"

                                    self.in_drop_invalid_dmac = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InDropInvalidDmac()
                                    self.in_drop_invalid_dmac.parent = self
                                    self._children_name_map["in_drop_invalid_dmac"] = "in-drop-invalid-dmac"

                                    self.in_drop_invalid_encap = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InDropInvalidEncap()
                                    self.in_drop_invalid_encap.parent = self
                                    self._children_name_map["in_drop_invalid_encap"] = "in-drop-invalid-encap"

                                    self.in_drop_other = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InDropOther()
                                    self.in_drop_other.parent = self
                                    self._children_name_map["in_drop_other"] = "in-drop-other"

                                    self.in_mib_giant = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InMibGiant()
                                    self.in_mib_giant.parent = self
                                    self._children_name_map["in_mib_giant"] = "in-mib-giant"

                                    self.in_mib_jabber = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InMibJabber()
                                    self.in_mib_jabber.parent = self
                                    self._children_name_map["in_mib_jabber"] = "in-mib-jabber"

                                    self.in_mibcrc = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InMibcrc()
                                    self.in_mibcrc.parent = self
                                    self._children_name_map["in_mibcrc"] = "in-mibcrc"

                                    self.in_error_collisions = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InErrorCollisions()
                                    self.in_error_collisions.parent = self
                                    self._children_name_map["in_error_collisions"] = "in-error-collisions"

                                    self.in_error_symbol = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InErrorSymbol()
                                    self.in_error_symbol.parent = self
                                    self._children_name_map["in_error_symbol"] = "in-error-symbol"

                                    self.out_good_bytes = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutGoodBytes()
                                    self.out_good_bytes.parent = self
                                    self._children_name_map["out_good_bytes"] = "out-good-bytes"

                                    self.out8021q_frames = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.Out8021qFrames()
                                    self.out8021q_frames.parent = self
                                    self._children_name_map["out8021q_frames"] = "out8021q-frames"

                                    self.out_pause_frames = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutPauseFrames()
                                    self.out_pause_frames.parent = self
                                    self._children_name_map["out_pause_frames"] = "out-pause-frames"

                                    self.out_pkts1519_max_octets = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutPkts1519MaxOctets()
                                    self.out_pkts1519_max_octets.parent = self
                                    self._children_name_map["out_pkts1519_max_octets"] = "out-pkts1519-max-octets"

                                    self.out_good_pkts = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutGoodPkts()
                                    self.out_good_pkts.parent = self
                                    self._children_name_map["out_good_pkts"] = "out-good-pkts"

                                    self.out_drop_underrun = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutDropUnderrun()
                                    self.out_drop_underrun.parent = self
                                    self._children_name_map["out_drop_underrun"] = "out-drop-underrun"

                                    self.out_drop_abort = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutDropAbort()
                                    self.out_drop_abort.parent = self
                                    self._children_name_map["out_drop_abort"] = "out-drop-abort"

                                    self.out_drop_other = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutDropOther()
                                    self.out_drop_other.parent = self
                                    self._children_name_map["out_drop_other"] = "out-drop-other"

                                    self.out_error_other = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutErrorOther()
                                    self.out_error_other.parent = self
                                    self._children_name_map["out_error_other"] = "out-error-other"

                                    self.in_error_giant = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InErrorGiant()
                                    self.in_error_giant.parent = self
                                    self._children_name_map["in_error_giant"] = "in-error-giant"

                                    self.in_error_runt = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InErrorRunt()
                                    self.in_error_runt.parent = self
                                    self._children_name_map["in_error_runt"] = "in-error-runt"

                                    self.in_error_jabbers = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InErrorJabbers()
                                    self.in_error_jabbers.parent = self
                                    self._children_name_map["in_error_jabbers"] = "in-error-jabbers"

                                    self.in_error_fragments = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InErrorFragments()
                                    self.in_error_fragments.parent = self
                                    self._children_name_map["in_error_fragments"] = "in-error-fragments"

                                    self.in_error_other = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InErrorOther()
                                    self.in_error_other.parent = self
                                    self._children_name_map["in_error_other"] = "in-error-other"

                                    self.in_pkt64_octet = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InPkt64Octet()
                                    self.in_pkt64_octet.parent = self
                                    self._children_name_map["in_pkt64_octet"] = "in-pkt64-octet"

                                    self.in_pkts65_to127_octets = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InPkts65To127Octets()
                                    self.in_pkts65_to127_octets.parent = self
                                    self._children_name_map["in_pkts65_to127_octets"] = "in-pkts65-to127-octets"

                                    self.in_pkts128_to255_octets = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InPkts128To255Octets()
                                    self.in_pkts128_to255_octets.parent = self
                                    self._children_name_map["in_pkts128_to255_octets"] = "in-pkts128-to255-octets"

                                    self.in_pkts256_to511_octets = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InPkts256To511Octets()
                                    self.in_pkts256_to511_octets.parent = self
                                    self._children_name_map["in_pkts256_to511_octets"] = "in-pkts256-to511-octets"

                                    self.in_pkts512_to1023_octets = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InPkts512To1023Octets()
                                    self.in_pkts512_to1023_octets.parent = self
                                    self._children_name_map["in_pkts512_to1023_octets"] = "in-pkts512-to1023-octets"

                                    self.in_pkts1024_to1518_octets = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InPkts1024To1518Octets()
                                    self.in_pkts1024_to1518_octets.parent = self
                                    self._children_name_map["in_pkts1024_to1518_octets"] = "in-pkts1024-to1518-octets"

                                    self.outpkt64octet = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.Outpkt64octet()
                                    self.outpkt64octet.parent = self
                                    self._children_name_map["outpkt64octet"] = "outpkt64octet"

                                    self.out_pkts65127_octets = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutPkts65127Octets()
                                    self.out_pkts65127_octets.parent = self
                                    self._children_name_map["out_pkts65127_octets"] = "out-pkts65127-octets"

                                    self.out_pkts128255_octets = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutPkts128255Octets()
                                    self.out_pkts128255_octets.parent = self
                                    self._children_name_map["out_pkts128255_octets"] = "out-pkts128255-octets"

                                    self.out_pkts256511_octets = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutPkts256511Octets()
                                    self.out_pkts256511_octets.parent = self
                                    self._children_name_map["out_pkts256511_octets"] = "out-pkts256511-octets"

                                    self.out_pkts5121023_octets = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutPkts5121023Octets()
                                    self.out_pkts5121023_octets.parent = self
                                    self._children_name_map["out_pkts5121023_octets"] = "out-pkts5121023-octets"

                                    self.out_pkts10241518_octets = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutPkts10241518Octets()
                                    self.out_pkts10241518_octets.parent = self
                                    self._children_name_map["out_pkts10241518_octets"] = "out-pkts10241518-octets"

                                    self.rx_util = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.RxUtil()
                                    self.rx_util.parent = self
                                    self._children_name_map["rx_util"] = "rx-util"

                                    self.tx_util = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.TxUtil()
                                    self.tx_util.parent = self
                                    self._children_name_map["tx_util"] = "tx-util"

                                    self.tx_undersized_pkt = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.TxUndersizedPkt()
                                    self.tx_undersized_pkt.parent = self
                                    self._children_name_map["tx_undersized_pkt"] = "tx-undersized-pkt"

                                    self.tx_oversized_pkt = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.TxOversizedPkt()
                                    self.tx_oversized_pkt.parent = self
                                    self._children_name_map["tx_oversized_pkt"] = "tx-oversized-pkt"

                                    self.tx_fragments = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.TxFragments()
                                    self.tx_fragments.parent = self
                                    self._children_name_map["tx_fragments"] = "tx-fragments"

                                    self.tx_jabber = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.TxJabber()
                                    self.tx_jabber.parent = self
                                    self._children_name_map["tx_jabber"] = "tx-jabber"

                                    self.tx_bad_fcs = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.TxBadFcs()
                                    self.tx_bad_fcs.parent = self
                                    self._children_name_map["tx_bad_fcs"] = "tx-bad-fcs"
                                    self._segment_path = lambda: "macsec-minute15-ether" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear30_sec_time', 'last_clear15_min_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                class RxPkt(Entity):
                                    """
                                    RX PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.RxPkt, self).__init__()

                                        self.yang_name = "rx-pkt"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "rx-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.RxPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class StatPkt(Entity):
                                    """
                                    STAT PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.StatPkt, self).__init__()

                                        self.yang_name = "stat-pkt"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "stat-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.StatPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OctetStat(Entity):
                                    """
                                    OCTET STAT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OctetStat, self).__init__()

                                        self.yang_name = "octet-stat"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "octet-stat"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OctetStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OversizePktStat(Entity):
                                    """
                                    OVERSIZE PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OversizePktStat, self).__init__()

                                        self.yang_name = "oversize-pkt-stat"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "oversize-pkt-stat"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OversizePktStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class FcsErrorsStat(Entity):
                                    """
                                    FCS ERR
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.FcsErrorsStat, self).__init__()

                                        self.yang_name = "fcs-errors-stat"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "fcs-errors-stat"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.FcsErrorsStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class LongFramesStat(Entity):
                                    """
                                    LONG FRAMES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.LongFramesStat, self).__init__()

                                        self.yang_name = "long-frames-stat"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "long-frames-stat"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.LongFramesStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class JabberStat(Entity):
                                    """
                                    JABBER STATS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.JabberStat, self).__init__()

                                        self.yang_name = "jabber-stat"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "jabber-stat"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.JabberStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class Ether64Octets(Entity):
                                    """
                                    SIXTY FOUR OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.Ether64Octets, self).__init__()

                                        self.yang_name = "ether64-octets"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ether64-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.Ether64Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class Ether65127Octet(Entity):
                                    """
                                    OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.Ether65127Octet, self).__init__()

                                        self.yang_name = "ether65127-octet"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ether65127-octet"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.Ether65127Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class Ether128255Octet(Entity):
                                    """
                                    TFF OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.Ether128255Octet, self).__init__()

                                        self.yang_name = "ether128255-octet"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ether128255-octet"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.Ether128255Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class Ether256511Octet(Entity):
                                    """
                                    FOO OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.Ether256511Octet, self).__init__()

                                        self.yang_name = "ether256511-octet"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ether256511-octet"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.Ether256511Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class Ether5121023Octet(Entity):
                                    """
                                    OZTT OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.Ether5121023Octet, self).__init__()

                                        self.yang_name = "ether5121023-octet"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ether5121023-octet"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.Ether5121023Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class Ether10241518Octet(Entity):
                                    """
                                    OFO OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.Ether10241518Octet, self).__init__()

                                        self.yang_name = "ether10241518-octet"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ether10241518-octet"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.Ether10241518Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InUcastPkt(Entity):
                                    """
                                    IN UCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InUcastPkt, self).__init__()

                                        self.yang_name = "in-ucast-pkt"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-ucast-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InUcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InMcastPkt(Entity):
                                    """
                                    IN MCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InMcastPkt, self).__init__()

                                        self.yang_name = "in-mcast-pkt"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-mcast-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InMcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InBcastPkt(Entity):
                                    """
                                    IN BCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InBcastPkt, self).__init__()

                                        self.yang_name = "in-bcast-pkt"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-bcast-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InBcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutUcastPkt(Entity):
                                    """
                                    OUT UCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutUcastPkt, self).__init__()

                                        self.yang_name = "out-ucast-pkt"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-ucast-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutUcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutBcastPkt(Entity):
                                    """
                                    OUT BCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutBcastPkt, self).__init__()

                                        self.yang_name = "out-bcast-pkt"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-bcast-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutBcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutMcastPkt(Entity):
                                    """
                                    OUT MCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutMcastPkt, self).__init__()

                                        self.yang_name = "out-mcast-pkt"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-mcast-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutMcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class TxPkt(Entity):
                                    """
                                    TX PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.TxPkt, self).__init__()

                                        self.yang_name = "tx-pkt"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "tx-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.TxPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class IfInErrors(Entity):
                                    """
                                    IFIN ERRORS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.IfInErrors, self).__init__()

                                        self.yang_name = "if-in-errors"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "if-in-errors"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.IfInErrors, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class IfInOctets(Entity):
                                    """
                                    IFIN OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.IfInOctets, self).__init__()

                                        self.yang_name = "if-in-octets"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "if-in-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.IfInOctets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class EtherStatMulticastPkt(Entity):
                                    """
                                    ETHER STAT MULTICAST PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.EtherStatMulticastPkt, self).__init__()

                                        self.yang_name = "ether-stat-multicast-pkt"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ether-stat-multicast-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.EtherStatMulticastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class EtherStatBroadcastPkt(Entity):
                                    """
                                    ETHER STAT BROADCAST PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.EtherStatBroadcastPkt, self).__init__()

                                        self.yang_name = "ether-stat-broadcast-pkt"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ether-stat-broadcast-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.EtherStatBroadcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class EtherStatUndersizedPkt(Entity):
                                    """
                                    ETHER STAT UNDERSIZED PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.EtherStatUndersizedPkt, self).__init__()

                                        self.yang_name = "ether-stat-undersized-pkt"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ether-stat-undersized-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.EtherStatUndersizedPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutOctets(Entity):
                                    """
                                    OUT OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutOctets, self).__init__()

                                        self.yang_name = "out-octets"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutOctets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPauseFrame(Entity):
                                    """
                                    INPUT PAUSE FRAME
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InPauseFrame, self).__init__()

                                        self.yang_name = "in-pause-frame"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pause-frame"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InPauseFrame, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InGoodBytes(Entity):
                                    """
                                    INPUT GOOD BYTES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InGoodBytes, self).__init__()

                                        self.yang_name = "in-good-bytes"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-good-bytes"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InGoodBytes, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class In8021qFrames(Entity):
                                    """
                                    INPUT 802 1Q FRAMES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.In8021qFrames, self).__init__()

                                        self.yang_name = "in8021q-frames"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in8021q-frames"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.In8021qFrames, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPkts1519MaxOctets(Entity):
                                    """
                                    INPUT PKTS 1519MAX OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InPkts1519MaxOctets, self).__init__()

                                        self.yang_name = "in-pkts1519-max-octets"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts1519-max-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InPkts1519MaxOctets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InGoodPkts(Entity):
                                    """
                                    INPUT GOOD PKTS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InGoodPkts, self).__init__()

                                        self.yang_name = "in-good-pkts"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-good-pkts"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InGoodPkts, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InDropOverrun(Entity):
                                    """
                                    INPUT DROP OVERRUN
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InDropOverrun, self).__init__()

                                        self.yang_name = "in-drop-overrun"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-drop-overrun"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InDropOverrun, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InDropAbort(Entity):
                                    """
                                    INPUT DROP ABORT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InDropAbort, self).__init__()

                                        self.yang_name = "in-drop-abort"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-drop-abort"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InDropAbort, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InDropInvalidVlan(Entity):
                                    """
                                    INPUT DROP INVALID VLAN
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InDropInvalidVlan, self).__init__()

                                        self.yang_name = "in-drop-invalid-vlan"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-drop-invalid-vlan"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InDropInvalidVlan, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InDropInvalidDmac(Entity):
                                    """
                                    INPUT DROP INVALID DMAC
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InDropInvalidDmac, self).__init__()

                                        self.yang_name = "in-drop-invalid-dmac"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-drop-invalid-dmac"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InDropInvalidDmac, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InDropInvalidEncap(Entity):
                                    """
                                    INPUT DROP INVALID ENCAP
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InDropInvalidEncap, self).__init__()

                                        self.yang_name = "in-drop-invalid-encap"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-drop-invalid-encap"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InDropInvalidEncap, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InDropOther(Entity):
                                    """
                                    INPUT DROP OTHER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InDropOther, self).__init__()

                                        self.yang_name = "in-drop-other"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-drop-other"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InDropOther, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InMibGiant(Entity):
                                    """
                                    INPUT MIB GIANT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InMibGiant, self).__init__()

                                        self.yang_name = "in-mib-giant"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-mib-giant"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InMibGiant, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InMibJabber(Entity):
                                    """
                                    INPUT MIB JABBER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InMibJabber, self).__init__()

                                        self.yang_name = "in-mib-jabber"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-mib-jabber"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InMibJabber, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InMibcrc(Entity):
                                    """
                                    IN MIB CRC
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InMibcrc, self).__init__()

                                        self.yang_name = "in-mibcrc"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-mibcrc"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InMibcrc, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InErrorCollisions(Entity):
                                    """
                                    IN ERROR COLLISIONS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InErrorCollisions, self).__init__()

                                        self.yang_name = "in-error-collisions"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-error-collisions"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InErrorCollisions, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InErrorSymbol(Entity):
                                    """
                                    IN ERROR SYMBOL
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InErrorSymbol, self).__init__()

                                        self.yang_name = "in-error-symbol"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-error-symbol"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InErrorSymbol, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutGoodBytes(Entity):
                                    """
                                    OUT GOOD BYTES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutGoodBytes, self).__init__()

                                        self.yang_name = "out-good-bytes"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-good-bytes"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutGoodBytes, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class Out8021qFrames(Entity):
                                    """
                                    OUT 802 1Q FRAMES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.Out8021qFrames, self).__init__()

                                        self.yang_name = "out8021q-frames"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out8021q-frames"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.Out8021qFrames, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutPauseFrames(Entity):
                                    """
                                    OUT PAUSE FRAMES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutPauseFrames, self).__init__()

                                        self.yang_name = "out-pause-frames"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-pause-frames"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutPauseFrames, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutPkts1519MaxOctets(Entity):
                                    """
                                    OUT PKTS 1519 MAX OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutPkts1519MaxOctets, self).__init__()

                                        self.yang_name = "out-pkts1519-max-octets"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-pkts1519-max-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutPkts1519MaxOctets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutGoodPkts(Entity):
                                    """
                                    OUT GOOD PKTS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutGoodPkts, self).__init__()

                                        self.yang_name = "out-good-pkts"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-good-pkts"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutGoodPkts, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutDropUnderrun(Entity):
                                    """
                                    OUT DROP UNDERRUN
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutDropUnderrun, self).__init__()

                                        self.yang_name = "out-drop-underrun"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-drop-underrun"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutDropUnderrun, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutDropAbort(Entity):
                                    """
                                    OUT DROP ABORT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutDropAbort, self).__init__()

                                        self.yang_name = "out-drop-abort"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-drop-abort"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutDropAbort, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutDropOther(Entity):
                                    """
                                    OUT DROP OTHER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutDropOther, self).__init__()

                                        self.yang_name = "out-drop-other"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-drop-other"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutDropOther, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutErrorOther(Entity):
                                    """
                                    OUT ERROR OTHER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutErrorOther, self).__init__()

                                        self.yang_name = "out-error-other"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-error-other"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutErrorOther, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InErrorGiant(Entity):
                                    """
                                    IN ERROR GIANT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InErrorGiant, self).__init__()

                                        self.yang_name = "in-error-giant"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-error-giant"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InErrorGiant, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InErrorRunt(Entity):
                                    """
                                    IN ERROR RUNT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InErrorRunt, self).__init__()

                                        self.yang_name = "in-error-runt"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-error-runt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InErrorRunt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InErrorJabbers(Entity):
                                    """
                                    IN ERROR JABBERS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InErrorJabbers, self).__init__()

                                        self.yang_name = "in-error-jabbers"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-error-jabbers"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InErrorJabbers, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InErrorFragments(Entity):
                                    """
                                    IN ERROR FRAGMENTS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InErrorFragments, self).__init__()

                                        self.yang_name = "in-error-fragments"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-error-fragments"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InErrorFragments, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InErrorOther(Entity):
                                    """
                                    IN ERROR OTHER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InErrorOther, self).__init__()

                                        self.yang_name = "in-error-other"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-error-other"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InErrorOther, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPkt64Octet(Entity):
                                    """
                                    IN PKT 64 OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InPkt64Octet, self).__init__()

                                        self.yang_name = "in-pkt64-octet"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkt64-octet"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InPkt64Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPkts65To127Octets(Entity):
                                    """
                                    IN PKTS 65 127OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InPkts65To127Octets, self).__init__()

                                        self.yang_name = "in-pkts65-to127-octets"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts65-to127-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InPkts65To127Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPkts128To255Octets(Entity):
                                    """
                                    IN PKTS 128 255 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InPkts128To255Octets, self).__init__()

                                        self.yang_name = "in-pkts128-to255-octets"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts128-to255-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InPkts128To255Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPkts256To511Octets(Entity):
                                    """
                                    IN PKTS 256 511 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InPkts256To511Octets, self).__init__()

                                        self.yang_name = "in-pkts256-to511-octets"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts256-to511-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InPkts256To511Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPkts512To1023Octets(Entity):
                                    """
                                    IN PKTS 512 1023 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InPkts512To1023Octets, self).__init__()

                                        self.yang_name = "in-pkts512-to1023-octets"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts512-to1023-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InPkts512To1023Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPkts1024To1518Octets(Entity):
                                    """
                                    IN PKTS 1024 1518 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InPkts1024To1518Octets, self).__init__()

                                        self.yang_name = "in-pkts1024-to1518-octets"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts1024-to1518-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.InPkts1024To1518Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class Outpkt64octet(Entity):
                                    """
                                    OUT PKT 64 OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.Outpkt64octet, self).__init__()

                                        self.yang_name = "outpkt64octet"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "outpkt64octet"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.Outpkt64octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutPkts65127Octets(Entity):
                                    """
                                    OUT PKTS 65 127OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutPkts65127Octets, self).__init__()

                                        self.yang_name = "out-pkts65127-octets"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-pkts65127-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutPkts65127Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutPkts128255Octets(Entity):
                                    """
                                    OUT PKTS 128 255 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutPkts128255Octets, self).__init__()

                                        self.yang_name = "out-pkts128255-octets"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-pkts128255-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutPkts128255Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutPkts256511Octets(Entity):
                                    """
                                    OUT PKTS 256 511 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutPkts256511Octets, self).__init__()

                                        self.yang_name = "out-pkts256511-octets"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-pkts256511-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutPkts256511Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutPkts5121023Octets(Entity):
                                    """
                                    OUT PKTS 512 1023 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutPkts5121023Octets, self).__init__()

                                        self.yang_name = "out-pkts5121023-octets"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-pkts5121023-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutPkts5121023Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutPkts10241518Octets(Entity):
                                    """
                                    OUT PKTS 1024 1518 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutPkts10241518Octets, self).__init__()

                                        self.yang_name = "out-pkts10241518-octets"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-pkts10241518-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.OutPkts10241518Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class RxUtil(Entity):
                                    """
                                    Rx Utilization in Percent
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: str
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.RxUtil, self).__init__()

                                        self.yang_name = "rx-util"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "rx-util"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.RxUtil, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class TxUtil(Entity):
                                    """
                                    Tx Utilization in Percent
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: str
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.TxUtil, self).__init__()

                                        self.yang_name = "tx-util"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "tx-util"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.TxUtil, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class TxUndersizedPkt(Entity):
                                    """
                                    TX Undersized Pkt
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.TxUndersizedPkt, self).__init__()

                                        self.yang_name = "tx-undersized-pkt"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "tx-undersized-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.TxUndersizedPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class TxOversizedPkt(Entity):
                                    """
                                    TX Oversized Pkt
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.TxOversizedPkt, self).__init__()

                                        self.yang_name = "tx-oversized-pkt"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "tx-oversized-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.TxOversizedPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class TxFragments(Entity):
                                    """
                                    TX Fragments
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.TxFragments, self).__init__()

                                        self.yang_name = "tx-fragments"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "tx-fragments"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.TxFragments, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class TxJabber(Entity):
                                    """
                                    TX Jabber
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.TxJabber, self).__init__()

                                        self.yang_name = "tx-jabber"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "tx-jabber"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.TxJabber, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class TxBadFcs(Entity):
                                    """
                                    TX Bad Fcs
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.TxBadFcs, self).__init__()

                                        self.yang_name = "tx-bad-fcs"
                                        self.yang_parent_name = "macsec-minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "tx-bad-fcs"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecMinute15.MacsecMinute15EtherS.MacsecMinute15Ether.TxBadFcs, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                    class MacsecSecond30(Entity):
                        """
                        port current performance data
                        
                        .. attribute:: macsec_second30secyifs
                        
                        	port current performance data
                        	**type**\:  :py:class:`MacsecSecond30secyifs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs>`
                        
                        .. attribute:: macsec_second30secyrxes
                        
                        	port current performance data
                        	**type**\:  :py:class:`MacsecSecond30secyrxes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes>`
                        
                        .. attribute:: macsec_second30_ether_s
                        
                        	port current performance data
                        	**type**\:  :py:class:`MacsecSecond30EtherS <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS>`
                        
                        .. attribute:: macsec_second30secytxes
                        
                        	port current performance data
                        	**type**\:  :py:class:`MacsecSecond30secytxes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secytxes>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30, self).__init__()

                            self.yang_name = "macsec-second30"
                            self.yang_parent_name = "macsec-current"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("macsec-second30secyifs", ("macsec_second30secyifs", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs)), ("macsec-second30secyrxes", ("macsec_second30secyrxes", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes)), ("macsec-second30-ether-s", ("macsec_second30_ether_s", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS)), ("macsec-second30secytxes", ("macsec_second30secytxes", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secytxes))])
                            self._leafs = OrderedDict()

                            self.macsec_second30secyifs = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs()
                            self.macsec_second30secyifs.parent = self
                            self._children_name_map["macsec_second30secyifs"] = "macsec-second30secyifs"

                            self.macsec_second30secyrxes = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes()
                            self.macsec_second30secyrxes.parent = self
                            self._children_name_map["macsec_second30secyrxes"] = "macsec-second30secyrxes"

                            self.macsec_second30_ether_s = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS()
                            self.macsec_second30_ether_s.parent = self
                            self._children_name_map["macsec_second30_ether_s"] = "macsec-second30-ether-s"

                            self.macsec_second30secytxes = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secytxes()
                            self.macsec_second30secytxes.parent = self
                            self._children_name_map["macsec_second30secytxes"] = "macsec-second30secytxes"
                            self._segment_path = lambda: "macsec-second30"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30, [], name, value)


                        class MacsecSecond30secyifs(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: macsec_second30secyif
                            
                            	port 30\-sec secy\-if performance data
                            	**type**\: list of  		 :py:class:`MacsecSecond30secyif <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs, self).__init__()

                                self.yang_name = "macsec-second30secyifs"
                                self.yang_parent_name = "macsec-second30"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("macsec-second30secyif", ("macsec_second30secyif", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif))])
                                self._leafs = OrderedDict()

                                self.macsec_second30secyif = YList(self)
                                self._segment_path = lambda: "macsec-second30secyifs"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs, [], name, value)


                            class MacsecSecond30secyif(Entity):
                                """
                                port 30\-sec secy\-if performance data
                                
                                .. attribute:: number  (key)
                                
                                	channel number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: in_pkts_untagged
                                
                                	In Packet Untagged
                                	**type**\:  :py:class:`InPktsUntagged <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.InPktsUntagged>`
                                
                                .. attribute:: in_pkts_no_tag
                                
                                	In Packet No tag
                                	**type**\:  :py:class:`InPktsNoTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.InPktsNoTag>`
                                
                                .. attribute:: in_pkts_bad_tag
                                
                                	In Packet Bad tag
                                	**type**\:  :py:class:`InPktsBadTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.InPktsBadTag>`
                                
                                .. attribute:: in_pkts_unknown_sci
                                
                                	In Packet Unknown sci
                                	**type**\:  :py:class:`InPktsUnknownSci <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.InPktsUnknownSci>`
                                
                                .. attribute:: in_pkts_no_sci
                                
                                	In Packet No sci
                                	**type**\:  :py:class:`InPktsNoSci <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.InPktsNoSci>`
                                
                                .. attribute:: in_pkts_overrun
                                
                                	In Packet Overrun
                                	**type**\:  :py:class:`InPktsOverrun <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.InPktsOverrun>`
                                
                                .. attribute:: in_octets_validated
                                
                                	In Octet Validated
                                	**type**\:  :py:class:`InOctetsValidated <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.InOctetsValidated>`
                                
                                .. attribute:: in_octets_decrypted
                                
                                	In Octet Decrypted
                                	**type**\:  :py:class:`InOctetsDecrypted <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.InOctetsDecrypted>`
                                
                                .. attribute:: out_pkts_untagged
                                
                                	Out Packet Untagged
                                	**type**\:  :py:class:`OutPktsUntagged <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.OutPktsUntagged>`
                                
                                .. attribute:: out_pkts_too_long
                                
                                	Out Packet Too Long
                                	**type**\:  :py:class:`OutPktsTooLong <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.OutPktsTooLong>`
                                
                                .. attribute:: out_octets_protected
                                
                                	Out Octet Protected
                                	**type**\:  :py:class:`OutOctetsProtected <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.OutOctetsProtected>`
                                
                                .. attribute:: out_octets_encrypted
                                
                                	Out Octet encrypted
                                	**type**\:  :py:class:`OutOctetsEncrypted <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.OutOctetsEncrypted>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\: bool
                                
                                .. attribute:: sample_count
                                
                                	Running Sample Count
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif, self).__init__()

                                    self.yang_name = "macsec-second30secyif"
                                    self.yang_parent_name = "macsec-second30secyifs"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("in-pkts-untagged", ("in_pkts_untagged", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.InPktsUntagged)), ("in-pkts-no-tag", ("in_pkts_no_tag", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.InPktsNoTag)), ("in-pkts-bad-tag", ("in_pkts_bad_tag", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.InPktsBadTag)), ("in-pkts-unknown-sci", ("in_pkts_unknown_sci", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.InPktsUnknownSci)), ("in-pkts-no-sci", ("in_pkts_no_sci", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.InPktsNoSci)), ("in-pkts-overrun", ("in_pkts_overrun", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.InPktsOverrun)), ("in-octets-validated", ("in_octets_validated", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.InOctetsValidated)), ("in-octets-decrypted", ("in_octets_decrypted", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.InOctetsDecrypted)), ("out-pkts-untagged", ("out_pkts_untagged", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.OutPktsUntagged)), ("out-pkts-too-long", ("out_pkts_too_long", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.OutPktsTooLong)), ("out-octets-protected", ("out_octets_protected", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.OutOctetsProtected)), ("out-octets-encrypted", ("out_octets_encrypted", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.OutOctetsEncrypted))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                        ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                        ('sample_count', (YLeaf(YType.uint64, 'sample-count'), ['int'])),
                                    ])
                                    self.number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear24_hr_time = None
                                    self.sec30_support = None
                                    self.sample_count = None

                                    self.in_pkts_untagged = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.InPktsUntagged()
                                    self.in_pkts_untagged.parent = self
                                    self._children_name_map["in_pkts_untagged"] = "in-pkts-untagged"

                                    self.in_pkts_no_tag = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.InPktsNoTag()
                                    self.in_pkts_no_tag.parent = self
                                    self._children_name_map["in_pkts_no_tag"] = "in-pkts-no-tag"

                                    self.in_pkts_bad_tag = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.InPktsBadTag()
                                    self.in_pkts_bad_tag.parent = self
                                    self._children_name_map["in_pkts_bad_tag"] = "in-pkts-bad-tag"

                                    self.in_pkts_unknown_sci = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.InPktsUnknownSci()
                                    self.in_pkts_unknown_sci.parent = self
                                    self._children_name_map["in_pkts_unknown_sci"] = "in-pkts-unknown-sci"

                                    self.in_pkts_no_sci = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.InPktsNoSci()
                                    self.in_pkts_no_sci.parent = self
                                    self._children_name_map["in_pkts_no_sci"] = "in-pkts-no-sci"

                                    self.in_pkts_overrun = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.InPktsOverrun()
                                    self.in_pkts_overrun.parent = self
                                    self._children_name_map["in_pkts_overrun"] = "in-pkts-overrun"

                                    self.in_octets_validated = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.InOctetsValidated()
                                    self.in_octets_validated.parent = self
                                    self._children_name_map["in_octets_validated"] = "in-octets-validated"

                                    self.in_octets_decrypted = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.InOctetsDecrypted()
                                    self.in_octets_decrypted.parent = self
                                    self._children_name_map["in_octets_decrypted"] = "in-octets-decrypted"

                                    self.out_pkts_untagged = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.OutPktsUntagged()
                                    self.out_pkts_untagged.parent = self
                                    self._children_name_map["out_pkts_untagged"] = "out-pkts-untagged"

                                    self.out_pkts_too_long = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.OutPktsTooLong()
                                    self.out_pkts_too_long.parent = self
                                    self._children_name_map["out_pkts_too_long"] = "out-pkts-too-long"

                                    self.out_octets_protected = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.OutOctetsProtected()
                                    self.out_octets_protected.parent = self
                                    self._children_name_map["out_octets_protected"] = "out-octets-protected"

                                    self.out_octets_encrypted = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.OutOctetsEncrypted()
                                    self.out_octets_encrypted.parent = self
                                    self._children_name_map["out_octets_encrypted"] = "out-octets-encrypted"
                                    self._segment_path = lambda: "macsec-second30secyif" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support', 'sample_count'], name, value)


                                class InPktsUntagged(Entity):
                                    """
                                    In Packet Untagged
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.InPktsUntagged, self).__init__()

                                        self.yang_name = "in-pkts-untagged"
                                        self.yang_parent_name = "macsec-second30secyif"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts-untagged"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.InPktsUntagged, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPktsNoTag(Entity):
                                    """
                                    In Packet No tag
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.InPktsNoTag, self).__init__()

                                        self.yang_name = "in-pkts-no-tag"
                                        self.yang_parent_name = "macsec-second30secyif"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts-no-tag"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.InPktsNoTag, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPktsBadTag(Entity):
                                    """
                                    In Packet Bad tag
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.InPktsBadTag, self).__init__()

                                        self.yang_name = "in-pkts-bad-tag"
                                        self.yang_parent_name = "macsec-second30secyif"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts-bad-tag"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.InPktsBadTag, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPktsUnknownSci(Entity):
                                    """
                                    In Packet Unknown sci
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.InPktsUnknownSci, self).__init__()

                                        self.yang_name = "in-pkts-unknown-sci"
                                        self.yang_parent_name = "macsec-second30secyif"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts-unknown-sci"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.InPktsUnknownSci, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPktsNoSci(Entity):
                                    """
                                    In Packet No sci
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.InPktsNoSci, self).__init__()

                                        self.yang_name = "in-pkts-no-sci"
                                        self.yang_parent_name = "macsec-second30secyif"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts-no-sci"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.InPktsNoSci, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPktsOverrun(Entity):
                                    """
                                    In Packet Overrun
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.InPktsOverrun, self).__init__()

                                        self.yang_name = "in-pkts-overrun"
                                        self.yang_parent_name = "macsec-second30secyif"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts-overrun"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.InPktsOverrun, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InOctetsValidated(Entity):
                                    """
                                    In Octet Validated
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.InOctetsValidated, self).__init__()

                                        self.yang_name = "in-octets-validated"
                                        self.yang_parent_name = "macsec-second30secyif"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-octets-validated"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.InOctetsValidated, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InOctetsDecrypted(Entity):
                                    """
                                    In Octet Decrypted
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.InOctetsDecrypted, self).__init__()

                                        self.yang_name = "in-octets-decrypted"
                                        self.yang_parent_name = "macsec-second30secyif"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-octets-decrypted"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.InOctetsDecrypted, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutPktsUntagged(Entity):
                                    """
                                    Out Packet Untagged
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.OutPktsUntagged, self).__init__()

                                        self.yang_name = "out-pkts-untagged"
                                        self.yang_parent_name = "macsec-second30secyif"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-pkts-untagged"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.OutPktsUntagged, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutPktsTooLong(Entity):
                                    """
                                    Out Packet Too Long
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.OutPktsTooLong, self).__init__()

                                        self.yang_name = "out-pkts-too-long"
                                        self.yang_parent_name = "macsec-second30secyif"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-pkts-too-long"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.OutPktsTooLong, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutOctetsProtected(Entity):
                                    """
                                    Out Octet Protected
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.OutOctetsProtected, self).__init__()

                                        self.yang_name = "out-octets-protected"
                                        self.yang_parent_name = "macsec-second30secyif"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-octets-protected"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.OutOctetsProtected, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutOctetsEncrypted(Entity):
                                    """
                                    Out Octet encrypted
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.OutOctetsEncrypted, self).__init__()

                                        self.yang_name = "out-octets-encrypted"
                                        self.yang_parent_name = "macsec-second30secyif"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-octets-encrypted"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyifs.MacsecSecond30secyif.OutOctetsEncrypted, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                        class MacsecSecond30secyrxes(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: macsec_second30secyrx
                            
                            	port 30\-sec secy\-rx performance data
                            	**type**\: list of  		 :py:class:`MacsecSecond30secyrx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes, self).__init__()

                                self.yang_name = "macsec-second30secyrxes"
                                self.yang_parent_name = "macsec-second30"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("macsec-second30secyrx", ("macsec_second30secyrx", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx))])
                                self._leafs = OrderedDict()

                                self.macsec_second30secyrx = YList(self)
                                self._segment_path = lambda: "macsec-second30secyrxes"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes, [], name, value)


                            class MacsecSecond30secyrx(Entity):
                                """
                                port 30\-sec secy\-rx performance data
                                
                                .. attribute:: number  (key)
                                
                                	channel number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: in_pkts_unchecked
                                
                                	In Packet Unchecked
                                	**type**\:  :py:class:`InPktsUnchecked <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx.InPktsUnchecked>`
                                
                                .. attribute:: in_pkts_delayed
                                
                                	In Packet Delay
                                	**type**\:  :py:class:`InPktsDelayed <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx.InPktsDelayed>`
                                
                                .. attribute:: in_pkts_late
                                
                                	In Packet Late
                                	**type**\:  :py:class:`InPktsLate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx.InPktsLate>`
                                
                                .. attribute:: in_pkts_ok
                                
                                	In Packet Ok
                                	**type**\:  :py:class:`InPktsOk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx.InPktsOk>`
                                
                                .. attribute:: in_pkts_invalid
                                
                                	In Packet Invalid
                                	**type**\:  :py:class:`InPktsInvalid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx.InPktsInvalid>`
                                
                                .. attribute:: in_pkts_not_valid
                                
                                	In Packet Not Valid
                                	**type**\:  :py:class:`InPktsNotValid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx.InPktsNotValid>`
                                
                                .. attribute:: in_pkts_not_using_sa
                                
                                	In Packet Not Using SA
                                	**type**\:  :py:class:`InPktsNotUsingSa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx.InPktsNotUsingSa>`
                                
                                .. attribute:: in_pkts_unused_sa
                                
                                	In Packet Unused SA
                                	**type**\:  :py:class:`InPktsUnusedSa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx.InPktsUnusedSa>`
                                
                                .. attribute:: in_pkts_untagged_hit
                                
                                	In Packet Untagged Hit
                                	**type**\:  :py:class:`InPktsUntaggedHit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx.InPktsUntaggedHit>`
                                
                                .. attribute:: in_octets_validated
                                
                                	In Octet Validated
                                	**type**\:  :py:class:`InOctetsValidated <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx.InOctetsValidated>`
                                
                                .. attribute:: in_octets_decrypted
                                
                                	In Octet Decrypted
                                	**type**\:  :py:class:`InOctetsDecrypted <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx.InOctetsDecrypted>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\: bool
                                
                                .. attribute:: sample_count
                                
                                	Running Sample Count
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx, self).__init__()

                                    self.yang_name = "macsec-second30secyrx"
                                    self.yang_parent_name = "macsec-second30secyrxes"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("in-pkts-unchecked", ("in_pkts_unchecked", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx.InPktsUnchecked)), ("in-pkts-delayed", ("in_pkts_delayed", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx.InPktsDelayed)), ("in-pkts-late", ("in_pkts_late", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx.InPktsLate)), ("in-pkts-ok", ("in_pkts_ok", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx.InPktsOk)), ("in-pkts-invalid", ("in_pkts_invalid", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx.InPktsInvalid)), ("in-pkts-not-valid", ("in_pkts_not_valid", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx.InPktsNotValid)), ("in-pkts-not-using-sa", ("in_pkts_not_using_sa", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx.InPktsNotUsingSa)), ("in-pkts-unused-sa", ("in_pkts_unused_sa", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx.InPktsUnusedSa)), ("in-pkts-untagged-hit", ("in_pkts_untagged_hit", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx.InPktsUntaggedHit)), ("in-octets-validated", ("in_octets_validated", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx.InOctetsValidated)), ("in-octets-decrypted", ("in_octets_decrypted", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx.InOctetsDecrypted))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                        ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                        ('sample_count', (YLeaf(YType.uint64, 'sample-count'), ['int'])),
                                    ])
                                    self.number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear24_hr_time = None
                                    self.sec30_support = None
                                    self.sample_count = None

                                    self.in_pkts_unchecked = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx.InPktsUnchecked()
                                    self.in_pkts_unchecked.parent = self
                                    self._children_name_map["in_pkts_unchecked"] = "in-pkts-unchecked"

                                    self.in_pkts_delayed = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx.InPktsDelayed()
                                    self.in_pkts_delayed.parent = self
                                    self._children_name_map["in_pkts_delayed"] = "in-pkts-delayed"

                                    self.in_pkts_late = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx.InPktsLate()
                                    self.in_pkts_late.parent = self
                                    self._children_name_map["in_pkts_late"] = "in-pkts-late"

                                    self.in_pkts_ok = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx.InPktsOk()
                                    self.in_pkts_ok.parent = self
                                    self._children_name_map["in_pkts_ok"] = "in-pkts-ok"

                                    self.in_pkts_invalid = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx.InPktsInvalid()
                                    self.in_pkts_invalid.parent = self
                                    self._children_name_map["in_pkts_invalid"] = "in-pkts-invalid"

                                    self.in_pkts_not_valid = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx.InPktsNotValid()
                                    self.in_pkts_not_valid.parent = self
                                    self._children_name_map["in_pkts_not_valid"] = "in-pkts-not-valid"

                                    self.in_pkts_not_using_sa = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx.InPktsNotUsingSa()
                                    self.in_pkts_not_using_sa.parent = self
                                    self._children_name_map["in_pkts_not_using_sa"] = "in-pkts-not-using-sa"

                                    self.in_pkts_unused_sa = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx.InPktsUnusedSa()
                                    self.in_pkts_unused_sa.parent = self
                                    self._children_name_map["in_pkts_unused_sa"] = "in-pkts-unused-sa"

                                    self.in_pkts_untagged_hit = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx.InPktsUntaggedHit()
                                    self.in_pkts_untagged_hit.parent = self
                                    self._children_name_map["in_pkts_untagged_hit"] = "in-pkts-untagged-hit"

                                    self.in_octets_validated = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx.InOctetsValidated()
                                    self.in_octets_validated.parent = self
                                    self._children_name_map["in_octets_validated"] = "in-octets-validated"

                                    self.in_octets_decrypted = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx.InOctetsDecrypted()
                                    self.in_octets_decrypted.parent = self
                                    self._children_name_map["in_octets_decrypted"] = "in-octets-decrypted"
                                    self._segment_path = lambda: "macsec-second30secyrx" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support', 'sample_count'], name, value)


                                class InPktsUnchecked(Entity):
                                    """
                                    In Packet Unchecked
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx.InPktsUnchecked, self).__init__()

                                        self.yang_name = "in-pkts-unchecked"
                                        self.yang_parent_name = "macsec-second30secyrx"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts-unchecked"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx.InPktsUnchecked, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPktsDelayed(Entity):
                                    """
                                    In Packet Delay
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx.InPktsDelayed, self).__init__()

                                        self.yang_name = "in-pkts-delayed"
                                        self.yang_parent_name = "macsec-second30secyrx"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts-delayed"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx.InPktsDelayed, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPktsLate(Entity):
                                    """
                                    In Packet Late
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx.InPktsLate, self).__init__()

                                        self.yang_name = "in-pkts-late"
                                        self.yang_parent_name = "macsec-second30secyrx"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts-late"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx.InPktsLate, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPktsOk(Entity):
                                    """
                                    In Packet Ok
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx.InPktsOk, self).__init__()

                                        self.yang_name = "in-pkts-ok"
                                        self.yang_parent_name = "macsec-second30secyrx"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts-ok"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx.InPktsOk, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPktsInvalid(Entity):
                                    """
                                    In Packet Invalid
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx.InPktsInvalid, self).__init__()

                                        self.yang_name = "in-pkts-invalid"
                                        self.yang_parent_name = "macsec-second30secyrx"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts-invalid"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx.InPktsInvalid, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPktsNotValid(Entity):
                                    """
                                    In Packet Not Valid
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx.InPktsNotValid, self).__init__()

                                        self.yang_name = "in-pkts-not-valid"
                                        self.yang_parent_name = "macsec-second30secyrx"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts-not-valid"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx.InPktsNotValid, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPktsNotUsingSa(Entity):
                                    """
                                    In Packet Not Using SA
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx.InPktsNotUsingSa, self).__init__()

                                        self.yang_name = "in-pkts-not-using-sa"
                                        self.yang_parent_name = "macsec-second30secyrx"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts-not-using-sa"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx.InPktsNotUsingSa, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPktsUnusedSa(Entity):
                                    """
                                    In Packet Unused SA
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx.InPktsUnusedSa, self).__init__()

                                        self.yang_name = "in-pkts-unused-sa"
                                        self.yang_parent_name = "macsec-second30secyrx"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts-unused-sa"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx.InPktsUnusedSa, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPktsUntaggedHit(Entity):
                                    """
                                    In Packet Untagged Hit
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx.InPktsUntaggedHit, self).__init__()

                                        self.yang_name = "in-pkts-untagged-hit"
                                        self.yang_parent_name = "macsec-second30secyrx"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts-untagged-hit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx.InPktsUntaggedHit, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InOctetsValidated(Entity):
                                    """
                                    In Octet Validated
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx.InOctetsValidated, self).__init__()

                                        self.yang_name = "in-octets-validated"
                                        self.yang_parent_name = "macsec-second30secyrx"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-octets-validated"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx.InOctetsValidated, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InOctetsDecrypted(Entity):
                                    """
                                    In Octet Decrypted
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx.InOctetsDecrypted, self).__init__()

                                        self.yang_name = "in-octets-decrypted"
                                        self.yang_parent_name = "macsec-second30secyrx"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-octets-decrypted"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secyrxes.MacsecSecond30secyrx.InOctetsDecrypted, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                        class MacsecSecond30EtherS(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: macsec_second30_ether
                            
                            	port 30\-sec ether performance data
                            	**type**\: list of  		 :py:class:`MacsecSecond30Ether <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS, self).__init__()

                                self.yang_name = "macsec-second30-ether-s"
                                self.yang_parent_name = "macsec-second30"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("macsec-second30-ether", ("macsec_second30_ether", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether))])
                                self._leafs = OrderedDict()

                                self.macsec_second30_ether = YList(self)
                                self._segment_path = lambda: "macsec-second30-ether-s"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS, [], name, value)


                            class MacsecSecond30Ether(Entity):
                                """
                                port 30\-sec ether performance data
                                
                                .. attribute:: number  (key)
                                
                                	channel number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rx_pkt
                                
                                	RX PKT
                                	**type**\:  :py:class:`RxPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.RxPkt>`
                                
                                .. attribute:: stat_pkt
                                
                                	STAT PKT
                                	**type**\:  :py:class:`StatPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.StatPkt>`
                                
                                .. attribute:: octet_stat
                                
                                	OCTET STAT
                                	**type**\:  :py:class:`OctetStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OctetStat>`
                                
                                .. attribute:: oversize_pkt_stat
                                
                                	OVERSIZE PKT
                                	**type**\:  :py:class:`OversizePktStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OversizePktStat>`
                                
                                .. attribute:: fcs_errors_stat
                                
                                	FCS ERR
                                	**type**\:  :py:class:`FcsErrorsStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.FcsErrorsStat>`
                                
                                .. attribute:: long_frames_stat
                                
                                	LONG FRAMES
                                	**type**\:  :py:class:`LongFramesStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.LongFramesStat>`
                                
                                .. attribute:: jabber_stat
                                
                                	JABBER STATS
                                	**type**\:  :py:class:`JabberStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.JabberStat>`
                                
                                .. attribute:: ether64_octets
                                
                                	SIXTY FOUR OCTET
                                	**type**\:  :py:class:`Ether64Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.Ether64Octets>`
                                
                                .. attribute:: ether65127_octet
                                
                                	OCTET
                                	**type**\:  :py:class:`Ether65127Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.Ether65127Octet>`
                                
                                .. attribute:: ether128255_octet
                                
                                	TFF OCTET
                                	**type**\:  :py:class:`Ether128255Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.Ether128255Octet>`
                                
                                .. attribute:: ether256511_octet
                                
                                	FOO OCTET
                                	**type**\:  :py:class:`Ether256511Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.Ether256511Octet>`
                                
                                .. attribute:: ether5121023_octet
                                
                                	OZTT OCTET
                                	**type**\:  :py:class:`Ether5121023Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.Ether5121023Octet>`
                                
                                .. attribute:: ether10241518_octet
                                
                                	OFO OCTET
                                	**type**\:  :py:class:`Ether10241518Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.Ether10241518Octet>`
                                
                                .. attribute:: in_ucast_pkt
                                
                                	IN UCAST
                                	**type**\:  :py:class:`InUcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InUcastPkt>`
                                
                                .. attribute:: in_mcast_pkt
                                
                                	IN MCAST
                                	**type**\:  :py:class:`InMcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InMcastPkt>`
                                
                                .. attribute:: in_bcast_pkt
                                
                                	IN BCAST
                                	**type**\:  :py:class:`InBcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InBcastPkt>`
                                
                                .. attribute:: out_ucast_pkt
                                
                                	OUT UCAST
                                	**type**\:  :py:class:`OutUcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutUcastPkt>`
                                
                                .. attribute:: out_bcast_pkt
                                
                                	OUT BCAST
                                	**type**\:  :py:class:`OutBcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutBcastPkt>`
                                
                                .. attribute:: out_mcast_pkt
                                
                                	OUT MCAST
                                	**type**\:  :py:class:`OutMcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutMcastPkt>`
                                
                                .. attribute:: tx_pkt
                                
                                	TX PKT
                                	**type**\:  :py:class:`TxPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.TxPkt>`
                                
                                .. attribute:: if_in_errors
                                
                                	IFIN ERRORS
                                	**type**\:  :py:class:`IfInErrors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.IfInErrors>`
                                
                                .. attribute:: if_in_octets
                                
                                	IFIN OCTETS
                                	**type**\:  :py:class:`IfInOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.IfInOctets>`
                                
                                .. attribute:: ether_stat_multicast_pkt
                                
                                	ETHER STAT MULTICAST PKT
                                	**type**\:  :py:class:`EtherStatMulticastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.EtherStatMulticastPkt>`
                                
                                .. attribute:: ether_stat_broadcast_pkt
                                
                                	ETHER STAT BROADCAST PKT
                                	**type**\:  :py:class:`EtherStatBroadcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.EtherStatBroadcastPkt>`
                                
                                .. attribute:: ether_stat_undersized_pkt
                                
                                	ETHER STAT UNDERSIZED PKT
                                	**type**\:  :py:class:`EtherStatUndersizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.EtherStatUndersizedPkt>`
                                
                                .. attribute:: out_octets
                                
                                	OUT OCTET
                                	**type**\:  :py:class:`OutOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutOctets>`
                                
                                .. attribute:: in_pause_frame
                                
                                	INPUT PAUSE FRAME
                                	**type**\:  :py:class:`InPauseFrame <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InPauseFrame>`
                                
                                .. attribute:: in_good_bytes
                                
                                	INPUT GOOD BYTES
                                	**type**\:  :py:class:`InGoodBytes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InGoodBytes>`
                                
                                .. attribute:: in8021q_frames
                                
                                	INPUT 802 1Q FRAMES
                                	**type**\:  :py:class:`In8021qFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.In8021qFrames>`
                                
                                .. attribute:: in_pkts1519_max_octets
                                
                                	INPUT PKTS 1519MAX OCTETS
                                	**type**\:  :py:class:`InPkts1519MaxOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InPkts1519MaxOctets>`
                                
                                .. attribute:: in_good_pkts
                                
                                	INPUT GOOD PKTS
                                	**type**\:  :py:class:`InGoodPkts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InGoodPkts>`
                                
                                .. attribute:: in_drop_overrun
                                
                                	INPUT DROP OVERRUN
                                	**type**\:  :py:class:`InDropOverrun <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InDropOverrun>`
                                
                                .. attribute:: in_drop_abort
                                
                                	INPUT DROP ABORT
                                	**type**\:  :py:class:`InDropAbort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InDropAbort>`
                                
                                .. attribute:: in_drop_invalid_vlan
                                
                                	INPUT DROP INVALID VLAN
                                	**type**\:  :py:class:`InDropInvalidVlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InDropInvalidVlan>`
                                
                                .. attribute:: in_drop_invalid_dmac
                                
                                	INPUT DROP INVALID DMAC
                                	**type**\:  :py:class:`InDropInvalidDmac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InDropInvalidDmac>`
                                
                                .. attribute:: in_drop_invalid_encap
                                
                                	INPUT DROP INVALID ENCAP
                                	**type**\:  :py:class:`InDropInvalidEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InDropInvalidEncap>`
                                
                                .. attribute:: in_drop_other
                                
                                	INPUT DROP OTHER
                                	**type**\:  :py:class:`InDropOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InDropOther>`
                                
                                .. attribute:: in_mib_giant
                                
                                	INPUT MIB GIANT
                                	**type**\:  :py:class:`InMibGiant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InMibGiant>`
                                
                                .. attribute:: in_mib_jabber
                                
                                	INPUT MIB JABBER
                                	**type**\:  :py:class:`InMibJabber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InMibJabber>`
                                
                                .. attribute:: in_mibcrc
                                
                                	IN MIB CRC
                                	**type**\:  :py:class:`InMibcrc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InMibcrc>`
                                
                                .. attribute:: in_error_collisions
                                
                                	IN ERROR COLLISIONS
                                	**type**\:  :py:class:`InErrorCollisions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InErrorCollisions>`
                                
                                .. attribute:: in_error_symbol
                                
                                	IN ERROR SYMBOL
                                	**type**\:  :py:class:`InErrorSymbol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InErrorSymbol>`
                                
                                .. attribute:: out_good_bytes
                                
                                	OUT GOOD BYTES
                                	**type**\:  :py:class:`OutGoodBytes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutGoodBytes>`
                                
                                .. attribute:: out8021q_frames
                                
                                	OUT 802 1Q FRAMES
                                	**type**\:  :py:class:`Out8021qFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.Out8021qFrames>`
                                
                                .. attribute:: out_pause_frames
                                
                                	OUT PAUSE FRAMES
                                	**type**\:  :py:class:`OutPauseFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutPauseFrames>`
                                
                                .. attribute:: out_pkts1519_max_octets
                                
                                	OUT PKTS 1519 MAX OCTETS
                                	**type**\:  :py:class:`OutPkts1519MaxOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutPkts1519MaxOctets>`
                                
                                .. attribute:: out_good_pkts
                                
                                	OUT GOOD PKTS
                                	**type**\:  :py:class:`OutGoodPkts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutGoodPkts>`
                                
                                .. attribute:: out_drop_underrun
                                
                                	OUT DROP UNDERRUN
                                	**type**\:  :py:class:`OutDropUnderrun <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutDropUnderrun>`
                                
                                .. attribute:: out_drop_abort
                                
                                	OUT DROP ABORT
                                	**type**\:  :py:class:`OutDropAbort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutDropAbort>`
                                
                                .. attribute:: out_drop_other
                                
                                	OUT DROP OTHER
                                	**type**\:  :py:class:`OutDropOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutDropOther>`
                                
                                .. attribute:: out_error_other
                                
                                	OUT ERROR OTHER
                                	**type**\:  :py:class:`OutErrorOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutErrorOther>`
                                
                                .. attribute:: in_error_giant
                                
                                	IN ERROR GIANT
                                	**type**\:  :py:class:`InErrorGiant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InErrorGiant>`
                                
                                .. attribute:: in_error_runt
                                
                                	IN ERROR RUNT
                                	**type**\:  :py:class:`InErrorRunt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InErrorRunt>`
                                
                                .. attribute:: in_error_jabbers
                                
                                	IN ERROR JABBERS
                                	**type**\:  :py:class:`InErrorJabbers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InErrorJabbers>`
                                
                                .. attribute:: in_error_fragments
                                
                                	IN ERROR FRAGMENTS
                                	**type**\:  :py:class:`InErrorFragments <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InErrorFragments>`
                                
                                .. attribute:: in_error_other
                                
                                	IN ERROR OTHER
                                	**type**\:  :py:class:`InErrorOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InErrorOther>`
                                
                                .. attribute:: in_pkt64_octet
                                
                                	IN PKT 64 OCTET
                                	**type**\:  :py:class:`InPkt64Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InPkt64Octet>`
                                
                                .. attribute:: in_pkts65_to127_octets
                                
                                	IN PKTS 65 127OCTETS
                                	**type**\:  :py:class:`InPkts65To127Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InPkts65To127Octets>`
                                
                                .. attribute:: in_pkts128_to255_octets
                                
                                	IN PKTS 128 255 OCTETS
                                	**type**\:  :py:class:`InPkts128To255Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InPkts128To255Octets>`
                                
                                .. attribute:: in_pkts256_to511_octets
                                
                                	IN PKTS 256 511 OCTETS
                                	**type**\:  :py:class:`InPkts256To511Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InPkts256To511Octets>`
                                
                                .. attribute:: in_pkts512_to1023_octets
                                
                                	IN PKTS 512 1023 OCTETS
                                	**type**\:  :py:class:`InPkts512To1023Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InPkts512To1023Octets>`
                                
                                .. attribute:: in_pkts1024_to1518_octets
                                
                                	IN PKTS 1024 1518 OCTETS
                                	**type**\:  :py:class:`InPkts1024To1518Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InPkts1024To1518Octets>`
                                
                                .. attribute:: outpkt64octet
                                
                                	OUT PKT 64 OCTET
                                	**type**\:  :py:class:`Outpkt64octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.Outpkt64octet>`
                                
                                .. attribute:: out_pkts65127_octets
                                
                                	OUT PKTS 65 127OCTETS
                                	**type**\:  :py:class:`OutPkts65127Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutPkts65127Octets>`
                                
                                .. attribute:: out_pkts128255_octets
                                
                                	OUT PKTS 128 255 OCTETS
                                	**type**\:  :py:class:`OutPkts128255Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutPkts128255Octets>`
                                
                                .. attribute:: out_pkts256511_octets
                                
                                	OUT PKTS 256 511 OCTETS
                                	**type**\:  :py:class:`OutPkts256511Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutPkts256511Octets>`
                                
                                .. attribute:: out_pkts5121023_octets
                                
                                	OUT PKTS 512 1023 OCTETS
                                	**type**\:  :py:class:`OutPkts5121023Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutPkts5121023Octets>`
                                
                                .. attribute:: out_pkts10241518_octets
                                
                                	OUT PKTS 1024 1518 OCTETS
                                	**type**\:  :py:class:`OutPkts10241518Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutPkts10241518Octets>`
                                
                                .. attribute:: rx_util
                                
                                	Rx Utilization in Percent
                                	**type**\:  :py:class:`RxUtil <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.RxUtil>`
                                
                                .. attribute:: tx_util
                                
                                	Tx Utilization in Percent
                                	**type**\:  :py:class:`TxUtil <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.TxUtil>`
                                
                                .. attribute:: tx_undersized_pkt
                                
                                	TX Undersized Pkt
                                	**type**\:  :py:class:`TxUndersizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.TxUndersizedPkt>`
                                
                                .. attribute:: tx_oversized_pkt
                                
                                	TX Oversized Pkt
                                	**type**\:  :py:class:`TxOversizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.TxOversizedPkt>`
                                
                                .. attribute:: tx_fragments
                                
                                	TX Fragments
                                	**type**\:  :py:class:`TxFragments <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.TxFragments>`
                                
                                .. attribute:: tx_jabber
                                
                                	TX Jabber
                                	**type**\:  :py:class:`TxJabber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.TxJabber>`
                                
                                .. attribute:: tx_bad_fcs
                                
                                	TX Bad Fcs
                                	**type**\:  :py:class:`TxBadFcs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.TxBadFcs>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether, self).__init__()

                                    self.yang_name = "macsec-second30-ether"
                                    self.yang_parent_name = "macsec-second30-ether-s"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("rx-pkt", ("rx_pkt", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.RxPkt)), ("stat-pkt", ("stat_pkt", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.StatPkt)), ("octet-stat", ("octet_stat", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OctetStat)), ("oversize-pkt-stat", ("oversize_pkt_stat", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OversizePktStat)), ("fcs-errors-stat", ("fcs_errors_stat", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.FcsErrorsStat)), ("long-frames-stat", ("long_frames_stat", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.LongFramesStat)), ("jabber-stat", ("jabber_stat", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.JabberStat)), ("ether64-octets", ("ether64_octets", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.Ether64Octets)), ("ether65127-octet", ("ether65127_octet", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.Ether65127Octet)), ("ether128255-octet", ("ether128255_octet", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.Ether128255Octet)), ("ether256511-octet", ("ether256511_octet", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.Ether256511Octet)), ("ether5121023-octet", ("ether5121023_octet", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.Ether5121023Octet)), ("ether10241518-octet", ("ether10241518_octet", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.Ether10241518Octet)), ("in-ucast-pkt", ("in_ucast_pkt", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InUcastPkt)), ("in-mcast-pkt", ("in_mcast_pkt", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InMcastPkt)), ("in-bcast-pkt", ("in_bcast_pkt", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InBcastPkt)), ("out-ucast-pkt", ("out_ucast_pkt", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutUcastPkt)), ("out-bcast-pkt", ("out_bcast_pkt", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutBcastPkt)), ("out-mcast-pkt", ("out_mcast_pkt", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutMcastPkt)), ("tx-pkt", ("tx_pkt", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.TxPkt)), ("if-in-errors", ("if_in_errors", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.IfInErrors)), ("if-in-octets", ("if_in_octets", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.IfInOctets)), ("ether-stat-multicast-pkt", ("ether_stat_multicast_pkt", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.EtherStatMulticastPkt)), ("ether-stat-broadcast-pkt", ("ether_stat_broadcast_pkt", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.EtherStatBroadcastPkt)), ("ether-stat-undersized-pkt", ("ether_stat_undersized_pkt", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.EtherStatUndersizedPkt)), ("out-octets", ("out_octets", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutOctets)), ("in-pause-frame", ("in_pause_frame", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InPauseFrame)), ("in-good-bytes", ("in_good_bytes", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InGoodBytes)), ("in8021q-frames", ("in8021q_frames", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.In8021qFrames)), ("in-pkts1519-max-octets", ("in_pkts1519_max_octets", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InPkts1519MaxOctets)), ("in-good-pkts", ("in_good_pkts", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InGoodPkts)), ("in-drop-overrun", ("in_drop_overrun", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InDropOverrun)), ("in-drop-abort", ("in_drop_abort", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InDropAbort)), ("in-drop-invalid-vlan", ("in_drop_invalid_vlan", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InDropInvalidVlan)), ("in-drop-invalid-dmac", ("in_drop_invalid_dmac", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InDropInvalidDmac)), ("in-drop-invalid-encap", ("in_drop_invalid_encap", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InDropInvalidEncap)), ("in-drop-other", ("in_drop_other", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InDropOther)), ("in-mib-giant", ("in_mib_giant", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InMibGiant)), ("in-mib-jabber", ("in_mib_jabber", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InMibJabber)), ("in-mibcrc", ("in_mibcrc", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InMibcrc)), ("in-error-collisions", ("in_error_collisions", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InErrorCollisions)), ("in-error-symbol", ("in_error_symbol", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InErrorSymbol)), ("out-good-bytes", ("out_good_bytes", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutGoodBytes)), ("out8021q-frames", ("out8021q_frames", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.Out8021qFrames)), ("out-pause-frames", ("out_pause_frames", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutPauseFrames)), ("out-pkts1519-max-octets", ("out_pkts1519_max_octets", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutPkts1519MaxOctets)), ("out-good-pkts", ("out_good_pkts", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutGoodPkts)), ("out-drop-underrun", ("out_drop_underrun", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutDropUnderrun)), ("out-drop-abort", ("out_drop_abort", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutDropAbort)), ("out-drop-other", ("out_drop_other", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutDropOther)), ("out-error-other", ("out_error_other", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutErrorOther)), ("in-error-giant", ("in_error_giant", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InErrorGiant)), ("in-error-runt", ("in_error_runt", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InErrorRunt)), ("in-error-jabbers", ("in_error_jabbers", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InErrorJabbers)), ("in-error-fragments", ("in_error_fragments", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InErrorFragments)), ("in-error-other", ("in_error_other", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InErrorOther)), ("in-pkt64-octet", ("in_pkt64_octet", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InPkt64Octet)), ("in-pkts65-to127-octets", ("in_pkts65_to127_octets", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InPkts65To127Octets)), ("in-pkts128-to255-octets", ("in_pkts128_to255_octets", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InPkts128To255Octets)), ("in-pkts256-to511-octets", ("in_pkts256_to511_octets", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InPkts256To511Octets)), ("in-pkts512-to1023-octets", ("in_pkts512_to1023_octets", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InPkts512To1023Octets)), ("in-pkts1024-to1518-octets", ("in_pkts1024_to1518_octets", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InPkts1024To1518Octets)), ("outpkt64octet", ("outpkt64octet", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.Outpkt64octet)), ("out-pkts65127-octets", ("out_pkts65127_octets", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutPkts65127Octets)), ("out-pkts128255-octets", ("out_pkts128255_octets", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutPkts128255Octets)), ("out-pkts256511-octets", ("out_pkts256511_octets", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutPkts256511Octets)), ("out-pkts5121023-octets", ("out_pkts5121023_octets", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutPkts5121023Octets)), ("out-pkts10241518-octets", ("out_pkts10241518_octets", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutPkts10241518Octets)), ("rx-util", ("rx_util", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.RxUtil)), ("tx-util", ("tx_util", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.TxUtil)), ("tx-undersized-pkt", ("tx_undersized_pkt", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.TxUndersizedPkt)), ("tx-oversized-pkt", ("tx_oversized_pkt", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.TxOversizedPkt)), ("tx-fragments", ("tx_fragments", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.TxFragments)), ("tx-jabber", ("tx_jabber", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.TxJabber)), ("tx-bad-fcs", ("tx_bad_fcs", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.TxBadFcs))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                        ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                    ])
                                    self.number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None
                                    self.sec30_support = None

                                    self.rx_pkt = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.RxPkt()
                                    self.rx_pkt.parent = self
                                    self._children_name_map["rx_pkt"] = "rx-pkt"

                                    self.stat_pkt = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.StatPkt()
                                    self.stat_pkt.parent = self
                                    self._children_name_map["stat_pkt"] = "stat-pkt"

                                    self.octet_stat = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OctetStat()
                                    self.octet_stat.parent = self
                                    self._children_name_map["octet_stat"] = "octet-stat"

                                    self.oversize_pkt_stat = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OversizePktStat()
                                    self.oversize_pkt_stat.parent = self
                                    self._children_name_map["oversize_pkt_stat"] = "oversize-pkt-stat"

                                    self.fcs_errors_stat = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.FcsErrorsStat()
                                    self.fcs_errors_stat.parent = self
                                    self._children_name_map["fcs_errors_stat"] = "fcs-errors-stat"

                                    self.long_frames_stat = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.LongFramesStat()
                                    self.long_frames_stat.parent = self
                                    self._children_name_map["long_frames_stat"] = "long-frames-stat"

                                    self.jabber_stat = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.JabberStat()
                                    self.jabber_stat.parent = self
                                    self._children_name_map["jabber_stat"] = "jabber-stat"

                                    self.ether64_octets = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.Ether64Octets()
                                    self.ether64_octets.parent = self
                                    self._children_name_map["ether64_octets"] = "ether64-octets"

                                    self.ether65127_octet = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.Ether65127Octet()
                                    self.ether65127_octet.parent = self
                                    self._children_name_map["ether65127_octet"] = "ether65127-octet"

                                    self.ether128255_octet = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.Ether128255Octet()
                                    self.ether128255_octet.parent = self
                                    self._children_name_map["ether128255_octet"] = "ether128255-octet"

                                    self.ether256511_octet = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.Ether256511Octet()
                                    self.ether256511_octet.parent = self
                                    self._children_name_map["ether256511_octet"] = "ether256511-octet"

                                    self.ether5121023_octet = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.Ether5121023Octet()
                                    self.ether5121023_octet.parent = self
                                    self._children_name_map["ether5121023_octet"] = "ether5121023-octet"

                                    self.ether10241518_octet = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.Ether10241518Octet()
                                    self.ether10241518_octet.parent = self
                                    self._children_name_map["ether10241518_octet"] = "ether10241518-octet"

                                    self.in_ucast_pkt = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InUcastPkt()
                                    self.in_ucast_pkt.parent = self
                                    self._children_name_map["in_ucast_pkt"] = "in-ucast-pkt"

                                    self.in_mcast_pkt = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InMcastPkt()
                                    self.in_mcast_pkt.parent = self
                                    self._children_name_map["in_mcast_pkt"] = "in-mcast-pkt"

                                    self.in_bcast_pkt = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InBcastPkt()
                                    self.in_bcast_pkt.parent = self
                                    self._children_name_map["in_bcast_pkt"] = "in-bcast-pkt"

                                    self.out_ucast_pkt = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutUcastPkt()
                                    self.out_ucast_pkt.parent = self
                                    self._children_name_map["out_ucast_pkt"] = "out-ucast-pkt"

                                    self.out_bcast_pkt = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutBcastPkt()
                                    self.out_bcast_pkt.parent = self
                                    self._children_name_map["out_bcast_pkt"] = "out-bcast-pkt"

                                    self.out_mcast_pkt = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutMcastPkt()
                                    self.out_mcast_pkt.parent = self
                                    self._children_name_map["out_mcast_pkt"] = "out-mcast-pkt"

                                    self.tx_pkt = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.TxPkt()
                                    self.tx_pkt.parent = self
                                    self._children_name_map["tx_pkt"] = "tx-pkt"

                                    self.if_in_errors = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.IfInErrors()
                                    self.if_in_errors.parent = self
                                    self._children_name_map["if_in_errors"] = "if-in-errors"

                                    self.if_in_octets = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.IfInOctets()
                                    self.if_in_octets.parent = self
                                    self._children_name_map["if_in_octets"] = "if-in-octets"

                                    self.ether_stat_multicast_pkt = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.EtherStatMulticastPkt()
                                    self.ether_stat_multicast_pkt.parent = self
                                    self._children_name_map["ether_stat_multicast_pkt"] = "ether-stat-multicast-pkt"

                                    self.ether_stat_broadcast_pkt = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.EtherStatBroadcastPkt()
                                    self.ether_stat_broadcast_pkt.parent = self
                                    self._children_name_map["ether_stat_broadcast_pkt"] = "ether-stat-broadcast-pkt"

                                    self.ether_stat_undersized_pkt = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.EtherStatUndersizedPkt()
                                    self.ether_stat_undersized_pkt.parent = self
                                    self._children_name_map["ether_stat_undersized_pkt"] = "ether-stat-undersized-pkt"

                                    self.out_octets = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutOctets()
                                    self.out_octets.parent = self
                                    self._children_name_map["out_octets"] = "out-octets"

                                    self.in_pause_frame = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InPauseFrame()
                                    self.in_pause_frame.parent = self
                                    self._children_name_map["in_pause_frame"] = "in-pause-frame"

                                    self.in_good_bytes = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InGoodBytes()
                                    self.in_good_bytes.parent = self
                                    self._children_name_map["in_good_bytes"] = "in-good-bytes"

                                    self.in8021q_frames = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.In8021qFrames()
                                    self.in8021q_frames.parent = self
                                    self._children_name_map["in8021q_frames"] = "in8021q-frames"

                                    self.in_pkts1519_max_octets = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InPkts1519MaxOctets()
                                    self.in_pkts1519_max_octets.parent = self
                                    self._children_name_map["in_pkts1519_max_octets"] = "in-pkts1519-max-octets"

                                    self.in_good_pkts = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InGoodPkts()
                                    self.in_good_pkts.parent = self
                                    self._children_name_map["in_good_pkts"] = "in-good-pkts"

                                    self.in_drop_overrun = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InDropOverrun()
                                    self.in_drop_overrun.parent = self
                                    self._children_name_map["in_drop_overrun"] = "in-drop-overrun"

                                    self.in_drop_abort = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InDropAbort()
                                    self.in_drop_abort.parent = self
                                    self._children_name_map["in_drop_abort"] = "in-drop-abort"

                                    self.in_drop_invalid_vlan = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InDropInvalidVlan()
                                    self.in_drop_invalid_vlan.parent = self
                                    self._children_name_map["in_drop_invalid_vlan"] = "in-drop-invalid-vlan"

                                    self.in_drop_invalid_dmac = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InDropInvalidDmac()
                                    self.in_drop_invalid_dmac.parent = self
                                    self._children_name_map["in_drop_invalid_dmac"] = "in-drop-invalid-dmac"

                                    self.in_drop_invalid_encap = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InDropInvalidEncap()
                                    self.in_drop_invalid_encap.parent = self
                                    self._children_name_map["in_drop_invalid_encap"] = "in-drop-invalid-encap"

                                    self.in_drop_other = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InDropOther()
                                    self.in_drop_other.parent = self
                                    self._children_name_map["in_drop_other"] = "in-drop-other"

                                    self.in_mib_giant = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InMibGiant()
                                    self.in_mib_giant.parent = self
                                    self._children_name_map["in_mib_giant"] = "in-mib-giant"

                                    self.in_mib_jabber = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InMibJabber()
                                    self.in_mib_jabber.parent = self
                                    self._children_name_map["in_mib_jabber"] = "in-mib-jabber"

                                    self.in_mibcrc = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InMibcrc()
                                    self.in_mibcrc.parent = self
                                    self._children_name_map["in_mibcrc"] = "in-mibcrc"

                                    self.in_error_collisions = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InErrorCollisions()
                                    self.in_error_collisions.parent = self
                                    self._children_name_map["in_error_collisions"] = "in-error-collisions"

                                    self.in_error_symbol = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InErrorSymbol()
                                    self.in_error_symbol.parent = self
                                    self._children_name_map["in_error_symbol"] = "in-error-symbol"

                                    self.out_good_bytes = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutGoodBytes()
                                    self.out_good_bytes.parent = self
                                    self._children_name_map["out_good_bytes"] = "out-good-bytes"

                                    self.out8021q_frames = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.Out8021qFrames()
                                    self.out8021q_frames.parent = self
                                    self._children_name_map["out8021q_frames"] = "out8021q-frames"

                                    self.out_pause_frames = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutPauseFrames()
                                    self.out_pause_frames.parent = self
                                    self._children_name_map["out_pause_frames"] = "out-pause-frames"

                                    self.out_pkts1519_max_octets = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutPkts1519MaxOctets()
                                    self.out_pkts1519_max_octets.parent = self
                                    self._children_name_map["out_pkts1519_max_octets"] = "out-pkts1519-max-octets"

                                    self.out_good_pkts = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutGoodPkts()
                                    self.out_good_pkts.parent = self
                                    self._children_name_map["out_good_pkts"] = "out-good-pkts"

                                    self.out_drop_underrun = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutDropUnderrun()
                                    self.out_drop_underrun.parent = self
                                    self._children_name_map["out_drop_underrun"] = "out-drop-underrun"

                                    self.out_drop_abort = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutDropAbort()
                                    self.out_drop_abort.parent = self
                                    self._children_name_map["out_drop_abort"] = "out-drop-abort"

                                    self.out_drop_other = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutDropOther()
                                    self.out_drop_other.parent = self
                                    self._children_name_map["out_drop_other"] = "out-drop-other"

                                    self.out_error_other = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutErrorOther()
                                    self.out_error_other.parent = self
                                    self._children_name_map["out_error_other"] = "out-error-other"

                                    self.in_error_giant = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InErrorGiant()
                                    self.in_error_giant.parent = self
                                    self._children_name_map["in_error_giant"] = "in-error-giant"

                                    self.in_error_runt = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InErrorRunt()
                                    self.in_error_runt.parent = self
                                    self._children_name_map["in_error_runt"] = "in-error-runt"

                                    self.in_error_jabbers = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InErrorJabbers()
                                    self.in_error_jabbers.parent = self
                                    self._children_name_map["in_error_jabbers"] = "in-error-jabbers"

                                    self.in_error_fragments = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InErrorFragments()
                                    self.in_error_fragments.parent = self
                                    self._children_name_map["in_error_fragments"] = "in-error-fragments"

                                    self.in_error_other = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InErrorOther()
                                    self.in_error_other.parent = self
                                    self._children_name_map["in_error_other"] = "in-error-other"

                                    self.in_pkt64_octet = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InPkt64Octet()
                                    self.in_pkt64_octet.parent = self
                                    self._children_name_map["in_pkt64_octet"] = "in-pkt64-octet"

                                    self.in_pkts65_to127_octets = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InPkts65To127Octets()
                                    self.in_pkts65_to127_octets.parent = self
                                    self._children_name_map["in_pkts65_to127_octets"] = "in-pkts65-to127-octets"

                                    self.in_pkts128_to255_octets = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InPkts128To255Octets()
                                    self.in_pkts128_to255_octets.parent = self
                                    self._children_name_map["in_pkts128_to255_octets"] = "in-pkts128-to255-octets"

                                    self.in_pkts256_to511_octets = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InPkts256To511Octets()
                                    self.in_pkts256_to511_octets.parent = self
                                    self._children_name_map["in_pkts256_to511_octets"] = "in-pkts256-to511-octets"

                                    self.in_pkts512_to1023_octets = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InPkts512To1023Octets()
                                    self.in_pkts512_to1023_octets.parent = self
                                    self._children_name_map["in_pkts512_to1023_octets"] = "in-pkts512-to1023-octets"

                                    self.in_pkts1024_to1518_octets = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InPkts1024To1518Octets()
                                    self.in_pkts1024_to1518_octets.parent = self
                                    self._children_name_map["in_pkts1024_to1518_octets"] = "in-pkts1024-to1518-octets"

                                    self.outpkt64octet = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.Outpkt64octet()
                                    self.outpkt64octet.parent = self
                                    self._children_name_map["outpkt64octet"] = "outpkt64octet"

                                    self.out_pkts65127_octets = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutPkts65127Octets()
                                    self.out_pkts65127_octets.parent = self
                                    self._children_name_map["out_pkts65127_octets"] = "out-pkts65127-octets"

                                    self.out_pkts128255_octets = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutPkts128255Octets()
                                    self.out_pkts128255_octets.parent = self
                                    self._children_name_map["out_pkts128255_octets"] = "out-pkts128255-octets"

                                    self.out_pkts256511_octets = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutPkts256511Octets()
                                    self.out_pkts256511_octets.parent = self
                                    self._children_name_map["out_pkts256511_octets"] = "out-pkts256511-octets"

                                    self.out_pkts5121023_octets = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutPkts5121023Octets()
                                    self.out_pkts5121023_octets.parent = self
                                    self._children_name_map["out_pkts5121023_octets"] = "out-pkts5121023-octets"

                                    self.out_pkts10241518_octets = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutPkts10241518Octets()
                                    self.out_pkts10241518_octets.parent = self
                                    self._children_name_map["out_pkts10241518_octets"] = "out-pkts10241518-octets"

                                    self.rx_util = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.RxUtil()
                                    self.rx_util.parent = self
                                    self._children_name_map["rx_util"] = "rx-util"

                                    self.tx_util = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.TxUtil()
                                    self.tx_util.parent = self
                                    self._children_name_map["tx_util"] = "tx-util"

                                    self.tx_undersized_pkt = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.TxUndersizedPkt()
                                    self.tx_undersized_pkt.parent = self
                                    self._children_name_map["tx_undersized_pkt"] = "tx-undersized-pkt"

                                    self.tx_oversized_pkt = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.TxOversizedPkt()
                                    self.tx_oversized_pkt.parent = self
                                    self._children_name_map["tx_oversized_pkt"] = "tx-oversized-pkt"

                                    self.tx_fragments = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.TxFragments()
                                    self.tx_fragments.parent = self
                                    self._children_name_map["tx_fragments"] = "tx-fragments"

                                    self.tx_jabber = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.TxJabber()
                                    self.tx_jabber.parent = self
                                    self._children_name_map["tx_jabber"] = "tx-jabber"

                                    self.tx_bad_fcs = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.TxBadFcs()
                                    self.tx_bad_fcs.parent = self
                                    self._children_name_map["tx_bad_fcs"] = "tx-bad-fcs"
                                    self._segment_path = lambda: "macsec-second30-ether" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear30_sec_time', 'last_clear15_min_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                class RxPkt(Entity):
                                    """
                                    RX PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.RxPkt, self).__init__()

                                        self.yang_name = "rx-pkt"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "rx-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.RxPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class StatPkt(Entity):
                                    """
                                    STAT PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.StatPkt, self).__init__()

                                        self.yang_name = "stat-pkt"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "stat-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.StatPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OctetStat(Entity):
                                    """
                                    OCTET STAT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OctetStat, self).__init__()

                                        self.yang_name = "octet-stat"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "octet-stat"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OctetStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OversizePktStat(Entity):
                                    """
                                    OVERSIZE PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OversizePktStat, self).__init__()

                                        self.yang_name = "oversize-pkt-stat"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "oversize-pkt-stat"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OversizePktStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class FcsErrorsStat(Entity):
                                    """
                                    FCS ERR
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.FcsErrorsStat, self).__init__()

                                        self.yang_name = "fcs-errors-stat"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "fcs-errors-stat"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.FcsErrorsStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class LongFramesStat(Entity):
                                    """
                                    LONG FRAMES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.LongFramesStat, self).__init__()

                                        self.yang_name = "long-frames-stat"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "long-frames-stat"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.LongFramesStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class JabberStat(Entity):
                                    """
                                    JABBER STATS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.JabberStat, self).__init__()

                                        self.yang_name = "jabber-stat"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "jabber-stat"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.JabberStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class Ether64Octets(Entity):
                                    """
                                    SIXTY FOUR OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.Ether64Octets, self).__init__()

                                        self.yang_name = "ether64-octets"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ether64-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.Ether64Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class Ether65127Octet(Entity):
                                    """
                                    OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.Ether65127Octet, self).__init__()

                                        self.yang_name = "ether65127-octet"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ether65127-octet"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.Ether65127Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class Ether128255Octet(Entity):
                                    """
                                    TFF OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.Ether128255Octet, self).__init__()

                                        self.yang_name = "ether128255-octet"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ether128255-octet"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.Ether128255Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class Ether256511Octet(Entity):
                                    """
                                    FOO OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.Ether256511Octet, self).__init__()

                                        self.yang_name = "ether256511-octet"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ether256511-octet"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.Ether256511Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class Ether5121023Octet(Entity):
                                    """
                                    OZTT OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.Ether5121023Octet, self).__init__()

                                        self.yang_name = "ether5121023-octet"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ether5121023-octet"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.Ether5121023Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class Ether10241518Octet(Entity):
                                    """
                                    OFO OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.Ether10241518Octet, self).__init__()

                                        self.yang_name = "ether10241518-octet"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ether10241518-octet"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.Ether10241518Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InUcastPkt(Entity):
                                    """
                                    IN UCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InUcastPkt, self).__init__()

                                        self.yang_name = "in-ucast-pkt"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-ucast-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InUcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InMcastPkt(Entity):
                                    """
                                    IN MCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InMcastPkt, self).__init__()

                                        self.yang_name = "in-mcast-pkt"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-mcast-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InMcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InBcastPkt(Entity):
                                    """
                                    IN BCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InBcastPkt, self).__init__()

                                        self.yang_name = "in-bcast-pkt"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-bcast-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InBcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutUcastPkt(Entity):
                                    """
                                    OUT UCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutUcastPkt, self).__init__()

                                        self.yang_name = "out-ucast-pkt"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-ucast-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutUcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutBcastPkt(Entity):
                                    """
                                    OUT BCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutBcastPkt, self).__init__()

                                        self.yang_name = "out-bcast-pkt"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-bcast-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutBcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutMcastPkt(Entity):
                                    """
                                    OUT MCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutMcastPkt, self).__init__()

                                        self.yang_name = "out-mcast-pkt"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-mcast-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutMcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class TxPkt(Entity):
                                    """
                                    TX PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.TxPkt, self).__init__()

                                        self.yang_name = "tx-pkt"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "tx-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.TxPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class IfInErrors(Entity):
                                    """
                                    IFIN ERRORS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.IfInErrors, self).__init__()

                                        self.yang_name = "if-in-errors"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "if-in-errors"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.IfInErrors, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class IfInOctets(Entity):
                                    """
                                    IFIN OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.IfInOctets, self).__init__()

                                        self.yang_name = "if-in-octets"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "if-in-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.IfInOctets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class EtherStatMulticastPkt(Entity):
                                    """
                                    ETHER STAT MULTICAST PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.EtherStatMulticastPkt, self).__init__()

                                        self.yang_name = "ether-stat-multicast-pkt"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ether-stat-multicast-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.EtherStatMulticastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class EtherStatBroadcastPkt(Entity):
                                    """
                                    ETHER STAT BROADCAST PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.EtherStatBroadcastPkt, self).__init__()

                                        self.yang_name = "ether-stat-broadcast-pkt"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ether-stat-broadcast-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.EtherStatBroadcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class EtherStatUndersizedPkt(Entity):
                                    """
                                    ETHER STAT UNDERSIZED PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.EtherStatUndersizedPkt, self).__init__()

                                        self.yang_name = "ether-stat-undersized-pkt"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ether-stat-undersized-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.EtherStatUndersizedPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutOctets(Entity):
                                    """
                                    OUT OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutOctets, self).__init__()

                                        self.yang_name = "out-octets"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutOctets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPauseFrame(Entity):
                                    """
                                    INPUT PAUSE FRAME
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InPauseFrame, self).__init__()

                                        self.yang_name = "in-pause-frame"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pause-frame"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InPauseFrame, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InGoodBytes(Entity):
                                    """
                                    INPUT GOOD BYTES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InGoodBytes, self).__init__()

                                        self.yang_name = "in-good-bytes"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-good-bytes"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InGoodBytes, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class In8021qFrames(Entity):
                                    """
                                    INPUT 802 1Q FRAMES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.In8021qFrames, self).__init__()

                                        self.yang_name = "in8021q-frames"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in8021q-frames"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.In8021qFrames, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPkts1519MaxOctets(Entity):
                                    """
                                    INPUT PKTS 1519MAX OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InPkts1519MaxOctets, self).__init__()

                                        self.yang_name = "in-pkts1519-max-octets"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts1519-max-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InPkts1519MaxOctets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InGoodPkts(Entity):
                                    """
                                    INPUT GOOD PKTS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InGoodPkts, self).__init__()

                                        self.yang_name = "in-good-pkts"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-good-pkts"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InGoodPkts, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InDropOverrun(Entity):
                                    """
                                    INPUT DROP OVERRUN
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InDropOverrun, self).__init__()

                                        self.yang_name = "in-drop-overrun"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-drop-overrun"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InDropOverrun, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InDropAbort(Entity):
                                    """
                                    INPUT DROP ABORT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InDropAbort, self).__init__()

                                        self.yang_name = "in-drop-abort"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-drop-abort"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InDropAbort, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InDropInvalidVlan(Entity):
                                    """
                                    INPUT DROP INVALID VLAN
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InDropInvalidVlan, self).__init__()

                                        self.yang_name = "in-drop-invalid-vlan"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-drop-invalid-vlan"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InDropInvalidVlan, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InDropInvalidDmac(Entity):
                                    """
                                    INPUT DROP INVALID DMAC
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InDropInvalidDmac, self).__init__()

                                        self.yang_name = "in-drop-invalid-dmac"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-drop-invalid-dmac"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InDropInvalidDmac, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InDropInvalidEncap(Entity):
                                    """
                                    INPUT DROP INVALID ENCAP
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InDropInvalidEncap, self).__init__()

                                        self.yang_name = "in-drop-invalid-encap"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-drop-invalid-encap"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InDropInvalidEncap, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InDropOther(Entity):
                                    """
                                    INPUT DROP OTHER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InDropOther, self).__init__()

                                        self.yang_name = "in-drop-other"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-drop-other"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InDropOther, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InMibGiant(Entity):
                                    """
                                    INPUT MIB GIANT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InMibGiant, self).__init__()

                                        self.yang_name = "in-mib-giant"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-mib-giant"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InMibGiant, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InMibJabber(Entity):
                                    """
                                    INPUT MIB JABBER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InMibJabber, self).__init__()

                                        self.yang_name = "in-mib-jabber"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-mib-jabber"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InMibJabber, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InMibcrc(Entity):
                                    """
                                    IN MIB CRC
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InMibcrc, self).__init__()

                                        self.yang_name = "in-mibcrc"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-mibcrc"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InMibcrc, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InErrorCollisions(Entity):
                                    """
                                    IN ERROR COLLISIONS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InErrorCollisions, self).__init__()

                                        self.yang_name = "in-error-collisions"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-error-collisions"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InErrorCollisions, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InErrorSymbol(Entity):
                                    """
                                    IN ERROR SYMBOL
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InErrorSymbol, self).__init__()

                                        self.yang_name = "in-error-symbol"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-error-symbol"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InErrorSymbol, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutGoodBytes(Entity):
                                    """
                                    OUT GOOD BYTES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutGoodBytes, self).__init__()

                                        self.yang_name = "out-good-bytes"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-good-bytes"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutGoodBytes, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class Out8021qFrames(Entity):
                                    """
                                    OUT 802 1Q FRAMES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.Out8021qFrames, self).__init__()

                                        self.yang_name = "out8021q-frames"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out8021q-frames"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.Out8021qFrames, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutPauseFrames(Entity):
                                    """
                                    OUT PAUSE FRAMES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutPauseFrames, self).__init__()

                                        self.yang_name = "out-pause-frames"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-pause-frames"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutPauseFrames, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutPkts1519MaxOctets(Entity):
                                    """
                                    OUT PKTS 1519 MAX OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutPkts1519MaxOctets, self).__init__()

                                        self.yang_name = "out-pkts1519-max-octets"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-pkts1519-max-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutPkts1519MaxOctets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutGoodPkts(Entity):
                                    """
                                    OUT GOOD PKTS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutGoodPkts, self).__init__()

                                        self.yang_name = "out-good-pkts"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-good-pkts"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutGoodPkts, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutDropUnderrun(Entity):
                                    """
                                    OUT DROP UNDERRUN
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutDropUnderrun, self).__init__()

                                        self.yang_name = "out-drop-underrun"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-drop-underrun"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutDropUnderrun, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutDropAbort(Entity):
                                    """
                                    OUT DROP ABORT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutDropAbort, self).__init__()

                                        self.yang_name = "out-drop-abort"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-drop-abort"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutDropAbort, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutDropOther(Entity):
                                    """
                                    OUT DROP OTHER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutDropOther, self).__init__()

                                        self.yang_name = "out-drop-other"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-drop-other"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutDropOther, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutErrorOther(Entity):
                                    """
                                    OUT ERROR OTHER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutErrorOther, self).__init__()

                                        self.yang_name = "out-error-other"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-error-other"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutErrorOther, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InErrorGiant(Entity):
                                    """
                                    IN ERROR GIANT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InErrorGiant, self).__init__()

                                        self.yang_name = "in-error-giant"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-error-giant"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InErrorGiant, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InErrorRunt(Entity):
                                    """
                                    IN ERROR RUNT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InErrorRunt, self).__init__()

                                        self.yang_name = "in-error-runt"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-error-runt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InErrorRunt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InErrorJabbers(Entity):
                                    """
                                    IN ERROR JABBERS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InErrorJabbers, self).__init__()

                                        self.yang_name = "in-error-jabbers"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-error-jabbers"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InErrorJabbers, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InErrorFragments(Entity):
                                    """
                                    IN ERROR FRAGMENTS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InErrorFragments, self).__init__()

                                        self.yang_name = "in-error-fragments"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-error-fragments"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InErrorFragments, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InErrorOther(Entity):
                                    """
                                    IN ERROR OTHER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InErrorOther, self).__init__()

                                        self.yang_name = "in-error-other"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-error-other"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InErrorOther, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPkt64Octet(Entity):
                                    """
                                    IN PKT 64 OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InPkt64Octet, self).__init__()

                                        self.yang_name = "in-pkt64-octet"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkt64-octet"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InPkt64Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPkts65To127Octets(Entity):
                                    """
                                    IN PKTS 65 127OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InPkts65To127Octets, self).__init__()

                                        self.yang_name = "in-pkts65-to127-octets"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts65-to127-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InPkts65To127Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPkts128To255Octets(Entity):
                                    """
                                    IN PKTS 128 255 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InPkts128To255Octets, self).__init__()

                                        self.yang_name = "in-pkts128-to255-octets"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts128-to255-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InPkts128To255Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPkts256To511Octets(Entity):
                                    """
                                    IN PKTS 256 511 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InPkts256To511Octets, self).__init__()

                                        self.yang_name = "in-pkts256-to511-octets"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts256-to511-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InPkts256To511Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPkts512To1023Octets(Entity):
                                    """
                                    IN PKTS 512 1023 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InPkts512To1023Octets, self).__init__()

                                        self.yang_name = "in-pkts512-to1023-octets"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts512-to1023-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InPkts512To1023Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPkts1024To1518Octets(Entity):
                                    """
                                    IN PKTS 1024 1518 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InPkts1024To1518Octets, self).__init__()

                                        self.yang_name = "in-pkts1024-to1518-octets"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts1024-to1518-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.InPkts1024To1518Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class Outpkt64octet(Entity):
                                    """
                                    OUT PKT 64 OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.Outpkt64octet, self).__init__()

                                        self.yang_name = "outpkt64octet"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "outpkt64octet"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.Outpkt64octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutPkts65127Octets(Entity):
                                    """
                                    OUT PKTS 65 127OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutPkts65127Octets, self).__init__()

                                        self.yang_name = "out-pkts65127-octets"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-pkts65127-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutPkts65127Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutPkts128255Octets(Entity):
                                    """
                                    OUT PKTS 128 255 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutPkts128255Octets, self).__init__()

                                        self.yang_name = "out-pkts128255-octets"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-pkts128255-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutPkts128255Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutPkts256511Octets(Entity):
                                    """
                                    OUT PKTS 256 511 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutPkts256511Octets, self).__init__()

                                        self.yang_name = "out-pkts256511-octets"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-pkts256511-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutPkts256511Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutPkts5121023Octets(Entity):
                                    """
                                    OUT PKTS 512 1023 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutPkts5121023Octets, self).__init__()

                                        self.yang_name = "out-pkts5121023-octets"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-pkts5121023-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutPkts5121023Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutPkts10241518Octets(Entity):
                                    """
                                    OUT PKTS 1024 1518 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutPkts10241518Octets, self).__init__()

                                        self.yang_name = "out-pkts10241518-octets"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-pkts10241518-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.OutPkts10241518Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class RxUtil(Entity):
                                    """
                                    Rx Utilization in Percent
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: str
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.RxUtil, self).__init__()

                                        self.yang_name = "rx-util"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "rx-util"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.RxUtil, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class TxUtil(Entity):
                                    """
                                    Tx Utilization in Percent
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: str
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.TxUtil, self).__init__()

                                        self.yang_name = "tx-util"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "tx-util"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.TxUtil, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class TxUndersizedPkt(Entity):
                                    """
                                    TX Undersized Pkt
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.TxUndersizedPkt, self).__init__()

                                        self.yang_name = "tx-undersized-pkt"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "tx-undersized-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.TxUndersizedPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class TxOversizedPkt(Entity):
                                    """
                                    TX Oversized Pkt
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.TxOversizedPkt, self).__init__()

                                        self.yang_name = "tx-oversized-pkt"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "tx-oversized-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.TxOversizedPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class TxFragments(Entity):
                                    """
                                    TX Fragments
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.TxFragments, self).__init__()

                                        self.yang_name = "tx-fragments"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "tx-fragments"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.TxFragments, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class TxJabber(Entity):
                                    """
                                    TX Jabber
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.TxJabber, self).__init__()

                                        self.yang_name = "tx-jabber"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "tx-jabber"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.TxJabber, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class TxBadFcs(Entity):
                                    """
                                    TX Bad Fcs
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.TxBadFcs, self).__init__()

                                        self.yang_name = "tx-bad-fcs"
                                        self.yang_parent_name = "macsec-second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "tx-bad-fcs"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30EtherS.MacsecSecond30Ether.TxBadFcs, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                        class MacsecSecond30secytxes(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: macsec_second30secytx
                            
                            	port 30\-sec secy\-tx performance data
                            	**type**\: list of  		 :py:class:`MacsecSecond30secytx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secytxes.MacsecSecond30secytx>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secytxes, self).__init__()

                                self.yang_name = "macsec-second30secytxes"
                                self.yang_parent_name = "macsec-second30"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("macsec-second30secytx", ("macsec_second30secytx", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secytxes.MacsecSecond30secytx))])
                                self._leafs = OrderedDict()

                                self.macsec_second30secytx = YList(self)
                                self._segment_path = lambda: "macsec-second30secytxes"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secytxes, [], name, value)


                            class MacsecSecond30secytx(Entity):
                                """
                                port 30\-sec secy\-tx performance data
                                
                                .. attribute:: number  (key)
                                
                                	channel number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: out_pkts_protected
                                
                                	Out Packets Protected
                                	**type**\:  :py:class:`OutPktsProtected <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secytxes.MacsecSecond30secytx.OutPktsProtected>`
                                
                                .. attribute:: out_pkts_encrypted
                                
                                	Out Packets Encrypted
                                	**type**\:  :py:class:`OutPktsEncrypted <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secytxes.MacsecSecond30secytx.OutPktsEncrypted>`
                                
                                .. attribute:: out_octets_protected
                                
                                	Out Octets Protected 
                                	**type**\:  :py:class:`OutOctetsProtected <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secytxes.MacsecSecond30secytx.OutOctetsProtected>`
                                
                                .. attribute:: out_octets_encrypted
                                
                                	Out Octets Encrypted
                                	**type**\:  :py:class:`OutOctetsEncrypted <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secytxes.MacsecSecond30secytx.OutOctetsEncrypted>`
                                
                                .. attribute:: out_pkts_too_long
                                
                                	Out Packets Too Long
                                	**type**\:  :py:class:`OutPktsTooLong <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secytxes.MacsecSecond30secytx.OutPktsTooLong>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\: bool
                                
                                .. attribute:: sample_count
                                
                                	Running Sample Count
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secytxes.MacsecSecond30secytx, self).__init__()

                                    self.yang_name = "macsec-second30secytx"
                                    self.yang_parent_name = "macsec-second30secytxes"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("out-pkts-protected", ("out_pkts_protected", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secytxes.MacsecSecond30secytx.OutPktsProtected)), ("out-pkts-encrypted", ("out_pkts_encrypted", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secytxes.MacsecSecond30secytx.OutPktsEncrypted)), ("out-octets-protected", ("out_octets_protected", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secytxes.MacsecSecond30secytx.OutOctetsProtected)), ("out-octets-encrypted", ("out_octets_encrypted", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secytxes.MacsecSecond30secytx.OutOctetsEncrypted)), ("out-pkts-too-long", ("out_pkts_too_long", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secytxes.MacsecSecond30secytx.OutPktsTooLong))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                        ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                        ('sample_count', (YLeaf(YType.uint64, 'sample-count'), ['int'])),
                                    ])
                                    self.number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear24_hr_time = None
                                    self.sec30_support = None
                                    self.sample_count = None

                                    self.out_pkts_protected = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secytxes.MacsecSecond30secytx.OutPktsProtected()
                                    self.out_pkts_protected.parent = self
                                    self._children_name_map["out_pkts_protected"] = "out-pkts-protected"

                                    self.out_pkts_encrypted = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secytxes.MacsecSecond30secytx.OutPktsEncrypted()
                                    self.out_pkts_encrypted.parent = self
                                    self._children_name_map["out_pkts_encrypted"] = "out-pkts-encrypted"

                                    self.out_octets_protected = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secytxes.MacsecSecond30secytx.OutOctetsProtected()
                                    self.out_octets_protected.parent = self
                                    self._children_name_map["out_octets_protected"] = "out-octets-protected"

                                    self.out_octets_encrypted = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secytxes.MacsecSecond30secytx.OutOctetsEncrypted()
                                    self.out_octets_encrypted.parent = self
                                    self._children_name_map["out_octets_encrypted"] = "out-octets-encrypted"

                                    self.out_pkts_too_long = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secytxes.MacsecSecond30secytx.OutPktsTooLong()
                                    self.out_pkts_too_long.parent = self
                                    self._children_name_map["out_pkts_too_long"] = "out-pkts-too-long"
                                    self._segment_path = lambda: "macsec-second30secytx" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secytxes.MacsecSecond30secytx, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support', 'sample_count'], name, value)


                                class OutPktsProtected(Entity):
                                    """
                                    Out Packets Protected
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secytxes.MacsecSecond30secytx.OutPktsProtected, self).__init__()

                                        self.yang_name = "out-pkts-protected"
                                        self.yang_parent_name = "macsec-second30secytx"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-pkts-protected"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secytxes.MacsecSecond30secytx.OutPktsProtected, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutPktsEncrypted(Entity):
                                    """
                                    Out Packets Encrypted
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secytxes.MacsecSecond30secytx.OutPktsEncrypted, self).__init__()

                                        self.yang_name = "out-pkts-encrypted"
                                        self.yang_parent_name = "macsec-second30secytx"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-pkts-encrypted"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secytxes.MacsecSecond30secytx.OutPktsEncrypted, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutOctetsProtected(Entity):
                                    """
                                    Out Octets Protected 
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secytxes.MacsecSecond30secytx.OutOctetsProtected, self).__init__()

                                        self.yang_name = "out-octets-protected"
                                        self.yang_parent_name = "macsec-second30secytx"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-octets-protected"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secytxes.MacsecSecond30secytx.OutOctetsProtected, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutOctetsEncrypted(Entity):
                                    """
                                    Out Octets Encrypted
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secytxes.MacsecSecond30secytx.OutOctetsEncrypted, self).__init__()

                                        self.yang_name = "out-octets-encrypted"
                                        self.yang_parent_name = "macsec-second30secytx"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-octets-encrypted"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secytxes.MacsecSecond30secytx.OutOctetsEncrypted, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutPktsTooLong(Entity):
                                    """
                                    Out Packets Too Long
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secytxes.MacsecSecond30secytx.OutPktsTooLong, self).__init__()

                                        self.yang_name = "out-pkts-too-long"
                                        self.yang_parent_name = "macsec-second30secytx"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-pkts-too-long"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecSecond30.MacsecSecond30secytxes.MacsecSecond30secytx.OutPktsTooLong, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                    class MacsecHour24(Entity):
                        """
                        port current performance data
                        
                        .. attribute:: macsec_hour24_ether_s
                        
                        	port current performance data
                        	**type**\:  :py:class:`MacsecHour24EtherS <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS>`
                        
                        .. attribute:: macsec_hour24secyifs
                        
                        	port current performance data
                        	**type**\:  :py:class:`MacsecHour24secyifs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs>`
                        
                        .. attribute:: macsec_hour24secyrxes
                        
                        	port current performance data
                        	**type**\:  :py:class:`MacsecHour24secyrxes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes>`
                        
                        .. attribute:: macsec_hour24secytxes
                        
                        	port current performance data
                        	**type**\:  :py:class:`MacsecHour24secytxes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secytxes>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24, self).__init__()

                            self.yang_name = "macsec-hour24"
                            self.yang_parent_name = "macsec-current"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("macsec-hour24-ether-s", ("macsec_hour24_ether_s", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS)), ("macsec-hour24secyifs", ("macsec_hour24secyifs", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs)), ("macsec-hour24secyrxes", ("macsec_hour24secyrxes", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes)), ("macsec-hour24secytxes", ("macsec_hour24secytxes", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secytxes))])
                            self._leafs = OrderedDict()

                            self.macsec_hour24_ether_s = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS()
                            self.macsec_hour24_ether_s.parent = self
                            self._children_name_map["macsec_hour24_ether_s"] = "macsec-hour24-ether-s"

                            self.macsec_hour24secyifs = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs()
                            self.macsec_hour24secyifs.parent = self
                            self._children_name_map["macsec_hour24secyifs"] = "macsec-hour24secyifs"

                            self.macsec_hour24secyrxes = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes()
                            self.macsec_hour24secyrxes.parent = self
                            self._children_name_map["macsec_hour24secyrxes"] = "macsec-hour24secyrxes"

                            self.macsec_hour24secytxes = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secytxes()
                            self.macsec_hour24secytxes.parent = self
                            self._children_name_map["macsec_hour24secytxes"] = "macsec-hour24secytxes"
                            self._segment_path = lambda: "macsec-hour24"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24, [], name, value)


                        class MacsecHour24EtherS(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: macsec_hour24_ether
                            
                            	port 24 hour ether performance data
                            	**type**\: list of  		 :py:class:`MacsecHour24Ether <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS, self).__init__()

                                self.yang_name = "macsec-hour24-ether-s"
                                self.yang_parent_name = "macsec-hour24"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("macsec-hour24-ether", ("macsec_hour24_ether", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether))])
                                self._leafs = OrderedDict()

                                self.macsec_hour24_ether = YList(self)
                                self._segment_path = lambda: "macsec-hour24-ether-s"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS, [], name, value)


                            class MacsecHour24Ether(Entity):
                                """
                                port 24 hour ether performance data
                                
                                .. attribute:: number  (key)
                                
                                	channel number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rx_pkt
                                
                                	RX PKT
                                	**type**\:  :py:class:`RxPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.RxPkt>`
                                
                                .. attribute:: stat_pkt
                                
                                	STAT PKT
                                	**type**\:  :py:class:`StatPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.StatPkt>`
                                
                                .. attribute:: octet_stat
                                
                                	OCTET STAT
                                	**type**\:  :py:class:`OctetStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OctetStat>`
                                
                                .. attribute:: oversize_pkt_stat
                                
                                	OVERSIZE PKT
                                	**type**\:  :py:class:`OversizePktStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OversizePktStat>`
                                
                                .. attribute:: fcs_errors_stat
                                
                                	FCS ERR
                                	**type**\:  :py:class:`FcsErrorsStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.FcsErrorsStat>`
                                
                                .. attribute:: long_frames_stat
                                
                                	LONG FRAMES
                                	**type**\:  :py:class:`LongFramesStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.LongFramesStat>`
                                
                                .. attribute:: jabber_stat
                                
                                	JABBER STATS
                                	**type**\:  :py:class:`JabberStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.JabberStat>`
                                
                                .. attribute:: ether64_octets
                                
                                	SIXTY FOUR OCTET
                                	**type**\:  :py:class:`Ether64Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.Ether64Octets>`
                                
                                .. attribute:: ether65127_octet
                                
                                	OCTET
                                	**type**\:  :py:class:`Ether65127Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.Ether65127Octet>`
                                
                                .. attribute:: ether128255_octet
                                
                                	TFF OCTET
                                	**type**\:  :py:class:`Ether128255Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.Ether128255Octet>`
                                
                                .. attribute:: ether256511_octet
                                
                                	FOO OCTET
                                	**type**\:  :py:class:`Ether256511Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.Ether256511Octet>`
                                
                                .. attribute:: ether5121023_octet
                                
                                	OZTT OCTET
                                	**type**\:  :py:class:`Ether5121023Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.Ether5121023Octet>`
                                
                                .. attribute:: ether10241518_octet
                                
                                	OFO OCTET
                                	**type**\:  :py:class:`Ether10241518Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.Ether10241518Octet>`
                                
                                .. attribute:: in_ucast_pkt
                                
                                	IN UCAST
                                	**type**\:  :py:class:`InUcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InUcastPkt>`
                                
                                .. attribute:: in_mcast_pkt
                                
                                	IN MCAST
                                	**type**\:  :py:class:`InMcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InMcastPkt>`
                                
                                .. attribute:: in_bcast_pkt
                                
                                	IN BCAST
                                	**type**\:  :py:class:`InBcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InBcastPkt>`
                                
                                .. attribute:: out_ucast_pkt
                                
                                	OUT UCAST
                                	**type**\:  :py:class:`OutUcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutUcastPkt>`
                                
                                .. attribute:: out_bcast_pkt
                                
                                	OUT BCAST
                                	**type**\:  :py:class:`OutBcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutBcastPkt>`
                                
                                .. attribute:: out_mcast_pkt
                                
                                	OUT MCAST
                                	**type**\:  :py:class:`OutMcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutMcastPkt>`
                                
                                .. attribute:: tx_pkt
                                
                                	TX PKT
                                	**type**\:  :py:class:`TxPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.TxPkt>`
                                
                                .. attribute:: if_in_errors
                                
                                	IFIN ERRORS
                                	**type**\:  :py:class:`IfInErrors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.IfInErrors>`
                                
                                .. attribute:: if_in_octets
                                
                                	IFIN OCTETS
                                	**type**\:  :py:class:`IfInOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.IfInOctets>`
                                
                                .. attribute:: ether_stat_multicast_pkt
                                
                                	ETHER STAT MULTICAST PKT
                                	**type**\:  :py:class:`EtherStatMulticastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.EtherStatMulticastPkt>`
                                
                                .. attribute:: ether_stat_broadcast_pkt
                                
                                	ETHER STAT BROADCAST PKT
                                	**type**\:  :py:class:`EtherStatBroadcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.EtherStatBroadcastPkt>`
                                
                                .. attribute:: ether_stat_undersized_pkt
                                
                                	ETHER STAT UNDERSIZED PKT
                                	**type**\:  :py:class:`EtherStatUndersizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.EtherStatUndersizedPkt>`
                                
                                .. attribute:: out_octets
                                
                                	OUT OCTET
                                	**type**\:  :py:class:`OutOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutOctets>`
                                
                                .. attribute:: in_pause_frame
                                
                                	INPUT PAUSE FRAME
                                	**type**\:  :py:class:`InPauseFrame <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InPauseFrame>`
                                
                                .. attribute:: in_good_bytes
                                
                                	INPUT GOOD BYTES
                                	**type**\:  :py:class:`InGoodBytes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InGoodBytes>`
                                
                                .. attribute:: in8021q_frames
                                
                                	INPUT 802 1Q FRAMES
                                	**type**\:  :py:class:`In8021qFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.In8021qFrames>`
                                
                                .. attribute:: in_pkts1519_max_octets
                                
                                	INPUT PKTS 1519MAX OCTETS
                                	**type**\:  :py:class:`InPkts1519MaxOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InPkts1519MaxOctets>`
                                
                                .. attribute:: in_good_pkts
                                
                                	INPUT GOOD PKTS
                                	**type**\:  :py:class:`InGoodPkts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InGoodPkts>`
                                
                                .. attribute:: in_drop_overrun
                                
                                	INPUT DROP OVERRUN
                                	**type**\:  :py:class:`InDropOverrun <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InDropOverrun>`
                                
                                .. attribute:: in_drop_abort
                                
                                	INPUT DROP ABORT
                                	**type**\:  :py:class:`InDropAbort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InDropAbort>`
                                
                                .. attribute:: in_drop_invalid_vlan
                                
                                	INPUT DROP INVALID VLAN
                                	**type**\:  :py:class:`InDropInvalidVlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InDropInvalidVlan>`
                                
                                .. attribute:: in_drop_invalid_dmac
                                
                                	INPUT DROP INVALID DMAC
                                	**type**\:  :py:class:`InDropInvalidDmac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InDropInvalidDmac>`
                                
                                .. attribute:: in_drop_invalid_encap
                                
                                	INPUT DROP INVALID ENCAP
                                	**type**\:  :py:class:`InDropInvalidEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InDropInvalidEncap>`
                                
                                .. attribute:: in_drop_other
                                
                                	INPUT DROP OTHER
                                	**type**\:  :py:class:`InDropOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InDropOther>`
                                
                                .. attribute:: in_mib_giant
                                
                                	INPUT MIB GIANT
                                	**type**\:  :py:class:`InMibGiant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InMibGiant>`
                                
                                .. attribute:: in_mib_jabber
                                
                                	INPUT MIB JABBER
                                	**type**\:  :py:class:`InMibJabber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InMibJabber>`
                                
                                .. attribute:: in_mibcrc
                                
                                	IN MIB CRC
                                	**type**\:  :py:class:`InMibcrc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InMibcrc>`
                                
                                .. attribute:: in_error_collisions
                                
                                	IN ERROR COLLISIONS
                                	**type**\:  :py:class:`InErrorCollisions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InErrorCollisions>`
                                
                                .. attribute:: in_error_symbol
                                
                                	IN ERROR SYMBOL
                                	**type**\:  :py:class:`InErrorSymbol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InErrorSymbol>`
                                
                                .. attribute:: out_good_bytes
                                
                                	OUT GOOD BYTES
                                	**type**\:  :py:class:`OutGoodBytes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutGoodBytes>`
                                
                                .. attribute:: out8021q_frames
                                
                                	OUT 802 1Q FRAMES
                                	**type**\:  :py:class:`Out8021qFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.Out8021qFrames>`
                                
                                .. attribute:: out_pause_frames
                                
                                	OUT PAUSE FRAMES
                                	**type**\:  :py:class:`OutPauseFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutPauseFrames>`
                                
                                .. attribute:: out_pkts1519_max_octets
                                
                                	OUT PKTS 1519 MAX OCTETS
                                	**type**\:  :py:class:`OutPkts1519MaxOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutPkts1519MaxOctets>`
                                
                                .. attribute:: out_good_pkts
                                
                                	OUT GOOD PKTS
                                	**type**\:  :py:class:`OutGoodPkts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutGoodPkts>`
                                
                                .. attribute:: out_drop_underrun
                                
                                	OUT DROP UNDERRUN
                                	**type**\:  :py:class:`OutDropUnderrun <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutDropUnderrun>`
                                
                                .. attribute:: out_drop_abort
                                
                                	OUT DROP ABORT
                                	**type**\:  :py:class:`OutDropAbort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutDropAbort>`
                                
                                .. attribute:: out_drop_other
                                
                                	OUT DROP OTHER
                                	**type**\:  :py:class:`OutDropOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutDropOther>`
                                
                                .. attribute:: out_error_other
                                
                                	OUT ERROR OTHER
                                	**type**\:  :py:class:`OutErrorOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutErrorOther>`
                                
                                .. attribute:: in_error_giant
                                
                                	IN ERROR GIANT
                                	**type**\:  :py:class:`InErrorGiant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InErrorGiant>`
                                
                                .. attribute:: in_error_runt
                                
                                	IN ERROR RUNT
                                	**type**\:  :py:class:`InErrorRunt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InErrorRunt>`
                                
                                .. attribute:: in_error_jabbers
                                
                                	IN ERROR JABBERS
                                	**type**\:  :py:class:`InErrorJabbers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InErrorJabbers>`
                                
                                .. attribute:: in_error_fragments
                                
                                	IN ERROR FRAGMENTS
                                	**type**\:  :py:class:`InErrorFragments <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InErrorFragments>`
                                
                                .. attribute:: in_error_other
                                
                                	IN ERROR OTHER
                                	**type**\:  :py:class:`InErrorOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InErrorOther>`
                                
                                .. attribute:: in_pkt64_octet
                                
                                	IN PKT 64 OCTET
                                	**type**\:  :py:class:`InPkt64Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InPkt64Octet>`
                                
                                .. attribute:: in_pkts65_to127_octets
                                
                                	IN PKTS 65 127OCTETS
                                	**type**\:  :py:class:`InPkts65To127Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InPkts65To127Octets>`
                                
                                .. attribute:: in_pkts128_to255_octets
                                
                                	IN PKTS 128 255 OCTETS
                                	**type**\:  :py:class:`InPkts128To255Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InPkts128To255Octets>`
                                
                                .. attribute:: in_pkts256_to511_octets
                                
                                	IN PKTS 256 511 OCTETS
                                	**type**\:  :py:class:`InPkts256To511Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InPkts256To511Octets>`
                                
                                .. attribute:: in_pkts512_to1023_octets
                                
                                	IN PKTS 512 1023 OCTETS
                                	**type**\:  :py:class:`InPkts512To1023Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InPkts512To1023Octets>`
                                
                                .. attribute:: in_pkts1024_to1518_octets
                                
                                	IN PKTS 1024 1518 OCTETS
                                	**type**\:  :py:class:`InPkts1024To1518Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InPkts1024To1518Octets>`
                                
                                .. attribute:: outpkt64octet
                                
                                	OUT PKT 64 OCTET
                                	**type**\:  :py:class:`Outpkt64octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.Outpkt64octet>`
                                
                                .. attribute:: out_pkts65127_octets
                                
                                	OUT PKTS 65 127OCTETS
                                	**type**\:  :py:class:`OutPkts65127Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutPkts65127Octets>`
                                
                                .. attribute:: out_pkts128255_octets
                                
                                	OUT PKTS 128 255 OCTETS
                                	**type**\:  :py:class:`OutPkts128255Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutPkts128255Octets>`
                                
                                .. attribute:: out_pkts256511_octets
                                
                                	OUT PKTS 256 511 OCTETS
                                	**type**\:  :py:class:`OutPkts256511Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutPkts256511Octets>`
                                
                                .. attribute:: out_pkts5121023_octets
                                
                                	OUT PKTS 512 1023 OCTETS
                                	**type**\:  :py:class:`OutPkts5121023Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutPkts5121023Octets>`
                                
                                .. attribute:: out_pkts10241518_octets
                                
                                	OUT PKTS 1024 1518 OCTETS
                                	**type**\:  :py:class:`OutPkts10241518Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutPkts10241518Octets>`
                                
                                .. attribute:: rx_util
                                
                                	Rx Utilization in Percent
                                	**type**\:  :py:class:`RxUtil <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.RxUtil>`
                                
                                .. attribute:: tx_util
                                
                                	Tx Utilization in Percent
                                	**type**\:  :py:class:`TxUtil <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.TxUtil>`
                                
                                .. attribute:: tx_undersized_pkt
                                
                                	TX Undersized Pkt
                                	**type**\:  :py:class:`TxUndersizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.TxUndersizedPkt>`
                                
                                .. attribute:: tx_oversized_pkt
                                
                                	TX Oversized Pkt
                                	**type**\:  :py:class:`TxOversizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.TxOversizedPkt>`
                                
                                .. attribute:: tx_fragments
                                
                                	TX Fragments
                                	**type**\:  :py:class:`TxFragments <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.TxFragments>`
                                
                                .. attribute:: tx_jabber
                                
                                	TX Jabber
                                	**type**\:  :py:class:`TxJabber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.TxJabber>`
                                
                                .. attribute:: tx_bad_fcs
                                
                                	TX Bad Fcs
                                	**type**\:  :py:class:`TxBadFcs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.TxBadFcs>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether, self).__init__()

                                    self.yang_name = "macsec-hour24-ether"
                                    self.yang_parent_name = "macsec-hour24-ether-s"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("rx-pkt", ("rx_pkt", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.RxPkt)), ("stat-pkt", ("stat_pkt", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.StatPkt)), ("octet-stat", ("octet_stat", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OctetStat)), ("oversize-pkt-stat", ("oversize_pkt_stat", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OversizePktStat)), ("fcs-errors-stat", ("fcs_errors_stat", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.FcsErrorsStat)), ("long-frames-stat", ("long_frames_stat", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.LongFramesStat)), ("jabber-stat", ("jabber_stat", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.JabberStat)), ("ether64-octets", ("ether64_octets", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.Ether64Octets)), ("ether65127-octet", ("ether65127_octet", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.Ether65127Octet)), ("ether128255-octet", ("ether128255_octet", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.Ether128255Octet)), ("ether256511-octet", ("ether256511_octet", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.Ether256511Octet)), ("ether5121023-octet", ("ether5121023_octet", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.Ether5121023Octet)), ("ether10241518-octet", ("ether10241518_octet", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.Ether10241518Octet)), ("in-ucast-pkt", ("in_ucast_pkt", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InUcastPkt)), ("in-mcast-pkt", ("in_mcast_pkt", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InMcastPkt)), ("in-bcast-pkt", ("in_bcast_pkt", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InBcastPkt)), ("out-ucast-pkt", ("out_ucast_pkt", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutUcastPkt)), ("out-bcast-pkt", ("out_bcast_pkt", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutBcastPkt)), ("out-mcast-pkt", ("out_mcast_pkt", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutMcastPkt)), ("tx-pkt", ("tx_pkt", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.TxPkt)), ("if-in-errors", ("if_in_errors", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.IfInErrors)), ("if-in-octets", ("if_in_octets", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.IfInOctets)), ("ether-stat-multicast-pkt", ("ether_stat_multicast_pkt", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.EtherStatMulticastPkt)), ("ether-stat-broadcast-pkt", ("ether_stat_broadcast_pkt", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.EtherStatBroadcastPkt)), ("ether-stat-undersized-pkt", ("ether_stat_undersized_pkt", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.EtherStatUndersizedPkt)), ("out-octets", ("out_octets", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutOctets)), ("in-pause-frame", ("in_pause_frame", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InPauseFrame)), ("in-good-bytes", ("in_good_bytes", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InGoodBytes)), ("in8021q-frames", ("in8021q_frames", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.In8021qFrames)), ("in-pkts1519-max-octets", ("in_pkts1519_max_octets", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InPkts1519MaxOctets)), ("in-good-pkts", ("in_good_pkts", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InGoodPkts)), ("in-drop-overrun", ("in_drop_overrun", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InDropOverrun)), ("in-drop-abort", ("in_drop_abort", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InDropAbort)), ("in-drop-invalid-vlan", ("in_drop_invalid_vlan", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InDropInvalidVlan)), ("in-drop-invalid-dmac", ("in_drop_invalid_dmac", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InDropInvalidDmac)), ("in-drop-invalid-encap", ("in_drop_invalid_encap", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InDropInvalidEncap)), ("in-drop-other", ("in_drop_other", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InDropOther)), ("in-mib-giant", ("in_mib_giant", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InMibGiant)), ("in-mib-jabber", ("in_mib_jabber", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InMibJabber)), ("in-mibcrc", ("in_mibcrc", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InMibcrc)), ("in-error-collisions", ("in_error_collisions", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InErrorCollisions)), ("in-error-symbol", ("in_error_symbol", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InErrorSymbol)), ("out-good-bytes", ("out_good_bytes", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutGoodBytes)), ("out8021q-frames", ("out8021q_frames", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.Out8021qFrames)), ("out-pause-frames", ("out_pause_frames", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutPauseFrames)), ("out-pkts1519-max-octets", ("out_pkts1519_max_octets", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutPkts1519MaxOctets)), ("out-good-pkts", ("out_good_pkts", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutGoodPkts)), ("out-drop-underrun", ("out_drop_underrun", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutDropUnderrun)), ("out-drop-abort", ("out_drop_abort", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutDropAbort)), ("out-drop-other", ("out_drop_other", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutDropOther)), ("out-error-other", ("out_error_other", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutErrorOther)), ("in-error-giant", ("in_error_giant", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InErrorGiant)), ("in-error-runt", ("in_error_runt", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InErrorRunt)), ("in-error-jabbers", ("in_error_jabbers", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InErrorJabbers)), ("in-error-fragments", ("in_error_fragments", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InErrorFragments)), ("in-error-other", ("in_error_other", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InErrorOther)), ("in-pkt64-octet", ("in_pkt64_octet", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InPkt64Octet)), ("in-pkts65-to127-octets", ("in_pkts65_to127_octets", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InPkts65To127Octets)), ("in-pkts128-to255-octets", ("in_pkts128_to255_octets", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InPkts128To255Octets)), ("in-pkts256-to511-octets", ("in_pkts256_to511_octets", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InPkts256To511Octets)), ("in-pkts512-to1023-octets", ("in_pkts512_to1023_octets", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InPkts512To1023Octets)), ("in-pkts1024-to1518-octets", ("in_pkts1024_to1518_octets", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InPkts1024To1518Octets)), ("outpkt64octet", ("outpkt64octet", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.Outpkt64octet)), ("out-pkts65127-octets", ("out_pkts65127_octets", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutPkts65127Octets)), ("out-pkts128255-octets", ("out_pkts128255_octets", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutPkts128255Octets)), ("out-pkts256511-octets", ("out_pkts256511_octets", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutPkts256511Octets)), ("out-pkts5121023-octets", ("out_pkts5121023_octets", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutPkts5121023Octets)), ("out-pkts10241518-octets", ("out_pkts10241518_octets", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutPkts10241518Octets)), ("rx-util", ("rx_util", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.RxUtil)), ("tx-util", ("tx_util", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.TxUtil)), ("tx-undersized-pkt", ("tx_undersized_pkt", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.TxUndersizedPkt)), ("tx-oversized-pkt", ("tx_oversized_pkt", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.TxOversizedPkt)), ("tx-fragments", ("tx_fragments", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.TxFragments)), ("tx-jabber", ("tx_jabber", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.TxJabber)), ("tx-bad-fcs", ("tx_bad_fcs", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.TxBadFcs))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                        ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                    ])
                                    self.number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None
                                    self.sec30_support = None

                                    self.rx_pkt = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.RxPkt()
                                    self.rx_pkt.parent = self
                                    self._children_name_map["rx_pkt"] = "rx-pkt"

                                    self.stat_pkt = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.StatPkt()
                                    self.stat_pkt.parent = self
                                    self._children_name_map["stat_pkt"] = "stat-pkt"

                                    self.octet_stat = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OctetStat()
                                    self.octet_stat.parent = self
                                    self._children_name_map["octet_stat"] = "octet-stat"

                                    self.oversize_pkt_stat = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OversizePktStat()
                                    self.oversize_pkt_stat.parent = self
                                    self._children_name_map["oversize_pkt_stat"] = "oversize-pkt-stat"

                                    self.fcs_errors_stat = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.FcsErrorsStat()
                                    self.fcs_errors_stat.parent = self
                                    self._children_name_map["fcs_errors_stat"] = "fcs-errors-stat"

                                    self.long_frames_stat = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.LongFramesStat()
                                    self.long_frames_stat.parent = self
                                    self._children_name_map["long_frames_stat"] = "long-frames-stat"

                                    self.jabber_stat = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.JabberStat()
                                    self.jabber_stat.parent = self
                                    self._children_name_map["jabber_stat"] = "jabber-stat"

                                    self.ether64_octets = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.Ether64Octets()
                                    self.ether64_octets.parent = self
                                    self._children_name_map["ether64_octets"] = "ether64-octets"

                                    self.ether65127_octet = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.Ether65127Octet()
                                    self.ether65127_octet.parent = self
                                    self._children_name_map["ether65127_octet"] = "ether65127-octet"

                                    self.ether128255_octet = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.Ether128255Octet()
                                    self.ether128255_octet.parent = self
                                    self._children_name_map["ether128255_octet"] = "ether128255-octet"

                                    self.ether256511_octet = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.Ether256511Octet()
                                    self.ether256511_octet.parent = self
                                    self._children_name_map["ether256511_octet"] = "ether256511-octet"

                                    self.ether5121023_octet = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.Ether5121023Octet()
                                    self.ether5121023_octet.parent = self
                                    self._children_name_map["ether5121023_octet"] = "ether5121023-octet"

                                    self.ether10241518_octet = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.Ether10241518Octet()
                                    self.ether10241518_octet.parent = self
                                    self._children_name_map["ether10241518_octet"] = "ether10241518-octet"

                                    self.in_ucast_pkt = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InUcastPkt()
                                    self.in_ucast_pkt.parent = self
                                    self._children_name_map["in_ucast_pkt"] = "in-ucast-pkt"

                                    self.in_mcast_pkt = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InMcastPkt()
                                    self.in_mcast_pkt.parent = self
                                    self._children_name_map["in_mcast_pkt"] = "in-mcast-pkt"

                                    self.in_bcast_pkt = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InBcastPkt()
                                    self.in_bcast_pkt.parent = self
                                    self._children_name_map["in_bcast_pkt"] = "in-bcast-pkt"

                                    self.out_ucast_pkt = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutUcastPkt()
                                    self.out_ucast_pkt.parent = self
                                    self._children_name_map["out_ucast_pkt"] = "out-ucast-pkt"

                                    self.out_bcast_pkt = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutBcastPkt()
                                    self.out_bcast_pkt.parent = self
                                    self._children_name_map["out_bcast_pkt"] = "out-bcast-pkt"

                                    self.out_mcast_pkt = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutMcastPkt()
                                    self.out_mcast_pkt.parent = self
                                    self._children_name_map["out_mcast_pkt"] = "out-mcast-pkt"

                                    self.tx_pkt = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.TxPkt()
                                    self.tx_pkt.parent = self
                                    self._children_name_map["tx_pkt"] = "tx-pkt"

                                    self.if_in_errors = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.IfInErrors()
                                    self.if_in_errors.parent = self
                                    self._children_name_map["if_in_errors"] = "if-in-errors"

                                    self.if_in_octets = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.IfInOctets()
                                    self.if_in_octets.parent = self
                                    self._children_name_map["if_in_octets"] = "if-in-octets"

                                    self.ether_stat_multicast_pkt = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.EtherStatMulticastPkt()
                                    self.ether_stat_multicast_pkt.parent = self
                                    self._children_name_map["ether_stat_multicast_pkt"] = "ether-stat-multicast-pkt"

                                    self.ether_stat_broadcast_pkt = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.EtherStatBroadcastPkt()
                                    self.ether_stat_broadcast_pkt.parent = self
                                    self._children_name_map["ether_stat_broadcast_pkt"] = "ether-stat-broadcast-pkt"

                                    self.ether_stat_undersized_pkt = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.EtherStatUndersizedPkt()
                                    self.ether_stat_undersized_pkt.parent = self
                                    self._children_name_map["ether_stat_undersized_pkt"] = "ether-stat-undersized-pkt"

                                    self.out_octets = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutOctets()
                                    self.out_octets.parent = self
                                    self._children_name_map["out_octets"] = "out-octets"

                                    self.in_pause_frame = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InPauseFrame()
                                    self.in_pause_frame.parent = self
                                    self._children_name_map["in_pause_frame"] = "in-pause-frame"

                                    self.in_good_bytes = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InGoodBytes()
                                    self.in_good_bytes.parent = self
                                    self._children_name_map["in_good_bytes"] = "in-good-bytes"

                                    self.in8021q_frames = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.In8021qFrames()
                                    self.in8021q_frames.parent = self
                                    self._children_name_map["in8021q_frames"] = "in8021q-frames"

                                    self.in_pkts1519_max_octets = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InPkts1519MaxOctets()
                                    self.in_pkts1519_max_octets.parent = self
                                    self._children_name_map["in_pkts1519_max_octets"] = "in-pkts1519-max-octets"

                                    self.in_good_pkts = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InGoodPkts()
                                    self.in_good_pkts.parent = self
                                    self._children_name_map["in_good_pkts"] = "in-good-pkts"

                                    self.in_drop_overrun = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InDropOverrun()
                                    self.in_drop_overrun.parent = self
                                    self._children_name_map["in_drop_overrun"] = "in-drop-overrun"

                                    self.in_drop_abort = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InDropAbort()
                                    self.in_drop_abort.parent = self
                                    self._children_name_map["in_drop_abort"] = "in-drop-abort"

                                    self.in_drop_invalid_vlan = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InDropInvalidVlan()
                                    self.in_drop_invalid_vlan.parent = self
                                    self._children_name_map["in_drop_invalid_vlan"] = "in-drop-invalid-vlan"

                                    self.in_drop_invalid_dmac = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InDropInvalidDmac()
                                    self.in_drop_invalid_dmac.parent = self
                                    self._children_name_map["in_drop_invalid_dmac"] = "in-drop-invalid-dmac"

                                    self.in_drop_invalid_encap = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InDropInvalidEncap()
                                    self.in_drop_invalid_encap.parent = self
                                    self._children_name_map["in_drop_invalid_encap"] = "in-drop-invalid-encap"

                                    self.in_drop_other = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InDropOther()
                                    self.in_drop_other.parent = self
                                    self._children_name_map["in_drop_other"] = "in-drop-other"

                                    self.in_mib_giant = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InMibGiant()
                                    self.in_mib_giant.parent = self
                                    self._children_name_map["in_mib_giant"] = "in-mib-giant"

                                    self.in_mib_jabber = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InMibJabber()
                                    self.in_mib_jabber.parent = self
                                    self._children_name_map["in_mib_jabber"] = "in-mib-jabber"

                                    self.in_mibcrc = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InMibcrc()
                                    self.in_mibcrc.parent = self
                                    self._children_name_map["in_mibcrc"] = "in-mibcrc"

                                    self.in_error_collisions = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InErrorCollisions()
                                    self.in_error_collisions.parent = self
                                    self._children_name_map["in_error_collisions"] = "in-error-collisions"

                                    self.in_error_symbol = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InErrorSymbol()
                                    self.in_error_symbol.parent = self
                                    self._children_name_map["in_error_symbol"] = "in-error-symbol"

                                    self.out_good_bytes = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutGoodBytes()
                                    self.out_good_bytes.parent = self
                                    self._children_name_map["out_good_bytes"] = "out-good-bytes"

                                    self.out8021q_frames = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.Out8021qFrames()
                                    self.out8021q_frames.parent = self
                                    self._children_name_map["out8021q_frames"] = "out8021q-frames"

                                    self.out_pause_frames = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutPauseFrames()
                                    self.out_pause_frames.parent = self
                                    self._children_name_map["out_pause_frames"] = "out-pause-frames"

                                    self.out_pkts1519_max_octets = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutPkts1519MaxOctets()
                                    self.out_pkts1519_max_octets.parent = self
                                    self._children_name_map["out_pkts1519_max_octets"] = "out-pkts1519-max-octets"

                                    self.out_good_pkts = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutGoodPkts()
                                    self.out_good_pkts.parent = self
                                    self._children_name_map["out_good_pkts"] = "out-good-pkts"

                                    self.out_drop_underrun = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutDropUnderrun()
                                    self.out_drop_underrun.parent = self
                                    self._children_name_map["out_drop_underrun"] = "out-drop-underrun"

                                    self.out_drop_abort = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutDropAbort()
                                    self.out_drop_abort.parent = self
                                    self._children_name_map["out_drop_abort"] = "out-drop-abort"

                                    self.out_drop_other = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutDropOther()
                                    self.out_drop_other.parent = self
                                    self._children_name_map["out_drop_other"] = "out-drop-other"

                                    self.out_error_other = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutErrorOther()
                                    self.out_error_other.parent = self
                                    self._children_name_map["out_error_other"] = "out-error-other"

                                    self.in_error_giant = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InErrorGiant()
                                    self.in_error_giant.parent = self
                                    self._children_name_map["in_error_giant"] = "in-error-giant"

                                    self.in_error_runt = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InErrorRunt()
                                    self.in_error_runt.parent = self
                                    self._children_name_map["in_error_runt"] = "in-error-runt"

                                    self.in_error_jabbers = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InErrorJabbers()
                                    self.in_error_jabbers.parent = self
                                    self._children_name_map["in_error_jabbers"] = "in-error-jabbers"

                                    self.in_error_fragments = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InErrorFragments()
                                    self.in_error_fragments.parent = self
                                    self._children_name_map["in_error_fragments"] = "in-error-fragments"

                                    self.in_error_other = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InErrorOther()
                                    self.in_error_other.parent = self
                                    self._children_name_map["in_error_other"] = "in-error-other"

                                    self.in_pkt64_octet = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InPkt64Octet()
                                    self.in_pkt64_octet.parent = self
                                    self._children_name_map["in_pkt64_octet"] = "in-pkt64-octet"

                                    self.in_pkts65_to127_octets = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InPkts65To127Octets()
                                    self.in_pkts65_to127_octets.parent = self
                                    self._children_name_map["in_pkts65_to127_octets"] = "in-pkts65-to127-octets"

                                    self.in_pkts128_to255_octets = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InPkts128To255Octets()
                                    self.in_pkts128_to255_octets.parent = self
                                    self._children_name_map["in_pkts128_to255_octets"] = "in-pkts128-to255-octets"

                                    self.in_pkts256_to511_octets = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InPkts256To511Octets()
                                    self.in_pkts256_to511_octets.parent = self
                                    self._children_name_map["in_pkts256_to511_octets"] = "in-pkts256-to511-octets"

                                    self.in_pkts512_to1023_octets = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InPkts512To1023Octets()
                                    self.in_pkts512_to1023_octets.parent = self
                                    self._children_name_map["in_pkts512_to1023_octets"] = "in-pkts512-to1023-octets"

                                    self.in_pkts1024_to1518_octets = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InPkts1024To1518Octets()
                                    self.in_pkts1024_to1518_octets.parent = self
                                    self._children_name_map["in_pkts1024_to1518_octets"] = "in-pkts1024-to1518-octets"

                                    self.outpkt64octet = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.Outpkt64octet()
                                    self.outpkt64octet.parent = self
                                    self._children_name_map["outpkt64octet"] = "outpkt64octet"

                                    self.out_pkts65127_octets = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutPkts65127Octets()
                                    self.out_pkts65127_octets.parent = self
                                    self._children_name_map["out_pkts65127_octets"] = "out-pkts65127-octets"

                                    self.out_pkts128255_octets = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutPkts128255Octets()
                                    self.out_pkts128255_octets.parent = self
                                    self._children_name_map["out_pkts128255_octets"] = "out-pkts128255-octets"

                                    self.out_pkts256511_octets = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutPkts256511Octets()
                                    self.out_pkts256511_octets.parent = self
                                    self._children_name_map["out_pkts256511_octets"] = "out-pkts256511-octets"

                                    self.out_pkts5121023_octets = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutPkts5121023Octets()
                                    self.out_pkts5121023_octets.parent = self
                                    self._children_name_map["out_pkts5121023_octets"] = "out-pkts5121023-octets"

                                    self.out_pkts10241518_octets = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutPkts10241518Octets()
                                    self.out_pkts10241518_octets.parent = self
                                    self._children_name_map["out_pkts10241518_octets"] = "out-pkts10241518-octets"

                                    self.rx_util = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.RxUtil()
                                    self.rx_util.parent = self
                                    self._children_name_map["rx_util"] = "rx-util"

                                    self.tx_util = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.TxUtil()
                                    self.tx_util.parent = self
                                    self._children_name_map["tx_util"] = "tx-util"

                                    self.tx_undersized_pkt = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.TxUndersizedPkt()
                                    self.tx_undersized_pkt.parent = self
                                    self._children_name_map["tx_undersized_pkt"] = "tx-undersized-pkt"

                                    self.tx_oversized_pkt = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.TxOversizedPkt()
                                    self.tx_oversized_pkt.parent = self
                                    self._children_name_map["tx_oversized_pkt"] = "tx-oversized-pkt"

                                    self.tx_fragments = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.TxFragments()
                                    self.tx_fragments.parent = self
                                    self._children_name_map["tx_fragments"] = "tx-fragments"

                                    self.tx_jabber = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.TxJabber()
                                    self.tx_jabber.parent = self
                                    self._children_name_map["tx_jabber"] = "tx-jabber"

                                    self.tx_bad_fcs = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.TxBadFcs()
                                    self.tx_bad_fcs.parent = self
                                    self._children_name_map["tx_bad_fcs"] = "tx-bad-fcs"
                                    self._segment_path = lambda: "macsec-hour24-ether" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear30_sec_time', 'last_clear15_min_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                class RxPkt(Entity):
                                    """
                                    RX PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.RxPkt, self).__init__()

                                        self.yang_name = "rx-pkt"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "rx-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.RxPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class StatPkt(Entity):
                                    """
                                    STAT PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.StatPkt, self).__init__()

                                        self.yang_name = "stat-pkt"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "stat-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.StatPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OctetStat(Entity):
                                    """
                                    OCTET STAT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OctetStat, self).__init__()

                                        self.yang_name = "octet-stat"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "octet-stat"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OctetStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OversizePktStat(Entity):
                                    """
                                    OVERSIZE PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OversizePktStat, self).__init__()

                                        self.yang_name = "oversize-pkt-stat"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "oversize-pkt-stat"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OversizePktStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class FcsErrorsStat(Entity):
                                    """
                                    FCS ERR
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.FcsErrorsStat, self).__init__()

                                        self.yang_name = "fcs-errors-stat"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "fcs-errors-stat"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.FcsErrorsStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class LongFramesStat(Entity):
                                    """
                                    LONG FRAMES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.LongFramesStat, self).__init__()

                                        self.yang_name = "long-frames-stat"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "long-frames-stat"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.LongFramesStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class JabberStat(Entity):
                                    """
                                    JABBER STATS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.JabberStat, self).__init__()

                                        self.yang_name = "jabber-stat"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "jabber-stat"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.JabberStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class Ether64Octets(Entity):
                                    """
                                    SIXTY FOUR OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.Ether64Octets, self).__init__()

                                        self.yang_name = "ether64-octets"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ether64-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.Ether64Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class Ether65127Octet(Entity):
                                    """
                                    OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.Ether65127Octet, self).__init__()

                                        self.yang_name = "ether65127-octet"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ether65127-octet"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.Ether65127Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class Ether128255Octet(Entity):
                                    """
                                    TFF OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.Ether128255Octet, self).__init__()

                                        self.yang_name = "ether128255-octet"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ether128255-octet"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.Ether128255Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class Ether256511Octet(Entity):
                                    """
                                    FOO OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.Ether256511Octet, self).__init__()

                                        self.yang_name = "ether256511-octet"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ether256511-octet"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.Ether256511Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class Ether5121023Octet(Entity):
                                    """
                                    OZTT OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.Ether5121023Octet, self).__init__()

                                        self.yang_name = "ether5121023-octet"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ether5121023-octet"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.Ether5121023Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class Ether10241518Octet(Entity):
                                    """
                                    OFO OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.Ether10241518Octet, self).__init__()

                                        self.yang_name = "ether10241518-octet"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ether10241518-octet"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.Ether10241518Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InUcastPkt(Entity):
                                    """
                                    IN UCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InUcastPkt, self).__init__()

                                        self.yang_name = "in-ucast-pkt"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-ucast-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InUcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InMcastPkt(Entity):
                                    """
                                    IN MCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InMcastPkt, self).__init__()

                                        self.yang_name = "in-mcast-pkt"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-mcast-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InMcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InBcastPkt(Entity):
                                    """
                                    IN BCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InBcastPkt, self).__init__()

                                        self.yang_name = "in-bcast-pkt"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-bcast-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InBcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutUcastPkt(Entity):
                                    """
                                    OUT UCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutUcastPkt, self).__init__()

                                        self.yang_name = "out-ucast-pkt"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-ucast-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutUcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutBcastPkt(Entity):
                                    """
                                    OUT BCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutBcastPkt, self).__init__()

                                        self.yang_name = "out-bcast-pkt"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-bcast-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutBcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutMcastPkt(Entity):
                                    """
                                    OUT MCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutMcastPkt, self).__init__()

                                        self.yang_name = "out-mcast-pkt"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-mcast-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutMcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class TxPkt(Entity):
                                    """
                                    TX PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.TxPkt, self).__init__()

                                        self.yang_name = "tx-pkt"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "tx-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.TxPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class IfInErrors(Entity):
                                    """
                                    IFIN ERRORS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.IfInErrors, self).__init__()

                                        self.yang_name = "if-in-errors"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "if-in-errors"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.IfInErrors, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class IfInOctets(Entity):
                                    """
                                    IFIN OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.IfInOctets, self).__init__()

                                        self.yang_name = "if-in-octets"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "if-in-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.IfInOctets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class EtherStatMulticastPkt(Entity):
                                    """
                                    ETHER STAT MULTICAST PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.EtherStatMulticastPkt, self).__init__()

                                        self.yang_name = "ether-stat-multicast-pkt"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ether-stat-multicast-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.EtherStatMulticastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class EtherStatBroadcastPkt(Entity):
                                    """
                                    ETHER STAT BROADCAST PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.EtherStatBroadcastPkt, self).__init__()

                                        self.yang_name = "ether-stat-broadcast-pkt"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ether-stat-broadcast-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.EtherStatBroadcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class EtherStatUndersizedPkt(Entity):
                                    """
                                    ETHER STAT UNDERSIZED PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.EtherStatUndersizedPkt, self).__init__()

                                        self.yang_name = "ether-stat-undersized-pkt"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ether-stat-undersized-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.EtherStatUndersizedPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutOctets(Entity):
                                    """
                                    OUT OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutOctets, self).__init__()

                                        self.yang_name = "out-octets"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutOctets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPauseFrame(Entity):
                                    """
                                    INPUT PAUSE FRAME
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InPauseFrame, self).__init__()

                                        self.yang_name = "in-pause-frame"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pause-frame"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InPauseFrame, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InGoodBytes(Entity):
                                    """
                                    INPUT GOOD BYTES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InGoodBytes, self).__init__()

                                        self.yang_name = "in-good-bytes"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-good-bytes"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InGoodBytes, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class In8021qFrames(Entity):
                                    """
                                    INPUT 802 1Q FRAMES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.In8021qFrames, self).__init__()

                                        self.yang_name = "in8021q-frames"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in8021q-frames"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.In8021qFrames, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPkts1519MaxOctets(Entity):
                                    """
                                    INPUT PKTS 1519MAX OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InPkts1519MaxOctets, self).__init__()

                                        self.yang_name = "in-pkts1519-max-octets"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts1519-max-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InPkts1519MaxOctets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InGoodPkts(Entity):
                                    """
                                    INPUT GOOD PKTS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InGoodPkts, self).__init__()

                                        self.yang_name = "in-good-pkts"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-good-pkts"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InGoodPkts, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InDropOverrun(Entity):
                                    """
                                    INPUT DROP OVERRUN
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InDropOverrun, self).__init__()

                                        self.yang_name = "in-drop-overrun"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-drop-overrun"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InDropOverrun, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InDropAbort(Entity):
                                    """
                                    INPUT DROP ABORT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InDropAbort, self).__init__()

                                        self.yang_name = "in-drop-abort"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-drop-abort"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InDropAbort, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InDropInvalidVlan(Entity):
                                    """
                                    INPUT DROP INVALID VLAN
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InDropInvalidVlan, self).__init__()

                                        self.yang_name = "in-drop-invalid-vlan"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-drop-invalid-vlan"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InDropInvalidVlan, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InDropInvalidDmac(Entity):
                                    """
                                    INPUT DROP INVALID DMAC
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InDropInvalidDmac, self).__init__()

                                        self.yang_name = "in-drop-invalid-dmac"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-drop-invalid-dmac"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InDropInvalidDmac, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InDropInvalidEncap(Entity):
                                    """
                                    INPUT DROP INVALID ENCAP
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InDropInvalidEncap, self).__init__()

                                        self.yang_name = "in-drop-invalid-encap"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-drop-invalid-encap"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InDropInvalidEncap, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InDropOther(Entity):
                                    """
                                    INPUT DROP OTHER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InDropOther, self).__init__()

                                        self.yang_name = "in-drop-other"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-drop-other"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InDropOther, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InMibGiant(Entity):
                                    """
                                    INPUT MIB GIANT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InMibGiant, self).__init__()

                                        self.yang_name = "in-mib-giant"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-mib-giant"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InMibGiant, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InMibJabber(Entity):
                                    """
                                    INPUT MIB JABBER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InMibJabber, self).__init__()

                                        self.yang_name = "in-mib-jabber"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-mib-jabber"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InMibJabber, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InMibcrc(Entity):
                                    """
                                    IN MIB CRC
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InMibcrc, self).__init__()

                                        self.yang_name = "in-mibcrc"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-mibcrc"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InMibcrc, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InErrorCollisions(Entity):
                                    """
                                    IN ERROR COLLISIONS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InErrorCollisions, self).__init__()

                                        self.yang_name = "in-error-collisions"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-error-collisions"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InErrorCollisions, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InErrorSymbol(Entity):
                                    """
                                    IN ERROR SYMBOL
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InErrorSymbol, self).__init__()

                                        self.yang_name = "in-error-symbol"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-error-symbol"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InErrorSymbol, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutGoodBytes(Entity):
                                    """
                                    OUT GOOD BYTES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutGoodBytes, self).__init__()

                                        self.yang_name = "out-good-bytes"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-good-bytes"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutGoodBytes, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class Out8021qFrames(Entity):
                                    """
                                    OUT 802 1Q FRAMES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.Out8021qFrames, self).__init__()

                                        self.yang_name = "out8021q-frames"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out8021q-frames"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.Out8021qFrames, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutPauseFrames(Entity):
                                    """
                                    OUT PAUSE FRAMES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutPauseFrames, self).__init__()

                                        self.yang_name = "out-pause-frames"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-pause-frames"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutPauseFrames, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutPkts1519MaxOctets(Entity):
                                    """
                                    OUT PKTS 1519 MAX OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutPkts1519MaxOctets, self).__init__()

                                        self.yang_name = "out-pkts1519-max-octets"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-pkts1519-max-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutPkts1519MaxOctets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutGoodPkts(Entity):
                                    """
                                    OUT GOOD PKTS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutGoodPkts, self).__init__()

                                        self.yang_name = "out-good-pkts"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-good-pkts"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutGoodPkts, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutDropUnderrun(Entity):
                                    """
                                    OUT DROP UNDERRUN
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutDropUnderrun, self).__init__()

                                        self.yang_name = "out-drop-underrun"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-drop-underrun"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutDropUnderrun, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutDropAbort(Entity):
                                    """
                                    OUT DROP ABORT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutDropAbort, self).__init__()

                                        self.yang_name = "out-drop-abort"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-drop-abort"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutDropAbort, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutDropOther(Entity):
                                    """
                                    OUT DROP OTHER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutDropOther, self).__init__()

                                        self.yang_name = "out-drop-other"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-drop-other"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutDropOther, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutErrorOther(Entity):
                                    """
                                    OUT ERROR OTHER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutErrorOther, self).__init__()

                                        self.yang_name = "out-error-other"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-error-other"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutErrorOther, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InErrorGiant(Entity):
                                    """
                                    IN ERROR GIANT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InErrorGiant, self).__init__()

                                        self.yang_name = "in-error-giant"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-error-giant"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InErrorGiant, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InErrorRunt(Entity):
                                    """
                                    IN ERROR RUNT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InErrorRunt, self).__init__()

                                        self.yang_name = "in-error-runt"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-error-runt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InErrorRunt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InErrorJabbers(Entity):
                                    """
                                    IN ERROR JABBERS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InErrorJabbers, self).__init__()

                                        self.yang_name = "in-error-jabbers"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-error-jabbers"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InErrorJabbers, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InErrorFragments(Entity):
                                    """
                                    IN ERROR FRAGMENTS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InErrorFragments, self).__init__()

                                        self.yang_name = "in-error-fragments"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-error-fragments"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InErrorFragments, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InErrorOther(Entity):
                                    """
                                    IN ERROR OTHER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InErrorOther, self).__init__()

                                        self.yang_name = "in-error-other"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-error-other"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InErrorOther, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPkt64Octet(Entity):
                                    """
                                    IN PKT 64 OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InPkt64Octet, self).__init__()

                                        self.yang_name = "in-pkt64-octet"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkt64-octet"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InPkt64Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPkts65To127Octets(Entity):
                                    """
                                    IN PKTS 65 127OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InPkts65To127Octets, self).__init__()

                                        self.yang_name = "in-pkts65-to127-octets"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts65-to127-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InPkts65To127Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPkts128To255Octets(Entity):
                                    """
                                    IN PKTS 128 255 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InPkts128To255Octets, self).__init__()

                                        self.yang_name = "in-pkts128-to255-octets"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts128-to255-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InPkts128To255Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPkts256To511Octets(Entity):
                                    """
                                    IN PKTS 256 511 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InPkts256To511Octets, self).__init__()

                                        self.yang_name = "in-pkts256-to511-octets"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts256-to511-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InPkts256To511Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPkts512To1023Octets(Entity):
                                    """
                                    IN PKTS 512 1023 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InPkts512To1023Octets, self).__init__()

                                        self.yang_name = "in-pkts512-to1023-octets"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts512-to1023-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InPkts512To1023Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPkts1024To1518Octets(Entity):
                                    """
                                    IN PKTS 1024 1518 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InPkts1024To1518Octets, self).__init__()

                                        self.yang_name = "in-pkts1024-to1518-octets"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts1024-to1518-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.InPkts1024To1518Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class Outpkt64octet(Entity):
                                    """
                                    OUT PKT 64 OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.Outpkt64octet, self).__init__()

                                        self.yang_name = "outpkt64octet"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "outpkt64octet"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.Outpkt64octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutPkts65127Octets(Entity):
                                    """
                                    OUT PKTS 65 127OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutPkts65127Octets, self).__init__()

                                        self.yang_name = "out-pkts65127-octets"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-pkts65127-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutPkts65127Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutPkts128255Octets(Entity):
                                    """
                                    OUT PKTS 128 255 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutPkts128255Octets, self).__init__()

                                        self.yang_name = "out-pkts128255-octets"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-pkts128255-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutPkts128255Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutPkts256511Octets(Entity):
                                    """
                                    OUT PKTS 256 511 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutPkts256511Octets, self).__init__()

                                        self.yang_name = "out-pkts256511-octets"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-pkts256511-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutPkts256511Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutPkts5121023Octets(Entity):
                                    """
                                    OUT PKTS 512 1023 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutPkts5121023Octets, self).__init__()

                                        self.yang_name = "out-pkts5121023-octets"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-pkts5121023-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutPkts5121023Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutPkts10241518Octets(Entity):
                                    """
                                    OUT PKTS 1024 1518 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutPkts10241518Octets, self).__init__()

                                        self.yang_name = "out-pkts10241518-octets"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-pkts10241518-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.OutPkts10241518Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class RxUtil(Entity):
                                    """
                                    Rx Utilization in Percent
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: str
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.RxUtil, self).__init__()

                                        self.yang_name = "rx-util"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "rx-util"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.RxUtil, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class TxUtil(Entity):
                                    """
                                    Tx Utilization in Percent
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: str
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.TxUtil, self).__init__()

                                        self.yang_name = "tx-util"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "tx-util"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.TxUtil, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class TxUndersizedPkt(Entity):
                                    """
                                    TX Undersized Pkt
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.TxUndersizedPkt, self).__init__()

                                        self.yang_name = "tx-undersized-pkt"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "tx-undersized-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.TxUndersizedPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class TxOversizedPkt(Entity):
                                    """
                                    TX Oversized Pkt
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.TxOversizedPkt, self).__init__()

                                        self.yang_name = "tx-oversized-pkt"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "tx-oversized-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.TxOversizedPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class TxFragments(Entity):
                                    """
                                    TX Fragments
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.TxFragments, self).__init__()

                                        self.yang_name = "tx-fragments"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "tx-fragments"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.TxFragments, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class TxJabber(Entity):
                                    """
                                    TX Jabber
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.TxJabber, self).__init__()

                                        self.yang_name = "tx-jabber"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "tx-jabber"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.TxJabber, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class TxBadFcs(Entity):
                                    """
                                    TX Bad Fcs
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.TxBadFcs, self).__init__()

                                        self.yang_name = "tx-bad-fcs"
                                        self.yang_parent_name = "macsec-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "tx-bad-fcs"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24EtherS.MacsecHour24Ether.TxBadFcs, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                        class MacsecHour24secyifs(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: macsec_hour24secyif
                            
                            	port 24 hour secy\-if performance data
                            	**type**\: list of  		 :py:class:`MacsecHour24secyif <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs, self).__init__()

                                self.yang_name = "macsec-hour24secyifs"
                                self.yang_parent_name = "macsec-hour24"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("macsec-hour24secyif", ("macsec_hour24secyif", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif))])
                                self._leafs = OrderedDict()

                                self.macsec_hour24secyif = YList(self)
                                self._segment_path = lambda: "macsec-hour24secyifs"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs, [], name, value)


                            class MacsecHour24secyif(Entity):
                                """
                                port 24 hour secy\-if performance data
                                
                                .. attribute:: number  (key)
                                
                                	channel number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: in_pkts_untagged
                                
                                	In Packet Untagged
                                	**type**\:  :py:class:`InPktsUntagged <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.InPktsUntagged>`
                                
                                .. attribute:: in_pkts_no_tag
                                
                                	In Packet No tag
                                	**type**\:  :py:class:`InPktsNoTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.InPktsNoTag>`
                                
                                .. attribute:: in_pkts_bad_tag
                                
                                	In Packet Bad tag
                                	**type**\:  :py:class:`InPktsBadTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.InPktsBadTag>`
                                
                                .. attribute:: in_pkts_unknown_sci
                                
                                	In Packet Unknown sci
                                	**type**\:  :py:class:`InPktsUnknownSci <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.InPktsUnknownSci>`
                                
                                .. attribute:: in_pkts_no_sci
                                
                                	In Packet No sci
                                	**type**\:  :py:class:`InPktsNoSci <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.InPktsNoSci>`
                                
                                .. attribute:: in_pkts_overrun
                                
                                	In Packet Overrun
                                	**type**\:  :py:class:`InPktsOverrun <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.InPktsOverrun>`
                                
                                .. attribute:: in_octets_validated
                                
                                	In Octet Validated
                                	**type**\:  :py:class:`InOctetsValidated <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.InOctetsValidated>`
                                
                                .. attribute:: in_octets_decrypted
                                
                                	In Octet Decrypted
                                	**type**\:  :py:class:`InOctetsDecrypted <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.InOctetsDecrypted>`
                                
                                .. attribute:: out_pkts_untagged
                                
                                	Out Packet Untagged
                                	**type**\:  :py:class:`OutPktsUntagged <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.OutPktsUntagged>`
                                
                                .. attribute:: out_pkts_too_long
                                
                                	Out Packet Too Long
                                	**type**\:  :py:class:`OutPktsTooLong <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.OutPktsTooLong>`
                                
                                .. attribute:: out_octets_protected
                                
                                	Out Octet Protected
                                	**type**\:  :py:class:`OutOctetsProtected <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.OutOctetsProtected>`
                                
                                .. attribute:: out_octets_encrypted
                                
                                	Out Octet encrypted
                                	**type**\:  :py:class:`OutOctetsEncrypted <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.OutOctetsEncrypted>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\: bool
                                
                                .. attribute:: sample_count
                                
                                	Running Sample Count
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif, self).__init__()

                                    self.yang_name = "macsec-hour24secyif"
                                    self.yang_parent_name = "macsec-hour24secyifs"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("in-pkts-untagged", ("in_pkts_untagged", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.InPktsUntagged)), ("in-pkts-no-tag", ("in_pkts_no_tag", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.InPktsNoTag)), ("in-pkts-bad-tag", ("in_pkts_bad_tag", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.InPktsBadTag)), ("in-pkts-unknown-sci", ("in_pkts_unknown_sci", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.InPktsUnknownSci)), ("in-pkts-no-sci", ("in_pkts_no_sci", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.InPktsNoSci)), ("in-pkts-overrun", ("in_pkts_overrun", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.InPktsOverrun)), ("in-octets-validated", ("in_octets_validated", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.InOctetsValidated)), ("in-octets-decrypted", ("in_octets_decrypted", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.InOctetsDecrypted)), ("out-pkts-untagged", ("out_pkts_untagged", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.OutPktsUntagged)), ("out-pkts-too-long", ("out_pkts_too_long", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.OutPktsTooLong)), ("out-octets-protected", ("out_octets_protected", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.OutOctetsProtected)), ("out-octets-encrypted", ("out_octets_encrypted", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.OutOctetsEncrypted))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                        ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                        ('sample_count', (YLeaf(YType.uint64, 'sample-count'), ['int'])),
                                    ])
                                    self.number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear24_hr_time = None
                                    self.sec30_support = None
                                    self.sample_count = None

                                    self.in_pkts_untagged = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.InPktsUntagged()
                                    self.in_pkts_untagged.parent = self
                                    self._children_name_map["in_pkts_untagged"] = "in-pkts-untagged"

                                    self.in_pkts_no_tag = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.InPktsNoTag()
                                    self.in_pkts_no_tag.parent = self
                                    self._children_name_map["in_pkts_no_tag"] = "in-pkts-no-tag"

                                    self.in_pkts_bad_tag = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.InPktsBadTag()
                                    self.in_pkts_bad_tag.parent = self
                                    self._children_name_map["in_pkts_bad_tag"] = "in-pkts-bad-tag"

                                    self.in_pkts_unknown_sci = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.InPktsUnknownSci()
                                    self.in_pkts_unknown_sci.parent = self
                                    self._children_name_map["in_pkts_unknown_sci"] = "in-pkts-unknown-sci"

                                    self.in_pkts_no_sci = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.InPktsNoSci()
                                    self.in_pkts_no_sci.parent = self
                                    self._children_name_map["in_pkts_no_sci"] = "in-pkts-no-sci"

                                    self.in_pkts_overrun = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.InPktsOverrun()
                                    self.in_pkts_overrun.parent = self
                                    self._children_name_map["in_pkts_overrun"] = "in-pkts-overrun"

                                    self.in_octets_validated = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.InOctetsValidated()
                                    self.in_octets_validated.parent = self
                                    self._children_name_map["in_octets_validated"] = "in-octets-validated"

                                    self.in_octets_decrypted = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.InOctetsDecrypted()
                                    self.in_octets_decrypted.parent = self
                                    self._children_name_map["in_octets_decrypted"] = "in-octets-decrypted"

                                    self.out_pkts_untagged = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.OutPktsUntagged()
                                    self.out_pkts_untagged.parent = self
                                    self._children_name_map["out_pkts_untagged"] = "out-pkts-untagged"

                                    self.out_pkts_too_long = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.OutPktsTooLong()
                                    self.out_pkts_too_long.parent = self
                                    self._children_name_map["out_pkts_too_long"] = "out-pkts-too-long"

                                    self.out_octets_protected = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.OutOctetsProtected()
                                    self.out_octets_protected.parent = self
                                    self._children_name_map["out_octets_protected"] = "out-octets-protected"

                                    self.out_octets_encrypted = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.OutOctetsEncrypted()
                                    self.out_octets_encrypted.parent = self
                                    self._children_name_map["out_octets_encrypted"] = "out-octets-encrypted"
                                    self._segment_path = lambda: "macsec-hour24secyif" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support', 'sample_count'], name, value)


                                class InPktsUntagged(Entity):
                                    """
                                    In Packet Untagged
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.InPktsUntagged, self).__init__()

                                        self.yang_name = "in-pkts-untagged"
                                        self.yang_parent_name = "macsec-hour24secyif"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts-untagged"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.InPktsUntagged, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPktsNoTag(Entity):
                                    """
                                    In Packet No tag
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.InPktsNoTag, self).__init__()

                                        self.yang_name = "in-pkts-no-tag"
                                        self.yang_parent_name = "macsec-hour24secyif"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts-no-tag"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.InPktsNoTag, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPktsBadTag(Entity):
                                    """
                                    In Packet Bad tag
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.InPktsBadTag, self).__init__()

                                        self.yang_name = "in-pkts-bad-tag"
                                        self.yang_parent_name = "macsec-hour24secyif"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts-bad-tag"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.InPktsBadTag, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPktsUnknownSci(Entity):
                                    """
                                    In Packet Unknown sci
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.InPktsUnknownSci, self).__init__()

                                        self.yang_name = "in-pkts-unknown-sci"
                                        self.yang_parent_name = "macsec-hour24secyif"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts-unknown-sci"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.InPktsUnknownSci, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPktsNoSci(Entity):
                                    """
                                    In Packet No sci
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.InPktsNoSci, self).__init__()

                                        self.yang_name = "in-pkts-no-sci"
                                        self.yang_parent_name = "macsec-hour24secyif"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts-no-sci"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.InPktsNoSci, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPktsOverrun(Entity):
                                    """
                                    In Packet Overrun
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.InPktsOverrun, self).__init__()

                                        self.yang_name = "in-pkts-overrun"
                                        self.yang_parent_name = "macsec-hour24secyif"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts-overrun"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.InPktsOverrun, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InOctetsValidated(Entity):
                                    """
                                    In Octet Validated
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.InOctetsValidated, self).__init__()

                                        self.yang_name = "in-octets-validated"
                                        self.yang_parent_name = "macsec-hour24secyif"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-octets-validated"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.InOctetsValidated, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InOctetsDecrypted(Entity):
                                    """
                                    In Octet Decrypted
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.InOctetsDecrypted, self).__init__()

                                        self.yang_name = "in-octets-decrypted"
                                        self.yang_parent_name = "macsec-hour24secyif"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-octets-decrypted"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.InOctetsDecrypted, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutPktsUntagged(Entity):
                                    """
                                    Out Packet Untagged
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.OutPktsUntagged, self).__init__()

                                        self.yang_name = "out-pkts-untagged"
                                        self.yang_parent_name = "macsec-hour24secyif"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-pkts-untagged"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.OutPktsUntagged, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutPktsTooLong(Entity):
                                    """
                                    Out Packet Too Long
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.OutPktsTooLong, self).__init__()

                                        self.yang_name = "out-pkts-too-long"
                                        self.yang_parent_name = "macsec-hour24secyif"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-pkts-too-long"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.OutPktsTooLong, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutOctetsProtected(Entity):
                                    """
                                    Out Octet Protected
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.OutOctetsProtected, self).__init__()

                                        self.yang_name = "out-octets-protected"
                                        self.yang_parent_name = "macsec-hour24secyif"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-octets-protected"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.OutOctetsProtected, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutOctetsEncrypted(Entity):
                                    """
                                    Out Octet encrypted
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.OutOctetsEncrypted, self).__init__()

                                        self.yang_name = "out-octets-encrypted"
                                        self.yang_parent_name = "macsec-hour24secyif"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-octets-encrypted"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyifs.MacsecHour24secyif.OutOctetsEncrypted, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                        class MacsecHour24secyrxes(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: macsec_hour24secyrx
                            
                            	port 24 hour secy\-rx performance data
                            	**type**\: list of  		 :py:class:`MacsecHour24secyrx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes, self).__init__()

                                self.yang_name = "macsec-hour24secyrxes"
                                self.yang_parent_name = "macsec-hour24"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("macsec-hour24secyrx", ("macsec_hour24secyrx", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx))])
                                self._leafs = OrderedDict()

                                self.macsec_hour24secyrx = YList(self)
                                self._segment_path = lambda: "macsec-hour24secyrxes"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes, [], name, value)


                            class MacsecHour24secyrx(Entity):
                                """
                                port 24 hour secy\-rx performance data
                                
                                .. attribute:: number  (key)
                                
                                	channel number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: in_pkts_unchecked
                                
                                	In Packet Unchecked
                                	**type**\:  :py:class:`InPktsUnchecked <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx.InPktsUnchecked>`
                                
                                .. attribute:: in_pkts_delayed
                                
                                	In Packet Delay
                                	**type**\:  :py:class:`InPktsDelayed <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx.InPktsDelayed>`
                                
                                .. attribute:: in_pkts_late
                                
                                	In Packet Late
                                	**type**\:  :py:class:`InPktsLate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx.InPktsLate>`
                                
                                .. attribute:: in_pkts_ok
                                
                                	In Packet Ok
                                	**type**\:  :py:class:`InPktsOk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx.InPktsOk>`
                                
                                .. attribute:: in_pkts_invalid
                                
                                	In Packet Invalid
                                	**type**\:  :py:class:`InPktsInvalid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx.InPktsInvalid>`
                                
                                .. attribute:: in_pkts_not_valid
                                
                                	In Packet Not Valid
                                	**type**\:  :py:class:`InPktsNotValid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx.InPktsNotValid>`
                                
                                .. attribute:: in_pkts_not_using_sa
                                
                                	In Packet Not Using SA
                                	**type**\:  :py:class:`InPktsNotUsingSa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx.InPktsNotUsingSa>`
                                
                                .. attribute:: in_pkts_unused_sa
                                
                                	In Packet Unused SA
                                	**type**\:  :py:class:`InPktsUnusedSa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx.InPktsUnusedSa>`
                                
                                .. attribute:: in_pkts_untagged_hit
                                
                                	In Packet Untagged Hit
                                	**type**\:  :py:class:`InPktsUntaggedHit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx.InPktsUntaggedHit>`
                                
                                .. attribute:: in_octets_validated
                                
                                	In Octet Validated
                                	**type**\:  :py:class:`InOctetsValidated <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx.InOctetsValidated>`
                                
                                .. attribute:: in_octets_decrypted
                                
                                	In Octet Decrypted
                                	**type**\:  :py:class:`InOctetsDecrypted <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx.InOctetsDecrypted>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\: bool
                                
                                .. attribute:: sample_count
                                
                                	Running Sample Count
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx, self).__init__()

                                    self.yang_name = "macsec-hour24secyrx"
                                    self.yang_parent_name = "macsec-hour24secyrxes"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("in-pkts-unchecked", ("in_pkts_unchecked", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx.InPktsUnchecked)), ("in-pkts-delayed", ("in_pkts_delayed", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx.InPktsDelayed)), ("in-pkts-late", ("in_pkts_late", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx.InPktsLate)), ("in-pkts-ok", ("in_pkts_ok", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx.InPktsOk)), ("in-pkts-invalid", ("in_pkts_invalid", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx.InPktsInvalid)), ("in-pkts-not-valid", ("in_pkts_not_valid", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx.InPktsNotValid)), ("in-pkts-not-using-sa", ("in_pkts_not_using_sa", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx.InPktsNotUsingSa)), ("in-pkts-unused-sa", ("in_pkts_unused_sa", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx.InPktsUnusedSa)), ("in-pkts-untagged-hit", ("in_pkts_untagged_hit", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx.InPktsUntaggedHit)), ("in-octets-validated", ("in_octets_validated", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx.InOctetsValidated)), ("in-octets-decrypted", ("in_octets_decrypted", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx.InOctetsDecrypted))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                        ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                        ('sample_count', (YLeaf(YType.uint64, 'sample-count'), ['int'])),
                                    ])
                                    self.number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear24_hr_time = None
                                    self.sec30_support = None
                                    self.sample_count = None

                                    self.in_pkts_unchecked = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx.InPktsUnchecked()
                                    self.in_pkts_unchecked.parent = self
                                    self._children_name_map["in_pkts_unchecked"] = "in-pkts-unchecked"

                                    self.in_pkts_delayed = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx.InPktsDelayed()
                                    self.in_pkts_delayed.parent = self
                                    self._children_name_map["in_pkts_delayed"] = "in-pkts-delayed"

                                    self.in_pkts_late = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx.InPktsLate()
                                    self.in_pkts_late.parent = self
                                    self._children_name_map["in_pkts_late"] = "in-pkts-late"

                                    self.in_pkts_ok = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx.InPktsOk()
                                    self.in_pkts_ok.parent = self
                                    self._children_name_map["in_pkts_ok"] = "in-pkts-ok"

                                    self.in_pkts_invalid = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx.InPktsInvalid()
                                    self.in_pkts_invalid.parent = self
                                    self._children_name_map["in_pkts_invalid"] = "in-pkts-invalid"

                                    self.in_pkts_not_valid = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx.InPktsNotValid()
                                    self.in_pkts_not_valid.parent = self
                                    self._children_name_map["in_pkts_not_valid"] = "in-pkts-not-valid"

                                    self.in_pkts_not_using_sa = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx.InPktsNotUsingSa()
                                    self.in_pkts_not_using_sa.parent = self
                                    self._children_name_map["in_pkts_not_using_sa"] = "in-pkts-not-using-sa"

                                    self.in_pkts_unused_sa = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx.InPktsUnusedSa()
                                    self.in_pkts_unused_sa.parent = self
                                    self._children_name_map["in_pkts_unused_sa"] = "in-pkts-unused-sa"

                                    self.in_pkts_untagged_hit = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx.InPktsUntaggedHit()
                                    self.in_pkts_untagged_hit.parent = self
                                    self._children_name_map["in_pkts_untagged_hit"] = "in-pkts-untagged-hit"

                                    self.in_octets_validated = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx.InOctetsValidated()
                                    self.in_octets_validated.parent = self
                                    self._children_name_map["in_octets_validated"] = "in-octets-validated"

                                    self.in_octets_decrypted = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx.InOctetsDecrypted()
                                    self.in_octets_decrypted.parent = self
                                    self._children_name_map["in_octets_decrypted"] = "in-octets-decrypted"
                                    self._segment_path = lambda: "macsec-hour24secyrx" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support', 'sample_count'], name, value)


                                class InPktsUnchecked(Entity):
                                    """
                                    In Packet Unchecked
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx.InPktsUnchecked, self).__init__()

                                        self.yang_name = "in-pkts-unchecked"
                                        self.yang_parent_name = "macsec-hour24secyrx"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts-unchecked"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx.InPktsUnchecked, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPktsDelayed(Entity):
                                    """
                                    In Packet Delay
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx.InPktsDelayed, self).__init__()

                                        self.yang_name = "in-pkts-delayed"
                                        self.yang_parent_name = "macsec-hour24secyrx"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts-delayed"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx.InPktsDelayed, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPktsLate(Entity):
                                    """
                                    In Packet Late
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx.InPktsLate, self).__init__()

                                        self.yang_name = "in-pkts-late"
                                        self.yang_parent_name = "macsec-hour24secyrx"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts-late"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx.InPktsLate, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPktsOk(Entity):
                                    """
                                    In Packet Ok
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx.InPktsOk, self).__init__()

                                        self.yang_name = "in-pkts-ok"
                                        self.yang_parent_name = "macsec-hour24secyrx"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts-ok"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx.InPktsOk, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPktsInvalid(Entity):
                                    """
                                    In Packet Invalid
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx.InPktsInvalid, self).__init__()

                                        self.yang_name = "in-pkts-invalid"
                                        self.yang_parent_name = "macsec-hour24secyrx"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts-invalid"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx.InPktsInvalid, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPktsNotValid(Entity):
                                    """
                                    In Packet Not Valid
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx.InPktsNotValid, self).__init__()

                                        self.yang_name = "in-pkts-not-valid"
                                        self.yang_parent_name = "macsec-hour24secyrx"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts-not-valid"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx.InPktsNotValid, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPktsNotUsingSa(Entity):
                                    """
                                    In Packet Not Using SA
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx.InPktsNotUsingSa, self).__init__()

                                        self.yang_name = "in-pkts-not-using-sa"
                                        self.yang_parent_name = "macsec-hour24secyrx"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts-not-using-sa"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx.InPktsNotUsingSa, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPktsUnusedSa(Entity):
                                    """
                                    In Packet Unused SA
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx.InPktsUnusedSa, self).__init__()

                                        self.yang_name = "in-pkts-unused-sa"
                                        self.yang_parent_name = "macsec-hour24secyrx"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts-unused-sa"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx.InPktsUnusedSa, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPktsUntaggedHit(Entity):
                                    """
                                    In Packet Untagged Hit
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx.InPktsUntaggedHit, self).__init__()

                                        self.yang_name = "in-pkts-untagged-hit"
                                        self.yang_parent_name = "macsec-hour24secyrx"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts-untagged-hit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx.InPktsUntaggedHit, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InOctetsValidated(Entity):
                                    """
                                    In Octet Validated
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx.InOctetsValidated, self).__init__()

                                        self.yang_name = "in-octets-validated"
                                        self.yang_parent_name = "macsec-hour24secyrx"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-octets-validated"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx.InOctetsValidated, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InOctetsDecrypted(Entity):
                                    """
                                    In Octet Decrypted
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx.InOctetsDecrypted, self).__init__()

                                        self.yang_name = "in-octets-decrypted"
                                        self.yang_parent_name = "macsec-hour24secyrx"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-octets-decrypted"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secyrxes.MacsecHour24secyrx.InOctetsDecrypted, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                        class MacsecHour24secytxes(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: macsec_hour24secytx
                            
                            	port 24 hour secy\-tx performance data
                            	**type**\: list of  		 :py:class:`MacsecHour24secytx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secytxes.MacsecHour24secytx>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secytxes, self).__init__()

                                self.yang_name = "macsec-hour24secytxes"
                                self.yang_parent_name = "macsec-hour24"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("macsec-hour24secytx", ("macsec_hour24secytx", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secytxes.MacsecHour24secytx))])
                                self._leafs = OrderedDict()

                                self.macsec_hour24secytx = YList(self)
                                self._segment_path = lambda: "macsec-hour24secytxes"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secytxes, [], name, value)


                            class MacsecHour24secytx(Entity):
                                """
                                port 24 hour secy\-tx performance data
                                
                                .. attribute:: number  (key)
                                
                                	channel number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: out_pkts_protected
                                
                                	Out Packets Protected
                                	**type**\:  :py:class:`OutPktsProtected <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secytxes.MacsecHour24secytx.OutPktsProtected>`
                                
                                .. attribute:: out_pkts_encrypted
                                
                                	Out Packets Encrypted
                                	**type**\:  :py:class:`OutPktsEncrypted <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secytxes.MacsecHour24secytx.OutPktsEncrypted>`
                                
                                .. attribute:: out_octets_protected
                                
                                	Out Octets Protected 
                                	**type**\:  :py:class:`OutOctetsProtected <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secytxes.MacsecHour24secytx.OutOctetsProtected>`
                                
                                .. attribute:: out_octets_encrypted
                                
                                	Out Octets Encrypted
                                	**type**\:  :py:class:`OutOctetsEncrypted <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secytxes.MacsecHour24secytx.OutOctetsEncrypted>`
                                
                                .. attribute:: out_pkts_too_long
                                
                                	Out Packets Too Long
                                	**type**\:  :py:class:`OutPktsTooLong <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secytxes.MacsecHour24secytx.OutPktsTooLong>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\: bool
                                
                                .. attribute:: sample_count
                                
                                	Running Sample Count
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secytxes.MacsecHour24secytx, self).__init__()

                                    self.yang_name = "macsec-hour24secytx"
                                    self.yang_parent_name = "macsec-hour24secytxes"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("out-pkts-protected", ("out_pkts_protected", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secytxes.MacsecHour24secytx.OutPktsProtected)), ("out-pkts-encrypted", ("out_pkts_encrypted", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secytxes.MacsecHour24secytx.OutPktsEncrypted)), ("out-octets-protected", ("out_octets_protected", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secytxes.MacsecHour24secytx.OutOctetsProtected)), ("out-octets-encrypted", ("out_octets_encrypted", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secytxes.MacsecHour24secytx.OutOctetsEncrypted)), ("out-pkts-too-long", ("out_pkts_too_long", PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secytxes.MacsecHour24secytx.OutPktsTooLong))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                        ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                        ('sample_count', (YLeaf(YType.uint64, 'sample-count'), ['int'])),
                                    ])
                                    self.number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear24_hr_time = None
                                    self.sec30_support = None
                                    self.sample_count = None

                                    self.out_pkts_protected = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secytxes.MacsecHour24secytx.OutPktsProtected()
                                    self.out_pkts_protected.parent = self
                                    self._children_name_map["out_pkts_protected"] = "out-pkts-protected"

                                    self.out_pkts_encrypted = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secytxes.MacsecHour24secytx.OutPktsEncrypted()
                                    self.out_pkts_encrypted.parent = self
                                    self._children_name_map["out_pkts_encrypted"] = "out-pkts-encrypted"

                                    self.out_octets_protected = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secytxes.MacsecHour24secytx.OutOctetsProtected()
                                    self.out_octets_protected.parent = self
                                    self._children_name_map["out_octets_protected"] = "out-octets-protected"

                                    self.out_octets_encrypted = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secytxes.MacsecHour24secytx.OutOctetsEncrypted()
                                    self.out_octets_encrypted.parent = self
                                    self._children_name_map["out_octets_encrypted"] = "out-octets-encrypted"

                                    self.out_pkts_too_long = PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secytxes.MacsecHour24secytx.OutPktsTooLong()
                                    self.out_pkts_too_long.parent = self
                                    self._children_name_map["out_pkts_too_long"] = "out-pkts-too-long"
                                    self._segment_path = lambda: "macsec-hour24secytx" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secytxes.MacsecHour24secytx, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support', 'sample_count'], name, value)


                                class OutPktsProtected(Entity):
                                    """
                                    Out Packets Protected
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secytxes.MacsecHour24secytx.OutPktsProtected, self).__init__()

                                        self.yang_name = "out-pkts-protected"
                                        self.yang_parent_name = "macsec-hour24secytx"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-pkts-protected"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secytxes.MacsecHour24secytx.OutPktsProtected, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutPktsEncrypted(Entity):
                                    """
                                    Out Packets Encrypted
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secytxes.MacsecHour24secytx.OutPktsEncrypted, self).__init__()

                                        self.yang_name = "out-pkts-encrypted"
                                        self.yang_parent_name = "macsec-hour24secytx"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-pkts-encrypted"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secytxes.MacsecHour24secytx.OutPktsEncrypted, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutOctetsProtected(Entity):
                                    """
                                    Out Octets Protected 
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secytxes.MacsecHour24secytx.OutOctetsProtected, self).__init__()

                                        self.yang_name = "out-octets-protected"
                                        self.yang_parent_name = "macsec-hour24secytx"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-octets-protected"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secytxes.MacsecHour24secytx.OutOctetsProtected, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutOctetsEncrypted(Entity):
                                    """
                                    Out Octets Encrypted
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secytxes.MacsecHour24secytx.OutOctetsEncrypted, self).__init__()

                                        self.yang_name = "out-octets-encrypted"
                                        self.yang_parent_name = "macsec-hour24secytx"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-octets-encrypted"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secytxes.MacsecHour24secytx.OutOctetsEncrypted, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutPktsTooLong(Entity):
                                    """
                                    Out Packets Too Long
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secytxes.MacsecHour24secytx.OutPktsTooLong, self).__init__()

                                        self.yang_name = "out-pkts-too-long"
                                        self.yang_parent_name = "macsec-hour24secytx"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-pkts-too-long"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Macsec.MacsecPorts.MacsecPort.MacsecCurrent.MacsecHour24.MacsecHour24secytxes.MacsecHour24secytx.OutPktsTooLong, ['data', 'threshold', 'tca_report', 'valid'], name, value)


    class HoVc(Entity):
        """
        HO\_VC controller performance data
        
        .. attribute:: ho_vc_ports
        
        	Port performance data
        	**type**\:  :py:class:`HoVcPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts>`
        
        

        """

        _prefix = 'pmengine-oper'
        _revision = '2017-09-07'

        def __init__(self):
            super(PerformanceManagement.HoVc, self).__init__()

            self.yang_name = "ho-vc"
            self.yang_parent_name = "performance-management"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("ho-vc-ports", ("ho_vc_ports", PerformanceManagement.HoVc.HoVcPorts))])
            self._leafs = OrderedDict()

            self.ho_vc_ports = PerformanceManagement.HoVc.HoVcPorts()
            self.ho_vc_ports.parent = self
            self._children_name_map["ho_vc_ports"] = "ho-vc-ports"
            self._segment_path = lambda: "ho-vc"
            self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(PerformanceManagement.HoVc, [], name, value)


        class HoVcPorts(Entity):
            """
            Port performance data
            
            .. attribute:: ho_vc_port
            
            	Port performance data
            	**type**\: list of  		 :py:class:`HoVcPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort>`
            
            

            """

            _prefix = 'pmengine-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(PerformanceManagement.HoVc.HoVcPorts, self).__init__()

                self.yang_name = "ho-vc-ports"
                self.yang_parent_name = "ho-vc"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("ho-vc-port", ("ho_vc_port", PerformanceManagement.HoVc.HoVcPorts.HoVcPort))])
                self._leafs = OrderedDict()

                self.ho_vc_port = YList(self)
                self._segment_path = lambda: "ho-vc-ports"
                self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management/ho-vc/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(PerformanceManagement.HoVc.HoVcPorts, [], name, value)


            class HoVcPort(Entity):
                """
                Port performance data
                
                .. attribute:: name  (key)
                
                	Port name
                	**type**\: str
                
                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                
                .. attribute:: ho_vc_current
                
                	port current performance data
                	**type**\:  :py:class:`HoVcCurrent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort, self).__init__()

                    self.yang_name = "ho-vc-port"
                    self.yang_parent_name = "ho-vc-ports"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("ho-vc-current", ("ho_vc_current", PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ])
                    self.name = None

                    self.ho_vc_current = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent()
                    self.ho_vc_current.parent = self
                    self._children_name_map["ho_vc_current"] = "ho-vc-current"
                    self._segment_path = lambda: "ho-vc-port" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management/ho-vc/ho-vc-ports/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(PerformanceManagement.HoVc.HoVcPorts.HoVcPort, ['name'], name, value)


                class HoVcCurrent(Entity):
                    """
                    port current performance data
                    
                    .. attribute:: ho_vc_hour24
                    
                    	port current performance data
                    	**type**\:  :py:class:`HoVcHour24 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24>`
                    
                    .. attribute:: ho_vc_minute15
                    
                    	port current performance data
                    	**type**\:  :py:class:`HoVcMinute15 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent, self).__init__()

                        self.yang_name = "ho-vc-current"
                        self.yang_parent_name = "ho-vc-port"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ho-vc-hour24", ("ho_vc_hour24", PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24)), ("ho-vc-minute15", ("ho_vc_minute15", PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15))])
                        self._leafs = OrderedDict()

                        self.ho_vc_hour24 = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24()
                        self.ho_vc_hour24.parent = self
                        self._children_name_map["ho_vc_hour24"] = "ho-vc-hour24"

                        self.ho_vc_minute15 = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15()
                        self.ho_vc_minute15.parent = self
                        self._children_name_map["ho_vc_minute15"] = "ho-vc-minute15"
                        self._segment_path = lambda: "ho-vc-current"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent, [], name, value)


                    class HoVcHour24(Entity):
                        """
                        port current performance data
                        
                        .. attribute:: ho_vc_hour24_paths
                        
                        	port current performance data
                        	**type**\:  :py:class:`HoVcHour24Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24, self).__init__()

                            self.yang_name = "ho-vc-hour24"
                            self.yang_parent_name = "ho-vc-current"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ho-vc-hour24-paths", ("ho_vc_hour24_paths", PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths))])
                            self._leafs = OrderedDict()

                            self.ho_vc_hour24_paths = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths()
                            self.ho_vc_hour24_paths.parent = self
                            self._children_name_map["ho_vc_hour24_paths"] = "ho-vc-hour24-paths"
                            self._segment_path = lambda: "ho-vc-hour24"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24, [], name, value)


                        class HoVcHour24Paths(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: ho_vc_hour24_path
                            
                            	port 24 hour Path performance data
                            	**type**\: list of  		 :py:class:`HoVcHour24Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths, self).__init__()

                                self.yang_name = "ho-vc-hour24-paths"
                                self.yang_parent_name = "ho-vc-hour24"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ho-vc-hour24-path", ("ho_vc_hour24_path", PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path))])
                                self._leafs = OrderedDict()

                                self.ho_vc_hour24_path = YList(self)
                                self._segment_path = lambda: "ho-vc-hour24-paths"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths, [], name, value)


                            class HoVcHour24Path(Entity):
                                """
                                port 24 hour Path performance data
                                
                                .. attribute:: number  (key)
                                
                                	channel number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path
                                
                                	PATH
                                	**type**\:  :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path>`
                                
                                .. attribute:: fe_path
                                
                                	Far End PATH
                                	**type**\:  :py:class:`FePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.FePath>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path, self).__init__()

                                    self.yang_name = "ho-vc-hour24-path"
                                    self.yang_parent_name = "ho-vc-hour24-paths"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("path", ("path", PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path)), ("fe-path", ("fe_path", PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.FePath))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                    ])
                                    self.number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None

                                    self.path = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path()
                                    self.path.parent = self
                                    self._children_name_map["path"] = "path"

                                    self.fe_path = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.FePath()
                                    self.fe_path.parent = self
                                    self._children_name_map["fe_path"] = "fe-path"
                                    self._segment_path = lambda: "ho-vc-hour24-path" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear24_hr_time'], name, value)


                                class Path(Entity):
                                    """
                                    PATH
                                    
                                    .. attribute:: path_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:  :py:class:`PathESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathESs>`
                                    
                                    .. attribute:: path_es_rs
                                    
                                    	The number of Errored Seconds
                                    	**type**\:  :py:class:`PathEsRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathEsRs>`
                                    
                                    .. attribute:: path_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:  :py:class:`PathSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathSeSs>`
                                    
                                    .. attribute:: path_ses_rs
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:  :py:class:`PathSesRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathSesRs>`
                                    
                                    .. attribute:: path_e_bs
                                    
                                    	The number of Errored blocks
                                    	**type**\:  :py:class:`PathEBs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathEBs>`
                                    
                                    .. attribute:: path_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\:  :py:class:`PathUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathUaSs>`
                                    
                                    .. attribute:: path_bb_es
                                    
                                    	The number of background block errors
                                    	**type**\:  :py:class:`PathBbEs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathBbEs>`
                                    
                                    .. attribute:: path_bbe_rs
                                    
                                    	The number of background block errors
                                    	**type**\:  :py:class:`PathBbeRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathBbeRs>`
                                    
                                    .. attribute:: path_status
                                    
                                    	 status of the interface
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path, self).__init__()

                                        self.yang_name = "path"
                                        self.yang_parent_name = "ho-vc-hour24-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("path-e-ss", ("path_e_ss", PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathESs)), ("path-es-rs", ("path_es_rs", PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathEsRs)), ("path-se-ss", ("path_se_ss", PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathSeSs)), ("path-ses-rs", ("path_ses_rs", PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathSesRs)), ("path-e-bs", ("path_e_bs", PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathEBs)), ("path-ua-ss", ("path_ua_ss", PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathUaSs)), ("path-bb-es", ("path_bb_es", PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathBbEs)), ("path-bbe-rs", ("path_bbe_rs", PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathBbeRs))])
                                        self._leafs = OrderedDict([
                                            ('path_status', (YLeaf(YType.int32, 'path-status'), ['int'])),
                                        ])
                                        self.path_status = None

                                        self.path_e_ss = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathESs()
                                        self.path_e_ss.parent = self
                                        self._children_name_map["path_e_ss"] = "path-e-ss"

                                        self.path_es_rs = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathEsRs()
                                        self.path_es_rs.parent = self
                                        self._children_name_map["path_es_rs"] = "path-es-rs"

                                        self.path_se_ss = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathSeSs()
                                        self.path_se_ss.parent = self
                                        self._children_name_map["path_se_ss"] = "path-se-ss"

                                        self.path_ses_rs = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathSesRs()
                                        self.path_ses_rs.parent = self
                                        self._children_name_map["path_ses_rs"] = "path-ses-rs"

                                        self.path_e_bs = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathEBs()
                                        self.path_e_bs.parent = self
                                        self._children_name_map["path_e_bs"] = "path-e-bs"

                                        self.path_ua_ss = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathUaSs()
                                        self.path_ua_ss.parent = self
                                        self._children_name_map["path_ua_ss"] = "path-ua-ss"

                                        self.path_bb_es = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathBbEs()
                                        self.path_bb_es.parent = self
                                        self._children_name_map["path_bb_es"] = "path-bb-es"

                                        self.path_bbe_rs = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathBbeRs()
                                        self.path_bbe_rs.parent = self
                                        self._children_name_map["path_bbe_rs"] = "path-bbe-rs"
                                        self._segment_path = lambda: "path"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path, ['path_status'], name, value)


                                    class PathESs(Entity):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathESs, self).__init__()

                                            self.yang_name = "path-e-ss"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "path-e-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathESs, ['data', 'threshold', 'tca_report'], name, value)


                                    class PathEsRs(Entity):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathEsRs, self).__init__()

                                            self.yang_name = "path-es-rs"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "path-es-rs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathEsRs, ['data', 'threshold', 'tca_report'], name, value)


                                    class PathSeSs(Entity):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathSeSs, self).__init__()

                                            self.yang_name = "path-se-ss"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "path-se-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathSeSs, ['data', 'threshold', 'tca_report'], name, value)


                                    class PathSesRs(Entity):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathSesRs, self).__init__()

                                            self.yang_name = "path-ses-rs"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "path-ses-rs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathSesRs, ['data', 'threshold', 'tca_report'], name, value)


                                    class PathEBs(Entity):
                                        """
                                        The number of Errored blocks
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathEBs, self).__init__()

                                            self.yang_name = "path-e-bs"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "path-e-bs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathEBs, ['data', 'threshold', 'tca_report'], name, value)


                                    class PathUaSs(Entity):
                                        """
                                        The number of Unavailable Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathUaSs, self).__init__()

                                            self.yang_name = "path-ua-ss"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "path-ua-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathUaSs, ['data', 'threshold', 'tca_report'], name, value)


                                    class PathBbEs(Entity):
                                        """
                                        The number of background block errors
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathBbEs, self).__init__()

                                            self.yang_name = "path-bb-es"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "path-bb-es"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathBbEs, ['data', 'threshold', 'tca_report'], name, value)


                                    class PathBbeRs(Entity):
                                        """
                                        The number of background block errors
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathBbeRs, self).__init__()

                                            self.yang_name = "path-bbe-rs"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "path-bbe-rs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathBbeRs, ['data', 'threshold', 'tca_report'], name, value)


                                class FePath(Entity):
                                    """
                                    Far End PATH
                                    
                                    .. attribute:: far_end_path_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: far_end_path_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: far_end_path_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: far_end_path_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.FePath, self).__init__()

                                        self.yang_name = "fe-path"
                                        self.yang_parent_name = "ho-vc-hour24-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('far_end_path_e_ss', (YLeaf(YType.uint32, 'far-end-path-e-ss'), ['int'])),
                                            ('far_end_path_se_ss', (YLeaf(YType.uint32, 'far-end-path-se-ss'), ['int'])),
                                            ('far_end_path_c_vs', (YLeaf(YType.uint32, 'far-end-path-c-vs'), ['int'])),
                                            ('far_end_path_ua_ss', (YLeaf(YType.uint32, 'far-end-path-ua-ss'), ['int'])),
                                        ])
                                        self.far_end_path_e_ss = None
                                        self.far_end_path_se_ss = None
                                        self.far_end_path_c_vs = None
                                        self.far_end_path_ua_ss = None
                                        self._segment_path = lambda: "fe-path"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.FePath, ['far_end_path_e_ss', 'far_end_path_se_ss', 'far_end_path_c_vs', 'far_end_path_ua_ss'], name, value)


                    class HoVcMinute15(Entity):
                        """
                        port current performance data
                        
                        .. attribute:: ho_vc_minute15_paths
                        
                        	port current performance data
                        	**type**\:  :py:class:`HoVcMinute15Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15, self).__init__()

                            self.yang_name = "ho-vc-minute15"
                            self.yang_parent_name = "ho-vc-current"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ho-vc-minute15-paths", ("ho_vc_minute15_paths", PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths))])
                            self._leafs = OrderedDict()

                            self.ho_vc_minute15_paths = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths()
                            self.ho_vc_minute15_paths.parent = self
                            self._children_name_map["ho_vc_minute15_paths"] = "ho-vc-minute15-paths"
                            self._segment_path = lambda: "ho-vc-minute15"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15, [], name, value)


                        class HoVcMinute15Paths(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: ho_vc_minute15_path
                            
                            	port 15\-minute Path performance data
                            	**type**\: list of  		 :py:class:`HoVcMinute15Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths, self).__init__()

                                self.yang_name = "ho-vc-minute15-paths"
                                self.yang_parent_name = "ho-vc-minute15"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ho-vc-minute15-path", ("ho_vc_minute15_path", PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path))])
                                self._leafs = OrderedDict()

                                self.ho_vc_minute15_path = YList(self)
                                self._segment_path = lambda: "ho-vc-minute15-paths"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths, [], name, value)


                            class HoVcMinute15Path(Entity):
                                """
                                port 15\-minute Path performance data
                                
                                .. attribute:: number  (key)
                                
                                	channel number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path
                                
                                	PATH
                                	**type**\:  :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path>`
                                
                                .. attribute:: fe_path
                                
                                	Far End PATH
                                	**type**\:  :py:class:`FePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.FePath>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path, self).__init__()

                                    self.yang_name = "ho-vc-minute15-path"
                                    self.yang_parent_name = "ho-vc-minute15-paths"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("path", ("path", PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path)), ("fe-path", ("fe_path", PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.FePath))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                    ])
                                    self.number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None

                                    self.path = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path()
                                    self.path.parent = self
                                    self._children_name_map["path"] = "path"

                                    self.fe_path = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.FePath()
                                    self.fe_path.parent = self
                                    self._children_name_map["fe_path"] = "fe-path"
                                    self._segment_path = lambda: "ho-vc-minute15-path" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear24_hr_time'], name, value)


                                class Path(Entity):
                                    """
                                    PATH
                                    
                                    .. attribute:: path_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:  :py:class:`PathESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathESs>`
                                    
                                    .. attribute:: path_es_rs
                                    
                                    	The number of Errored Seconds
                                    	**type**\:  :py:class:`PathEsRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathEsRs>`
                                    
                                    .. attribute:: path_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:  :py:class:`PathSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathSeSs>`
                                    
                                    .. attribute:: path_ses_rs
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:  :py:class:`PathSesRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathSesRs>`
                                    
                                    .. attribute:: path_e_bs
                                    
                                    	The number of Errored blocks
                                    	**type**\:  :py:class:`PathEBs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathEBs>`
                                    
                                    .. attribute:: path_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\:  :py:class:`PathUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathUaSs>`
                                    
                                    .. attribute:: path_bb_es
                                    
                                    	The number of background block errors
                                    	**type**\:  :py:class:`PathBbEs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathBbEs>`
                                    
                                    .. attribute:: path_bbe_rs
                                    
                                    	The number of background block errors
                                    	**type**\:  :py:class:`PathBbeRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathBbeRs>`
                                    
                                    .. attribute:: path_status
                                    
                                    	 status of the interface
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path, self).__init__()

                                        self.yang_name = "path"
                                        self.yang_parent_name = "ho-vc-minute15-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("path-e-ss", ("path_e_ss", PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathESs)), ("path-es-rs", ("path_es_rs", PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathEsRs)), ("path-se-ss", ("path_se_ss", PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathSeSs)), ("path-ses-rs", ("path_ses_rs", PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathSesRs)), ("path-e-bs", ("path_e_bs", PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathEBs)), ("path-ua-ss", ("path_ua_ss", PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathUaSs)), ("path-bb-es", ("path_bb_es", PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathBbEs)), ("path-bbe-rs", ("path_bbe_rs", PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathBbeRs))])
                                        self._leafs = OrderedDict([
                                            ('path_status', (YLeaf(YType.int32, 'path-status'), ['int'])),
                                        ])
                                        self.path_status = None

                                        self.path_e_ss = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathESs()
                                        self.path_e_ss.parent = self
                                        self._children_name_map["path_e_ss"] = "path-e-ss"

                                        self.path_es_rs = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathEsRs()
                                        self.path_es_rs.parent = self
                                        self._children_name_map["path_es_rs"] = "path-es-rs"

                                        self.path_se_ss = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathSeSs()
                                        self.path_se_ss.parent = self
                                        self._children_name_map["path_se_ss"] = "path-se-ss"

                                        self.path_ses_rs = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathSesRs()
                                        self.path_ses_rs.parent = self
                                        self._children_name_map["path_ses_rs"] = "path-ses-rs"

                                        self.path_e_bs = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathEBs()
                                        self.path_e_bs.parent = self
                                        self._children_name_map["path_e_bs"] = "path-e-bs"

                                        self.path_ua_ss = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathUaSs()
                                        self.path_ua_ss.parent = self
                                        self._children_name_map["path_ua_ss"] = "path-ua-ss"

                                        self.path_bb_es = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathBbEs()
                                        self.path_bb_es.parent = self
                                        self._children_name_map["path_bb_es"] = "path-bb-es"

                                        self.path_bbe_rs = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathBbeRs()
                                        self.path_bbe_rs.parent = self
                                        self._children_name_map["path_bbe_rs"] = "path-bbe-rs"
                                        self._segment_path = lambda: "path"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path, ['path_status'], name, value)


                                    class PathESs(Entity):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathESs, self).__init__()

                                            self.yang_name = "path-e-ss"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "path-e-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathESs, ['data', 'threshold', 'tca_report'], name, value)


                                    class PathEsRs(Entity):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathEsRs, self).__init__()

                                            self.yang_name = "path-es-rs"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "path-es-rs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathEsRs, ['data', 'threshold', 'tca_report'], name, value)


                                    class PathSeSs(Entity):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathSeSs, self).__init__()

                                            self.yang_name = "path-se-ss"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "path-se-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathSeSs, ['data', 'threshold', 'tca_report'], name, value)


                                    class PathSesRs(Entity):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathSesRs, self).__init__()

                                            self.yang_name = "path-ses-rs"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "path-ses-rs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathSesRs, ['data', 'threshold', 'tca_report'], name, value)


                                    class PathEBs(Entity):
                                        """
                                        The number of Errored blocks
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathEBs, self).__init__()

                                            self.yang_name = "path-e-bs"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "path-e-bs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathEBs, ['data', 'threshold', 'tca_report'], name, value)


                                    class PathUaSs(Entity):
                                        """
                                        The number of Unavailable Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathUaSs, self).__init__()

                                            self.yang_name = "path-ua-ss"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "path-ua-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathUaSs, ['data', 'threshold', 'tca_report'], name, value)


                                    class PathBbEs(Entity):
                                        """
                                        The number of background block errors
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathBbEs, self).__init__()

                                            self.yang_name = "path-bb-es"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "path-bb-es"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathBbEs, ['data', 'threshold', 'tca_report'], name, value)


                                    class PathBbeRs(Entity):
                                        """
                                        The number of background block errors
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathBbeRs, self).__init__()

                                            self.yang_name = "path-bbe-rs"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "path-bbe-rs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathBbeRs, ['data', 'threshold', 'tca_report'], name, value)


                                class FePath(Entity):
                                    """
                                    Far End PATH
                                    
                                    .. attribute:: far_end_path_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: far_end_path_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: far_end_path_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: far_end_path_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.FePath, self).__init__()

                                        self.yang_name = "fe-path"
                                        self.yang_parent_name = "ho-vc-minute15-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('far_end_path_e_ss', (YLeaf(YType.uint32, 'far-end-path-e-ss'), ['int'])),
                                            ('far_end_path_se_ss', (YLeaf(YType.uint32, 'far-end-path-se-ss'), ['int'])),
                                            ('far_end_path_c_vs', (YLeaf(YType.uint32, 'far-end-path-c-vs'), ['int'])),
                                            ('far_end_path_ua_ss', (YLeaf(YType.uint32, 'far-end-path-ua-ss'), ['int'])),
                                        ])
                                        self.far_end_path_e_ss = None
                                        self.far_end_path_se_ss = None
                                        self.far_end_path_c_vs = None
                                        self.far_end_path_ua_ss = None
                                        self._segment_path = lambda: "fe-path"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.FePath, ['far_end_path_e_ss', 'far_end_path_se_ss', 'far_end_path_c_vs', 'far_end_path_ua_ss'], name, value)


    class Odu(Entity):
        """
        ODU controller performance data
        
        .. attribute:: odu_ports
        
        	Port performance data
        	**type**\:  :py:class:`OduPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts>`
        
        

        """

        _prefix = 'pmengine-oper'
        _revision = '2017-09-07'

        def __init__(self):
            super(PerformanceManagement.Odu, self).__init__()

            self.yang_name = "odu"
            self.yang_parent_name = "performance-management"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("odu-ports", ("odu_ports", PerformanceManagement.Odu.OduPorts))])
            self._leafs = OrderedDict()

            self.odu_ports = PerformanceManagement.Odu.OduPorts()
            self.odu_ports.parent = self
            self._children_name_map["odu_ports"] = "odu-ports"
            self._segment_path = lambda: "odu"
            self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(PerformanceManagement.Odu, [], name, value)


        class OduPorts(Entity):
            """
            Port performance data
            
            .. attribute:: odu_port
            
            	Port performance data
            	**type**\: list of  		 :py:class:`OduPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort>`
            
            

            """

            _prefix = 'pmengine-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(PerformanceManagement.Odu.OduPorts, self).__init__()

                self.yang_name = "odu-ports"
                self.yang_parent_name = "odu"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("odu-port", ("odu_port", PerformanceManagement.Odu.OduPorts.OduPort))])
                self._leafs = OrderedDict()

                self.odu_port = YList(self)
                self._segment_path = lambda: "odu-ports"
                self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management/odu/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(PerformanceManagement.Odu.OduPorts, [], name, value)


            class OduPort(Entity):
                """
                Port performance data
                
                .. attribute:: name  (key)
                
                	Port name
                	**type**\: str
                
                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                
                .. attribute:: odu_current
                
                	port current performance data
                	**type**\:  :py:class:`OduCurrent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(PerformanceManagement.Odu.OduPorts.OduPort, self).__init__()

                    self.yang_name = "odu-port"
                    self.yang_parent_name = "odu-ports"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("odu-current", ("odu_current", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ])
                    self.name = None

                    self.odu_current = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent()
                    self.odu_current.parent = self
                    self._children_name_map["odu_current"] = "odu-current"
                    self._segment_path = lambda: "odu-port" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management/odu/odu-ports/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort, ['name'], name, value)


                class OduCurrent(Entity):
                    """
                    port current performance data
                    
                    .. attribute:: odu_minute15
                    
                    	port current performance data
                    	**type**\:  :py:class:`OduMinute15 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15>`
                    
                    .. attribute:: odu_hour24
                    
                    	port current performance data
                    	**type**\:  :py:class:`OduHour24 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent, self).__init__()

                        self.yang_name = "odu-current"
                        self.yang_parent_name = "odu-port"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("odu-minute15", ("odu_minute15", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15)), ("odu-hour24", ("odu_hour24", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24))])
                        self._leafs = OrderedDict()

                        self.odu_minute15 = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15()
                        self.odu_minute15.parent = self
                        self._children_name_map["odu_minute15"] = "odu-minute15"

                        self.odu_hour24 = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24()
                        self.odu_hour24.parent = self
                        self._children_name_map["odu_hour24"] = "odu-hour24"
                        self._segment_path = lambda: "odu-current"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent, [], name, value)


                    class OduMinute15(Entity):
                        """
                        port current performance data
                        
                        .. attribute:: odu_minute15gfps
                        
                        	port current performance data
                        	**type**\:  :py:class:`OduMinute15gfps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15gfps>`
                        
                        .. attribute:: odu_minute15prbses
                        
                        	port current performance data
                        	**type**\:  :py:class:`OduMinute15prbses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15prbses>`
                        
                        .. attribute:: odu_minute15otns
                        
                        	port current performance data
                        	**type**\:  :py:class:`OduMinute15otns <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15, self).__init__()

                            self.yang_name = "odu-minute15"
                            self.yang_parent_name = "odu-current"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("odu-minute15gfps", ("odu_minute15gfps", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15gfps)), ("odu-minute15prbses", ("odu_minute15prbses", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15prbses)), ("odu-minute15otns", ("odu_minute15otns", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns))])
                            self._leafs = OrderedDict()

                            self.odu_minute15gfps = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15gfps()
                            self.odu_minute15gfps.parent = self
                            self._children_name_map["odu_minute15gfps"] = "odu-minute15gfps"

                            self.odu_minute15prbses = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15prbses()
                            self.odu_minute15prbses.parent = self
                            self._children_name_map["odu_minute15prbses"] = "odu-minute15prbses"

                            self.odu_minute15otns = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns()
                            self.odu_minute15otns.parent = self
                            self._children_name_map["odu_minute15otns"] = "odu-minute15otns"
                            self._segment_path = lambda: "odu-minute15"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15, [], name, value)


                        class OduMinute15gfps(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: odu_minute15gfp
                            
                            	port 15\-minute otn performance data
                            	**type**\: list of  		 :py:class:`OduMinute15gfp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15gfps.OduMinute15gfp>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15gfps, self).__init__()

                                self.yang_name = "odu-minute15gfps"
                                self.yang_parent_name = "odu-minute15"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("odu-minute15gfp", ("odu_minute15gfp", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15gfps.OduMinute15gfp))])
                                self._leafs = OrderedDict()

                                self.odu_minute15gfp = YList(self)
                                self._segment_path = lambda: "odu-minute15gfps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15gfps, [], name, value)


                            class OduMinute15gfp(Entity):
                                """
                                port 15\-minute otn performance data
                                
                                .. attribute:: number  (key)
                                
                                	channel number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rx_bit_err
                                
                                	RX BIT ERR
                                	**type**\:  :py:class:`RxBitErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15gfps.OduMinute15gfp.RxBitErr>`
                                
                                .. attribute:: rx_inv_typ
                                
                                	RX INV TYP
                                	**type**\:  :py:class:`RxInvTyp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15gfps.OduMinute15gfp.RxInvTyp>`
                                
                                .. attribute:: rx_crc
                                
                                	RX CRC
                                	**type**\:  :py:class:`RxCrc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15gfps.OduMinute15gfp.RxCrc>`
                                
                                .. attribute:: rx_lfd
                                
                                	RX LFD
                                	**type**\:  :py:class:`RxLfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15gfps.OduMinute15gfp.RxLfd>`
                                
                                .. attribute:: rx_csf
                                
                                	RX CSF
                                	**type**\:  :py:class:`RxCsf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15gfps.OduMinute15gfp.RxCsf>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15gfps.OduMinute15gfp, self).__init__()

                                    self.yang_name = "odu-minute15gfp"
                                    self.yang_parent_name = "odu-minute15gfps"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("rx-bit-err", ("rx_bit_err", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15gfps.OduMinute15gfp.RxBitErr)), ("rx-inv-typ", ("rx_inv_typ", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15gfps.OduMinute15gfp.RxInvTyp)), ("rx-crc", ("rx_crc", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15gfps.OduMinute15gfp.RxCrc)), ("rx-lfd", ("rx_lfd", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15gfps.OduMinute15gfp.RxLfd)), ("rx-csf", ("rx_csf", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15gfps.OduMinute15gfp.RxCsf))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                        ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                    ])
                                    self.number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear24_hr_time = None
                                    self.sec30_support = None

                                    self.rx_bit_err = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15gfps.OduMinute15gfp.RxBitErr()
                                    self.rx_bit_err.parent = self
                                    self._children_name_map["rx_bit_err"] = "rx-bit-err"

                                    self.rx_inv_typ = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15gfps.OduMinute15gfp.RxInvTyp()
                                    self.rx_inv_typ.parent = self
                                    self._children_name_map["rx_inv_typ"] = "rx-inv-typ"

                                    self.rx_crc = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15gfps.OduMinute15gfp.RxCrc()
                                    self.rx_crc.parent = self
                                    self._children_name_map["rx_crc"] = "rx-crc"

                                    self.rx_lfd = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15gfps.OduMinute15gfp.RxLfd()
                                    self.rx_lfd.parent = self
                                    self._children_name_map["rx_lfd"] = "rx-lfd"

                                    self.rx_csf = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15gfps.OduMinute15gfp.RxCsf()
                                    self.rx_csf.parent = self
                                    self._children_name_map["rx_csf"] = "rx-csf"
                                    self._segment_path = lambda: "odu-minute15gfp" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15gfps.OduMinute15gfp, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                class RxBitErr(Entity):
                                    """
                                    RX BIT ERR
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15gfps.OduMinute15gfp.RxBitErr, self).__init__()

                                        self.yang_name = "rx-bit-err"
                                        self.yang_parent_name = "odu-minute15gfp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "rx-bit-err"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15gfps.OduMinute15gfp.RxBitErr, ['data', 'threshold', 'tca_report'], name, value)


                                class RxInvTyp(Entity):
                                    """
                                    RX INV TYP
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15gfps.OduMinute15gfp.RxInvTyp, self).__init__()

                                        self.yang_name = "rx-inv-typ"
                                        self.yang_parent_name = "odu-minute15gfp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "rx-inv-typ"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15gfps.OduMinute15gfp.RxInvTyp, ['data', 'threshold', 'tca_report'], name, value)


                                class RxCrc(Entity):
                                    """
                                    RX CRC
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15gfps.OduMinute15gfp.RxCrc, self).__init__()

                                        self.yang_name = "rx-crc"
                                        self.yang_parent_name = "odu-minute15gfp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "rx-crc"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15gfps.OduMinute15gfp.RxCrc, ['data', 'threshold', 'tca_report'], name, value)


                                class RxLfd(Entity):
                                    """
                                    RX LFD
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15gfps.OduMinute15gfp.RxLfd, self).__init__()

                                        self.yang_name = "rx-lfd"
                                        self.yang_parent_name = "odu-minute15gfp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "rx-lfd"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15gfps.OduMinute15gfp.RxLfd, ['data', 'threshold', 'tca_report'], name, value)


                                class RxCsf(Entity):
                                    """
                                    RX CSF
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15gfps.OduMinute15gfp.RxCsf, self).__init__()

                                        self.yang_name = "rx-csf"
                                        self.yang_parent_name = "odu-minute15gfp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "rx-csf"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15gfps.OduMinute15gfp.RxCsf, ['data', 'threshold', 'tca_report'], name, value)


                        class OduMinute15prbses(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: odu_minute15prbs
                            
                            	port 15\-minute prbs performance data
                            	**type**\: list of  		 :py:class:`OduMinute15prbs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15prbses.OduMinute15prbs>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15prbses, self).__init__()

                                self.yang_name = "odu-minute15prbses"
                                self.yang_parent_name = "odu-minute15"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("odu-minute15prbs", ("odu_minute15prbs", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15prbses.OduMinute15prbs))])
                                self._leafs = OrderedDict()

                                self.odu_minute15prbs = YList(self)
                                self._segment_path = lambda: "odu-minute15prbses"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15prbses, [], name, value)


                            class OduMinute15prbs(Entity):
                                """
                                port 15\-minute prbs performance data
                                
                                .. attribute:: number  (key)
                                
                                	channel number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rcv_patt
                                
                                	RCVD PTRN
                                	**type**\:  :py:class:`RcvPatt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15prbses.OduMinute15prbs.RcvPatt>`
                                
                                .. attribute:: prbs_status
                                
                                	PRBS STATUS
                                	**type**\:  :py:class:`PrbsStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15prbses.OduMinute15prbs.PrbsStatus>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: ebc
                                
                                	EBC
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: found_count
                                
                                	FOUND COUNT
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lost_count
                                
                                	LOST COUNT
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: found_at_time
                                
                                	FOUND AT TS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: lost_at_time
                                
                                	LOST AT TS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: conf_patt
                                
                                	CONFIG PTRN
                                	**type**\:  :py:class:`PmPrbsPatternEt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmPrbsPatternEt>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15prbses.OduMinute15prbs, self).__init__()

                                    self.yang_name = "odu-minute15prbs"
                                    self.yang_parent_name = "odu-minute15prbses"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("rcv-patt", ("rcv_patt", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15prbses.OduMinute15prbs.RcvPatt)), ("prbs-status", ("prbs_status", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15prbses.OduMinute15prbs.PrbsStatus))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                        ('ebc', (YLeaf(YType.uint64, 'ebc'), ['int'])),
                                        ('found_count', (YLeaf(YType.uint32, 'found-count'), ['int'])),
                                        ('lost_count', (YLeaf(YType.uint32, 'lost-count'), ['int'])),
                                        ('found_at_time', (YLeaf(YType.uint64, 'found-at-time'), ['int'])),
                                        ('lost_at_time', (YLeaf(YType.uint64, 'lost-at-time'), ['int'])),
                                        ('conf_patt', (YLeaf(YType.enumeration, 'conf-patt'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper', 'PmPrbsPatternEt', '')])),
                                    ])
                                    self.number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None
                                    self.ebc = None
                                    self.found_count = None
                                    self.lost_count = None
                                    self.found_at_time = None
                                    self.lost_at_time = None
                                    self.conf_patt = None

                                    self.rcv_patt = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15prbses.OduMinute15prbs.RcvPatt()
                                    self.rcv_patt.parent = self
                                    self._children_name_map["rcv_patt"] = "rcv-patt"

                                    self.prbs_status = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15prbses.OduMinute15prbs.PrbsStatus()
                                    self.prbs_status.parent = self
                                    self._children_name_map["prbs_status"] = "prbs-status"
                                    self._segment_path = lambda: "odu-minute15prbs" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15prbses.OduMinute15prbs, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear24_hr_time', 'ebc', 'found_count', 'lost_count', 'found_at_time', 'lost_at_time', 'conf_patt'], name, value)


                                class RcvPatt(Entity):
                                    """
                                    RCVD PTRN
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: rcv_patt
                                    
                                    	RCVD PTRN
                                    	**type**\:  :py:class:`PmPrbsPatternEt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmPrbsPatternEt>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15prbses.OduMinute15prbs.RcvPatt, self).__init__()

                                        self.yang_name = "rcv-patt"
                                        self.yang_parent_name = "odu-minute15prbs"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('rcv_patt', (YLeaf(YType.enumeration, 'rcv-patt'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper', 'PmPrbsPatternEt', '')])),
                                        ])
                                        self.valid = None
                                        self.rcv_patt = None
                                        self._segment_path = lambda: "rcv-patt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15prbses.OduMinute15prbs.RcvPatt, ['valid', 'rcv_patt'], name, value)


                                class PrbsStatus(Entity):
                                    """
                                    PRBS STATUS
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: prbs_status
                                    
                                    	Prbs Status
                                    	**type**\:  :py:class:`PmPrbsStatusEt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmPrbsStatusEt>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15prbses.OduMinute15prbs.PrbsStatus, self).__init__()

                                        self.yang_name = "prbs-status"
                                        self.yang_parent_name = "odu-minute15prbs"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('prbs_status', (YLeaf(YType.enumeration, 'prbs-status'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper', 'PmPrbsStatusEt', '')])),
                                        ])
                                        self.valid = None
                                        self.prbs_status = None
                                        self._segment_path = lambda: "prbs-status"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15prbses.OduMinute15prbs.PrbsStatus, ['valid', 'prbs_status'], name, value)


                        class OduMinute15otns(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: odu_minute15otn
                            
                            	port 15\-minute otn performance data
                            	**type**\: list of  		 :py:class:`OduMinute15otn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns, self).__init__()

                                self.yang_name = "odu-minute15otns"
                                self.yang_parent_name = "odu-minute15"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("odu-minute15otn", ("odu_minute15otn", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn))])
                                self._leafs = OrderedDict()

                                self.odu_minute15otn = YList(self)
                                self._segment_path = lambda: "odu-minute15otns"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns, [], name, value)


                            class OduMinute15otn(Entity):
                                """
                                port 15\-minute otn performance data
                                
                                .. attribute:: number  (key)
                                
                                	channel number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lbc
                                
                                	LBC
                                	**type**\:  :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.Lbc>`
                                
                                .. attribute:: es_ne
                                
                                	ES SM NE
                                	**type**\:  :py:class:`EsNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.EsNe>`
                                
                                .. attribute:: esr_ne
                                
                                	ESR PM NE
                                	**type**\:  :py:class:`EsrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.EsrNe>`
                                
                                .. attribute:: ses_ne
                                
                                	SES SM NE
                                	**type**\:  :py:class:`SesNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.SesNe>`
                                
                                .. attribute:: sesr_ne
                                
                                	SESR SM NE
                                	**type**\:  :py:class:`SesrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.SesrNe>`
                                
                                .. attribute:: uas_ne
                                
                                	UAS SM NE
                                	**type**\:  :py:class:`UasNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.UasNe>`
                                
                                .. attribute:: bbe_ne
                                
                                	BBE SM NE
                                	**type**\:  :py:class:`BbeNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.BbeNe>`
                                
                                .. attribute:: bber_ne
                                
                                	BBER SM NE
                                	**type**\:  :py:class:`BberNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.BberNe>`
                                
                                .. attribute:: fc_ne
                                
                                	FC SM NE
                                	**type**\:  :py:class:`FcNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.FcNe>`
                                
                                .. attribute:: es_fe
                                
                                	ES SM FE
                                	**type**\:  :py:class:`EsFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.EsFe>`
                                
                                .. attribute:: esr_fe
                                
                                	ESR PM FE
                                	**type**\:  :py:class:`EsrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.EsrFe>`
                                
                                .. attribute:: ses_fe
                                
                                	SES SM FE
                                	**type**\:  :py:class:`SesFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.SesFe>`
                                
                                .. attribute:: sesr_fe
                                
                                	SESR SM FE
                                	**type**\:  :py:class:`SesrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.SesrFe>`
                                
                                .. attribute:: uas_fe
                                
                                	UAS SM FE
                                	**type**\:  :py:class:`UasFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.UasFe>`
                                
                                .. attribute:: bbe_fe
                                
                                	BBE SM FE
                                	**type**\:  :py:class:`BbeFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.BbeFe>`
                                
                                .. attribute:: bber_fe
                                
                                	BBER SM FE
                                	**type**\:  :py:class:`BberFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.BberFe>`
                                
                                .. attribute:: fc_fe
                                
                                	FC SM FE
                                	**type**\:  :py:class:`FcFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.FcFe>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn, self).__init__()

                                    self.yang_name = "odu-minute15otn"
                                    self.yang_parent_name = "odu-minute15otns"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("lbc", ("lbc", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.Lbc)), ("es-ne", ("es_ne", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.EsNe)), ("esr-ne", ("esr_ne", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.EsrNe)), ("ses-ne", ("ses_ne", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.SesNe)), ("sesr-ne", ("sesr_ne", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.SesrNe)), ("uas-ne", ("uas_ne", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.UasNe)), ("bbe-ne", ("bbe_ne", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.BbeNe)), ("bber-ne", ("bber_ne", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.BberNe)), ("fc-ne", ("fc_ne", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.FcNe)), ("es-fe", ("es_fe", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.EsFe)), ("esr-fe", ("esr_fe", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.EsrFe)), ("ses-fe", ("ses_fe", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.SesFe)), ("sesr-fe", ("sesr_fe", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.SesrFe)), ("uas-fe", ("uas_fe", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.UasFe)), ("bbe-fe", ("bbe_fe", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.BbeFe)), ("bber-fe", ("bber_fe", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.BberFe)), ("fc-fe", ("fc_fe", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.FcFe))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                        ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                    ])
                                    self.number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear24_hr_time = None
                                    self.sec30_support = None

                                    self.lbc = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.Lbc()
                                    self.lbc.parent = self
                                    self._children_name_map["lbc"] = "lbc"

                                    self.es_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.EsNe()
                                    self.es_ne.parent = self
                                    self._children_name_map["es_ne"] = "es-ne"

                                    self.esr_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.EsrNe()
                                    self.esr_ne.parent = self
                                    self._children_name_map["esr_ne"] = "esr-ne"

                                    self.ses_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.SesNe()
                                    self.ses_ne.parent = self
                                    self._children_name_map["ses_ne"] = "ses-ne"

                                    self.sesr_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.SesrNe()
                                    self.sesr_ne.parent = self
                                    self._children_name_map["sesr_ne"] = "sesr-ne"

                                    self.uas_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.UasNe()
                                    self.uas_ne.parent = self
                                    self._children_name_map["uas_ne"] = "uas-ne"

                                    self.bbe_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.BbeNe()
                                    self.bbe_ne.parent = self
                                    self._children_name_map["bbe_ne"] = "bbe-ne"

                                    self.bber_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.BberNe()
                                    self.bber_ne.parent = self
                                    self._children_name_map["bber_ne"] = "bber-ne"

                                    self.fc_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.FcNe()
                                    self.fc_ne.parent = self
                                    self._children_name_map["fc_ne"] = "fc-ne"

                                    self.es_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.EsFe()
                                    self.es_fe.parent = self
                                    self._children_name_map["es_fe"] = "es-fe"

                                    self.esr_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.EsrFe()
                                    self.esr_fe.parent = self
                                    self._children_name_map["esr_fe"] = "esr-fe"

                                    self.ses_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.SesFe()
                                    self.ses_fe.parent = self
                                    self._children_name_map["ses_fe"] = "ses-fe"

                                    self.sesr_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.SesrFe()
                                    self.sesr_fe.parent = self
                                    self._children_name_map["sesr_fe"] = "sesr-fe"

                                    self.uas_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.UasFe()
                                    self.uas_fe.parent = self
                                    self._children_name_map["uas_fe"] = "uas-fe"

                                    self.bbe_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.BbeFe()
                                    self.bbe_fe.parent = self
                                    self._children_name_map["bbe_fe"] = "bbe-fe"

                                    self.bber_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.BberFe()
                                    self.bber_fe.parent = self
                                    self._children_name_map["bber_fe"] = "bber-fe"

                                    self.fc_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.FcFe()
                                    self.fc_fe.parent = self
                                    self._children_name_map["fc_fe"] = "fc-fe"
                                    self._segment_path = lambda: "odu-minute15otn" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                class Lbc(Entity):
                                    """
                                    LBC
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.Lbc, self).__init__()

                                        self.yang_name = "lbc"
                                        self.yang_parent_name = "odu-minute15otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "lbc"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.Lbc, ['data', 'threshold', 'tca_report'], name, value)


                                class EsNe(Entity):
                                    """
                                    ES SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.EsNe, self).__init__()

                                        self.yang_name = "es-ne"
                                        self.yang_parent_name = "odu-minute15otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "es-ne"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.EsNe, ['data', 'threshold', 'tca_report'], name, value)


                                class EsrNe(Entity):
                                    """
                                    ESR PM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: str
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.EsrNe, self).__init__()

                                        self.yang_name = "esr-ne"
                                        self.yang_parent_name = "odu-minute15otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "esr-ne"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.EsrNe, ['data', 'threshold', 'tca_report'], name, value)


                                class SesNe(Entity):
                                    """
                                    SES SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.SesNe, self).__init__()

                                        self.yang_name = "ses-ne"
                                        self.yang_parent_name = "odu-minute15otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "ses-ne"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.SesNe, ['data', 'threshold', 'tca_report'], name, value)


                                class SesrNe(Entity):
                                    """
                                    SESR SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: str
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.SesrNe, self).__init__()

                                        self.yang_name = "sesr-ne"
                                        self.yang_parent_name = "odu-minute15otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "sesr-ne"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.SesrNe, ['data', 'threshold', 'tca_report'], name, value)


                                class UasNe(Entity):
                                    """
                                    UAS SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.UasNe, self).__init__()

                                        self.yang_name = "uas-ne"
                                        self.yang_parent_name = "odu-minute15otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "uas-ne"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.UasNe, ['data', 'threshold', 'tca_report'], name, value)


                                class BbeNe(Entity):
                                    """
                                    BBE SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.BbeNe, self).__init__()

                                        self.yang_name = "bbe-ne"
                                        self.yang_parent_name = "odu-minute15otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "bbe-ne"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.BbeNe, ['data', 'threshold', 'tca_report'], name, value)


                                class BberNe(Entity):
                                    """
                                    BBER SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: str
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.BberNe, self).__init__()

                                        self.yang_name = "bber-ne"
                                        self.yang_parent_name = "odu-minute15otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "bber-ne"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.BberNe, ['data', 'threshold', 'tca_report'], name, value)


                                class FcNe(Entity):
                                    """
                                    FC SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.FcNe, self).__init__()

                                        self.yang_name = "fc-ne"
                                        self.yang_parent_name = "odu-minute15otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "fc-ne"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.FcNe, ['data', 'threshold', 'tca_report'], name, value)


                                class EsFe(Entity):
                                    """
                                    ES SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.EsFe, self).__init__()

                                        self.yang_name = "es-fe"
                                        self.yang_parent_name = "odu-minute15otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "es-fe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.EsFe, ['data', 'threshold', 'tca_report'], name, value)


                                class EsrFe(Entity):
                                    """
                                    ESR PM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: str
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.EsrFe, self).__init__()

                                        self.yang_name = "esr-fe"
                                        self.yang_parent_name = "odu-minute15otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "esr-fe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.EsrFe, ['data', 'threshold', 'tca_report'], name, value)


                                class SesFe(Entity):
                                    """
                                    SES SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.SesFe, self).__init__()

                                        self.yang_name = "ses-fe"
                                        self.yang_parent_name = "odu-minute15otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "ses-fe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.SesFe, ['data', 'threshold', 'tca_report'], name, value)


                                class SesrFe(Entity):
                                    """
                                    SESR SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: str
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.SesrFe, self).__init__()

                                        self.yang_name = "sesr-fe"
                                        self.yang_parent_name = "odu-minute15otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "sesr-fe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.SesrFe, ['data', 'threshold', 'tca_report'], name, value)


                                class UasFe(Entity):
                                    """
                                    UAS SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.UasFe, self).__init__()

                                        self.yang_name = "uas-fe"
                                        self.yang_parent_name = "odu-minute15otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "uas-fe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.UasFe, ['data', 'threshold', 'tca_report'], name, value)


                                class BbeFe(Entity):
                                    """
                                    BBE SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.BbeFe, self).__init__()

                                        self.yang_name = "bbe-fe"
                                        self.yang_parent_name = "odu-minute15otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "bbe-fe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.BbeFe, ['data', 'threshold', 'tca_report'], name, value)


                                class BberFe(Entity):
                                    """
                                    BBER SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: str
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.BberFe, self).__init__()

                                        self.yang_name = "bber-fe"
                                        self.yang_parent_name = "odu-minute15otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "bber-fe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.BberFe, ['data', 'threshold', 'tca_report'], name, value)


                                class FcFe(Entity):
                                    """
                                    FC SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.FcFe, self).__init__()

                                        self.yang_name = "fc-fe"
                                        self.yang_parent_name = "odu-minute15otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "fc-fe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15otns.OduMinute15otn.FcFe, ['data', 'threshold', 'tca_report'], name, value)


                    class OduHour24(Entity):
                        """
                        port current performance data
                        
                        .. attribute:: odu_hour24prbses
                        
                        	port 24 hour performance data
                        	**type**\:  :py:class:`OduHour24prbses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24prbses>`
                        
                        .. attribute:: odu_hour24gfps
                        
                        	port 24 hour performance data
                        	**type**\:  :py:class:`OduHour24gfps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24gfps>`
                        
                        .. attribute:: odu_hour24otns
                        
                        	port 24 hour performance data
                        	**type**\:  :py:class:`OduHour24otns <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24, self).__init__()

                            self.yang_name = "odu-hour24"
                            self.yang_parent_name = "odu-current"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("odu-hour24prbses", ("odu_hour24prbses", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24prbses)), ("odu-hour24gfps", ("odu_hour24gfps", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24gfps)), ("odu-hour24otns", ("odu_hour24otns", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns))])
                            self._leafs = OrderedDict()

                            self.odu_hour24prbses = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24prbses()
                            self.odu_hour24prbses.parent = self
                            self._children_name_map["odu_hour24prbses"] = "odu-hour24prbses"

                            self.odu_hour24gfps = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24gfps()
                            self.odu_hour24gfps.parent = self
                            self._children_name_map["odu_hour24gfps"] = "odu-hour24gfps"

                            self.odu_hour24otns = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns()
                            self.odu_hour24otns.parent = self
                            self._children_name_map["odu_hour24otns"] = "odu-hour24otns"
                            self._segment_path = lambda: "odu-hour24"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24, [], name, value)


                        class OduHour24prbses(Entity):
                            """
                            port 24 hour performance data
                            
                            .. attribute:: odu_hour24prbs
                            
                            	port 24 hour otn performance data
                            	**type**\: list of  		 :py:class:`OduHour24prbs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24prbses.OduHour24prbs>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24prbses, self).__init__()

                                self.yang_name = "odu-hour24prbses"
                                self.yang_parent_name = "odu-hour24"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("odu-hour24prbs", ("odu_hour24prbs", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24prbses.OduHour24prbs))])
                                self._leafs = OrderedDict()

                                self.odu_hour24prbs = YList(self)
                                self._segment_path = lambda: "odu-hour24prbses"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24prbses, [], name, value)


                            class OduHour24prbs(Entity):
                                """
                                port 24 hour otn performance data
                                
                                .. attribute:: number  (key)
                                
                                	channel number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rcv_patt
                                
                                	RCVD PTRN
                                	**type**\:  :py:class:`RcvPatt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24prbses.OduHour24prbs.RcvPatt>`
                                
                                .. attribute:: prbs_status
                                
                                	PRBS STATUS
                                	**type**\:  :py:class:`PrbsStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24prbses.OduHour24prbs.PrbsStatus>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: ebc
                                
                                	EBC
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: found_count
                                
                                	FOUND COUNT
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lost_count
                                
                                	LOST COUNT
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: found_at_time
                                
                                	FOUND AT TS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: lost_at_time
                                
                                	LOST AT TS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: conf_patt
                                
                                	CONFIG PTRN
                                	**type**\:  :py:class:`PmPrbsPatternEt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmPrbsPatternEt>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24prbses.OduHour24prbs, self).__init__()

                                    self.yang_name = "odu-hour24prbs"
                                    self.yang_parent_name = "odu-hour24prbses"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("rcv-patt", ("rcv_patt", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24prbses.OduHour24prbs.RcvPatt)), ("prbs-status", ("prbs_status", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24prbses.OduHour24prbs.PrbsStatus))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                        ('ebc', (YLeaf(YType.uint64, 'ebc'), ['int'])),
                                        ('found_count', (YLeaf(YType.uint32, 'found-count'), ['int'])),
                                        ('lost_count', (YLeaf(YType.uint32, 'lost-count'), ['int'])),
                                        ('found_at_time', (YLeaf(YType.uint64, 'found-at-time'), ['int'])),
                                        ('lost_at_time', (YLeaf(YType.uint64, 'lost-at-time'), ['int'])),
                                        ('conf_patt', (YLeaf(YType.enumeration, 'conf-patt'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper', 'PmPrbsPatternEt', '')])),
                                    ])
                                    self.number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None
                                    self.ebc = None
                                    self.found_count = None
                                    self.lost_count = None
                                    self.found_at_time = None
                                    self.lost_at_time = None
                                    self.conf_patt = None

                                    self.rcv_patt = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24prbses.OduHour24prbs.RcvPatt()
                                    self.rcv_patt.parent = self
                                    self._children_name_map["rcv_patt"] = "rcv-patt"

                                    self.prbs_status = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24prbses.OduHour24prbs.PrbsStatus()
                                    self.prbs_status.parent = self
                                    self._children_name_map["prbs_status"] = "prbs-status"
                                    self._segment_path = lambda: "odu-hour24prbs" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24prbses.OduHour24prbs, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear24_hr_time', 'ebc', 'found_count', 'lost_count', 'found_at_time', 'lost_at_time', 'conf_patt'], name, value)


                                class RcvPatt(Entity):
                                    """
                                    RCVD PTRN
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: rcv_patt
                                    
                                    	RCVD PTRN
                                    	**type**\:  :py:class:`PmPrbsPatternEt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmPrbsPatternEt>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24prbses.OduHour24prbs.RcvPatt, self).__init__()

                                        self.yang_name = "rcv-patt"
                                        self.yang_parent_name = "odu-hour24prbs"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('rcv_patt', (YLeaf(YType.enumeration, 'rcv-patt'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper', 'PmPrbsPatternEt', '')])),
                                        ])
                                        self.valid = None
                                        self.rcv_patt = None
                                        self._segment_path = lambda: "rcv-patt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24prbses.OduHour24prbs.RcvPatt, ['valid', 'rcv_patt'], name, value)


                                class PrbsStatus(Entity):
                                    """
                                    PRBS STATUS
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: prbs_status
                                    
                                    	Prbs Status
                                    	**type**\:  :py:class:`PmPrbsStatusEt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmPrbsStatusEt>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24prbses.OduHour24prbs.PrbsStatus, self).__init__()

                                        self.yang_name = "prbs-status"
                                        self.yang_parent_name = "odu-hour24prbs"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('prbs_status', (YLeaf(YType.enumeration, 'prbs-status'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper', 'PmPrbsStatusEt', '')])),
                                        ])
                                        self.valid = None
                                        self.prbs_status = None
                                        self._segment_path = lambda: "prbs-status"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24prbses.OduHour24prbs.PrbsStatus, ['valid', 'prbs_status'], name, value)


                        class OduHour24gfps(Entity):
                            """
                            port 24 hour performance data
                            
                            .. attribute:: odu_hour24gfp
                            
                            	port 24 hour otn performance data
                            	**type**\: list of  		 :py:class:`OduHour24gfp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24gfps.OduHour24gfp>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24gfps, self).__init__()

                                self.yang_name = "odu-hour24gfps"
                                self.yang_parent_name = "odu-hour24"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("odu-hour24gfp", ("odu_hour24gfp", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24gfps.OduHour24gfp))])
                                self._leafs = OrderedDict()

                                self.odu_hour24gfp = YList(self)
                                self._segment_path = lambda: "odu-hour24gfps"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24gfps, [], name, value)


                            class OduHour24gfp(Entity):
                                """
                                port 24 hour otn performance data
                                
                                .. attribute:: number  (key)
                                
                                	channel number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rx_bit_err
                                
                                	RX BIT ERR
                                	**type**\:  :py:class:`RxBitErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24gfps.OduHour24gfp.RxBitErr>`
                                
                                .. attribute:: rx_inv_typ
                                
                                	RX INV TYP
                                	**type**\:  :py:class:`RxInvTyp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24gfps.OduHour24gfp.RxInvTyp>`
                                
                                .. attribute:: rx_crc
                                
                                	RX CRC
                                	**type**\:  :py:class:`RxCrc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24gfps.OduHour24gfp.RxCrc>`
                                
                                .. attribute:: rx_lfd
                                
                                	RX LFD
                                	**type**\:  :py:class:`RxLfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24gfps.OduHour24gfp.RxLfd>`
                                
                                .. attribute:: rx_csf
                                
                                	RX CSF
                                	**type**\:  :py:class:`RxCsf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24gfps.OduHour24gfp.RxCsf>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24gfps.OduHour24gfp, self).__init__()

                                    self.yang_name = "odu-hour24gfp"
                                    self.yang_parent_name = "odu-hour24gfps"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("rx-bit-err", ("rx_bit_err", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24gfps.OduHour24gfp.RxBitErr)), ("rx-inv-typ", ("rx_inv_typ", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24gfps.OduHour24gfp.RxInvTyp)), ("rx-crc", ("rx_crc", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24gfps.OduHour24gfp.RxCrc)), ("rx-lfd", ("rx_lfd", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24gfps.OduHour24gfp.RxLfd)), ("rx-csf", ("rx_csf", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24gfps.OduHour24gfp.RxCsf))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                        ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                    ])
                                    self.number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear24_hr_time = None
                                    self.sec30_support = None

                                    self.rx_bit_err = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24gfps.OduHour24gfp.RxBitErr()
                                    self.rx_bit_err.parent = self
                                    self._children_name_map["rx_bit_err"] = "rx-bit-err"

                                    self.rx_inv_typ = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24gfps.OduHour24gfp.RxInvTyp()
                                    self.rx_inv_typ.parent = self
                                    self._children_name_map["rx_inv_typ"] = "rx-inv-typ"

                                    self.rx_crc = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24gfps.OduHour24gfp.RxCrc()
                                    self.rx_crc.parent = self
                                    self._children_name_map["rx_crc"] = "rx-crc"

                                    self.rx_lfd = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24gfps.OduHour24gfp.RxLfd()
                                    self.rx_lfd.parent = self
                                    self._children_name_map["rx_lfd"] = "rx-lfd"

                                    self.rx_csf = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24gfps.OduHour24gfp.RxCsf()
                                    self.rx_csf.parent = self
                                    self._children_name_map["rx_csf"] = "rx-csf"
                                    self._segment_path = lambda: "odu-hour24gfp" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24gfps.OduHour24gfp, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                class RxBitErr(Entity):
                                    """
                                    RX BIT ERR
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24gfps.OduHour24gfp.RxBitErr, self).__init__()

                                        self.yang_name = "rx-bit-err"
                                        self.yang_parent_name = "odu-hour24gfp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "rx-bit-err"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24gfps.OduHour24gfp.RxBitErr, ['data', 'threshold', 'tca_report'], name, value)


                                class RxInvTyp(Entity):
                                    """
                                    RX INV TYP
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24gfps.OduHour24gfp.RxInvTyp, self).__init__()

                                        self.yang_name = "rx-inv-typ"
                                        self.yang_parent_name = "odu-hour24gfp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "rx-inv-typ"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24gfps.OduHour24gfp.RxInvTyp, ['data', 'threshold', 'tca_report'], name, value)


                                class RxCrc(Entity):
                                    """
                                    RX CRC
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24gfps.OduHour24gfp.RxCrc, self).__init__()

                                        self.yang_name = "rx-crc"
                                        self.yang_parent_name = "odu-hour24gfp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "rx-crc"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24gfps.OduHour24gfp.RxCrc, ['data', 'threshold', 'tca_report'], name, value)


                                class RxLfd(Entity):
                                    """
                                    RX LFD
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24gfps.OduHour24gfp.RxLfd, self).__init__()

                                        self.yang_name = "rx-lfd"
                                        self.yang_parent_name = "odu-hour24gfp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "rx-lfd"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24gfps.OduHour24gfp.RxLfd, ['data', 'threshold', 'tca_report'], name, value)


                                class RxCsf(Entity):
                                    """
                                    RX CSF
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24gfps.OduHour24gfp.RxCsf, self).__init__()

                                        self.yang_name = "rx-csf"
                                        self.yang_parent_name = "odu-hour24gfp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "rx-csf"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24gfps.OduHour24gfp.RxCsf, ['data', 'threshold', 'tca_report'], name, value)


                        class OduHour24otns(Entity):
                            """
                            port 24 hour performance data
                            
                            .. attribute:: odu_hour24otn
                            
                            	port 24 hour otn performance data
                            	**type**\: list of  		 :py:class:`OduHour24otn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns, self).__init__()

                                self.yang_name = "odu-hour24otns"
                                self.yang_parent_name = "odu-hour24"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("odu-hour24otn", ("odu_hour24otn", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn))])
                                self._leafs = OrderedDict()

                                self.odu_hour24otn = YList(self)
                                self._segment_path = lambda: "odu-hour24otns"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns, [], name, value)


                            class OduHour24otn(Entity):
                                """
                                port 24 hour otn performance data
                                
                                .. attribute:: number  (key)
                                
                                	channel number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lbc
                                
                                	LBC
                                	**type**\:  :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.Lbc>`
                                
                                .. attribute:: es_ne
                                
                                	ES SM NE
                                	**type**\:  :py:class:`EsNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.EsNe>`
                                
                                .. attribute:: esr_ne
                                
                                	ESR PM NE
                                	**type**\:  :py:class:`EsrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.EsrNe>`
                                
                                .. attribute:: ses_ne
                                
                                	SES SM NE
                                	**type**\:  :py:class:`SesNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.SesNe>`
                                
                                .. attribute:: sesr_ne
                                
                                	SESR SM NE
                                	**type**\:  :py:class:`SesrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.SesrNe>`
                                
                                .. attribute:: uas_ne
                                
                                	UAS SM NE
                                	**type**\:  :py:class:`UasNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.UasNe>`
                                
                                .. attribute:: bbe_ne
                                
                                	BBE SM NE
                                	**type**\:  :py:class:`BbeNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.BbeNe>`
                                
                                .. attribute:: bber_ne
                                
                                	BBER SM NE
                                	**type**\:  :py:class:`BberNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.BberNe>`
                                
                                .. attribute:: fc_ne
                                
                                	FC SM NE
                                	**type**\:  :py:class:`FcNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.FcNe>`
                                
                                .. attribute:: es_fe
                                
                                	ES SM FE
                                	**type**\:  :py:class:`EsFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.EsFe>`
                                
                                .. attribute:: esr_fe
                                
                                	ESR PM FE
                                	**type**\:  :py:class:`EsrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.EsrFe>`
                                
                                .. attribute:: ses_fe
                                
                                	SES SM FE
                                	**type**\:  :py:class:`SesFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.SesFe>`
                                
                                .. attribute:: sesr_fe
                                
                                	SESR SM FE
                                	**type**\:  :py:class:`SesrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.SesrFe>`
                                
                                .. attribute:: uas_fe
                                
                                	UAS SM FE
                                	**type**\:  :py:class:`UasFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.UasFe>`
                                
                                .. attribute:: bbe_fe
                                
                                	BBE SM FE
                                	**type**\:  :py:class:`BbeFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.BbeFe>`
                                
                                .. attribute:: bber_fe
                                
                                	BBER SM FE
                                	**type**\:  :py:class:`BberFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.BberFe>`
                                
                                .. attribute:: fc_fe
                                
                                	FC SM FE
                                	**type**\:  :py:class:`FcFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.FcFe>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn, self).__init__()

                                    self.yang_name = "odu-hour24otn"
                                    self.yang_parent_name = "odu-hour24otns"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("lbc", ("lbc", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.Lbc)), ("es-ne", ("es_ne", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.EsNe)), ("esr-ne", ("esr_ne", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.EsrNe)), ("ses-ne", ("ses_ne", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.SesNe)), ("sesr-ne", ("sesr_ne", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.SesrNe)), ("uas-ne", ("uas_ne", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.UasNe)), ("bbe-ne", ("bbe_ne", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.BbeNe)), ("bber-ne", ("bber_ne", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.BberNe)), ("fc-ne", ("fc_ne", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.FcNe)), ("es-fe", ("es_fe", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.EsFe)), ("esr-fe", ("esr_fe", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.EsrFe)), ("ses-fe", ("ses_fe", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.SesFe)), ("sesr-fe", ("sesr_fe", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.SesrFe)), ("uas-fe", ("uas_fe", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.UasFe)), ("bbe-fe", ("bbe_fe", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.BbeFe)), ("bber-fe", ("bber_fe", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.BberFe)), ("fc-fe", ("fc_fe", PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.FcFe))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                        ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                    ])
                                    self.number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear24_hr_time = None
                                    self.sec30_support = None

                                    self.lbc = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.Lbc()
                                    self.lbc.parent = self
                                    self._children_name_map["lbc"] = "lbc"

                                    self.es_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.EsNe()
                                    self.es_ne.parent = self
                                    self._children_name_map["es_ne"] = "es-ne"

                                    self.esr_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.EsrNe()
                                    self.esr_ne.parent = self
                                    self._children_name_map["esr_ne"] = "esr-ne"

                                    self.ses_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.SesNe()
                                    self.ses_ne.parent = self
                                    self._children_name_map["ses_ne"] = "ses-ne"

                                    self.sesr_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.SesrNe()
                                    self.sesr_ne.parent = self
                                    self._children_name_map["sesr_ne"] = "sesr-ne"

                                    self.uas_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.UasNe()
                                    self.uas_ne.parent = self
                                    self._children_name_map["uas_ne"] = "uas-ne"

                                    self.bbe_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.BbeNe()
                                    self.bbe_ne.parent = self
                                    self._children_name_map["bbe_ne"] = "bbe-ne"

                                    self.bber_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.BberNe()
                                    self.bber_ne.parent = self
                                    self._children_name_map["bber_ne"] = "bber-ne"

                                    self.fc_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.FcNe()
                                    self.fc_ne.parent = self
                                    self._children_name_map["fc_ne"] = "fc-ne"

                                    self.es_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.EsFe()
                                    self.es_fe.parent = self
                                    self._children_name_map["es_fe"] = "es-fe"

                                    self.esr_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.EsrFe()
                                    self.esr_fe.parent = self
                                    self._children_name_map["esr_fe"] = "esr-fe"

                                    self.ses_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.SesFe()
                                    self.ses_fe.parent = self
                                    self._children_name_map["ses_fe"] = "ses-fe"

                                    self.sesr_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.SesrFe()
                                    self.sesr_fe.parent = self
                                    self._children_name_map["sesr_fe"] = "sesr-fe"

                                    self.uas_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.UasFe()
                                    self.uas_fe.parent = self
                                    self._children_name_map["uas_fe"] = "uas-fe"

                                    self.bbe_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.BbeFe()
                                    self.bbe_fe.parent = self
                                    self._children_name_map["bbe_fe"] = "bbe-fe"

                                    self.bber_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.BberFe()
                                    self.bber_fe.parent = self
                                    self._children_name_map["bber_fe"] = "bber-fe"

                                    self.fc_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.FcFe()
                                    self.fc_fe.parent = self
                                    self._children_name_map["fc_fe"] = "fc-fe"
                                    self._segment_path = lambda: "odu-hour24otn" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                class Lbc(Entity):
                                    """
                                    LBC
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.Lbc, self).__init__()

                                        self.yang_name = "lbc"
                                        self.yang_parent_name = "odu-hour24otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "lbc"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.Lbc, ['data', 'threshold', 'tca_report'], name, value)


                                class EsNe(Entity):
                                    """
                                    ES SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.EsNe, self).__init__()

                                        self.yang_name = "es-ne"
                                        self.yang_parent_name = "odu-hour24otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "es-ne"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.EsNe, ['data', 'threshold', 'tca_report'], name, value)


                                class EsrNe(Entity):
                                    """
                                    ESR PM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: str
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.EsrNe, self).__init__()

                                        self.yang_name = "esr-ne"
                                        self.yang_parent_name = "odu-hour24otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "esr-ne"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.EsrNe, ['data', 'threshold', 'tca_report'], name, value)


                                class SesNe(Entity):
                                    """
                                    SES SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.SesNe, self).__init__()

                                        self.yang_name = "ses-ne"
                                        self.yang_parent_name = "odu-hour24otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "ses-ne"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.SesNe, ['data', 'threshold', 'tca_report'], name, value)


                                class SesrNe(Entity):
                                    """
                                    SESR SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: str
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.SesrNe, self).__init__()

                                        self.yang_name = "sesr-ne"
                                        self.yang_parent_name = "odu-hour24otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "sesr-ne"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.SesrNe, ['data', 'threshold', 'tca_report'], name, value)


                                class UasNe(Entity):
                                    """
                                    UAS SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.UasNe, self).__init__()

                                        self.yang_name = "uas-ne"
                                        self.yang_parent_name = "odu-hour24otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "uas-ne"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.UasNe, ['data', 'threshold', 'tca_report'], name, value)


                                class BbeNe(Entity):
                                    """
                                    BBE SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.BbeNe, self).__init__()

                                        self.yang_name = "bbe-ne"
                                        self.yang_parent_name = "odu-hour24otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "bbe-ne"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.BbeNe, ['data', 'threshold', 'tca_report'], name, value)


                                class BberNe(Entity):
                                    """
                                    BBER SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: str
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.BberNe, self).__init__()

                                        self.yang_name = "bber-ne"
                                        self.yang_parent_name = "odu-hour24otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "bber-ne"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.BberNe, ['data', 'threshold', 'tca_report'], name, value)


                                class FcNe(Entity):
                                    """
                                    FC SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.FcNe, self).__init__()

                                        self.yang_name = "fc-ne"
                                        self.yang_parent_name = "odu-hour24otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "fc-ne"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.FcNe, ['data', 'threshold', 'tca_report'], name, value)


                                class EsFe(Entity):
                                    """
                                    ES SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.EsFe, self).__init__()

                                        self.yang_name = "es-fe"
                                        self.yang_parent_name = "odu-hour24otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "es-fe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.EsFe, ['data', 'threshold', 'tca_report'], name, value)


                                class EsrFe(Entity):
                                    """
                                    ESR PM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: str
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.EsrFe, self).__init__()

                                        self.yang_name = "esr-fe"
                                        self.yang_parent_name = "odu-hour24otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "esr-fe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.EsrFe, ['data', 'threshold', 'tca_report'], name, value)


                                class SesFe(Entity):
                                    """
                                    SES SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.SesFe, self).__init__()

                                        self.yang_name = "ses-fe"
                                        self.yang_parent_name = "odu-hour24otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "ses-fe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.SesFe, ['data', 'threshold', 'tca_report'], name, value)


                                class SesrFe(Entity):
                                    """
                                    SESR SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: str
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.SesrFe, self).__init__()

                                        self.yang_name = "sesr-fe"
                                        self.yang_parent_name = "odu-hour24otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "sesr-fe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.SesrFe, ['data', 'threshold', 'tca_report'], name, value)


                                class UasFe(Entity):
                                    """
                                    UAS SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.UasFe, self).__init__()

                                        self.yang_name = "uas-fe"
                                        self.yang_parent_name = "odu-hour24otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "uas-fe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.UasFe, ['data', 'threshold', 'tca_report'], name, value)


                                class BbeFe(Entity):
                                    """
                                    BBE SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.BbeFe, self).__init__()

                                        self.yang_name = "bbe-fe"
                                        self.yang_parent_name = "odu-hour24otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "bbe-fe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.BbeFe, ['data', 'threshold', 'tca_report'], name, value)


                                class BberFe(Entity):
                                    """
                                    BBER SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: str
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.BberFe, self).__init__()

                                        self.yang_name = "bber-fe"
                                        self.yang_parent_name = "odu-hour24otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "bber-fe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.BberFe, ['data', 'threshold', 'tca_report'], name, value)


                                class FcFe(Entity):
                                    """
                                    FC SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.FcFe, self).__init__()

                                        self.yang_name = "fc-fe"
                                        self.yang_parent_name = "odu-hour24otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "fc-fe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24otns.OduHour24otn.FcFe, ['data', 'threshold', 'tca_report'], name, value)


    class Otu(Entity):
        """
        OTU controller performance data
        
        .. attribute:: otu_ports
        
        	Port performance data
        	**type**\:  :py:class:`OtuPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts>`
        
        

        """

        _prefix = 'pmengine-oper'
        _revision = '2017-09-07'

        def __init__(self):
            super(PerformanceManagement.Otu, self).__init__()

            self.yang_name = "otu"
            self.yang_parent_name = "performance-management"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("otu-ports", ("otu_ports", PerformanceManagement.Otu.OtuPorts))])
            self._leafs = OrderedDict()

            self.otu_ports = PerformanceManagement.Otu.OtuPorts()
            self.otu_ports.parent = self
            self._children_name_map["otu_ports"] = "otu-ports"
            self._segment_path = lambda: "otu"
            self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(PerformanceManagement.Otu, [], name, value)


        class OtuPorts(Entity):
            """
            Port performance data
            
            .. attribute:: otu_port
            
            	Port performance data
            	**type**\: list of  		 :py:class:`OtuPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort>`
            
            

            """

            _prefix = 'pmengine-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(PerformanceManagement.Otu.OtuPorts, self).__init__()

                self.yang_name = "otu-ports"
                self.yang_parent_name = "otu"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("otu-port", ("otu_port", PerformanceManagement.Otu.OtuPorts.OtuPort))])
                self._leafs = OrderedDict()

                self.otu_port = YList(self)
                self._segment_path = lambda: "otu-ports"
                self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management/otu/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(PerformanceManagement.Otu.OtuPorts, [], name, value)


            class OtuPort(Entity):
                """
                Port performance data
                
                .. attribute:: name  (key)
                
                	Port name
                	**type**\: str
                
                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                
                .. attribute:: otu_current
                
                	port current performance data
                	**type**\:  :py:class:`OtuCurrent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(PerformanceManagement.Otu.OtuPorts.OtuPort, self).__init__()

                    self.yang_name = "otu-port"
                    self.yang_parent_name = "otu-ports"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("otu-current", ("otu_current", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ])
                    self.name = None

                    self.otu_current = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent()
                    self.otu_current.parent = self
                    self._children_name_map["otu_current"] = "otu-current"
                    self._segment_path = lambda: "otu-port" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management/otu/otu-ports/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort, ['name'], name, value)


                class OtuCurrent(Entity):
                    """
                    port current performance data
                    
                    .. attribute:: otu_minute15
                    
                    	port current performance data
                    	**type**\:  :py:class:`OtuMinute15 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15>`
                    
                    .. attribute:: otu_second30
                    
                    	port current performance data
                    	**type**\:  :py:class:`OtuSecond30 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30>`
                    
                    .. attribute:: otu_hour24
                    
                    	port current performance data
                    	**type**\:  :py:class:`OtuHour24 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent, self).__init__()

                        self.yang_name = "otu-current"
                        self.yang_parent_name = "otu-port"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("otu-minute15", ("otu_minute15", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15)), ("otu-second30", ("otu_second30", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30)), ("otu-hour24", ("otu_hour24", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24))])
                        self._leafs = OrderedDict()

                        self.otu_minute15 = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15()
                        self.otu_minute15.parent = self
                        self._children_name_map["otu_minute15"] = "otu-minute15"

                        self.otu_second30 = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30()
                        self.otu_second30.parent = self
                        self._children_name_map["otu_second30"] = "otu-second30"

                        self.otu_hour24 = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24()
                        self.otu_hour24.parent = self
                        self._children_name_map["otu_hour24"] = "otu-hour24"
                        self._segment_path = lambda: "otu-current"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent, [], name, value)


                    class OtuMinute15(Entity):
                        """
                        port current performance data
                        
                        .. attribute:: otu_minute15fecs
                        
                        	port current performance data
                        	**type**\:  :py:class:`OtuMinute15fecs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15fecs>`
                        
                        .. attribute:: otu_minute15otns
                        
                        	port current performance data
                        	**type**\:  :py:class:`OtuMinute15otns <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns>`
                        
                        .. attribute:: otu_minute15prbses
                        
                        	port current performance data
                        	**type**\:  :py:class:`OtuMinute15prbses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15prbses>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15, self).__init__()

                            self.yang_name = "otu-minute15"
                            self.yang_parent_name = "otu-current"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("otu-minute15fecs", ("otu_minute15fecs", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15fecs)), ("otu-minute15otns", ("otu_minute15otns", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns)), ("otu-minute15prbses", ("otu_minute15prbses", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15prbses))])
                            self._leafs = OrderedDict()

                            self.otu_minute15fecs = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15fecs()
                            self.otu_minute15fecs.parent = self
                            self._children_name_map["otu_minute15fecs"] = "otu-minute15fecs"

                            self.otu_minute15otns = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns()
                            self.otu_minute15otns.parent = self
                            self._children_name_map["otu_minute15otns"] = "otu-minute15otns"

                            self.otu_minute15prbses = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15prbses()
                            self.otu_minute15prbses.parent = self
                            self._children_name_map["otu_minute15prbses"] = "otu-minute15prbses"
                            self._segment_path = lambda: "otu-minute15"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15, [], name, value)


                        class OtuMinute15fecs(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: otu_minute15fec
                            
                            	port 15\-minute fec performance data
                            	**type**\: list of  		 :py:class:`OtuMinute15fec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15fecs.OtuMinute15fec>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15fecs, self).__init__()

                                self.yang_name = "otu-minute15fecs"
                                self.yang_parent_name = "otu-minute15"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("otu-minute15fec", ("otu_minute15fec", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15fecs.OtuMinute15fec))])
                                self._leafs = OrderedDict()

                                self.otu_minute15fec = YList(self)
                                self._segment_path = lambda: "otu-minute15fecs"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15fecs, [], name, value)


                            class OtuMinute15fec(Entity):
                                """
                                port 15\-minute fec performance data
                                
                                .. attribute:: number  (key)
                                
                                	channel number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ec_bits
                                
                                	EC BITS
                                	**type**\:  :py:class:`EcBits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15fecs.OtuMinute15fec.EcBits>`
                                
                                .. attribute:: uc_words
                                
                                	UC WORDS
                                	**type**\:  :py:class:`UcWords <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15fecs.OtuMinute15fec.UcWords>`
                                
                                .. attribute:: pre_fec_ber
                                
                                	Pre FEC BER
                                	**type**\:  :py:class:`PreFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15fecs.OtuMinute15fec.PreFecBer>`
                                
                                .. attribute:: post_fec_ber
                                
                                	Post FEC BER
                                	**type**\:  :py:class:`PostFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15fecs.OtuMinute15fec.PostFecBer>`
                                
                                .. attribute:: q
                                
                                	Q
                                	**type**\:  :py:class:`Q <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15fecs.OtuMinute15fec.Q>`
                                
                                .. attribute:: qmargin
                                
                                	Q Margin
                                	**type**\:  :py:class:`Qmargin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15fecs.OtuMinute15fec.Qmargin>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15fecs.OtuMinute15fec, self).__init__()

                                    self.yang_name = "otu-minute15fec"
                                    self.yang_parent_name = "otu-minute15fecs"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("ec-bits", ("ec_bits", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15fecs.OtuMinute15fec.EcBits)), ("uc-words", ("uc_words", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15fecs.OtuMinute15fec.UcWords)), ("pre-fec-ber", ("pre_fec_ber", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15fecs.OtuMinute15fec.PreFecBer)), ("post-fec-ber", ("post_fec_ber", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15fecs.OtuMinute15fec.PostFecBer)), ("q", ("q", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15fecs.OtuMinute15fec.Q)), ("qmargin", ("qmargin", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15fecs.OtuMinute15fec.Qmargin))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                        ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                    ])
                                    self.number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear24_hr_time = None
                                    self.sec30_support = None

                                    self.ec_bits = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15fecs.OtuMinute15fec.EcBits()
                                    self.ec_bits.parent = self
                                    self._children_name_map["ec_bits"] = "ec-bits"

                                    self.uc_words = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15fecs.OtuMinute15fec.UcWords()
                                    self.uc_words.parent = self
                                    self._children_name_map["uc_words"] = "uc-words"

                                    self.pre_fec_ber = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15fecs.OtuMinute15fec.PreFecBer()
                                    self.pre_fec_ber.parent = self
                                    self._children_name_map["pre_fec_ber"] = "pre-fec-ber"

                                    self.post_fec_ber = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15fecs.OtuMinute15fec.PostFecBer()
                                    self.post_fec_ber.parent = self
                                    self._children_name_map["post_fec_ber"] = "post-fec-ber"

                                    self.q = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15fecs.OtuMinute15fec.Q()
                                    self.q.parent = self
                                    self._children_name_map["q"] = "q"

                                    self.qmargin = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15fecs.OtuMinute15fec.Qmargin()
                                    self.qmargin.parent = self
                                    self._children_name_map["qmargin"] = "qmargin"
                                    self._segment_path = lambda: "otu-minute15fec" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15fecs.OtuMinute15fec, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                class EcBits(Entity):
                                    """
                                    EC BITS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15fecs.OtuMinute15fec.EcBits, self).__init__()

                                        self.yang_name = "ec-bits"
                                        self.yang_parent_name = "otu-minute15fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ec-bits"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15fecs.OtuMinute15fec.EcBits, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class UcWords(Entity):
                                    """
                                    UC WORDS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15fecs.OtuMinute15fec.UcWords, self).__init__()

                                        self.yang_name = "uc-words"
                                        self.yang_parent_name = "otu-minute15fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "uc-words"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15fecs.OtuMinute15fec.UcWords, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class PreFecBer(Entity):
                                    """
                                    Pre FEC BER
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15fecs.OtuMinute15fec.PreFecBer, self).__init__()

                                        self.yang_name = "pre-fec-ber"
                                        self.yang_parent_name = "otu-minute15fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.maximum_tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "pre-fec-ber"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15fecs.OtuMinute15fec.PreFecBer, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                class PostFecBer(Entity):
                                    """
                                    Post FEC BER
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15fecs.OtuMinute15fec.PostFecBer, self).__init__()

                                        self.yang_name = "post-fec-ber"
                                        self.yang_parent_name = "otu-minute15fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.maximum_tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "post-fec-ber"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15fecs.OtuMinute15fec.PostFecBer, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                class Q(Entity):
                                    """
                                    Q
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15fecs.OtuMinute15fec.Q, self).__init__()

                                        self.yang_name = "q"
                                        self.yang_parent_name = "otu-minute15fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.maximum_tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "q"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15fecs.OtuMinute15fec.Q, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                class Qmargin(Entity):
                                    """
                                    Q Margin
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15fecs.OtuMinute15fec.Qmargin, self).__init__()

                                        self.yang_name = "qmargin"
                                        self.yang_parent_name = "otu-minute15fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.maximum_tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "qmargin"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15fecs.OtuMinute15fec.Qmargin, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                        class OtuMinute15otns(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: otu_minute15otn
                            
                            	port 15\-minute otn performance data
                            	**type**\: list of  		 :py:class:`OtuMinute15otn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns, self).__init__()

                                self.yang_name = "otu-minute15otns"
                                self.yang_parent_name = "otu-minute15"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("otu-minute15otn", ("otu_minute15otn", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn))])
                                self._leafs = OrderedDict()

                                self.otu_minute15otn = YList(self)
                                self._segment_path = lambda: "otu-minute15otns"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns, [], name, value)


                            class OtuMinute15otn(Entity):
                                """
                                port 15\-minute otn performance data
                                
                                .. attribute:: number  (key)
                                
                                	channel number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lbc
                                
                                	LBC
                                	**type**\:  :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.Lbc>`
                                
                                .. attribute:: es_ne
                                
                                	ES SM NE
                                	**type**\:  :py:class:`EsNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.EsNe>`
                                
                                .. attribute:: esr_ne
                                
                                	ESR PM NE
                                	**type**\:  :py:class:`EsrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.EsrNe>`
                                
                                .. attribute:: ses_ne
                                
                                	SES SM NE
                                	**type**\:  :py:class:`SesNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.SesNe>`
                                
                                .. attribute:: sesr_ne
                                
                                	SESR SM NE
                                	**type**\:  :py:class:`SesrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.SesrNe>`
                                
                                .. attribute:: uas_ne
                                
                                	UAS SM NE
                                	**type**\:  :py:class:`UasNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.UasNe>`
                                
                                .. attribute:: bbe_ne
                                
                                	BBE SM NE
                                	**type**\:  :py:class:`BbeNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.BbeNe>`
                                
                                .. attribute:: bber_ne
                                
                                	BBER SM NE
                                	**type**\:  :py:class:`BberNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.BberNe>`
                                
                                .. attribute:: fc_ne
                                
                                	FC SM NE
                                	**type**\:  :py:class:`FcNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.FcNe>`
                                
                                .. attribute:: es_fe
                                
                                	ES SM FE
                                	**type**\:  :py:class:`EsFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.EsFe>`
                                
                                .. attribute:: esr_fe
                                
                                	ESR PM FE
                                	**type**\:  :py:class:`EsrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.EsrFe>`
                                
                                .. attribute:: ses_fe
                                
                                	SES SM FE
                                	**type**\:  :py:class:`SesFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.SesFe>`
                                
                                .. attribute:: sesr_fe
                                
                                	SESR SM FE
                                	**type**\:  :py:class:`SesrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.SesrFe>`
                                
                                .. attribute:: uas_fe
                                
                                	UAS SM FE
                                	**type**\:  :py:class:`UasFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.UasFe>`
                                
                                .. attribute:: bbe_fe
                                
                                	BBE SM FE
                                	**type**\:  :py:class:`BbeFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.BbeFe>`
                                
                                .. attribute:: bber_fe
                                
                                	BBER SM FE
                                	**type**\:  :py:class:`BberFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.BberFe>`
                                
                                .. attribute:: fc_fe
                                
                                	FC SM FE
                                	**type**\:  :py:class:`FcFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.FcFe>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn, self).__init__()

                                    self.yang_name = "otu-minute15otn"
                                    self.yang_parent_name = "otu-minute15otns"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("lbc", ("lbc", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.Lbc)), ("es-ne", ("es_ne", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.EsNe)), ("esr-ne", ("esr_ne", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.EsrNe)), ("ses-ne", ("ses_ne", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.SesNe)), ("sesr-ne", ("sesr_ne", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.SesrNe)), ("uas-ne", ("uas_ne", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.UasNe)), ("bbe-ne", ("bbe_ne", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.BbeNe)), ("bber-ne", ("bber_ne", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.BberNe)), ("fc-ne", ("fc_ne", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.FcNe)), ("es-fe", ("es_fe", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.EsFe)), ("esr-fe", ("esr_fe", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.EsrFe)), ("ses-fe", ("ses_fe", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.SesFe)), ("sesr-fe", ("sesr_fe", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.SesrFe)), ("uas-fe", ("uas_fe", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.UasFe)), ("bbe-fe", ("bbe_fe", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.BbeFe)), ("bber-fe", ("bber_fe", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.BberFe)), ("fc-fe", ("fc_fe", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.FcFe))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                        ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                    ])
                                    self.number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear24_hr_time = None
                                    self.sec30_support = None

                                    self.lbc = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.Lbc()
                                    self.lbc.parent = self
                                    self._children_name_map["lbc"] = "lbc"

                                    self.es_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.EsNe()
                                    self.es_ne.parent = self
                                    self._children_name_map["es_ne"] = "es-ne"

                                    self.esr_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.EsrNe()
                                    self.esr_ne.parent = self
                                    self._children_name_map["esr_ne"] = "esr-ne"

                                    self.ses_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.SesNe()
                                    self.ses_ne.parent = self
                                    self._children_name_map["ses_ne"] = "ses-ne"

                                    self.sesr_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.SesrNe()
                                    self.sesr_ne.parent = self
                                    self._children_name_map["sesr_ne"] = "sesr-ne"

                                    self.uas_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.UasNe()
                                    self.uas_ne.parent = self
                                    self._children_name_map["uas_ne"] = "uas-ne"

                                    self.bbe_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.BbeNe()
                                    self.bbe_ne.parent = self
                                    self._children_name_map["bbe_ne"] = "bbe-ne"

                                    self.bber_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.BberNe()
                                    self.bber_ne.parent = self
                                    self._children_name_map["bber_ne"] = "bber-ne"

                                    self.fc_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.FcNe()
                                    self.fc_ne.parent = self
                                    self._children_name_map["fc_ne"] = "fc-ne"

                                    self.es_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.EsFe()
                                    self.es_fe.parent = self
                                    self._children_name_map["es_fe"] = "es-fe"

                                    self.esr_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.EsrFe()
                                    self.esr_fe.parent = self
                                    self._children_name_map["esr_fe"] = "esr-fe"

                                    self.ses_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.SesFe()
                                    self.ses_fe.parent = self
                                    self._children_name_map["ses_fe"] = "ses-fe"

                                    self.sesr_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.SesrFe()
                                    self.sesr_fe.parent = self
                                    self._children_name_map["sesr_fe"] = "sesr-fe"

                                    self.uas_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.UasFe()
                                    self.uas_fe.parent = self
                                    self._children_name_map["uas_fe"] = "uas-fe"

                                    self.bbe_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.BbeFe()
                                    self.bbe_fe.parent = self
                                    self._children_name_map["bbe_fe"] = "bbe-fe"

                                    self.bber_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.BberFe()
                                    self.bber_fe.parent = self
                                    self._children_name_map["bber_fe"] = "bber-fe"

                                    self.fc_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.FcFe()
                                    self.fc_fe.parent = self
                                    self._children_name_map["fc_fe"] = "fc-fe"
                                    self._segment_path = lambda: "otu-minute15otn" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                class Lbc(Entity):
                                    """
                                    LBC
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.Lbc, self).__init__()

                                        self.yang_name = "lbc"
                                        self.yang_parent_name = "otu-minute15otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "lbc"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.Lbc, ['data', 'threshold', 'tca_report'], name, value)


                                class EsNe(Entity):
                                    """
                                    ES SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.EsNe, self).__init__()

                                        self.yang_name = "es-ne"
                                        self.yang_parent_name = "otu-minute15otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "es-ne"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.EsNe, ['data', 'threshold', 'tca_report'], name, value)


                                class EsrNe(Entity):
                                    """
                                    ESR PM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: str
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.EsrNe, self).__init__()

                                        self.yang_name = "esr-ne"
                                        self.yang_parent_name = "otu-minute15otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "esr-ne"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.EsrNe, ['data', 'threshold', 'tca_report'], name, value)


                                class SesNe(Entity):
                                    """
                                    SES SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.SesNe, self).__init__()

                                        self.yang_name = "ses-ne"
                                        self.yang_parent_name = "otu-minute15otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "ses-ne"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.SesNe, ['data', 'threshold', 'tca_report'], name, value)


                                class SesrNe(Entity):
                                    """
                                    SESR SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: str
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.SesrNe, self).__init__()

                                        self.yang_name = "sesr-ne"
                                        self.yang_parent_name = "otu-minute15otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "sesr-ne"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.SesrNe, ['data', 'threshold', 'tca_report'], name, value)


                                class UasNe(Entity):
                                    """
                                    UAS SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.UasNe, self).__init__()

                                        self.yang_name = "uas-ne"
                                        self.yang_parent_name = "otu-minute15otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "uas-ne"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.UasNe, ['data', 'threshold', 'tca_report'], name, value)


                                class BbeNe(Entity):
                                    """
                                    BBE SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.BbeNe, self).__init__()

                                        self.yang_name = "bbe-ne"
                                        self.yang_parent_name = "otu-minute15otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "bbe-ne"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.BbeNe, ['data', 'threshold', 'tca_report'], name, value)


                                class BberNe(Entity):
                                    """
                                    BBER SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: str
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.BberNe, self).__init__()

                                        self.yang_name = "bber-ne"
                                        self.yang_parent_name = "otu-minute15otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "bber-ne"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.BberNe, ['data', 'threshold', 'tca_report'], name, value)


                                class FcNe(Entity):
                                    """
                                    FC SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.FcNe, self).__init__()

                                        self.yang_name = "fc-ne"
                                        self.yang_parent_name = "otu-minute15otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "fc-ne"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.FcNe, ['data', 'threshold', 'tca_report'], name, value)


                                class EsFe(Entity):
                                    """
                                    ES SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.EsFe, self).__init__()

                                        self.yang_name = "es-fe"
                                        self.yang_parent_name = "otu-minute15otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "es-fe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.EsFe, ['data', 'threshold', 'tca_report'], name, value)


                                class EsrFe(Entity):
                                    """
                                    ESR PM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: str
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.EsrFe, self).__init__()

                                        self.yang_name = "esr-fe"
                                        self.yang_parent_name = "otu-minute15otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "esr-fe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.EsrFe, ['data', 'threshold', 'tca_report'], name, value)


                                class SesFe(Entity):
                                    """
                                    SES SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.SesFe, self).__init__()

                                        self.yang_name = "ses-fe"
                                        self.yang_parent_name = "otu-minute15otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "ses-fe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.SesFe, ['data', 'threshold', 'tca_report'], name, value)


                                class SesrFe(Entity):
                                    """
                                    SESR SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: str
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.SesrFe, self).__init__()

                                        self.yang_name = "sesr-fe"
                                        self.yang_parent_name = "otu-minute15otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "sesr-fe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.SesrFe, ['data', 'threshold', 'tca_report'], name, value)


                                class UasFe(Entity):
                                    """
                                    UAS SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.UasFe, self).__init__()

                                        self.yang_name = "uas-fe"
                                        self.yang_parent_name = "otu-minute15otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "uas-fe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.UasFe, ['data', 'threshold', 'tca_report'], name, value)


                                class BbeFe(Entity):
                                    """
                                    BBE SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.BbeFe, self).__init__()

                                        self.yang_name = "bbe-fe"
                                        self.yang_parent_name = "otu-minute15otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "bbe-fe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.BbeFe, ['data', 'threshold', 'tca_report'], name, value)


                                class BberFe(Entity):
                                    """
                                    BBER SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: str
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.BberFe, self).__init__()

                                        self.yang_name = "bber-fe"
                                        self.yang_parent_name = "otu-minute15otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "bber-fe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.BberFe, ['data', 'threshold', 'tca_report'], name, value)


                                class FcFe(Entity):
                                    """
                                    FC SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.FcFe, self).__init__()

                                        self.yang_name = "fc-fe"
                                        self.yang_parent_name = "otu-minute15otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "fc-fe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15otns.OtuMinute15otn.FcFe, ['data', 'threshold', 'tca_report'], name, value)


                        class OtuMinute15prbses(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: otu_minute15prbs
                            
                            	port 15\-minute prbs performance data
                            	**type**\: list of  		 :py:class:`OtuMinute15prbs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15prbses.OtuMinute15prbs>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15prbses, self).__init__()

                                self.yang_name = "otu-minute15prbses"
                                self.yang_parent_name = "otu-minute15"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("otu-minute15prbs", ("otu_minute15prbs", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15prbses.OtuMinute15prbs))])
                                self._leafs = OrderedDict()

                                self.otu_minute15prbs = YList(self)
                                self._segment_path = lambda: "otu-minute15prbses"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15prbses, [], name, value)


                            class OtuMinute15prbs(Entity):
                                """
                                port 15\-minute prbs performance data
                                
                                .. attribute:: number  (key)
                                
                                	channel number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rcv_patt
                                
                                	RCVD PTRN
                                	**type**\:  :py:class:`RcvPatt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15prbses.OtuMinute15prbs.RcvPatt>`
                                
                                .. attribute:: prbs_status
                                
                                	PRBS STATUS
                                	**type**\:  :py:class:`PrbsStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15prbses.OtuMinute15prbs.PrbsStatus>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: ebc
                                
                                	EBC
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: found_count
                                
                                	FOUND COUNT
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lost_count
                                
                                	LOST COUNT
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: found_at_time
                                
                                	FOUND AT TS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: lost_at_time
                                
                                	LOST AT TS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: conf_patt
                                
                                	CONFIG PTRN
                                	**type**\:  :py:class:`PmPrbsPatternEt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmPrbsPatternEt>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15prbses.OtuMinute15prbs, self).__init__()

                                    self.yang_name = "otu-minute15prbs"
                                    self.yang_parent_name = "otu-minute15prbses"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("rcv-patt", ("rcv_patt", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15prbses.OtuMinute15prbs.RcvPatt)), ("prbs-status", ("prbs_status", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15prbses.OtuMinute15prbs.PrbsStatus))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                        ('ebc', (YLeaf(YType.uint64, 'ebc'), ['int'])),
                                        ('found_count', (YLeaf(YType.uint32, 'found-count'), ['int'])),
                                        ('lost_count', (YLeaf(YType.uint32, 'lost-count'), ['int'])),
                                        ('found_at_time', (YLeaf(YType.uint64, 'found-at-time'), ['int'])),
                                        ('lost_at_time', (YLeaf(YType.uint64, 'lost-at-time'), ['int'])),
                                        ('conf_patt', (YLeaf(YType.enumeration, 'conf-patt'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper', 'PmPrbsPatternEt', '')])),
                                    ])
                                    self.number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None
                                    self.ebc = None
                                    self.found_count = None
                                    self.lost_count = None
                                    self.found_at_time = None
                                    self.lost_at_time = None
                                    self.conf_patt = None

                                    self.rcv_patt = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15prbses.OtuMinute15prbs.RcvPatt()
                                    self.rcv_patt.parent = self
                                    self._children_name_map["rcv_patt"] = "rcv-patt"

                                    self.prbs_status = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15prbses.OtuMinute15prbs.PrbsStatus()
                                    self.prbs_status.parent = self
                                    self._children_name_map["prbs_status"] = "prbs-status"
                                    self._segment_path = lambda: "otu-minute15prbs" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15prbses.OtuMinute15prbs, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear24_hr_time', 'ebc', 'found_count', 'lost_count', 'found_at_time', 'lost_at_time', 'conf_patt'], name, value)


                                class RcvPatt(Entity):
                                    """
                                    RCVD PTRN
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: rcv_patt
                                    
                                    	RCVD PTRN
                                    	**type**\:  :py:class:`PmPrbsPatternEt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmPrbsPatternEt>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15prbses.OtuMinute15prbs.RcvPatt, self).__init__()

                                        self.yang_name = "rcv-patt"
                                        self.yang_parent_name = "otu-minute15prbs"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('rcv_patt', (YLeaf(YType.enumeration, 'rcv-patt'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper', 'PmPrbsPatternEt', '')])),
                                        ])
                                        self.valid = None
                                        self.rcv_patt = None
                                        self._segment_path = lambda: "rcv-patt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15prbses.OtuMinute15prbs.RcvPatt, ['valid', 'rcv_patt'], name, value)


                                class PrbsStatus(Entity):
                                    """
                                    PRBS STATUS
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: prbs_status
                                    
                                    	Prbs Status
                                    	**type**\:  :py:class:`PmPrbsStatusEt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmPrbsStatusEt>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15prbses.OtuMinute15prbs.PrbsStatus, self).__init__()

                                        self.yang_name = "prbs-status"
                                        self.yang_parent_name = "otu-minute15prbs"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('prbs_status', (YLeaf(YType.enumeration, 'prbs-status'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper', 'PmPrbsStatusEt', '')])),
                                        ])
                                        self.valid = None
                                        self.prbs_status = None
                                        self._segment_path = lambda: "prbs-status"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15prbses.OtuMinute15prbs.PrbsStatus, ['valid', 'prbs_status'], name, value)


                    class OtuSecond30(Entity):
                        """
                        port current performance data
                        
                        .. attribute:: otu_second30fecs
                        
                        	port current performance data
                        	**type**\:  :py:class:`OtuSecond30fecs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30fecs>`
                        
                        .. attribute:: otu_second30otns
                        
                        	port current performance data
                        	**type**\:  :py:class:`OtuSecond30otns <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30, self).__init__()

                            self.yang_name = "otu-second30"
                            self.yang_parent_name = "otu-current"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("otu-second30fecs", ("otu_second30fecs", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30fecs)), ("otu-second30otns", ("otu_second30otns", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns))])
                            self._leafs = OrderedDict()

                            self.otu_second30fecs = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30fecs()
                            self.otu_second30fecs.parent = self
                            self._children_name_map["otu_second30fecs"] = "otu-second30fecs"

                            self.otu_second30otns = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns()
                            self.otu_second30otns.parent = self
                            self._children_name_map["otu_second30otns"] = "otu-second30otns"
                            self._segment_path = lambda: "otu-second30"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30, [], name, value)


                        class OtuSecond30fecs(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: otu_second30fec
                            
                            	port 30\-sec fec performance data
                            	**type**\: list of  		 :py:class:`OtuSecond30fec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30fecs.OtuSecond30fec>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30fecs, self).__init__()

                                self.yang_name = "otu-second30fecs"
                                self.yang_parent_name = "otu-second30"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("otu-second30fec", ("otu_second30fec", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30fecs.OtuSecond30fec))])
                                self._leafs = OrderedDict()

                                self.otu_second30fec = YList(self)
                                self._segment_path = lambda: "otu-second30fecs"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30fecs, [], name, value)


                            class OtuSecond30fec(Entity):
                                """
                                port 30\-sec fec performance data
                                
                                .. attribute:: number  (key)
                                
                                	channel number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ec_bits
                                
                                	EC BITS
                                	**type**\:  :py:class:`EcBits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30fecs.OtuSecond30fec.EcBits>`
                                
                                .. attribute:: uc_words
                                
                                	UC WORDS
                                	**type**\:  :py:class:`UcWords <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30fecs.OtuSecond30fec.UcWords>`
                                
                                .. attribute:: pre_fec_ber
                                
                                	Pre FEC BER
                                	**type**\:  :py:class:`PreFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30fecs.OtuSecond30fec.PreFecBer>`
                                
                                .. attribute:: post_fec_ber
                                
                                	Post FEC BER
                                	**type**\:  :py:class:`PostFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30fecs.OtuSecond30fec.PostFecBer>`
                                
                                .. attribute:: q
                                
                                	Q
                                	**type**\:  :py:class:`Q <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30fecs.OtuSecond30fec.Q>`
                                
                                .. attribute:: qmargin
                                
                                	Q Margin
                                	**type**\:  :py:class:`Qmargin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30fecs.OtuSecond30fec.Qmargin>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30fecs.OtuSecond30fec, self).__init__()

                                    self.yang_name = "otu-second30fec"
                                    self.yang_parent_name = "otu-second30fecs"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("ec-bits", ("ec_bits", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30fecs.OtuSecond30fec.EcBits)), ("uc-words", ("uc_words", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30fecs.OtuSecond30fec.UcWords)), ("pre-fec-ber", ("pre_fec_ber", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30fecs.OtuSecond30fec.PreFecBer)), ("post-fec-ber", ("post_fec_ber", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30fecs.OtuSecond30fec.PostFecBer)), ("q", ("q", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30fecs.OtuSecond30fec.Q)), ("qmargin", ("qmargin", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30fecs.OtuSecond30fec.Qmargin))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                        ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                    ])
                                    self.number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear24_hr_time = None
                                    self.sec30_support = None

                                    self.ec_bits = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30fecs.OtuSecond30fec.EcBits()
                                    self.ec_bits.parent = self
                                    self._children_name_map["ec_bits"] = "ec-bits"

                                    self.uc_words = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30fecs.OtuSecond30fec.UcWords()
                                    self.uc_words.parent = self
                                    self._children_name_map["uc_words"] = "uc-words"

                                    self.pre_fec_ber = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30fecs.OtuSecond30fec.PreFecBer()
                                    self.pre_fec_ber.parent = self
                                    self._children_name_map["pre_fec_ber"] = "pre-fec-ber"

                                    self.post_fec_ber = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30fecs.OtuSecond30fec.PostFecBer()
                                    self.post_fec_ber.parent = self
                                    self._children_name_map["post_fec_ber"] = "post-fec-ber"

                                    self.q = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30fecs.OtuSecond30fec.Q()
                                    self.q.parent = self
                                    self._children_name_map["q"] = "q"

                                    self.qmargin = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30fecs.OtuSecond30fec.Qmargin()
                                    self.qmargin.parent = self
                                    self._children_name_map["qmargin"] = "qmargin"
                                    self._segment_path = lambda: "otu-second30fec" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30fecs.OtuSecond30fec, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                class EcBits(Entity):
                                    """
                                    EC BITS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30fecs.OtuSecond30fec.EcBits, self).__init__()

                                        self.yang_name = "ec-bits"
                                        self.yang_parent_name = "otu-second30fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ec-bits"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30fecs.OtuSecond30fec.EcBits, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class UcWords(Entity):
                                    """
                                    UC WORDS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30fecs.OtuSecond30fec.UcWords, self).__init__()

                                        self.yang_name = "uc-words"
                                        self.yang_parent_name = "otu-second30fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "uc-words"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30fecs.OtuSecond30fec.UcWords, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class PreFecBer(Entity):
                                    """
                                    Pre FEC BER
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30fecs.OtuSecond30fec.PreFecBer, self).__init__()

                                        self.yang_name = "pre-fec-ber"
                                        self.yang_parent_name = "otu-second30fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.maximum_tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "pre-fec-ber"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30fecs.OtuSecond30fec.PreFecBer, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                class PostFecBer(Entity):
                                    """
                                    Post FEC BER
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30fecs.OtuSecond30fec.PostFecBer, self).__init__()

                                        self.yang_name = "post-fec-ber"
                                        self.yang_parent_name = "otu-second30fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.maximum_tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "post-fec-ber"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30fecs.OtuSecond30fec.PostFecBer, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                class Q(Entity):
                                    """
                                    Q
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30fecs.OtuSecond30fec.Q, self).__init__()

                                        self.yang_name = "q"
                                        self.yang_parent_name = "otu-second30fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.maximum_tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "q"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30fecs.OtuSecond30fec.Q, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                class Qmargin(Entity):
                                    """
                                    Q Margin
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30fecs.OtuSecond30fec.Qmargin, self).__init__()

                                        self.yang_name = "qmargin"
                                        self.yang_parent_name = "otu-second30fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.maximum_tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "qmargin"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30fecs.OtuSecond30fec.Qmargin, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                        class OtuSecond30otns(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: otu_second30otn
                            
                            	port 30\-sec otn performance data
                            	**type**\: list of  		 :py:class:`OtuSecond30otn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns, self).__init__()

                                self.yang_name = "otu-second30otns"
                                self.yang_parent_name = "otu-second30"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("otu-second30otn", ("otu_second30otn", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn))])
                                self._leafs = OrderedDict()

                                self.otu_second30otn = YList(self)
                                self._segment_path = lambda: "otu-second30otns"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns, [], name, value)


                            class OtuSecond30otn(Entity):
                                """
                                port 30\-sec otn performance data
                                
                                .. attribute:: number  (key)
                                
                                	channel number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lbc
                                
                                	LBC
                                	**type**\:  :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.Lbc>`
                                
                                .. attribute:: es_ne
                                
                                	ES SM NE
                                	**type**\:  :py:class:`EsNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.EsNe>`
                                
                                .. attribute:: esr_ne
                                
                                	ESR PM NE
                                	**type**\:  :py:class:`EsrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.EsrNe>`
                                
                                .. attribute:: ses_ne
                                
                                	SES SM NE
                                	**type**\:  :py:class:`SesNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.SesNe>`
                                
                                .. attribute:: sesr_ne
                                
                                	SESR SM NE
                                	**type**\:  :py:class:`SesrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.SesrNe>`
                                
                                .. attribute:: uas_ne
                                
                                	UAS SM NE
                                	**type**\:  :py:class:`UasNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.UasNe>`
                                
                                .. attribute:: bbe_ne
                                
                                	BBE SM NE
                                	**type**\:  :py:class:`BbeNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.BbeNe>`
                                
                                .. attribute:: bber_ne
                                
                                	BBER SM NE
                                	**type**\:  :py:class:`BberNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.BberNe>`
                                
                                .. attribute:: fc_ne
                                
                                	FC SM NE
                                	**type**\:  :py:class:`FcNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.FcNe>`
                                
                                .. attribute:: es_fe
                                
                                	ES SM FE
                                	**type**\:  :py:class:`EsFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.EsFe>`
                                
                                .. attribute:: esr_fe
                                
                                	ESR PM FE
                                	**type**\:  :py:class:`EsrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.EsrFe>`
                                
                                .. attribute:: ses_fe
                                
                                	SES SM FE
                                	**type**\:  :py:class:`SesFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.SesFe>`
                                
                                .. attribute:: sesr_fe
                                
                                	SESR SM FE
                                	**type**\:  :py:class:`SesrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.SesrFe>`
                                
                                .. attribute:: uas_fe
                                
                                	UAS SM FE
                                	**type**\:  :py:class:`UasFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.UasFe>`
                                
                                .. attribute:: bbe_fe
                                
                                	BBE SM FE
                                	**type**\:  :py:class:`BbeFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.BbeFe>`
                                
                                .. attribute:: bber_fe
                                
                                	BBER SM FE
                                	**type**\:  :py:class:`BberFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.BberFe>`
                                
                                .. attribute:: fc_fe
                                
                                	FC SM FE
                                	**type**\:  :py:class:`FcFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.FcFe>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn, self).__init__()

                                    self.yang_name = "otu-second30otn"
                                    self.yang_parent_name = "otu-second30otns"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("lbc", ("lbc", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.Lbc)), ("es-ne", ("es_ne", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.EsNe)), ("esr-ne", ("esr_ne", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.EsrNe)), ("ses-ne", ("ses_ne", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.SesNe)), ("sesr-ne", ("sesr_ne", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.SesrNe)), ("uas-ne", ("uas_ne", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.UasNe)), ("bbe-ne", ("bbe_ne", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.BbeNe)), ("bber-ne", ("bber_ne", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.BberNe)), ("fc-ne", ("fc_ne", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.FcNe)), ("es-fe", ("es_fe", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.EsFe)), ("esr-fe", ("esr_fe", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.EsrFe)), ("ses-fe", ("ses_fe", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.SesFe)), ("sesr-fe", ("sesr_fe", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.SesrFe)), ("uas-fe", ("uas_fe", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.UasFe)), ("bbe-fe", ("bbe_fe", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.BbeFe)), ("bber-fe", ("bber_fe", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.BberFe)), ("fc-fe", ("fc_fe", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.FcFe))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                        ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                    ])
                                    self.number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear24_hr_time = None
                                    self.sec30_support = None

                                    self.lbc = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.Lbc()
                                    self.lbc.parent = self
                                    self._children_name_map["lbc"] = "lbc"

                                    self.es_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.EsNe()
                                    self.es_ne.parent = self
                                    self._children_name_map["es_ne"] = "es-ne"

                                    self.esr_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.EsrNe()
                                    self.esr_ne.parent = self
                                    self._children_name_map["esr_ne"] = "esr-ne"

                                    self.ses_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.SesNe()
                                    self.ses_ne.parent = self
                                    self._children_name_map["ses_ne"] = "ses-ne"

                                    self.sesr_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.SesrNe()
                                    self.sesr_ne.parent = self
                                    self._children_name_map["sesr_ne"] = "sesr-ne"

                                    self.uas_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.UasNe()
                                    self.uas_ne.parent = self
                                    self._children_name_map["uas_ne"] = "uas-ne"

                                    self.bbe_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.BbeNe()
                                    self.bbe_ne.parent = self
                                    self._children_name_map["bbe_ne"] = "bbe-ne"

                                    self.bber_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.BberNe()
                                    self.bber_ne.parent = self
                                    self._children_name_map["bber_ne"] = "bber-ne"

                                    self.fc_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.FcNe()
                                    self.fc_ne.parent = self
                                    self._children_name_map["fc_ne"] = "fc-ne"

                                    self.es_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.EsFe()
                                    self.es_fe.parent = self
                                    self._children_name_map["es_fe"] = "es-fe"

                                    self.esr_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.EsrFe()
                                    self.esr_fe.parent = self
                                    self._children_name_map["esr_fe"] = "esr-fe"

                                    self.ses_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.SesFe()
                                    self.ses_fe.parent = self
                                    self._children_name_map["ses_fe"] = "ses-fe"

                                    self.sesr_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.SesrFe()
                                    self.sesr_fe.parent = self
                                    self._children_name_map["sesr_fe"] = "sesr-fe"

                                    self.uas_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.UasFe()
                                    self.uas_fe.parent = self
                                    self._children_name_map["uas_fe"] = "uas-fe"

                                    self.bbe_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.BbeFe()
                                    self.bbe_fe.parent = self
                                    self._children_name_map["bbe_fe"] = "bbe-fe"

                                    self.bber_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.BberFe()
                                    self.bber_fe.parent = self
                                    self._children_name_map["bber_fe"] = "bber-fe"

                                    self.fc_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.FcFe()
                                    self.fc_fe.parent = self
                                    self._children_name_map["fc_fe"] = "fc-fe"
                                    self._segment_path = lambda: "otu-second30otn" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                class Lbc(Entity):
                                    """
                                    LBC
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.Lbc, self).__init__()

                                        self.yang_name = "lbc"
                                        self.yang_parent_name = "otu-second30otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "lbc"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.Lbc, ['data', 'threshold', 'tca_report'], name, value)


                                class EsNe(Entity):
                                    """
                                    ES SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.EsNe, self).__init__()

                                        self.yang_name = "es-ne"
                                        self.yang_parent_name = "otu-second30otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "es-ne"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.EsNe, ['data', 'threshold', 'tca_report'], name, value)


                                class EsrNe(Entity):
                                    """
                                    ESR PM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: str
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.EsrNe, self).__init__()

                                        self.yang_name = "esr-ne"
                                        self.yang_parent_name = "otu-second30otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "esr-ne"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.EsrNe, ['data', 'threshold', 'tca_report'], name, value)


                                class SesNe(Entity):
                                    """
                                    SES SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.SesNe, self).__init__()

                                        self.yang_name = "ses-ne"
                                        self.yang_parent_name = "otu-second30otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "ses-ne"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.SesNe, ['data', 'threshold', 'tca_report'], name, value)


                                class SesrNe(Entity):
                                    """
                                    SESR SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: str
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.SesrNe, self).__init__()

                                        self.yang_name = "sesr-ne"
                                        self.yang_parent_name = "otu-second30otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "sesr-ne"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.SesrNe, ['data', 'threshold', 'tca_report'], name, value)


                                class UasNe(Entity):
                                    """
                                    UAS SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.UasNe, self).__init__()

                                        self.yang_name = "uas-ne"
                                        self.yang_parent_name = "otu-second30otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "uas-ne"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.UasNe, ['data', 'threshold', 'tca_report'], name, value)


                                class BbeNe(Entity):
                                    """
                                    BBE SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.BbeNe, self).__init__()

                                        self.yang_name = "bbe-ne"
                                        self.yang_parent_name = "otu-second30otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "bbe-ne"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.BbeNe, ['data', 'threshold', 'tca_report'], name, value)


                                class BberNe(Entity):
                                    """
                                    BBER SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: str
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.BberNe, self).__init__()

                                        self.yang_name = "bber-ne"
                                        self.yang_parent_name = "otu-second30otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "bber-ne"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.BberNe, ['data', 'threshold', 'tca_report'], name, value)


                                class FcNe(Entity):
                                    """
                                    FC SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.FcNe, self).__init__()

                                        self.yang_name = "fc-ne"
                                        self.yang_parent_name = "otu-second30otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "fc-ne"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.FcNe, ['data', 'threshold', 'tca_report'], name, value)


                                class EsFe(Entity):
                                    """
                                    ES SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.EsFe, self).__init__()

                                        self.yang_name = "es-fe"
                                        self.yang_parent_name = "otu-second30otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "es-fe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.EsFe, ['data', 'threshold', 'tca_report'], name, value)


                                class EsrFe(Entity):
                                    """
                                    ESR PM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: str
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.EsrFe, self).__init__()

                                        self.yang_name = "esr-fe"
                                        self.yang_parent_name = "otu-second30otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "esr-fe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.EsrFe, ['data', 'threshold', 'tca_report'], name, value)


                                class SesFe(Entity):
                                    """
                                    SES SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.SesFe, self).__init__()

                                        self.yang_name = "ses-fe"
                                        self.yang_parent_name = "otu-second30otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "ses-fe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.SesFe, ['data', 'threshold', 'tca_report'], name, value)


                                class SesrFe(Entity):
                                    """
                                    SESR SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: str
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.SesrFe, self).__init__()

                                        self.yang_name = "sesr-fe"
                                        self.yang_parent_name = "otu-second30otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "sesr-fe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.SesrFe, ['data', 'threshold', 'tca_report'], name, value)


                                class UasFe(Entity):
                                    """
                                    UAS SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.UasFe, self).__init__()

                                        self.yang_name = "uas-fe"
                                        self.yang_parent_name = "otu-second30otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "uas-fe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.UasFe, ['data', 'threshold', 'tca_report'], name, value)


                                class BbeFe(Entity):
                                    """
                                    BBE SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.BbeFe, self).__init__()

                                        self.yang_name = "bbe-fe"
                                        self.yang_parent_name = "otu-second30otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "bbe-fe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.BbeFe, ['data', 'threshold', 'tca_report'], name, value)


                                class BberFe(Entity):
                                    """
                                    BBER SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: str
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.BberFe, self).__init__()

                                        self.yang_name = "bber-fe"
                                        self.yang_parent_name = "otu-second30otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "bber-fe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.BberFe, ['data', 'threshold', 'tca_report'], name, value)


                                class FcFe(Entity):
                                    """
                                    FC SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.FcFe, self).__init__()

                                        self.yang_name = "fc-fe"
                                        self.yang_parent_name = "otu-second30otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "fc-fe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30otns.OtuSecond30otn.FcFe, ['data', 'threshold', 'tca_report'], name, value)


                    class OtuHour24(Entity):
                        """
                        port current performance data
                        
                        .. attribute:: otu_hour24fecs
                        
                        	port current performance data
                        	**type**\:  :py:class:`OtuHour24fecs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24fecs>`
                        
                        .. attribute:: otu_hour24prbses
                        
                        	port 24 hour performance data
                        	**type**\:  :py:class:`OtuHour24prbses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24prbses>`
                        
                        .. attribute:: otu_hour24otns
                        
                        	port 24 hour performance data
                        	**type**\:  :py:class:`OtuHour24otns <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24, self).__init__()

                            self.yang_name = "otu-hour24"
                            self.yang_parent_name = "otu-current"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("otu-hour24fecs", ("otu_hour24fecs", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24fecs)), ("otu-hour24prbses", ("otu_hour24prbses", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24prbses)), ("otu-hour24otns", ("otu_hour24otns", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns))])
                            self._leafs = OrderedDict()

                            self.otu_hour24fecs = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24fecs()
                            self.otu_hour24fecs.parent = self
                            self._children_name_map["otu_hour24fecs"] = "otu-hour24fecs"

                            self.otu_hour24prbses = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24prbses()
                            self.otu_hour24prbses.parent = self
                            self._children_name_map["otu_hour24prbses"] = "otu-hour24prbses"

                            self.otu_hour24otns = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns()
                            self.otu_hour24otns.parent = self
                            self._children_name_map["otu_hour24otns"] = "otu-hour24otns"
                            self._segment_path = lambda: "otu-hour24"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24, [], name, value)


                        class OtuHour24fecs(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: otu_hour24fec
                            
                            	port 24 hour fec performance data
                            	**type**\: list of  		 :py:class:`OtuHour24fec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24fecs.OtuHour24fec>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24fecs, self).__init__()

                                self.yang_name = "otu-hour24fecs"
                                self.yang_parent_name = "otu-hour24"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("otu-hour24fec", ("otu_hour24fec", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24fecs.OtuHour24fec))])
                                self._leafs = OrderedDict()

                                self.otu_hour24fec = YList(self)
                                self._segment_path = lambda: "otu-hour24fecs"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24fecs, [], name, value)


                            class OtuHour24fec(Entity):
                                """
                                port 24 hour fec performance data
                                
                                .. attribute:: number  (key)
                                
                                	channel number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ec_bits
                                
                                	EC BITS
                                	**type**\:  :py:class:`EcBits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24fecs.OtuHour24fec.EcBits>`
                                
                                .. attribute:: uc_words
                                
                                	UC WORDS
                                	**type**\:  :py:class:`UcWords <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24fecs.OtuHour24fec.UcWords>`
                                
                                .. attribute:: pre_fec_ber
                                
                                	Pre FEC BER
                                	**type**\:  :py:class:`PreFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24fecs.OtuHour24fec.PreFecBer>`
                                
                                .. attribute:: post_fec_ber
                                
                                	Post FEC BER
                                	**type**\:  :py:class:`PostFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24fecs.OtuHour24fec.PostFecBer>`
                                
                                .. attribute:: q
                                
                                	Q
                                	**type**\:  :py:class:`Q <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24fecs.OtuHour24fec.Q>`
                                
                                .. attribute:: qmargin
                                
                                	Q Margin
                                	**type**\:  :py:class:`Qmargin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24fecs.OtuHour24fec.Qmargin>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24fecs.OtuHour24fec, self).__init__()

                                    self.yang_name = "otu-hour24fec"
                                    self.yang_parent_name = "otu-hour24fecs"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("ec-bits", ("ec_bits", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24fecs.OtuHour24fec.EcBits)), ("uc-words", ("uc_words", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24fecs.OtuHour24fec.UcWords)), ("pre-fec-ber", ("pre_fec_ber", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24fecs.OtuHour24fec.PreFecBer)), ("post-fec-ber", ("post_fec_ber", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24fecs.OtuHour24fec.PostFecBer)), ("q", ("q", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24fecs.OtuHour24fec.Q)), ("qmargin", ("qmargin", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24fecs.OtuHour24fec.Qmargin))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                        ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                    ])
                                    self.number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear24_hr_time = None
                                    self.sec30_support = None

                                    self.ec_bits = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24fecs.OtuHour24fec.EcBits()
                                    self.ec_bits.parent = self
                                    self._children_name_map["ec_bits"] = "ec-bits"

                                    self.uc_words = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24fecs.OtuHour24fec.UcWords()
                                    self.uc_words.parent = self
                                    self._children_name_map["uc_words"] = "uc-words"

                                    self.pre_fec_ber = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24fecs.OtuHour24fec.PreFecBer()
                                    self.pre_fec_ber.parent = self
                                    self._children_name_map["pre_fec_ber"] = "pre-fec-ber"

                                    self.post_fec_ber = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24fecs.OtuHour24fec.PostFecBer()
                                    self.post_fec_ber.parent = self
                                    self._children_name_map["post_fec_ber"] = "post-fec-ber"

                                    self.q = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24fecs.OtuHour24fec.Q()
                                    self.q.parent = self
                                    self._children_name_map["q"] = "q"

                                    self.qmargin = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24fecs.OtuHour24fec.Qmargin()
                                    self.qmargin.parent = self
                                    self._children_name_map["qmargin"] = "qmargin"
                                    self._segment_path = lambda: "otu-hour24fec" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24fecs.OtuHour24fec, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                class EcBits(Entity):
                                    """
                                    EC BITS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24fecs.OtuHour24fec.EcBits, self).__init__()

                                        self.yang_name = "ec-bits"
                                        self.yang_parent_name = "otu-hour24fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ec-bits"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24fecs.OtuHour24fec.EcBits, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class UcWords(Entity):
                                    """
                                    UC WORDS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24fecs.OtuHour24fec.UcWords, self).__init__()

                                        self.yang_name = "uc-words"
                                        self.yang_parent_name = "otu-hour24fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "uc-words"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24fecs.OtuHour24fec.UcWords, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class PreFecBer(Entity):
                                    """
                                    Pre FEC BER
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24fecs.OtuHour24fec.PreFecBer, self).__init__()

                                        self.yang_name = "pre-fec-ber"
                                        self.yang_parent_name = "otu-hour24fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.maximum_tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "pre-fec-ber"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24fecs.OtuHour24fec.PreFecBer, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                class PostFecBer(Entity):
                                    """
                                    Post FEC BER
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24fecs.OtuHour24fec.PostFecBer, self).__init__()

                                        self.yang_name = "post-fec-ber"
                                        self.yang_parent_name = "otu-hour24fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.maximum_tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "post-fec-ber"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24fecs.OtuHour24fec.PostFecBer, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                class Q(Entity):
                                    """
                                    Q
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24fecs.OtuHour24fec.Q, self).__init__()

                                        self.yang_name = "q"
                                        self.yang_parent_name = "otu-hour24fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.maximum_tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "q"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24fecs.OtuHour24fec.Q, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                class Qmargin(Entity):
                                    """
                                    Q Margin
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24fecs.OtuHour24fec.Qmargin, self).__init__()

                                        self.yang_name = "qmargin"
                                        self.yang_parent_name = "otu-hour24fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.maximum_tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "qmargin"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24fecs.OtuHour24fec.Qmargin, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                        class OtuHour24prbses(Entity):
                            """
                            port 24 hour performance data
                            
                            .. attribute:: otu_hour24prbs
                            
                            	port 24 hour otn performance data
                            	**type**\: list of  		 :py:class:`OtuHour24prbs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24prbses.OtuHour24prbs>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24prbses, self).__init__()

                                self.yang_name = "otu-hour24prbses"
                                self.yang_parent_name = "otu-hour24"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("otu-hour24prbs", ("otu_hour24prbs", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24prbses.OtuHour24prbs))])
                                self._leafs = OrderedDict()

                                self.otu_hour24prbs = YList(self)
                                self._segment_path = lambda: "otu-hour24prbses"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24prbses, [], name, value)


                            class OtuHour24prbs(Entity):
                                """
                                port 24 hour otn performance data
                                
                                .. attribute:: number  (key)
                                
                                	channel number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rcv_patt
                                
                                	RCVD PTRN
                                	**type**\:  :py:class:`RcvPatt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24prbses.OtuHour24prbs.RcvPatt>`
                                
                                .. attribute:: prbs_status
                                
                                	PRBS STATUS
                                	**type**\:  :py:class:`PrbsStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24prbses.OtuHour24prbs.PrbsStatus>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: ebc
                                
                                	EBC
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: found_count
                                
                                	FOUND COUNT
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lost_count
                                
                                	LOST COUNT
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: found_at_time
                                
                                	FOUND AT TS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: lost_at_time
                                
                                	LOST AT TS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: conf_patt
                                
                                	CONFIG PTRN
                                	**type**\:  :py:class:`PmPrbsPatternEt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmPrbsPatternEt>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24prbses.OtuHour24prbs, self).__init__()

                                    self.yang_name = "otu-hour24prbs"
                                    self.yang_parent_name = "otu-hour24prbses"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("rcv-patt", ("rcv_patt", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24prbses.OtuHour24prbs.RcvPatt)), ("prbs-status", ("prbs_status", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24prbses.OtuHour24prbs.PrbsStatus))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                        ('ebc', (YLeaf(YType.uint64, 'ebc'), ['int'])),
                                        ('found_count', (YLeaf(YType.uint32, 'found-count'), ['int'])),
                                        ('lost_count', (YLeaf(YType.uint32, 'lost-count'), ['int'])),
                                        ('found_at_time', (YLeaf(YType.uint64, 'found-at-time'), ['int'])),
                                        ('lost_at_time', (YLeaf(YType.uint64, 'lost-at-time'), ['int'])),
                                        ('conf_patt', (YLeaf(YType.enumeration, 'conf-patt'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper', 'PmPrbsPatternEt', '')])),
                                    ])
                                    self.number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None
                                    self.ebc = None
                                    self.found_count = None
                                    self.lost_count = None
                                    self.found_at_time = None
                                    self.lost_at_time = None
                                    self.conf_patt = None

                                    self.rcv_patt = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24prbses.OtuHour24prbs.RcvPatt()
                                    self.rcv_patt.parent = self
                                    self._children_name_map["rcv_patt"] = "rcv-patt"

                                    self.prbs_status = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24prbses.OtuHour24prbs.PrbsStatus()
                                    self.prbs_status.parent = self
                                    self._children_name_map["prbs_status"] = "prbs-status"
                                    self._segment_path = lambda: "otu-hour24prbs" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24prbses.OtuHour24prbs, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear24_hr_time', 'ebc', 'found_count', 'lost_count', 'found_at_time', 'lost_at_time', 'conf_patt'], name, value)


                                class RcvPatt(Entity):
                                    """
                                    RCVD PTRN
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: rcv_patt
                                    
                                    	RCVD PTRN
                                    	**type**\:  :py:class:`PmPrbsPatternEt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmPrbsPatternEt>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24prbses.OtuHour24prbs.RcvPatt, self).__init__()

                                        self.yang_name = "rcv-patt"
                                        self.yang_parent_name = "otu-hour24prbs"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('rcv_patt', (YLeaf(YType.enumeration, 'rcv-patt'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper', 'PmPrbsPatternEt', '')])),
                                        ])
                                        self.valid = None
                                        self.rcv_patt = None
                                        self._segment_path = lambda: "rcv-patt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24prbses.OtuHour24prbs.RcvPatt, ['valid', 'rcv_patt'], name, value)


                                class PrbsStatus(Entity):
                                    """
                                    PRBS STATUS
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: prbs_status
                                    
                                    	Prbs Status
                                    	**type**\:  :py:class:`PmPrbsStatusEt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmPrbsStatusEt>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24prbses.OtuHour24prbs.PrbsStatus, self).__init__()

                                        self.yang_name = "prbs-status"
                                        self.yang_parent_name = "otu-hour24prbs"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('prbs_status', (YLeaf(YType.enumeration, 'prbs-status'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper', 'PmPrbsStatusEt', '')])),
                                        ])
                                        self.valid = None
                                        self.prbs_status = None
                                        self._segment_path = lambda: "prbs-status"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24prbses.OtuHour24prbs.PrbsStatus, ['valid', 'prbs_status'], name, value)


                        class OtuHour24otns(Entity):
                            """
                            port 24 hour performance data
                            
                            .. attribute:: otu_hour24otn
                            
                            	port 24 hour otn performance data
                            	**type**\: list of  		 :py:class:`OtuHour24otn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns, self).__init__()

                                self.yang_name = "otu-hour24otns"
                                self.yang_parent_name = "otu-hour24"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("otu-hour24otn", ("otu_hour24otn", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn))])
                                self._leafs = OrderedDict()

                                self.otu_hour24otn = YList(self)
                                self._segment_path = lambda: "otu-hour24otns"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns, [], name, value)


                            class OtuHour24otn(Entity):
                                """
                                port 24 hour otn performance data
                                
                                .. attribute:: number  (key)
                                
                                	channel number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lbc
                                
                                	LBC
                                	**type**\:  :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.Lbc>`
                                
                                .. attribute:: es_ne
                                
                                	ES SM NE
                                	**type**\:  :py:class:`EsNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.EsNe>`
                                
                                .. attribute:: esr_ne
                                
                                	ESR PM NE
                                	**type**\:  :py:class:`EsrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.EsrNe>`
                                
                                .. attribute:: ses_ne
                                
                                	SES SM NE
                                	**type**\:  :py:class:`SesNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.SesNe>`
                                
                                .. attribute:: sesr_ne
                                
                                	SESR SM NE
                                	**type**\:  :py:class:`SesrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.SesrNe>`
                                
                                .. attribute:: uas_ne
                                
                                	UAS SM NE
                                	**type**\:  :py:class:`UasNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.UasNe>`
                                
                                .. attribute:: bbe_ne
                                
                                	BBE SM NE
                                	**type**\:  :py:class:`BbeNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.BbeNe>`
                                
                                .. attribute:: bber_ne
                                
                                	BBER SM NE
                                	**type**\:  :py:class:`BberNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.BberNe>`
                                
                                .. attribute:: fc_ne
                                
                                	FC SM NE
                                	**type**\:  :py:class:`FcNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.FcNe>`
                                
                                .. attribute:: es_fe
                                
                                	ES SM FE
                                	**type**\:  :py:class:`EsFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.EsFe>`
                                
                                .. attribute:: esr_fe
                                
                                	ESR PM FE
                                	**type**\:  :py:class:`EsrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.EsrFe>`
                                
                                .. attribute:: ses_fe
                                
                                	SES SM FE
                                	**type**\:  :py:class:`SesFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.SesFe>`
                                
                                .. attribute:: sesr_fe
                                
                                	SESR SM FE
                                	**type**\:  :py:class:`SesrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.SesrFe>`
                                
                                .. attribute:: uas_fe
                                
                                	UAS SM FE
                                	**type**\:  :py:class:`UasFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.UasFe>`
                                
                                .. attribute:: bbe_fe
                                
                                	BBE SM FE
                                	**type**\:  :py:class:`BbeFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.BbeFe>`
                                
                                .. attribute:: bber_fe
                                
                                	BBER SM FE
                                	**type**\:  :py:class:`BberFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.BberFe>`
                                
                                .. attribute:: fc_fe
                                
                                	FC SM FE
                                	**type**\:  :py:class:`FcFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.FcFe>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn, self).__init__()

                                    self.yang_name = "otu-hour24otn"
                                    self.yang_parent_name = "otu-hour24otns"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("lbc", ("lbc", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.Lbc)), ("es-ne", ("es_ne", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.EsNe)), ("esr-ne", ("esr_ne", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.EsrNe)), ("ses-ne", ("ses_ne", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.SesNe)), ("sesr-ne", ("sesr_ne", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.SesrNe)), ("uas-ne", ("uas_ne", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.UasNe)), ("bbe-ne", ("bbe_ne", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.BbeNe)), ("bber-ne", ("bber_ne", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.BberNe)), ("fc-ne", ("fc_ne", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.FcNe)), ("es-fe", ("es_fe", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.EsFe)), ("esr-fe", ("esr_fe", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.EsrFe)), ("ses-fe", ("ses_fe", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.SesFe)), ("sesr-fe", ("sesr_fe", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.SesrFe)), ("uas-fe", ("uas_fe", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.UasFe)), ("bbe-fe", ("bbe_fe", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.BbeFe)), ("bber-fe", ("bber_fe", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.BberFe)), ("fc-fe", ("fc_fe", PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.FcFe))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                        ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                    ])
                                    self.number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear24_hr_time = None
                                    self.sec30_support = None

                                    self.lbc = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.Lbc()
                                    self.lbc.parent = self
                                    self._children_name_map["lbc"] = "lbc"

                                    self.es_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.EsNe()
                                    self.es_ne.parent = self
                                    self._children_name_map["es_ne"] = "es-ne"

                                    self.esr_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.EsrNe()
                                    self.esr_ne.parent = self
                                    self._children_name_map["esr_ne"] = "esr-ne"

                                    self.ses_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.SesNe()
                                    self.ses_ne.parent = self
                                    self._children_name_map["ses_ne"] = "ses-ne"

                                    self.sesr_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.SesrNe()
                                    self.sesr_ne.parent = self
                                    self._children_name_map["sesr_ne"] = "sesr-ne"

                                    self.uas_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.UasNe()
                                    self.uas_ne.parent = self
                                    self._children_name_map["uas_ne"] = "uas-ne"

                                    self.bbe_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.BbeNe()
                                    self.bbe_ne.parent = self
                                    self._children_name_map["bbe_ne"] = "bbe-ne"

                                    self.bber_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.BberNe()
                                    self.bber_ne.parent = self
                                    self._children_name_map["bber_ne"] = "bber-ne"

                                    self.fc_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.FcNe()
                                    self.fc_ne.parent = self
                                    self._children_name_map["fc_ne"] = "fc-ne"

                                    self.es_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.EsFe()
                                    self.es_fe.parent = self
                                    self._children_name_map["es_fe"] = "es-fe"

                                    self.esr_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.EsrFe()
                                    self.esr_fe.parent = self
                                    self._children_name_map["esr_fe"] = "esr-fe"

                                    self.ses_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.SesFe()
                                    self.ses_fe.parent = self
                                    self._children_name_map["ses_fe"] = "ses-fe"

                                    self.sesr_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.SesrFe()
                                    self.sesr_fe.parent = self
                                    self._children_name_map["sesr_fe"] = "sesr-fe"

                                    self.uas_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.UasFe()
                                    self.uas_fe.parent = self
                                    self._children_name_map["uas_fe"] = "uas-fe"

                                    self.bbe_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.BbeFe()
                                    self.bbe_fe.parent = self
                                    self._children_name_map["bbe_fe"] = "bbe-fe"

                                    self.bber_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.BberFe()
                                    self.bber_fe.parent = self
                                    self._children_name_map["bber_fe"] = "bber-fe"

                                    self.fc_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.FcFe()
                                    self.fc_fe.parent = self
                                    self._children_name_map["fc_fe"] = "fc-fe"
                                    self._segment_path = lambda: "otu-hour24otn" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                class Lbc(Entity):
                                    """
                                    LBC
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.Lbc, self).__init__()

                                        self.yang_name = "lbc"
                                        self.yang_parent_name = "otu-hour24otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "lbc"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.Lbc, ['data', 'threshold', 'tca_report'], name, value)


                                class EsNe(Entity):
                                    """
                                    ES SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.EsNe, self).__init__()

                                        self.yang_name = "es-ne"
                                        self.yang_parent_name = "otu-hour24otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "es-ne"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.EsNe, ['data', 'threshold', 'tca_report'], name, value)


                                class EsrNe(Entity):
                                    """
                                    ESR PM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: str
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.EsrNe, self).__init__()

                                        self.yang_name = "esr-ne"
                                        self.yang_parent_name = "otu-hour24otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "esr-ne"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.EsrNe, ['data', 'threshold', 'tca_report'], name, value)


                                class SesNe(Entity):
                                    """
                                    SES SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.SesNe, self).__init__()

                                        self.yang_name = "ses-ne"
                                        self.yang_parent_name = "otu-hour24otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "ses-ne"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.SesNe, ['data', 'threshold', 'tca_report'], name, value)


                                class SesrNe(Entity):
                                    """
                                    SESR SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: str
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.SesrNe, self).__init__()

                                        self.yang_name = "sesr-ne"
                                        self.yang_parent_name = "otu-hour24otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "sesr-ne"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.SesrNe, ['data', 'threshold', 'tca_report'], name, value)


                                class UasNe(Entity):
                                    """
                                    UAS SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.UasNe, self).__init__()

                                        self.yang_name = "uas-ne"
                                        self.yang_parent_name = "otu-hour24otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "uas-ne"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.UasNe, ['data', 'threshold', 'tca_report'], name, value)


                                class BbeNe(Entity):
                                    """
                                    BBE SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.BbeNe, self).__init__()

                                        self.yang_name = "bbe-ne"
                                        self.yang_parent_name = "otu-hour24otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "bbe-ne"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.BbeNe, ['data', 'threshold', 'tca_report'], name, value)


                                class BberNe(Entity):
                                    """
                                    BBER SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: str
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.BberNe, self).__init__()

                                        self.yang_name = "bber-ne"
                                        self.yang_parent_name = "otu-hour24otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "bber-ne"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.BberNe, ['data', 'threshold', 'tca_report'], name, value)


                                class FcNe(Entity):
                                    """
                                    FC SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.FcNe, self).__init__()

                                        self.yang_name = "fc-ne"
                                        self.yang_parent_name = "otu-hour24otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "fc-ne"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.FcNe, ['data', 'threshold', 'tca_report'], name, value)


                                class EsFe(Entity):
                                    """
                                    ES SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.EsFe, self).__init__()

                                        self.yang_name = "es-fe"
                                        self.yang_parent_name = "otu-hour24otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "es-fe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.EsFe, ['data', 'threshold', 'tca_report'], name, value)


                                class EsrFe(Entity):
                                    """
                                    ESR PM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: str
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.EsrFe, self).__init__()

                                        self.yang_name = "esr-fe"
                                        self.yang_parent_name = "otu-hour24otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "esr-fe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.EsrFe, ['data', 'threshold', 'tca_report'], name, value)


                                class SesFe(Entity):
                                    """
                                    SES SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.SesFe, self).__init__()

                                        self.yang_name = "ses-fe"
                                        self.yang_parent_name = "otu-hour24otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "ses-fe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.SesFe, ['data', 'threshold', 'tca_report'], name, value)


                                class SesrFe(Entity):
                                    """
                                    SESR SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: str
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.SesrFe, self).__init__()

                                        self.yang_name = "sesr-fe"
                                        self.yang_parent_name = "otu-hour24otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "sesr-fe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.SesrFe, ['data', 'threshold', 'tca_report'], name, value)


                                class UasFe(Entity):
                                    """
                                    UAS SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.UasFe, self).__init__()

                                        self.yang_name = "uas-fe"
                                        self.yang_parent_name = "otu-hour24otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "uas-fe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.UasFe, ['data', 'threshold', 'tca_report'], name, value)


                                class BbeFe(Entity):
                                    """
                                    BBE SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.BbeFe, self).__init__()

                                        self.yang_name = "bbe-fe"
                                        self.yang_parent_name = "otu-hour24otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "bbe-fe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.BbeFe, ['data', 'threshold', 'tca_report'], name, value)


                                class BberFe(Entity):
                                    """
                                    BBER SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: str
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.BberFe, self).__init__()

                                        self.yang_name = "bber-fe"
                                        self.yang_parent_name = "otu-hour24otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "bber-fe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.BberFe, ['data', 'threshold', 'tca_report'], name, value)


                                class FcFe(Entity):
                                    """
                                    FC SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.FcFe, self).__init__()

                                        self.yang_name = "fc-fe"
                                        self.yang_parent_name = "otu-hour24otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "fc-fe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24otns.OtuHour24otn.FcFe, ['data', 'threshold', 'tca_report'], name, value)


    class Stm(Entity):
        """
        STM controller performance data
        
        .. attribute:: stm_ports
        
        	Port performance data
        	**type**\:  :py:class:`StmPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts>`
        
        

        """

        _prefix = 'pmengine-oper'
        _revision = '2017-09-07'

        def __init__(self):
            super(PerformanceManagement.Stm, self).__init__()

            self.yang_name = "stm"
            self.yang_parent_name = "performance-management"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("stm-ports", ("stm_ports", PerformanceManagement.Stm.StmPorts))])
            self._leafs = OrderedDict()

            self.stm_ports = PerformanceManagement.Stm.StmPorts()
            self.stm_ports.parent = self
            self._children_name_map["stm_ports"] = "stm-ports"
            self._segment_path = lambda: "stm"
            self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(PerformanceManagement.Stm, [], name, value)


        class StmPorts(Entity):
            """
            Port performance data
            
            .. attribute:: stm_port
            
            	Port performance data
            	**type**\: list of  		 :py:class:`StmPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort>`
            
            

            """

            _prefix = 'pmengine-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(PerformanceManagement.Stm.StmPorts, self).__init__()

                self.yang_name = "stm-ports"
                self.yang_parent_name = "stm"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("stm-port", ("stm_port", PerformanceManagement.Stm.StmPorts.StmPort))])
                self._leafs = OrderedDict()

                self.stm_port = YList(self)
                self._segment_path = lambda: "stm-ports"
                self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management/stm/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(PerformanceManagement.Stm.StmPorts, [], name, value)


            class StmPort(Entity):
                """
                Port performance data
                
                .. attribute:: name  (key)
                
                	Port name
                	**type**\: str
                
                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                
                .. attribute:: stm_current
                
                	port current performance data
                	**type**\:  :py:class:`StmCurrent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(PerformanceManagement.Stm.StmPorts.StmPort, self).__init__()

                    self.yang_name = "stm-port"
                    self.yang_parent_name = "stm-ports"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("stm-current", ("stm_current", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ])
                    self.name = None

                    self.stm_current = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent()
                    self.stm_current.parent = self
                    self._children_name_map["stm_current"] = "stm-current"
                    self._segment_path = lambda: "stm-port" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management/stm/stm-ports/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort, ['name'], name, value)


                class StmCurrent(Entity):
                    """
                    port current performance data
                    
                    .. attribute:: stm_hour24
                    
                    	port current performance data
                    	**type**\:  :py:class:`StmHour24 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24>`
                    
                    .. attribute:: stm_minute15
                    
                    	port current performance data
                    	**type**\:  :py:class:`StmMinute15 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent, self).__init__()

                        self.yang_name = "stm-current"
                        self.yang_parent_name = "stm-port"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("stm-hour24", ("stm_hour24", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24)), ("stm-minute15", ("stm_minute15", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15))])
                        self._leafs = OrderedDict()

                        self.stm_hour24 = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24()
                        self.stm_hour24.parent = self
                        self._children_name_map["stm_hour24"] = "stm-hour24"

                        self.stm_minute15 = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15()
                        self.stm_minute15.parent = self
                        self._children_name_map["stm_minute15"] = "stm-minute15"
                        self._segment_path = lambda: "stm-current"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent, [], name, value)


                    class StmHour24(Entity):
                        """
                        port current performance data
                        
                        .. attribute:: stm_hour24stms
                        
                        	port current performance data
                        	**type**\:  :py:class:`StmHour24stms <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24, self).__init__()

                            self.yang_name = "stm-hour24"
                            self.yang_parent_name = "stm-current"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("stm-hour24stms", ("stm_hour24stms", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms))])
                            self._leafs = OrderedDict()

                            self.stm_hour24stms = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms()
                            self.stm_hour24stms.parent = self
                            self._children_name_map["stm_hour24stms"] = "stm-hour24stms"
                            self._segment_path = lambda: "stm-hour24"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24, [], name, value)


                        class StmHour24stms(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: stm_hour24stm
                            
                            	port 24 hour stm performance data
                            	**type**\: list of  		 :py:class:`StmHour24stm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms, self).__init__()

                                self.yang_name = "stm-hour24stms"
                                self.yang_parent_name = "stm-hour24"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("stm-hour24stm", ("stm_hour24stm", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm))])
                                self._leafs = OrderedDict()

                                self.stm_hour24stm = YList(self)
                                self._segment_path = lambda: "stm-hour24stms"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms, [], name, value)


                            class StmHour24stm(Entity):
                                """
                                port 24 hour stm performance data
                                
                                .. attribute:: number  (key)
                                
                                	channel number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: section
                                
                                	SECTION
                                	**type**\:  :py:class:`Section <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Section>`
                                
                                .. attribute:: line
                                
                                	LINE
                                	**type**\:  :py:class:`Line <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Line>`
                                
                                .. attribute:: fe_line
                                
                                	FarEnd LINE
                                	**type**\:  :py:class:`FeLine <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.FeLine>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm, self).__init__()

                                    self.yang_name = "stm-hour24stm"
                                    self.yang_parent_name = "stm-hour24stms"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("section", ("section", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Section)), ("line", ("line", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Line)), ("fe-line", ("fe_line", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.FeLine))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                    ])
                                    self.number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None

                                    self.section = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Section()
                                    self.section.parent = self
                                    self._children_name_map["section"] = "section"

                                    self.line = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Line()
                                    self.line.parent = self
                                    self._children_name_map["line"] = "line"

                                    self.fe_line = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.FeLine()
                                    self.fe_line.parent = self
                                    self._children_name_map["fe_line"] = "fe-line"
                                    self._segment_path = lambda: "stm-hour24stm" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear24_hr_time'], name, value)


                                class Section(Entity):
                                    """
                                    SECTION
                                    
                                    .. attribute:: section_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:  :py:class:`SectionESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Section.SectionESs>`
                                    
                                    .. attribute:: section_es_rs
                                    
                                    	The number of Errored Seconds Ratio
                                    	**type**\:  :py:class:`SectionEsRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Section.SectionEsRs>`
                                    
                                    .. attribute:: section_bb_es
                                    
                                    	The number of Background Block Errors
                                    	**type**\:  :py:class:`SectionBbEs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Section.SectionBbEs>`
                                    
                                    .. attribute:: section_bbe_rs
                                    
                                    	The number of Background Block Errors
                                    	**type**\:  :py:class:`SectionBbeRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Section.SectionBbeRs>`
                                    
                                    .. attribute:: section_se_ss
                                    
                                    	The number of Severely Errored Second
                                    	**type**\:  :py:class:`SectionSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Section.SectionSeSs>`
                                    
                                    .. attribute:: section_ses_rs
                                    
                                    	The number of Severely Errored Second Ratio
                                    	**type**\:  :py:class:`SectionSesRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Section.SectionSesRs>`
                                    
                                    .. attribute:: section_ua_ss
                                    
                                    	The number of Unavailable Second
                                    	**type**\:  :py:class:`SectionUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Section.SectionUaSs>`
                                    
                                    .. attribute:: section_e_bs
                                    
                                    	The number of Errored Block Second
                                    	**type**\:  :py:class:`SectionEBs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Section.SectionEBs>`
                                    
                                    .. attribute:: section_status
                                    
                                    	 status of the interface
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Section, self).__init__()

                                        self.yang_name = "section"
                                        self.yang_parent_name = "stm-hour24stm"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("section-e-ss", ("section_e_ss", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Section.SectionESs)), ("section-es-rs", ("section_es_rs", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Section.SectionEsRs)), ("section-bb-es", ("section_bb_es", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Section.SectionBbEs)), ("section-bbe-rs", ("section_bbe_rs", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Section.SectionBbeRs)), ("section-se-ss", ("section_se_ss", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Section.SectionSeSs)), ("section-ses-rs", ("section_ses_rs", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Section.SectionSesRs)), ("section-ua-ss", ("section_ua_ss", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Section.SectionUaSs)), ("section-e-bs", ("section_e_bs", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Section.SectionEBs))])
                                        self._leafs = OrderedDict([
                                            ('section_status', (YLeaf(YType.int32, 'section-status'), ['int'])),
                                        ])
                                        self.section_status = None

                                        self.section_e_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Section.SectionESs()
                                        self.section_e_ss.parent = self
                                        self._children_name_map["section_e_ss"] = "section-e-ss"

                                        self.section_es_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Section.SectionEsRs()
                                        self.section_es_rs.parent = self
                                        self._children_name_map["section_es_rs"] = "section-es-rs"

                                        self.section_bb_es = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Section.SectionBbEs()
                                        self.section_bb_es.parent = self
                                        self._children_name_map["section_bb_es"] = "section-bb-es"

                                        self.section_bbe_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Section.SectionBbeRs()
                                        self.section_bbe_rs.parent = self
                                        self._children_name_map["section_bbe_rs"] = "section-bbe-rs"

                                        self.section_se_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Section.SectionSeSs()
                                        self.section_se_ss.parent = self
                                        self._children_name_map["section_se_ss"] = "section-se-ss"

                                        self.section_ses_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Section.SectionSesRs()
                                        self.section_ses_rs.parent = self
                                        self._children_name_map["section_ses_rs"] = "section-ses-rs"

                                        self.section_ua_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Section.SectionUaSs()
                                        self.section_ua_ss.parent = self
                                        self._children_name_map["section_ua_ss"] = "section-ua-ss"

                                        self.section_e_bs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Section.SectionEBs()
                                        self.section_e_bs.parent = self
                                        self._children_name_map["section_e_bs"] = "section-e-bs"
                                        self._segment_path = lambda: "section"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Section, ['section_status'], name, value)


                                    class SectionESs(Entity):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Section.SectionESs, self).__init__()

                                            self.yang_name = "section-e-ss"
                                            self.yang_parent_name = "section"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "section-e-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Section.SectionESs, ['data', 'threshold', 'tca_report'], name, value)


                                    class SectionEsRs(Entity):
                                        """
                                        The number of Errored Seconds Ratio
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Section.SectionEsRs, self).__init__()

                                            self.yang_name = "section-es-rs"
                                            self.yang_parent_name = "section"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "section-es-rs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Section.SectionEsRs, ['data', 'threshold', 'tca_report'], name, value)


                                    class SectionBbEs(Entity):
                                        """
                                        The number of Background Block Errors
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Section.SectionBbEs, self).__init__()

                                            self.yang_name = "section-bb-es"
                                            self.yang_parent_name = "section"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "section-bb-es"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Section.SectionBbEs, ['data', 'threshold', 'tca_report'], name, value)


                                    class SectionBbeRs(Entity):
                                        """
                                        The number of Background Block Errors
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Section.SectionBbeRs, self).__init__()

                                            self.yang_name = "section-bbe-rs"
                                            self.yang_parent_name = "section"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "section-bbe-rs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Section.SectionBbeRs, ['data', 'threshold', 'tca_report'], name, value)


                                    class SectionSeSs(Entity):
                                        """
                                        The number of Severely Errored Second
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Section.SectionSeSs, self).__init__()

                                            self.yang_name = "section-se-ss"
                                            self.yang_parent_name = "section"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "section-se-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Section.SectionSeSs, ['data', 'threshold', 'tca_report'], name, value)


                                    class SectionSesRs(Entity):
                                        """
                                        The number of Severely Errored Second Ratio
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Section.SectionSesRs, self).__init__()

                                            self.yang_name = "section-ses-rs"
                                            self.yang_parent_name = "section"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "section-ses-rs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Section.SectionSesRs, ['data', 'threshold', 'tca_report'], name, value)


                                    class SectionUaSs(Entity):
                                        """
                                        The number of Unavailable Second
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Section.SectionUaSs, self).__init__()

                                            self.yang_name = "section-ua-ss"
                                            self.yang_parent_name = "section"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "section-ua-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Section.SectionUaSs, ['data', 'threshold', 'tca_report'], name, value)


                                    class SectionEBs(Entity):
                                        """
                                        The number of Errored Block Second
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Section.SectionEBs, self).__init__()

                                            self.yang_name = "section-e-bs"
                                            self.yang_parent_name = "section"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "section-e-bs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Section.SectionEBs, ['data', 'threshold', 'tca_report'], name, value)


                                class Line(Entity):
                                    """
                                    LINE
                                    
                                    .. attribute:: line_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:  :py:class:`LineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Line.LineESs>`
                                    
                                    .. attribute:: line_es_rs
                                    
                                    	The number of Errored Seconds Ratio
                                    	**type**\:  :py:class:`LineEsRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Line.LineEsRs>`
                                    
                                    .. attribute:: line_bb_es
                                    
                                    	The number of Background Block Errors
                                    	**type**\:  :py:class:`LineBbEs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Line.LineBbEs>`
                                    
                                    .. attribute:: line_bbe_rs
                                    
                                    	The number of Background Block Errors
                                    	**type**\:  :py:class:`LineBbeRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Line.LineBbeRs>`
                                    
                                    .. attribute:: line_se_ss
                                    
                                    	The number of Severely Errored Second
                                    	**type**\:  :py:class:`LineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Line.LineSeSs>`
                                    
                                    .. attribute:: line_ses_rs
                                    
                                    	The number of Severely Errored Second Ratio
                                    	**type**\:  :py:class:`LineSesRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Line.LineSesRs>`
                                    
                                    .. attribute:: line_ua_ss
                                    
                                    	The number of Unavailable Second
                                    	**type**\:  :py:class:`LineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Line.LineUaSs>`
                                    
                                    .. attribute:: line_e_bs
                                    
                                    	The number of Errored Block Second
                                    	**type**\:  :py:class:`LineEBs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Line.LineEBs>`
                                    
                                    .. attribute:: line_status
                                    
                                    	 status of the interface
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Line, self).__init__()

                                        self.yang_name = "line"
                                        self.yang_parent_name = "stm-hour24stm"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("line-e-ss", ("line_e_ss", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Line.LineESs)), ("line-es-rs", ("line_es_rs", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Line.LineEsRs)), ("line-bb-es", ("line_bb_es", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Line.LineBbEs)), ("line-bbe-rs", ("line_bbe_rs", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Line.LineBbeRs)), ("line-se-ss", ("line_se_ss", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Line.LineSeSs)), ("line-ses-rs", ("line_ses_rs", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Line.LineSesRs)), ("line-ua-ss", ("line_ua_ss", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Line.LineUaSs)), ("line-e-bs", ("line_e_bs", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Line.LineEBs))])
                                        self._leafs = OrderedDict([
                                            ('line_status', (YLeaf(YType.int32, 'line-status'), ['int'])),
                                        ])
                                        self.line_status = None

                                        self.line_e_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Line.LineESs()
                                        self.line_e_ss.parent = self
                                        self._children_name_map["line_e_ss"] = "line-e-ss"

                                        self.line_es_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Line.LineEsRs()
                                        self.line_es_rs.parent = self
                                        self._children_name_map["line_es_rs"] = "line-es-rs"

                                        self.line_bb_es = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Line.LineBbEs()
                                        self.line_bb_es.parent = self
                                        self._children_name_map["line_bb_es"] = "line-bb-es"

                                        self.line_bbe_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Line.LineBbeRs()
                                        self.line_bbe_rs.parent = self
                                        self._children_name_map["line_bbe_rs"] = "line-bbe-rs"

                                        self.line_se_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Line.LineSeSs()
                                        self.line_se_ss.parent = self
                                        self._children_name_map["line_se_ss"] = "line-se-ss"

                                        self.line_ses_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Line.LineSesRs()
                                        self.line_ses_rs.parent = self
                                        self._children_name_map["line_ses_rs"] = "line-ses-rs"

                                        self.line_ua_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Line.LineUaSs()
                                        self.line_ua_ss.parent = self
                                        self._children_name_map["line_ua_ss"] = "line-ua-ss"

                                        self.line_e_bs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Line.LineEBs()
                                        self.line_e_bs.parent = self
                                        self._children_name_map["line_e_bs"] = "line-e-bs"
                                        self._segment_path = lambda: "line"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Line, ['line_status'], name, value)


                                    class LineESs(Entity):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Line.LineESs, self).__init__()

                                            self.yang_name = "line-e-ss"
                                            self.yang_parent_name = "line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "line-e-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Line.LineESs, ['data', 'threshold', 'tca_report'], name, value)


                                    class LineEsRs(Entity):
                                        """
                                        The number of Errored Seconds Ratio
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Line.LineEsRs, self).__init__()

                                            self.yang_name = "line-es-rs"
                                            self.yang_parent_name = "line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "line-es-rs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Line.LineEsRs, ['data', 'threshold', 'tca_report'], name, value)


                                    class LineBbEs(Entity):
                                        """
                                        The number of Background Block Errors
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Line.LineBbEs, self).__init__()

                                            self.yang_name = "line-bb-es"
                                            self.yang_parent_name = "line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "line-bb-es"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Line.LineBbEs, ['data', 'threshold', 'tca_report'], name, value)


                                    class LineBbeRs(Entity):
                                        """
                                        The number of Background Block Errors
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Line.LineBbeRs, self).__init__()

                                            self.yang_name = "line-bbe-rs"
                                            self.yang_parent_name = "line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "line-bbe-rs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Line.LineBbeRs, ['data', 'threshold', 'tca_report'], name, value)


                                    class LineSeSs(Entity):
                                        """
                                        The number of Severely Errored Second
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Line.LineSeSs, self).__init__()

                                            self.yang_name = "line-se-ss"
                                            self.yang_parent_name = "line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "line-se-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Line.LineSeSs, ['data', 'threshold', 'tca_report'], name, value)


                                    class LineSesRs(Entity):
                                        """
                                        The number of Severely Errored Second Ratio
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Line.LineSesRs, self).__init__()

                                            self.yang_name = "line-ses-rs"
                                            self.yang_parent_name = "line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "line-ses-rs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Line.LineSesRs, ['data', 'threshold', 'tca_report'], name, value)


                                    class LineUaSs(Entity):
                                        """
                                        The number of Unavailable Second
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Line.LineUaSs, self).__init__()

                                            self.yang_name = "line-ua-ss"
                                            self.yang_parent_name = "line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "line-ua-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Line.LineUaSs, ['data', 'threshold', 'tca_report'], name, value)


                                    class LineEBs(Entity):
                                        """
                                        The number of Errored Block Second
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Line.LineEBs, self).__init__()

                                            self.yang_name = "line-e-bs"
                                            self.yang_parent_name = "line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "line-e-bs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.Line.LineEBs, ['data', 'threshold', 'tca_report'], name, value)


                                class FeLine(Entity):
                                    """
                                    FarEnd LINE
                                    
                                    .. attribute:: far_end_line_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:  :py:class:`FarEndLineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.FeLine.FarEndLineESs>`
                                    
                                    .. attribute:: far_end_line_es_rs
                                    
                                    	The number of Errored Seconds Ratio
                                    	**type**\:  :py:class:`FarEndLineEsRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.FeLine.FarEndLineEsRs>`
                                    
                                    .. attribute:: far_end_line_ebb_es
                                    
                                    	The number of Background Block Errors
                                    	**type**\:  :py:class:`FarEndLineEbbEs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.FeLine.FarEndLineEbbEs>`
                                    
                                    .. attribute:: far_end_line_bbe_rs
                                    
                                    	The number of Background Block Errors
                                    	**type**\:  :py:class:`FarEndLineBbeRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.FeLine.FarEndLineBbeRs>`
                                    
                                    .. attribute:: far_end_line_se_ss
                                    
                                    	The number of Severely Errored Second
                                    	**type**\:  :py:class:`FarEndLineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.FeLine.FarEndLineSeSs>`
                                    
                                    .. attribute:: far_end_line_ses_rs
                                    
                                    	The number of Severely Errored Second Ratio
                                    	**type**\:  :py:class:`FarEndLineSesRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.FeLine.FarEndLineSesRs>`
                                    
                                    .. attribute:: far_end_line_ua_ss
                                    
                                    	The number of Unavailable Second
                                    	**type**\:  :py:class:`FarEndLineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.FeLine.FarEndLineUaSs>`
                                    
                                    .. attribute:: far_end_line_e_bs
                                    
                                    	The number of Errored Block Second
                                    	**type**\:  :py:class:`FarEndLineEBs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.FeLine.FarEndLineEBs>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.FeLine, self).__init__()

                                        self.yang_name = "fe-line"
                                        self.yang_parent_name = "stm-hour24stm"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("far-end-line-e-ss", ("far_end_line_e_ss", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.FeLine.FarEndLineESs)), ("far-end-line-es-rs", ("far_end_line_es_rs", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.FeLine.FarEndLineEsRs)), ("far-end-line-ebb-es", ("far_end_line_ebb_es", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.FeLine.FarEndLineEbbEs)), ("far-end-line-bbe-rs", ("far_end_line_bbe_rs", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.FeLine.FarEndLineBbeRs)), ("far-end-line-se-ss", ("far_end_line_se_ss", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.FeLine.FarEndLineSeSs)), ("far-end-line-ses-rs", ("far_end_line_ses_rs", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.FeLine.FarEndLineSesRs)), ("far-end-line-ua-ss", ("far_end_line_ua_ss", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.FeLine.FarEndLineUaSs)), ("far-end-line-e-bs", ("far_end_line_e_bs", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.FeLine.FarEndLineEBs))])
                                        self._leafs = OrderedDict()

                                        self.far_end_line_e_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.FeLine.FarEndLineESs()
                                        self.far_end_line_e_ss.parent = self
                                        self._children_name_map["far_end_line_e_ss"] = "far-end-line-e-ss"

                                        self.far_end_line_es_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.FeLine.FarEndLineEsRs()
                                        self.far_end_line_es_rs.parent = self
                                        self._children_name_map["far_end_line_es_rs"] = "far-end-line-es-rs"

                                        self.far_end_line_ebb_es = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.FeLine.FarEndLineEbbEs()
                                        self.far_end_line_ebb_es.parent = self
                                        self._children_name_map["far_end_line_ebb_es"] = "far-end-line-ebb-es"

                                        self.far_end_line_bbe_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.FeLine.FarEndLineBbeRs()
                                        self.far_end_line_bbe_rs.parent = self
                                        self._children_name_map["far_end_line_bbe_rs"] = "far-end-line-bbe-rs"

                                        self.far_end_line_se_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.FeLine.FarEndLineSeSs()
                                        self.far_end_line_se_ss.parent = self
                                        self._children_name_map["far_end_line_se_ss"] = "far-end-line-se-ss"

                                        self.far_end_line_ses_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.FeLine.FarEndLineSesRs()
                                        self.far_end_line_ses_rs.parent = self
                                        self._children_name_map["far_end_line_ses_rs"] = "far-end-line-ses-rs"

                                        self.far_end_line_ua_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.FeLine.FarEndLineUaSs()
                                        self.far_end_line_ua_ss.parent = self
                                        self._children_name_map["far_end_line_ua_ss"] = "far-end-line-ua-ss"

                                        self.far_end_line_e_bs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.FeLine.FarEndLineEBs()
                                        self.far_end_line_e_bs.parent = self
                                        self._children_name_map["far_end_line_e_bs"] = "far-end-line-e-bs"
                                        self._segment_path = lambda: "fe-line"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.FeLine, [], name, value)


                                    class FarEndLineESs(Entity):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.FeLine.FarEndLineESs, self).__init__()

                                            self.yang_name = "far-end-line-e-ss"
                                            self.yang_parent_name = "fe-line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "far-end-line-e-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.FeLine.FarEndLineESs, ['data', 'threshold', 'tca_report'], name, value)


                                    class FarEndLineEsRs(Entity):
                                        """
                                        The number of Errored Seconds Ratio
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.FeLine.FarEndLineEsRs, self).__init__()

                                            self.yang_name = "far-end-line-es-rs"
                                            self.yang_parent_name = "fe-line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "far-end-line-es-rs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.FeLine.FarEndLineEsRs, ['data', 'threshold', 'tca_report'], name, value)


                                    class FarEndLineEbbEs(Entity):
                                        """
                                        The number of Background Block Errors
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.FeLine.FarEndLineEbbEs, self).__init__()

                                            self.yang_name = "far-end-line-ebb-es"
                                            self.yang_parent_name = "fe-line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "far-end-line-ebb-es"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.FeLine.FarEndLineEbbEs, ['data', 'threshold', 'tca_report'], name, value)


                                    class FarEndLineBbeRs(Entity):
                                        """
                                        The number of Background Block Errors
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.FeLine.FarEndLineBbeRs, self).__init__()

                                            self.yang_name = "far-end-line-bbe-rs"
                                            self.yang_parent_name = "fe-line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "far-end-line-bbe-rs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.FeLine.FarEndLineBbeRs, ['data', 'threshold', 'tca_report'], name, value)


                                    class FarEndLineSeSs(Entity):
                                        """
                                        The number of Severely Errored Second
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.FeLine.FarEndLineSeSs, self).__init__()

                                            self.yang_name = "far-end-line-se-ss"
                                            self.yang_parent_name = "fe-line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "far-end-line-se-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.FeLine.FarEndLineSeSs, ['data', 'threshold', 'tca_report'], name, value)


                                    class FarEndLineSesRs(Entity):
                                        """
                                        The number of Severely Errored Second Ratio
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.FeLine.FarEndLineSesRs, self).__init__()

                                            self.yang_name = "far-end-line-ses-rs"
                                            self.yang_parent_name = "fe-line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "far-end-line-ses-rs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.FeLine.FarEndLineSesRs, ['data', 'threshold', 'tca_report'], name, value)


                                    class FarEndLineUaSs(Entity):
                                        """
                                        The number of Unavailable Second
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.FeLine.FarEndLineUaSs, self).__init__()

                                            self.yang_name = "far-end-line-ua-ss"
                                            self.yang_parent_name = "fe-line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "far-end-line-ua-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.FeLine.FarEndLineUaSs, ['data', 'threshold', 'tca_report'], name, value)


                                    class FarEndLineEBs(Entity):
                                        """
                                        The number of Errored Block Second
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.FeLine.FarEndLineEBs, self).__init__()

                                            self.yang_name = "far-end-line-e-bs"
                                            self.yang_parent_name = "fe-line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "far-end-line-e-bs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24stms.StmHour24stm.FeLine.FarEndLineEBs, ['data', 'threshold', 'tca_report'], name, value)


                    class StmMinute15(Entity):
                        """
                        port current performance data
                        
                        .. attribute:: stm_minute15stms
                        
                        	port current performance data
                        	**type**\:  :py:class:`StmMinute15stms <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15, self).__init__()

                            self.yang_name = "stm-minute15"
                            self.yang_parent_name = "stm-current"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("stm-minute15stms", ("stm_minute15stms", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms))])
                            self._leafs = OrderedDict()

                            self.stm_minute15stms = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms()
                            self.stm_minute15stms.parent = self
                            self._children_name_map["stm_minute15stms"] = "stm-minute15stms"
                            self._segment_path = lambda: "stm-minute15"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15, [], name, value)


                        class StmMinute15stms(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: stm_minute15stm
                            
                            	port 15\-minute stm performance data
                            	**type**\: list of  		 :py:class:`StmMinute15stm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms, self).__init__()

                                self.yang_name = "stm-minute15stms"
                                self.yang_parent_name = "stm-minute15"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("stm-minute15stm", ("stm_minute15stm", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm))])
                                self._leafs = OrderedDict()

                                self.stm_minute15stm = YList(self)
                                self._segment_path = lambda: "stm-minute15stms"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms, [], name, value)


                            class StmMinute15stm(Entity):
                                """
                                port 15\-minute stm performance data
                                
                                .. attribute:: number  (key)
                                
                                	channel number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: section
                                
                                	SECTION
                                	**type**\:  :py:class:`Section <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Section>`
                                
                                .. attribute:: line
                                
                                	LINE
                                	**type**\:  :py:class:`Line <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Line>`
                                
                                .. attribute:: fe_line
                                
                                	FarEnd LINE
                                	**type**\:  :py:class:`FeLine <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.FeLine>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm, self).__init__()

                                    self.yang_name = "stm-minute15stm"
                                    self.yang_parent_name = "stm-minute15stms"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("section", ("section", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Section)), ("line", ("line", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Line)), ("fe-line", ("fe_line", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.FeLine))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                    ])
                                    self.number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None

                                    self.section = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Section()
                                    self.section.parent = self
                                    self._children_name_map["section"] = "section"

                                    self.line = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Line()
                                    self.line.parent = self
                                    self._children_name_map["line"] = "line"

                                    self.fe_line = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.FeLine()
                                    self.fe_line.parent = self
                                    self._children_name_map["fe_line"] = "fe-line"
                                    self._segment_path = lambda: "stm-minute15stm" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear24_hr_time'], name, value)


                                class Section(Entity):
                                    """
                                    SECTION
                                    
                                    .. attribute:: section_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:  :py:class:`SectionESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Section.SectionESs>`
                                    
                                    .. attribute:: section_es_rs
                                    
                                    	The number of Errored Seconds Ratio
                                    	**type**\:  :py:class:`SectionEsRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Section.SectionEsRs>`
                                    
                                    .. attribute:: section_bb_es
                                    
                                    	The number of Background Block Errors
                                    	**type**\:  :py:class:`SectionBbEs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Section.SectionBbEs>`
                                    
                                    .. attribute:: section_bbe_rs
                                    
                                    	The number of Background Block Errors
                                    	**type**\:  :py:class:`SectionBbeRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Section.SectionBbeRs>`
                                    
                                    .. attribute:: section_se_ss
                                    
                                    	The number of Severely Errored Second
                                    	**type**\:  :py:class:`SectionSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Section.SectionSeSs>`
                                    
                                    .. attribute:: section_ses_rs
                                    
                                    	The number of Severely Errored Second Ratio
                                    	**type**\:  :py:class:`SectionSesRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Section.SectionSesRs>`
                                    
                                    .. attribute:: section_ua_ss
                                    
                                    	The number of Unavailable Second
                                    	**type**\:  :py:class:`SectionUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Section.SectionUaSs>`
                                    
                                    .. attribute:: section_e_bs
                                    
                                    	The number of Errored Block Second
                                    	**type**\:  :py:class:`SectionEBs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Section.SectionEBs>`
                                    
                                    .. attribute:: section_status
                                    
                                    	 status of the interface
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Section, self).__init__()

                                        self.yang_name = "section"
                                        self.yang_parent_name = "stm-minute15stm"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("section-e-ss", ("section_e_ss", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Section.SectionESs)), ("section-es-rs", ("section_es_rs", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Section.SectionEsRs)), ("section-bb-es", ("section_bb_es", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Section.SectionBbEs)), ("section-bbe-rs", ("section_bbe_rs", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Section.SectionBbeRs)), ("section-se-ss", ("section_se_ss", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Section.SectionSeSs)), ("section-ses-rs", ("section_ses_rs", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Section.SectionSesRs)), ("section-ua-ss", ("section_ua_ss", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Section.SectionUaSs)), ("section-e-bs", ("section_e_bs", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Section.SectionEBs))])
                                        self._leafs = OrderedDict([
                                            ('section_status', (YLeaf(YType.int32, 'section-status'), ['int'])),
                                        ])
                                        self.section_status = None

                                        self.section_e_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Section.SectionESs()
                                        self.section_e_ss.parent = self
                                        self._children_name_map["section_e_ss"] = "section-e-ss"

                                        self.section_es_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Section.SectionEsRs()
                                        self.section_es_rs.parent = self
                                        self._children_name_map["section_es_rs"] = "section-es-rs"

                                        self.section_bb_es = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Section.SectionBbEs()
                                        self.section_bb_es.parent = self
                                        self._children_name_map["section_bb_es"] = "section-bb-es"

                                        self.section_bbe_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Section.SectionBbeRs()
                                        self.section_bbe_rs.parent = self
                                        self._children_name_map["section_bbe_rs"] = "section-bbe-rs"

                                        self.section_se_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Section.SectionSeSs()
                                        self.section_se_ss.parent = self
                                        self._children_name_map["section_se_ss"] = "section-se-ss"

                                        self.section_ses_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Section.SectionSesRs()
                                        self.section_ses_rs.parent = self
                                        self._children_name_map["section_ses_rs"] = "section-ses-rs"

                                        self.section_ua_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Section.SectionUaSs()
                                        self.section_ua_ss.parent = self
                                        self._children_name_map["section_ua_ss"] = "section-ua-ss"

                                        self.section_e_bs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Section.SectionEBs()
                                        self.section_e_bs.parent = self
                                        self._children_name_map["section_e_bs"] = "section-e-bs"
                                        self._segment_path = lambda: "section"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Section, ['section_status'], name, value)


                                    class SectionESs(Entity):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Section.SectionESs, self).__init__()

                                            self.yang_name = "section-e-ss"
                                            self.yang_parent_name = "section"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "section-e-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Section.SectionESs, ['data', 'threshold', 'tca_report'], name, value)


                                    class SectionEsRs(Entity):
                                        """
                                        The number of Errored Seconds Ratio
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Section.SectionEsRs, self).__init__()

                                            self.yang_name = "section-es-rs"
                                            self.yang_parent_name = "section"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "section-es-rs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Section.SectionEsRs, ['data', 'threshold', 'tca_report'], name, value)


                                    class SectionBbEs(Entity):
                                        """
                                        The number of Background Block Errors
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Section.SectionBbEs, self).__init__()

                                            self.yang_name = "section-bb-es"
                                            self.yang_parent_name = "section"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "section-bb-es"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Section.SectionBbEs, ['data', 'threshold', 'tca_report'], name, value)


                                    class SectionBbeRs(Entity):
                                        """
                                        The number of Background Block Errors
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Section.SectionBbeRs, self).__init__()

                                            self.yang_name = "section-bbe-rs"
                                            self.yang_parent_name = "section"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "section-bbe-rs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Section.SectionBbeRs, ['data', 'threshold', 'tca_report'], name, value)


                                    class SectionSeSs(Entity):
                                        """
                                        The number of Severely Errored Second
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Section.SectionSeSs, self).__init__()

                                            self.yang_name = "section-se-ss"
                                            self.yang_parent_name = "section"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "section-se-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Section.SectionSeSs, ['data', 'threshold', 'tca_report'], name, value)


                                    class SectionSesRs(Entity):
                                        """
                                        The number of Severely Errored Second Ratio
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Section.SectionSesRs, self).__init__()

                                            self.yang_name = "section-ses-rs"
                                            self.yang_parent_name = "section"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "section-ses-rs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Section.SectionSesRs, ['data', 'threshold', 'tca_report'], name, value)


                                    class SectionUaSs(Entity):
                                        """
                                        The number of Unavailable Second
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Section.SectionUaSs, self).__init__()

                                            self.yang_name = "section-ua-ss"
                                            self.yang_parent_name = "section"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "section-ua-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Section.SectionUaSs, ['data', 'threshold', 'tca_report'], name, value)


                                    class SectionEBs(Entity):
                                        """
                                        The number of Errored Block Second
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Section.SectionEBs, self).__init__()

                                            self.yang_name = "section-e-bs"
                                            self.yang_parent_name = "section"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "section-e-bs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Section.SectionEBs, ['data', 'threshold', 'tca_report'], name, value)


                                class Line(Entity):
                                    """
                                    LINE
                                    
                                    .. attribute:: line_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:  :py:class:`LineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Line.LineESs>`
                                    
                                    .. attribute:: line_es_rs
                                    
                                    	The number of Errored Seconds Ratio
                                    	**type**\:  :py:class:`LineEsRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Line.LineEsRs>`
                                    
                                    .. attribute:: line_bb_es
                                    
                                    	The number of Background Block Errors
                                    	**type**\:  :py:class:`LineBbEs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Line.LineBbEs>`
                                    
                                    .. attribute:: line_bbe_rs
                                    
                                    	The number of Background Block Errors
                                    	**type**\:  :py:class:`LineBbeRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Line.LineBbeRs>`
                                    
                                    .. attribute:: line_se_ss
                                    
                                    	The number of Severely Errored Second
                                    	**type**\:  :py:class:`LineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Line.LineSeSs>`
                                    
                                    .. attribute:: line_ses_rs
                                    
                                    	The number of Severely Errored Second Ratio
                                    	**type**\:  :py:class:`LineSesRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Line.LineSesRs>`
                                    
                                    .. attribute:: line_ua_ss
                                    
                                    	The number of Unavailable Second
                                    	**type**\:  :py:class:`LineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Line.LineUaSs>`
                                    
                                    .. attribute:: line_e_bs
                                    
                                    	The number of Errored Block Second
                                    	**type**\:  :py:class:`LineEBs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Line.LineEBs>`
                                    
                                    .. attribute:: line_status
                                    
                                    	 status of the interface
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Line, self).__init__()

                                        self.yang_name = "line"
                                        self.yang_parent_name = "stm-minute15stm"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("line-e-ss", ("line_e_ss", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Line.LineESs)), ("line-es-rs", ("line_es_rs", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Line.LineEsRs)), ("line-bb-es", ("line_bb_es", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Line.LineBbEs)), ("line-bbe-rs", ("line_bbe_rs", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Line.LineBbeRs)), ("line-se-ss", ("line_se_ss", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Line.LineSeSs)), ("line-ses-rs", ("line_ses_rs", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Line.LineSesRs)), ("line-ua-ss", ("line_ua_ss", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Line.LineUaSs)), ("line-e-bs", ("line_e_bs", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Line.LineEBs))])
                                        self._leafs = OrderedDict([
                                            ('line_status', (YLeaf(YType.int32, 'line-status'), ['int'])),
                                        ])
                                        self.line_status = None

                                        self.line_e_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Line.LineESs()
                                        self.line_e_ss.parent = self
                                        self._children_name_map["line_e_ss"] = "line-e-ss"

                                        self.line_es_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Line.LineEsRs()
                                        self.line_es_rs.parent = self
                                        self._children_name_map["line_es_rs"] = "line-es-rs"

                                        self.line_bb_es = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Line.LineBbEs()
                                        self.line_bb_es.parent = self
                                        self._children_name_map["line_bb_es"] = "line-bb-es"

                                        self.line_bbe_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Line.LineBbeRs()
                                        self.line_bbe_rs.parent = self
                                        self._children_name_map["line_bbe_rs"] = "line-bbe-rs"

                                        self.line_se_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Line.LineSeSs()
                                        self.line_se_ss.parent = self
                                        self._children_name_map["line_se_ss"] = "line-se-ss"

                                        self.line_ses_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Line.LineSesRs()
                                        self.line_ses_rs.parent = self
                                        self._children_name_map["line_ses_rs"] = "line-ses-rs"

                                        self.line_ua_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Line.LineUaSs()
                                        self.line_ua_ss.parent = self
                                        self._children_name_map["line_ua_ss"] = "line-ua-ss"

                                        self.line_e_bs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Line.LineEBs()
                                        self.line_e_bs.parent = self
                                        self._children_name_map["line_e_bs"] = "line-e-bs"
                                        self._segment_path = lambda: "line"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Line, ['line_status'], name, value)


                                    class LineESs(Entity):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Line.LineESs, self).__init__()

                                            self.yang_name = "line-e-ss"
                                            self.yang_parent_name = "line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "line-e-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Line.LineESs, ['data', 'threshold', 'tca_report'], name, value)


                                    class LineEsRs(Entity):
                                        """
                                        The number of Errored Seconds Ratio
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Line.LineEsRs, self).__init__()

                                            self.yang_name = "line-es-rs"
                                            self.yang_parent_name = "line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "line-es-rs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Line.LineEsRs, ['data', 'threshold', 'tca_report'], name, value)


                                    class LineBbEs(Entity):
                                        """
                                        The number of Background Block Errors
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Line.LineBbEs, self).__init__()

                                            self.yang_name = "line-bb-es"
                                            self.yang_parent_name = "line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "line-bb-es"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Line.LineBbEs, ['data', 'threshold', 'tca_report'], name, value)


                                    class LineBbeRs(Entity):
                                        """
                                        The number of Background Block Errors
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Line.LineBbeRs, self).__init__()

                                            self.yang_name = "line-bbe-rs"
                                            self.yang_parent_name = "line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "line-bbe-rs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Line.LineBbeRs, ['data', 'threshold', 'tca_report'], name, value)


                                    class LineSeSs(Entity):
                                        """
                                        The number of Severely Errored Second
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Line.LineSeSs, self).__init__()

                                            self.yang_name = "line-se-ss"
                                            self.yang_parent_name = "line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "line-se-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Line.LineSeSs, ['data', 'threshold', 'tca_report'], name, value)


                                    class LineSesRs(Entity):
                                        """
                                        The number of Severely Errored Second Ratio
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Line.LineSesRs, self).__init__()

                                            self.yang_name = "line-ses-rs"
                                            self.yang_parent_name = "line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "line-ses-rs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Line.LineSesRs, ['data', 'threshold', 'tca_report'], name, value)


                                    class LineUaSs(Entity):
                                        """
                                        The number of Unavailable Second
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Line.LineUaSs, self).__init__()

                                            self.yang_name = "line-ua-ss"
                                            self.yang_parent_name = "line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "line-ua-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Line.LineUaSs, ['data', 'threshold', 'tca_report'], name, value)


                                    class LineEBs(Entity):
                                        """
                                        The number of Errored Block Second
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Line.LineEBs, self).__init__()

                                            self.yang_name = "line-e-bs"
                                            self.yang_parent_name = "line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "line-e-bs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.Line.LineEBs, ['data', 'threshold', 'tca_report'], name, value)


                                class FeLine(Entity):
                                    """
                                    FarEnd LINE
                                    
                                    .. attribute:: far_end_line_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:  :py:class:`FarEndLineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.FeLine.FarEndLineESs>`
                                    
                                    .. attribute:: far_end_line_es_rs
                                    
                                    	The number of Errored Seconds Ratio
                                    	**type**\:  :py:class:`FarEndLineEsRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.FeLine.FarEndLineEsRs>`
                                    
                                    .. attribute:: far_end_line_ebb_es
                                    
                                    	The number of Background Block Errors
                                    	**type**\:  :py:class:`FarEndLineEbbEs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.FeLine.FarEndLineEbbEs>`
                                    
                                    .. attribute:: far_end_line_bbe_rs
                                    
                                    	The number of Background Block Errors
                                    	**type**\:  :py:class:`FarEndLineBbeRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.FeLine.FarEndLineBbeRs>`
                                    
                                    .. attribute:: far_end_line_se_ss
                                    
                                    	The number of Severely Errored Second
                                    	**type**\:  :py:class:`FarEndLineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.FeLine.FarEndLineSeSs>`
                                    
                                    .. attribute:: far_end_line_ses_rs
                                    
                                    	The number of Severely Errored Second Ratio
                                    	**type**\:  :py:class:`FarEndLineSesRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.FeLine.FarEndLineSesRs>`
                                    
                                    .. attribute:: far_end_line_ua_ss
                                    
                                    	The number of Unavailable Second
                                    	**type**\:  :py:class:`FarEndLineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.FeLine.FarEndLineUaSs>`
                                    
                                    .. attribute:: far_end_line_e_bs
                                    
                                    	The number of Errored Block Second
                                    	**type**\:  :py:class:`FarEndLineEBs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.FeLine.FarEndLineEBs>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.FeLine, self).__init__()

                                        self.yang_name = "fe-line"
                                        self.yang_parent_name = "stm-minute15stm"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("far-end-line-e-ss", ("far_end_line_e_ss", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.FeLine.FarEndLineESs)), ("far-end-line-es-rs", ("far_end_line_es_rs", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.FeLine.FarEndLineEsRs)), ("far-end-line-ebb-es", ("far_end_line_ebb_es", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.FeLine.FarEndLineEbbEs)), ("far-end-line-bbe-rs", ("far_end_line_bbe_rs", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.FeLine.FarEndLineBbeRs)), ("far-end-line-se-ss", ("far_end_line_se_ss", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.FeLine.FarEndLineSeSs)), ("far-end-line-ses-rs", ("far_end_line_ses_rs", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.FeLine.FarEndLineSesRs)), ("far-end-line-ua-ss", ("far_end_line_ua_ss", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.FeLine.FarEndLineUaSs)), ("far-end-line-e-bs", ("far_end_line_e_bs", PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.FeLine.FarEndLineEBs))])
                                        self._leafs = OrderedDict()

                                        self.far_end_line_e_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.FeLine.FarEndLineESs()
                                        self.far_end_line_e_ss.parent = self
                                        self._children_name_map["far_end_line_e_ss"] = "far-end-line-e-ss"

                                        self.far_end_line_es_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.FeLine.FarEndLineEsRs()
                                        self.far_end_line_es_rs.parent = self
                                        self._children_name_map["far_end_line_es_rs"] = "far-end-line-es-rs"

                                        self.far_end_line_ebb_es = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.FeLine.FarEndLineEbbEs()
                                        self.far_end_line_ebb_es.parent = self
                                        self._children_name_map["far_end_line_ebb_es"] = "far-end-line-ebb-es"

                                        self.far_end_line_bbe_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.FeLine.FarEndLineBbeRs()
                                        self.far_end_line_bbe_rs.parent = self
                                        self._children_name_map["far_end_line_bbe_rs"] = "far-end-line-bbe-rs"

                                        self.far_end_line_se_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.FeLine.FarEndLineSeSs()
                                        self.far_end_line_se_ss.parent = self
                                        self._children_name_map["far_end_line_se_ss"] = "far-end-line-se-ss"

                                        self.far_end_line_ses_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.FeLine.FarEndLineSesRs()
                                        self.far_end_line_ses_rs.parent = self
                                        self._children_name_map["far_end_line_ses_rs"] = "far-end-line-ses-rs"

                                        self.far_end_line_ua_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.FeLine.FarEndLineUaSs()
                                        self.far_end_line_ua_ss.parent = self
                                        self._children_name_map["far_end_line_ua_ss"] = "far-end-line-ua-ss"

                                        self.far_end_line_e_bs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.FeLine.FarEndLineEBs()
                                        self.far_end_line_e_bs.parent = self
                                        self._children_name_map["far_end_line_e_bs"] = "far-end-line-e-bs"
                                        self._segment_path = lambda: "fe-line"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.FeLine, [], name, value)


                                    class FarEndLineESs(Entity):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.FeLine.FarEndLineESs, self).__init__()

                                            self.yang_name = "far-end-line-e-ss"
                                            self.yang_parent_name = "fe-line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "far-end-line-e-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.FeLine.FarEndLineESs, ['data', 'threshold', 'tca_report'], name, value)


                                    class FarEndLineEsRs(Entity):
                                        """
                                        The number of Errored Seconds Ratio
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.FeLine.FarEndLineEsRs, self).__init__()

                                            self.yang_name = "far-end-line-es-rs"
                                            self.yang_parent_name = "fe-line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "far-end-line-es-rs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.FeLine.FarEndLineEsRs, ['data', 'threshold', 'tca_report'], name, value)


                                    class FarEndLineEbbEs(Entity):
                                        """
                                        The number of Background Block Errors
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.FeLine.FarEndLineEbbEs, self).__init__()

                                            self.yang_name = "far-end-line-ebb-es"
                                            self.yang_parent_name = "fe-line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "far-end-line-ebb-es"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.FeLine.FarEndLineEbbEs, ['data', 'threshold', 'tca_report'], name, value)


                                    class FarEndLineBbeRs(Entity):
                                        """
                                        The number of Background Block Errors
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.FeLine.FarEndLineBbeRs, self).__init__()

                                            self.yang_name = "far-end-line-bbe-rs"
                                            self.yang_parent_name = "fe-line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "far-end-line-bbe-rs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.FeLine.FarEndLineBbeRs, ['data', 'threshold', 'tca_report'], name, value)


                                    class FarEndLineSeSs(Entity):
                                        """
                                        The number of Severely Errored Second
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.FeLine.FarEndLineSeSs, self).__init__()

                                            self.yang_name = "far-end-line-se-ss"
                                            self.yang_parent_name = "fe-line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "far-end-line-se-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.FeLine.FarEndLineSeSs, ['data', 'threshold', 'tca_report'], name, value)


                                    class FarEndLineSesRs(Entity):
                                        """
                                        The number of Severely Errored Second Ratio
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.FeLine.FarEndLineSesRs, self).__init__()

                                            self.yang_name = "far-end-line-ses-rs"
                                            self.yang_parent_name = "fe-line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "far-end-line-ses-rs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.FeLine.FarEndLineSesRs, ['data', 'threshold', 'tca_report'], name, value)


                                    class FarEndLineUaSs(Entity):
                                        """
                                        The number of Unavailable Second
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.FeLine.FarEndLineUaSs, self).__init__()

                                            self.yang_name = "far-end-line-ua-ss"
                                            self.yang_parent_name = "fe-line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "far-end-line-ua-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.FeLine.FarEndLineUaSs, ['data', 'threshold', 'tca_report'], name, value)


                                    class FarEndLineEBs(Entity):
                                        """
                                        The number of Errored Block Second
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.FeLine.FarEndLineEBs, self).__init__()

                                            self.yang_name = "far-end-line-e-bs"
                                            self.yang_parent_name = "fe-line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "far-end-line-e-bs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15stms.StmMinute15stm.FeLine.FarEndLineEBs, ['data', 'threshold', 'tca_report'], name, value)


    class Sonet(Entity):
        """
        SONET controller performance data
        
        .. attribute:: sonet_ports
        
        	Port performance data
        	**type**\:  :py:class:`SonetPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts>`
        
        

        """

        _prefix = 'pmengine-oper'
        _revision = '2017-09-07'

        def __init__(self):
            super(PerformanceManagement.Sonet, self).__init__()

            self.yang_name = "sonet"
            self.yang_parent_name = "performance-management"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("sonet-ports", ("sonet_ports", PerformanceManagement.Sonet.SonetPorts))])
            self._leafs = OrderedDict()

            self.sonet_ports = PerformanceManagement.Sonet.SonetPorts()
            self.sonet_ports.parent = self
            self._children_name_map["sonet_ports"] = "sonet-ports"
            self._segment_path = lambda: "sonet"
            self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(PerformanceManagement.Sonet, [], name, value)


        class SonetPorts(Entity):
            """
            Port performance data
            
            .. attribute:: sonet_port
            
            	Port performance data
            	**type**\: list of  		 :py:class:`SonetPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort>`
            
            

            """

            _prefix = 'pmengine-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(PerformanceManagement.Sonet.SonetPorts, self).__init__()

                self.yang_name = "sonet-ports"
                self.yang_parent_name = "sonet"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("sonet-port", ("sonet_port", PerformanceManagement.Sonet.SonetPorts.SonetPort))])
                self._leafs = OrderedDict()

                self.sonet_port = YList(self)
                self._segment_path = lambda: "sonet-ports"
                self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management/sonet/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(PerformanceManagement.Sonet.SonetPorts, [], name, value)


            class SonetPort(Entity):
                """
                Port performance data
                
                .. attribute:: name  (key)
                
                	Port name
                	**type**\: str
                
                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                
                .. attribute:: sonet_current
                
                	port current performance data
                	**type**\:  :py:class:`SonetCurrent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(PerformanceManagement.Sonet.SonetPorts.SonetPort, self).__init__()

                    self.yang_name = "sonet-port"
                    self.yang_parent_name = "sonet-ports"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("sonet-current", ("sonet_current", PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ])
                    self.name = None

                    self.sonet_current = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent()
                    self.sonet_current.parent = self
                    self._children_name_map["sonet_current"] = "sonet-current"
                    self._segment_path = lambda: "sonet-port" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management/sonet/sonet-ports/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(PerformanceManagement.Sonet.SonetPorts.SonetPort, ['name'], name, value)


                class SonetCurrent(Entity):
                    """
                    port current performance data
                    
                    .. attribute:: sonet_minute15
                    
                    	port current performance data
                    	**type**\:  :py:class:`SonetMinute15 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15>`
                    
                    .. attribute:: sonet_hour24
                    
                    	port current performance data
                    	**type**\:  :py:class:`SonetHour24 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent, self).__init__()

                        self.yang_name = "sonet-current"
                        self.yang_parent_name = "sonet-port"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("sonet-minute15", ("sonet_minute15", PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15)), ("sonet-hour24", ("sonet_hour24", PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24))])
                        self._leafs = OrderedDict()

                        self.sonet_minute15 = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15()
                        self.sonet_minute15.parent = self
                        self._children_name_map["sonet_minute15"] = "sonet-minute15"

                        self.sonet_hour24 = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24()
                        self.sonet_hour24.parent = self
                        self._children_name_map["sonet_hour24"] = "sonet-hour24"
                        self._segment_path = lambda: "sonet-current"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent, [], name, value)


                    class SonetMinute15(Entity):
                        """
                        port current performance data
                        
                        .. attribute:: sonet_minute15_paths
                        
                        	port current performance data
                        	**type**\:  :py:class:`SonetMinute15Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths>`
                        
                        .. attribute:: sonet_minute15ocns
                        
                        	port current performance data
                        	**type**\:  :py:class:`SonetMinute15ocns <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15, self).__init__()

                            self.yang_name = "sonet-minute15"
                            self.yang_parent_name = "sonet-current"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("sonet-minute15-paths", ("sonet_minute15_paths", PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths)), ("sonet-minute15ocns", ("sonet_minute15ocns", PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns))])
                            self._leafs = OrderedDict()

                            self.sonet_minute15_paths = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths()
                            self.sonet_minute15_paths.parent = self
                            self._children_name_map["sonet_minute15_paths"] = "sonet-minute15-paths"

                            self.sonet_minute15ocns = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns()
                            self.sonet_minute15ocns.parent = self
                            self._children_name_map["sonet_minute15ocns"] = "sonet-minute15ocns"
                            self._segment_path = lambda: "sonet-minute15"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15, [], name, value)


                        class SonetMinute15Paths(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: sonet_minute15_path
                            
                            	port 15\-minute Path performance data
                            	**type**\: list of  		 :py:class:`SonetMinute15Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths, self).__init__()

                                self.yang_name = "sonet-minute15-paths"
                                self.yang_parent_name = "sonet-minute15"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("sonet-minute15-path", ("sonet_minute15_path", PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path))])
                                self._leafs = OrderedDict()

                                self.sonet_minute15_path = YList(self)
                                self._segment_path = lambda: "sonet-minute15-paths"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths, [], name, value)


                            class SonetMinute15Path(Entity):
                                """
                                port 15\-minute Path performance data
                                
                                .. attribute:: number  (key)
                                
                                	channel number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path
                                
                                	PATH
                                	**type**\:  :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path>`
                                
                                .. attribute:: fe_path
                                
                                	Far End PATH
                                	**type**\:  :py:class:`FePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.FePath>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path, self).__init__()

                                    self.yang_name = "sonet-minute15-path"
                                    self.yang_parent_name = "sonet-minute15-paths"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("path", ("path", PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path)), ("fe-path", ("fe_path", PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.FePath))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                    ])
                                    self.number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None

                                    self.path = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path()
                                    self.path.parent = self
                                    self._children_name_map["path"] = "path"

                                    self.fe_path = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.FePath()
                                    self.fe_path.parent = self
                                    self._children_name_map["fe_path"] = "fe-path"
                                    self._segment_path = lambda: "sonet-minute15-path" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear24_hr_time'], name, value)


                                class Path(Entity):
                                    """
                                    PATH
                                    
                                    .. attribute:: path_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:  :py:class:`PathESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path.PathESs>`
                                    
                                    .. attribute:: path_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:  :py:class:`PathSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path.PathSeSs>`
                                    
                                    .. attribute:: path_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:  :py:class:`PathCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path.PathCVs>`
                                    
                                    .. attribute:: path_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\:  :py:class:`PathUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path.PathUaSs>`
                                    
                                    .. attribute:: path_width
                                    
                                    	Indicates the type of the SONET/SDH Path
                                    	**type**\:  :py:class:`PmSonetPathWidthEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmSonetPathWidthEnum>`
                                    
                                    .. attribute:: path_status
                                    
                                    	 status of the interface
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path, self).__init__()

                                        self.yang_name = "path"
                                        self.yang_parent_name = "sonet-minute15-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("path-e-ss", ("path_e_ss", PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path.PathESs)), ("path-se-ss", ("path_se_ss", PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path.PathSeSs)), ("path-c-vs", ("path_c_vs", PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path.PathCVs)), ("path-ua-ss", ("path_ua_ss", PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path.PathUaSs))])
                                        self._leafs = OrderedDict([
                                            ('path_width', (YLeaf(YType.enumeration, 'path-width'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper', 'PmSonetPathWidthEnum', '')])),
                                            ('path_status', (YLeaf(YType.int32, 'path-status'), ['int'])),
                                        ])
                                        self.path_width = None
                                        self.path_status = None

                                        self.path_e_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path.PathESs()
                                        self.path_e_ss.parent = self
                                        self._children_name_map["path_e_ss"] = "path-e-ss"

                                        self.path_se_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path.PathSeSs()
                                        self.path_se_ss.parent = self
                                        self._children_name_map["path_se_ss"] = "path-se-ss"

                                        self.path_c_vs = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path.PathCVs()
                                        self.path_c_vs.parent = self
                                        self._children_name_map["path_c_vs"] = "path-c-vs"

                                        self.path_ua_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path.PathUaSs()
                                        self.path_ua_ss.parent = self
                                        self._children_name_map["path_ua_ss"] = "path-ua-ss"
                                        self._segment_path = lambda: "path"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path, ['path_width', 'path_status'], name, value)


                                    class PathESs(Entity):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path.PathESs, self).__init__()

                                            self.yang_name = "path-e-ss"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "path-e-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path.PathESs, ['data', 'threshold', 'tca_report'], name, value)


                                    class PathSeSs(Entity):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path.PathSeSs, self).__init__()

                                            self.yang_name = "path-se-ss"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "path-se-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path.PathSeSs, ['data', 'threshold', 'tca_report'], name, value)


                                    class PathCVs(Entity):
                                        """
                                        The number of Coding Violations
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path.PathCVs, self).__init__()

                                            self.yang_name = "path-c-vs"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "path-c-vs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path.PathCVs, ['data', 'threshold', 'tca_report'], name, value)


                                    class PathUaSs(Entity):
                                        """
                                        The number of Unavailable Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path.PathUaSs, self).__init__()

                                            self.yang_name = "path-ua-ss"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "path-ua-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path.PathUaSs, ['data', 'threshold', 'tca_report'], name, value)


                                class FePath(Entity):
                                    """
                                    Far End PATH
                                    
                                    .. attribute:: far_end_path_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: far_end_path_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: far_end_path_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: far_end_path_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.FePath, self).__init__()

                                        self.yang_name = "fe-path"
                                        self.yang_parent_name = "sonet-minute15-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('far_end_path_e_ss', (YLeaf(YType.uint32, 'far-end-path-e-ss'), ['int'])),
                                            ('far_end_path_se_ss', (YLeaf(YType.uint32, 'far-end-path-se-ss'), ['int'])),
                                            ('far_end_path_c_vs', (YLeaf(YType.uint32, 'far-end-path-c-vs'), ['int'])),
                                            ('far_end_path_ua_ss', (YLeaf(YType.uint32, 'far-end-path-ua-ss'), ['int'])),
                                        ])
                                        self.far_end_path_e_ss = None
                                        self.far_end_path_se_ss = None
                                        self.far_end_path_c_vs = None
                                        self.far_end_path_ua_ss = None
                                        self._segment_path = lambda: "fe-path"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.FePath, ['far_end_path_e_ss', 'far_end_path_se_ss', 'far_end_path_c_vs', 'far_end_path_ua_ss'], name, value)


                        class SonetMinute15ocns(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: sonet_minute15ocn
                            
                            	port 15\-minute ocn performance data
                            	**type**\: list of  		 :py:class:`SonetMinute15ocn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns, self).__init__()

                                self.yang_name = "sonet-minute15ocns"
                                self.yang_parent_name = "sonet-minute15"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("sonet-minute15ocn", ("sonet_minute15ocn", PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn))])
                                self._leafs = OrderedDict()

                                self.sonet_minute15ocn = YList(self)
                                self._segment_path = lambda: "sonet-minute15ocns"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns, [], name, value)


                            class SonetMinute15ocn(Entity):
                                """
                                port 15\-minute ocn performance data
                                
                                .. attribute:: number  (key)
                                
                                	channel number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: section
                                
                                	SECTION
                                	**type**\:  :py:class:`Section <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.Section>`
                                
                                .. attribute:: line
                                
                                	LINE
                                	**type**\:  :py:class:`Line <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.Line>`
                                
                                .. attribute:: fe_line
                                
                                	FarEnd LINE
                                	**type**\:  :py:class:`FeLine <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.FeLine>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn, self).__init__()

                                    self.yang_name = "sonet-minute15ocn"
                                    self.yang_parent_name = "sonet-minute15ocns"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("section", ("section", PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.Section)), ("line", ("line", PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.Line)), ("fe-line", ("fe_line", PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.FeLine))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                    ])
                                    self.number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None

                                    self.section = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.Section()
                                    self.section.parent = self
                                    self._children_name_map["section"] = "section"

                                    self.line = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.Line()
                                    self.line.parent = self
                                    self._children_name_map["line"] = "line"

                                    self.fe_line = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.FeLine()
                                    self.fe_line.parent = self
                                    self._children_name_map["fe_line"] = "fe-line"
                                    self._segment_path = lambda: "sonet-minute15ocn" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear24_hr_time'], name, value)


                                class Section(Entity):
                                    """
                                    SECTION
                                    
                                    .. attribute:: section_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:  :py:class:`SectionESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.Section.SectionESs>`
                                    
                                    .. attribute:: section_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:  :py:class:`SectionSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.Section.SectionSeSs>`
                                    
                                    .. attribute:: section_sef_ss
                                    
                                    	The number of Severely Errored Framing Seconds
                                    	**type**\:  :py:class:`SectionSefSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.Section.SectionSefSs>`
                                    
                                    .. attribute:: section_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:  :py:class:`SectionCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.Section.SectionCVs>`
                                    
                                    .. attribute:: section_status
                                    
                                    	 status of the interface
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.Section, self).__init__()

                                        self.yang_name = "section"
                                        self.yang_parent_name = "sonet-minute15ocn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("section-e-ss", ("section_e_ss", PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.Section.SectionESs)), ("section-se-ss", ("section_se_ss", PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.Section.SectionSeSs)), ("section-sef-ss", ("section_sef_ss", PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.Section.SectionSefSs)), ("section-c-vs", ("section_c_vs", PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.Section.SectionCVs))])
                                        self._leafs = OrderedDict([
                                            ('section_status', (YLeaf(YType.int32, 'section-status'), ['int'])),
                                        ])
                                        self.section_status = None

                                        self.section_e_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.Section.SectionESs()
                                        self.section_e_ss.parent = self
                                        self._children_name_map["section_e_ss"] = "section-e-ss"

                                        self.section_se_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.Section.SectionSeSs()
                                        self.section_se_ss.parent = self
                                        self._children_name_map["section_se_ss"] = "section-se-ss"

                                        self.section_sef_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.Section.SectionSefSs()
                                        self.section_sef_ss.parent = self
                                        self._children_name_map["section_sef_ss"] = "section-sef-ss"

                                        self.section_c_vs = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.Section.SectionCVs()
                                        self.section_c_vs.parent = self
                                        self._children_name_map["section_c_vs"] = "section-c-vs"
                                        self._segment_path = lambda: "section"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.Section, ['section_status'], name, value)


                                    class SectionESs(Entity):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.Section.SectionESs, self).__init__()

                                            self.yang_name = "section-e-ss"
                                            self.yang_parent_name = "section"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "section-e-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.Section.SectionESs, ['data', 'threshold', 'tca_report'], name, value)


                                    class SectionSeSs(Entity):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.Section.SectionSeSs, self).__init__()

                                            self.yang_name = "section-se-ss"
                                            self.yang_parent_name = "section"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "section-se-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.Section.SectionSeSs, ['data', 'threshold', 'tca_report'], name, value)


                                    class SectionSefSs(Entity):
                                        """
                                        The number of Severely Errored Framing Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.Section.SectionSefSs, self).__init__()

                                            self.yang_name = "section-sef-ss"
                                            self.yang_parent_name = "section"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "section-sef-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.Section.SectionSefSs, ['data', 'threshold', 'tca_report'], name, value)


                                    class SectionCVs(Entity):
                                        """
                                        The number of Coding Violations
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.Section.SectionCVs, self).__init__()

                                            self.yang_name = "section-c-vs"
                                            self.yang_parent_name = "section"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "section-c-vs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.Section.SectionCVs, ['data', 'threshold', 'tca_report'], name, value)


                                class Line(Entity):
                                    """
                                    LINE
                                    
                                    .. attribute:: line_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:  :py:class:`LineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.Line.LineESs>`
                                    
                                    .. attribute:: line_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:  :py:class:`LineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.Line.LineSeSs>`
                                    
                                    .. attribute:: line_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:  :py:class:`LineCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.Line.LineCVs>`
                                    
                                    .. attribute:: line_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\:  :py:class:`LineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.Line.LineUaSs>`
                                    
                                    .. attribute:: line_fc_ls
                                    
                                    	The number of Failure counts Seconds
                                    	**type**\:  :py:class:`LineFcLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.Line.LineFcLs>`
                                    
                                    .. attribute:: line_status
                                    
                                    	 status of the interface
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.Line, self).__init__()

                                        self.yang_name = "line"
                                        self.yang_parent_name = "sonet-minute15ocn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("line-e-ss", ("line_e_ss", PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.Line.LineESs)), ("line-se-ss", ("line_se_ss", PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.Line.LineSeSs)), ("line-c-vs", ("line_c_vs", PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.Line.LineCVs)), ("line-ua-ss", ("line_ua_ss", PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.Line.LineUaSs)), ("line-fc-ls", ("line_fc_ls", PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.Line.LineFcLs))])
                                        self._leafs = OrderedDict([
                                            ('line_status', (YLeaf(YType.int32, 'line-status'), ['int'])),
                                        ])
                                        self.line_status = None

                                        self.line_e_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.Line.LineESs()
                                        self.line_e_ss.parent = self
                                        self._children_name_map["line_e_ss"] = "line-e-ss"

                                        self.line_se_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.Line.LineSeSs()
                                        self.line_se_ss.parent = self
                                        self._children_name_map["line_se_ss"] = "line-se-ss"

                                        self.line_c_vs = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.Line.LineCVs()
                                        self.line_c_vs.parent = self
                                        self._children_name_map["line_c_vs"] = "line-c-vs"

                                        self.line_ua_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.Line.LineUaSs()
                                        self.line_ua_ss.parent = self
                                        self._children_name_map["line_ua_ss"] = "line-ua-ss"

                                        self.line_fc_ls = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.Line.LineFcLs()
                                        self.line_fc_ls.parent = self
                                        self._children_name_map["line_fc_ls"] = "line-fc-ls"
                                        self._segment_path = lambda: "line"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.Line, ['line_status'], name, value)


                                    class LineESs(Entity):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.Line.LineESs, self).__init__()

                                            self.yang_name = "line-e-ss"
                                            self.yang_parent_name = "line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "line-e-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.Line.LineESs, ['data', 'threshold', 'tca_report'], name, value)


                                    class LineSeSs(Entity):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.Line.LineSeSs, self).__init__()

                                            self.yang_name = "line-se-ss"
                                            self.yang_parent_name = "line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "line-se-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.Line.LineSeSs, ['data', 'threshold', 'tca_report'], name, value)


                                    class LineCVs(Entity):
                                        """
                                        The number of Coding Violations
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.Line.LineCVs, self).__init__()

                                            self.yang_name = "line-c-vs"
                                            self.yang_parent_name = "line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "line-c-vs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.Line.LineCVs, ['data', 'threshold', 'tca_report'], name, value)


                                    class LineUaSs(Entity):
                                        """
                                        The number of Unavailable Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.Line.LineUaSs, self).__init__()

                                            self.yang_name = "line-ua-ss"
                                            self.yang_parent_name = "line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "line-ua-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.Line.LineUaSs, ['data', 'threshold', 'tca_report'], name, value)


                                    class LineFcLs(Entity):
                                        """
                                        The number of Failure counts Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.Line.LineFcLs, self).__init__()

                                            self.yang_name = "line-fc-ls"
                                            self.yang_parent_name = "line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "line-fc-ls"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.Line.LineFcLs, ['data', 'threshold', 'tca_report'], name, value)


                                class FeLine(Entity):
                                    """
                                    FarEnd LINE
                                    
                                    .. attribute:: far_end_line_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:  :py:class:`FarEndLineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.FeLine.FarEndLineESs>`
                                    
                                    .. attribute:: far_end_line_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:  :py:class:`FarEndLineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.FeLine.FarEndLineSeSs>`
                                    
                                    .. attribute:: far_end_line_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:  :py:class:`FarEndLineCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.FeLine.FarEndLineCVs>`
                                    
                                    .. attribute:: far_end_line_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\:  :py:class:`FarEndLineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.FeLine.FarEndLineUaSs>`
                                    
                                    .. attribute:: far_end_line_fc_ls
                                    
                                    	The number of Failure counts Seconds
                                    	**type**\:  :py:class:`FarEndLineFcLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.FeLine.FarEndLineFcLs>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.FeLine, self).__init__()

                                        self.yang_name = "fe-line"
                                        self.yang_parent_name = "sonet-minute15ocn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("far-end-line-e-ss", ("far_end_line_e_ss", PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.FeLine.FarEndLineESs)), ("far-end-line-se-ss", ("far_end_line_se_ss", PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.FeLine.FarEndLineSeSs)), ("far-end-line-c-vs", ("far_end_line_c_vs", PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.FeLine.FarEndLineCVs)), ("far-end-line-ua-ss", ("far_end_line_ua_ss", PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.FeLine.FarEndLineUaSs)), ("far-end-line-fc-ls", ("far_end_line_fc_ls", PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.FeLine.FarEndLineFcLs))])
                                        self._leafs = OrderedDict()

                                        self.far_end_line_e_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.FeLine.FarEndLineESs()
                                        self.far_end_line_e_ss.parent = self
                                        self._children_name_map["far_end_line_e_ss"] = "far-end-line-e-ss"

                                        self.far_end_line_se_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.FeLine.FarEndLineSeSs()
                                        self.far_end_line_se_ss.parent = self
                                        self._children_name_map["far_end_line_se_ss"] = "far-end-line-se-ss"

                                        self.far_end_line_c_vs = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.FeLine.FarEndLineCVs()
                                        self.far_end_line_c_vs.parent = self
                                        self._children_name_map["far_end_line_c_vs"] = "far-end-line-c-vs"

                                        self.far_end_line_ua_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.FeLine.FarEndLineUaSs()
                                        self.far_end_line_ua_ss.parent = self
                                        self._children_name_map["far_end_line_ua_ss"] = "far-end-line-ua-ss"

                                        self.far_end_line_fc_ls = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.FeLine.FarEndLineFcLs()
                                        self.far_end_line_fc_ls.parent = self
                                        self._children_name_map["far_end_line_fc_ls"] = "far-end-line-fc-ls"
                                        self._segment_path = lambda: "fe-line"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.FeLine, [], name, value)


                                    class FarEndLineESs(Entity):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.FeLine.FarEndLineESs, self).__init__()

                                            self.yang_name = "far-end-line-e-ss"
                                            self.yang_parent_name = "fe-line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "far-end-line-e-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.FeLine.FarEndLineESs, ['data', 'threshold', 'tca_report'], name, value)


                                    class FarEndLineSeSs(Entity):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.FeLine.FarEndLineSeSs, self).__init__()

                                            self.yang_name = "far-end-line-se-ss"
                                            self.yang_parent_name = "fe-line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "far-end-line-se-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.FeLine.FarEndLineSeSs, ['data', 'threshold', 'tca_report'], name, value)


                                    class FarEndLineCVs(Entity):
                                        """
                                        The number of Coding Violations
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.FeLine.FarEndLineCVs, self).__init__()

                                            self.yang_name = "far-end-line-c-vs"
                                            self.yang_parent_name = "fe-line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "far-end-line-c-vs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.FeLine.FarEndLineCVs, ['data', 'threshold', 'tca_report'], name, value)


                                    class FarEndLineUaSs(Entity):
                                        """
                                        The number of Unavailable Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.FeLine.FarEndLineUaSs, self).__init__()

                                            self.yang_name = "far-end-line-ua-ss"
                                            self.yang_parent_name = "fe-line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "far-end-line-ua-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.FeLine.FarEndLineUaSs, ['data', 'threshold', 'tca_report'], name, value)


                                    class FarEndLineFcLs(Entity):
                                        """
                                        The number of Failure counts Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.FeLine.FarEndLineFcLs, self).__init__()

                                            self.yang_name = "far-end-line-fc-ls"
                                            self.yang_parent_name = "fe-line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "far-end-line-fc-ls"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15ocns.SonetMinute15ocn.FeLine.FarEndLineFcLs, ['data', 'threshold', 'tca_report'], name, value)


                    class SonetHour24(Entity):
                        """
                        port current performance data
                        
                        .. attribute:: sonet_hour24ocns
                        
                        	port current performance data
                        	**type**\:  :py:class:`SonetHour24ocns <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns>`
                        
                        .. attribute:: sonet_hour24_paths
                        
                        	port current performance data
                        	**type**\:  :py:class:`SonetHour24Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24, self).__init__()

                            self.yang_name = "sonet-hour24"
                            self.yang_parent_name = "sonet-current"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("sonet-hour24ocns", ("sonet_hour24ocns", PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns)), ("sonet-hour24-paths", ("sonet_hour24_paths", PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths))])
                            self._leafs = OrderedDict()

                            self.sonet_hour24ocns = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns()
                            self.sonet_hour24ocns.parent = self
                            self._children_name_map["sonet_hour24ocns"] = "sonet-hour24ocns"

                            self.sonet_hour24_paths = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths()
                            self.sonet_hour24_paths.parent = self
                            self._children_name_map["sonet_hour24_paths"] = "sonet-hour24-paths"
                            self._segment_path = lambda: "sonet-hour24"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24, [], name, value)


                        class SonetHour24ocns(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: sonet_hour24ocn
                            
                            	port 24 hour ocn performance data
                            	**type**\: list of  		 :py:class:`SonetHour24ocn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns, self).__init__()

                                self.yang_name = "sonet-hour24ocns"
                                self.yang_parent_name = "sonet-hour24"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("sonet-hour24ocn", ("sonet_hour24ocn", PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn))])
                                self._leafs = OrderedDict()

                                self.sonet_hour24ocn = YList(self)
                                self._segment_path = lambda: "sonet-hour24ocns"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns, [], name, value)


                            class SonetHour24ocn(Entity):
                                """
                                port 24 hour ocn performance data
                                
                                .. attribute:: number  (key)
                                
                                	channel number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: section
                                
                                	SECTION
                                	**type**\:  :py:class:`Section <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.Section>`
                                
                                .. attribute:: line
                                
                                	LINE
                                	**type**\:  :py:class:`Line <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.Line>`
                                
                                .. attribute:: fe_line
                                
                                	FarEnd LINE
                                	**type**\:  :py:class:`FeLine <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.FeLine>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn, self).__init__()

                                    self.yang_name = "sonet-hour24ocn"
                                    self.yang_parent_name = "sonet-hour24ocns"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("section", ("section", PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.Section)), ("line", ("line", PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.Line)), ("fe-line", ("fe_line", PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.FeLine))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                    ])
                                    self.number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None

                                    self.section = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.Section()
                                    self.section.parent = self
                                    self._children_name_map["section"] = "section"

                                    self.line = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.Line()
                                    self.line.parent = self
                                    self._children_name_map["line"] = "line"

                                    self.fe_line = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.FeLine()
                                    self.fe_line.parent = self
                                    self._children_name_map["fe_line"] = "fe-line"
                                    self._segment_path = lambda: "sonet-hour24ocn" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear24_hr_time'], name, value)


                                class Section(Entity):
                                    """
                                    SECTION
                                    
                                    .. attribute:: section_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:  :py:class:`SectionESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.Section.SectionESs>`
                                    
                                    .. attribute:: section_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:  :py:class:`SectionSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.Section.SectionSeSs>`
                                    
                                    .. attribute:: section_sef_ss
                                    
                                    	The number of Severely Errored Framing Seconds
                                    	**type**\:  :py:class:`SectionSefSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.Section.SectionSefSs>`
                                    
                                    .. attribute:: section_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:  :py:class:`SectionCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.Section.SectionCVs>`
                                    
                                    .. attribute:: section_status
                                    
                                    	 status of the interface
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.Section, self).__init__()

                                        self.yang_name = "section"
                                        self.yang_parent_name = "sonet-hour24ocn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("section-e-ss", ("section_e_ss", PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.Section.SectionESs)), ("section-se-ss", ("section_se_ss", PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.Section.SectionSeSs)), ("section-sef-ss", ("section_sef_ss", PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.Section.SectionSefSs)), ("section-c-vs", ("section_c_vs", PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.Section.SectionCVs))])
                                        self._leafs = OrderedDict([
                                            ('section_status', (YLeaf(YType.int32, 'section-status'), ['int'])),
                                        ])
                                        self.section_status = None

                                        self.section_e_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.Section.SectionESs()
                                        self.section_e_ss.parent = self
                                        self._children_name_map["section_e_ss"] = "section-e-ss"

                                        self.section_se_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.Section.SectionSeSs()
                                        self.section_se_ss.parent = self
                                        self._children_name_map["section_se_ss"] = "section-se-ss"

                                        self.section_sef_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.Section.SectionSefSs()
                                        self.section_sef_ss.parent = self
                                        self._children_name_map["section_sef_ss"] = "section-sef-ss"

                                        self.section_c_vs = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.Section.SectionCVs()
                                        self.section_c_vs.parent = self
                                        self._children_name_map["section_c_vs"] = "section-c-vs"
                                        self._segment_path = lambda: "section"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.Section, ['section_status'], name, value)


                                    class SectionESs(Entity):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.Section.SectionESs, self).__init__()

                                            self.yang_name = "section-e-ss"
                                            self.yang_parent_name = "section"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "section-e-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.Section.SectionESs, ['data', 'threshold', 'tca_report'], name, value)


                                    class SectionSeSs(Entity):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.Section.SectionSeSs, self).__init__()

                                            self.yang_name = "section-se-ss"
                                            self.yang_parent_name = "section"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "section-se-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.Section.SectionSeSs, ['data', 'threshold', 'tca_report'], name, value)


                                    class SectionSefSs(Entity):
                                        """
                                        The number of Severely Errored Framing Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.Section.SectionSefSs, self).__init__()

                                            self.yang_name = "section-sef-ss"
                                            self.yang_parent_name = "section"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "section-sef-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.Section.SectionSefSs, ['data', 'threshold', 'tca_report'], name, value)


                                    class SectionCVs(Entity):
                                        """
                                        The number of Coding Violations
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.Section.SectionCVs, self).__init__()

                                            self.yang_name = "section-c-vs"
                                            self.yang_parent_name = "section"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "section-c-vs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.Section.SectionCVs, ['data', 'threshold', 'tca_report'], name, value)


                                class Line(Entity):
                                    """
                                    LINE
                                    
                                    .. attribute:: line_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:  :py:class:`LineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.Line.LineESs>`
                                    
                                    .. attribute:: line_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:  :py:class:`LineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.Line.LineSeSs>`
                                    
                                    .. attribute:: line_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:  :py:class:`LineCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.Line.LineCVs>`
                                    
                                    .. attribute:: line_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\:  :py:class:`LineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.Line.LineUaSs>`
                                    
                                    .. attribute:: line_fc_ls
                                    
                                    	The number of Failure counts Seconds
                                    	**type**\:  :py:class:`LineFcLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.Line.LineFcLs>`
                                    
                                    .. attribute:: line_status
                                    
                                    	 status of the interface
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.Line, self).__init__()

                                        self.yang_name = "line"
                                        self.yang_parent_name = "sonet-hour24ocn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("line-e-ss", ("line_e_ss", PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.Line.LineESs)), ("line-se-ss", ("line_se_ss", PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.Line.LineSeSs)), ("line-c-vs", ("line_c_vs", PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.Line.LineCVs)), ("line-ua-ss", ("line_ua_ss", PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.Line.LineUaSs)), ("line-fc-ls", ("line_fc_ls", PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.Line.LineFcLs))])
                                        self._leafs = OrderedDict([
                                            ('line_status', (YLeaf(YType.int32, 'line-status'), ['int'])),
                                        ])
                                        self.line_status = None

                                        self.line_e_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.Line.LineESs()
                                        self.line_e_ss.parent = self
                                        self._children_name_map["line_e_ss"] = "line-e-ss"

                                        self.line_se_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.Line.LineSeSs()
                                        self.line_se_ss.parent = self
                                        self._children_name_map["line_se_ss"] = "line-se-ss"

                                        self.line_c_vs = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.Line.LineCVs()
                                        self.line_c_vs.parent = self
                                        self._children_name_map["line_c_vs"] = "line-c-vs"

                                        self.line_ua_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.Line.LineUaSs()
                                        self.line_ua_ss.parent = self
                                        self._children_name_map["line_ua_ss"] = "line-ua-ss"

                                        self.line_fc_ls = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.Line.LineFcLs()
                                        self.line_fc_ls.parent = self
                                        self._children_name_map["line_fc_ls"] = "line-fc-ls"
                                        self._segment_path = lambda: "line"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.Line, ['line_status'], name, value)


                                    class LineESs(Entity):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.Line.LineESs, self).__init__()

                                            self.yang_name = "line-e-ss"
                                            self.yang_parent_name = "line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "line-e-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.Line.LineESs, ['data', 'threshold', 'tca_report'], name, value)


                                    class LineSeSs(Entity):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.Line.LineSeSs, self).__init__()

                                            self.yang_name = "line-se-ss"
                                            self.yang_parent_name = "line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "line-se-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.Line.LineSeSs, ['data', 'threshold', 'tca_report'], name, value)


                                    class LineCVs(Entity):
                                        """
                                        The number of Coding Violations
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.Line.LineCVs, self).__init__()

                                            self.yang_name = "line-c-vs"
                                            self.yang_parent_name = "line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "line-c-vs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.Line.LineCVs, ['data', 'threshold', 'tca_report'], name, value)


                                    class LineUaSs(Entity):
                                        """
                                        The number of Unavailable Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.Line.LineUaSs, self).__init__()

                                            self.yang_name = "line-ua-ss"
                                            self.yang_parent_name = "line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "line-ua-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.Line.LineUaSs, ['data', 'threshold', 'tca_report'], name, value)


                                    class LineFcLs(Entity):
                                        """
                                        The number of Failure counts Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.Line.LineFcLs, self).__init__()

                                            self.yang_name = "line-fc-ls"
                                            self.yang_parent_name = "line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "line-fc-ls"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.Line.LineFcLs, ['data', 'threshold', 'tca_report'], name, value)


                                class FeLine(Entity):
                                    """
                                    FarEnd LINE
                                    
                                    .. attribute:: far_end_line_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:  :py:class:`FarEndLineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.FeLine.FarEndLineESs>`
                                    
                                    .. attribute:: far_end_line_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:  :py:class:`FarEndLineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.FeLine.FarEndLineSeSs>`
                                    
                                    .. attribute:: far_end_line_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:  :py:class:`FarEndLineCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.FeLine.FarEndLineCVs>`
                                    
                                    .. attribute:: far_end_line_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\:  :py:class:`FarEndLineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.FeLine.FarEndLineUaSs>`
                                    
                                    .. attribute:: far_end_line_fc_ls
                                    
                                    	The number of Failure counts Seconds
                                    	**type**\:  :py:class:`FarEndLineFcLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.FeLine.FarEndLineFcLs>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.FeLine, self).__init__()

                                        self.yang_name = "fe-line"
                                        self.yang_parent_name = "sonet-hour24ocn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("far-end-line-e-ss", ("far_end_line_e_ss", PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.FeLine.FarEndLineESs)), ("far-end-line-se-ss", ("far_end_line_se_ss", PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.FeLine.FarEndLineSeSs)), ("far-end-line-c-vs", ("far_end_line_c_vs", PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.FeLine.FarEndLineCVs)), ("far-end-line-ua-ss", ("far_end_line_ua_ss", PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.FeLine.FarEndLineUaSs)), ("far-end-line-fc-ls", ("far_end_line_fc_ls", PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.FeLine.FarEndLineFcLs))])
                                        self._leafs = OrderedDict()

                                        self.far_end_line_e_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.FeLine.FarEndLineESs()
                                        self.far_end_line_e_ss.parent = self
                                        self._children_name_map["far_end_line_e_ss"] = "far-end-line-e-ss"

                                        self.far_end_line_se_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.FeLine.FarEndLineSeSs()
                                        self.far_end_line_se_ss.parent = self
                                        self._children_name_map["far_end_line_se_ss"] = "far-end-line-se-ss"

                                        self.far_end_line_c_vs = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.FeLine.FarEndLineCVs()
                                        self.far_end_line_c_vs.parent = self
                                        self._children_name_map["far_end_line_c_vs"] = "far-end-line-c-vs"

                                        self.far_end_line_ua_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.FeLine.FarEndLineUaSs()
                                        self.far_end_line_ua_ss.parent = self
                                        self._children_name_map["far_end_line_ua_ss"] = "far-end-line-ua-ss"

                                        self.far_end_line_fc_ls = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.FeLine.FarEndLineFcLs()
                                        self.far_end_line_fc_ls.parent = self
                                        self._children_name_map["far_end_line_fc_ls"] = "far-end-line-fc-ls"
                                        self._segment_path = lambda: "fe-line"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.FeLine, [], name, value)


                                    class FarEndLineESs(Entity):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.FeLine.FarEndLineESs, self).__init__()

                                            self.yang_name = "far-end-line-e-ss"
                                            self.yang_parent_name = "fe-line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "far-end-line-e-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.FeLine.FarEndLineESs, ['data', 'threshold', 'tca_report'], name, value)


                                    class FarEndLineSeSs(Entity):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.FeLine.FarEndLineSeSs, self).__init__()

                                            self.yang_name = "far-end-line-se-ss"
                                            self.yang_parent_name = "fe-line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "far-end-line-se-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.FeLine.FarEndLineSeSs, ['data', 'threshold', 'tca_report'], name, value)


                                    class FarEndLineCVs(Entity):
                                        """
                                        The number of Coding Violations
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.FeLine.FarEndLineCVs, self).__init__()

                                            self.yang_name = "far-end-line-c-vs"
                                            self.yang_parent_name = "fe-line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "far-end-line-c-vs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.FeLine.FarEndLineCVs, ['data', 'threshold', 'tca_report'], name, value)


                                    class FarEndLineUaSs(Entity):
                                        """
                                        The number of Unavailable Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.FeLine.FarEndLineUaSs, self).__init__()

                                            self.yang_name = "far-end-line-ua-ss"
                                            self.yang_parent_name = "fe-line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "far-end-line-ua-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.FeLine.FarEndLineUaSs, ['data', 'threshold', 'tca_report'], name, value)


                                    class FarEndLineFcLs(Entity):
                                        """
                                        The number of Failure counts Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.FeLine.FarEndLineFcLs, self).__init__()

                                            self.yang_name = "far-end-line-fc-ls"
                                            self.yang_parent_name = "fe-line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "far-end-line-fc-ls"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24ocns.SonetHour24ocn.FeLine.FarEndLineFcLs, ['data', 'threshold', 'tca_report'], name, value)


                        class SonetHour24Paths(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: sonet_hour24_path
                            
                            	port 24 hour Path performance data
                            	**type**\: list of  		 :py:class:`SonetHour24Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths, self).__init__()

                                self.yang_name = "sonet-hour24-paths"
                                self.yang_parent_name = "sonet-hour24"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("sonet-hour24-path", ("sonet_hour24_path", PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path))])
                                self._leafs = OrderedDict()

                                self.sonet_hour24_path = YList(self)
                                self._segment_path = lambda: "sonet-hour24-paths"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths, [], name, value)


                            class SonetHour24Path(Entity):
                                """
                                port 24 hour Path performance data
                                
                                .. attribute:: number  (key)
                                
                                	channel number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path
                                
                                	PATH
                                	**type**\:  :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path>`
                                
                                .. attribute:: fe_path
                                
                                	Far End PATH
                                	**type**\:  :py:class:`FePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.FePath>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path, self).__init__()

                                    self.yang_name = "sonet-hour24-path"
                                    self.yang_parent_name = "sonet-hour24-paths"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("path", ("path", PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path)), ("fe-path", ("fe_path", PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.FePath))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                    ])
                                    self.number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None

                                    self.path = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path()
                                    self.path.parent = self
                                    self._children_name_map["path"] = "path"

                                    self.fe_path = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.FePath()
                                    self.fe_path.parent = self
                                    self._children_name_map["fe_path"] = "fe-path"
                                    self._segment_path = lambda: "sonet-hour24-path" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear24_hr_time'], name, value)


                                class Path(Entity):
                                    """
                                    PATH
                                    
                                    .. attribute:: path_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:  :py:class:`PathESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path.PathESs>`
                                    
                                    .. attribute:: path_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:  :py:class:`PathSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path.PathSeSs>`
                                    
                                    .. attribute:: path_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:  :py:class:`PathCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path.PathCVs>`
                                    
                                    .. attribute:: path_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\:  :py:class:`PathUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path.PathUaSs>`
                                    
                                    .. attribute:: path_width
                                    
                                    	Indicates the type of the SONET/SDH Path
                                    	**type**\:  :py:class:`PmSonetPathWidthEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmSonetPathWidthEnum>`
                                    
                                    .. attribute:: path_status
                                    
                                    	 status of the interface
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path, self).__init__()

                                        self.yang_name = "path"
                                        self.yang_parent_name = "sonet-hour24-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("path-e-ss", ("path_e_ss", PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path.PathESs)), ("path-se-ss", ("path_se_ss", PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path.PathSeSs)), ("path-c-vs", ("path_c_vs", PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path.PathCVs)), ("path-ua-ss", ("path_ua_ss", PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path.PathUaSs))])
                                        self._leafs = OrderedDict([
                                            ('path_width', (YLeaf(YType.enumeration, 'path-width'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper', 'PmSonetPathWidthEnum', '')])),
                                            ('path_status', (YLeaf(YType.int32, 'path-status'), ['int'])),
                                        ])
                                        self.path_width = None
                                        self.path_status = None

                                        self.path_e_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path.PathESs()
                                        self.path_e_ss.parent = self
                                        self._children_name_map["path_e_ss"] = "path-e-ss"

                                        self.path_se_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path.PathSeSs()
                                        self.path_se_ss.parent = self
                                        self._children_name_map["path_se_ss"] = "path-se-ss"

                                        self.path_c_vs = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path.PathCVs()
                                        self.path_c_vs.parent = self
                                        self._children_name_map["path_c_vs"] = "path-c-vs"

                                        self.path_ua_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path.PathUaSs()
                                        self.path_ua_ss.parent = self
                                        self._children_name_map["path_ua_ss"] = "path-ua-ss"
                                        self._segment_path = lambda: "path"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path, ['path_width', 'path_status'], name, value)


                                    class PathESs(Entity):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path.PathESs, self).__init__()

                                            self.yang_name = "path-e-ss"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "path-e-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path.PathESs, ['data', 'threshold', 'tca_report'], name, value)


                                    class PathSeSs(Entity):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path.PathSeSs, self).__init__()

                                            self.yang_name = "path-se-ss"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "path-se-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path.PathSeSs, ['data', 'threshold', 'tca_report'], name, value)


                                    class PathCVs(Entity):
                                        """
                                        The number of Coding Violations
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path.PathCVs, self).__init__()

                                            self.yang_name = "path-c-vs"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "path-c-vs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path.PathCVs, ['data', 'threshold', 'tca_report'], name, value)


                                    class PathUaSs(Entity):
                                        """
                                        The number of Unavailable Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path.PathUaSs, self).__init__()

                                            self.yang_name = "path-ua-ss"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "path-ua-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path.PathUaSs, ['data', 'threshold', 'tca_report'], name, value)


                                class FePath(Entity):
                                    """
                                    Far End PATH
                                    
                                    .. attribute:: far_end_path_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: far_end_path_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: far_end_path_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: far_end_path_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.FePath, self).__init__()

                                        self.yang_name = "fe-path"
                                        self.yang_parent_name = "sonet-hour24-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('far_end_path_e_ss', (YLeaf(YType.uint32, 'far-end-path-e-ss'), ['int'])),
                                            ('far_end_path_se_ss', (YLeaf(YType.uint32, 'far-end-path-se-ss'), ['int'])),
                                            ('far_end_path_c_vs', (YLeaf(YType.uint32, 'far-end-path-c-vs'), ['int'])),
                                            ('far_end_path_ua_ss', (YLeaf(YType.uint32, 'far-end-path-ua-ss'), ['int'])),
                                        ])
                                        self.far_end_path_e_ss = None
                                        self.far_end_path_se_ss = None
                                        self.far_end_path_c_vs = None
                                        self.far_end_path_ua_ss = None
                                        self._segment_path = lambda: "fe-path"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.FePath, ['far_end_path_e_ss', 'far_end_path_se_ss', 'far_end_path_c_vs', 'far_end_path_ua_ss'], name, value)


    class Optics(Entity):
        """
        OPTICS controller performance data
        
        .. attribute:: optics_ports
        
        	Port performance data
        	**type**\:  :py:class:`OpticsPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts>`
        
        

        """

        _prefix = 'pmengine-oper'
        _revision = '2017-09-07'

        def __init__(self):
            super(PerformanceManagement.Optics, self).__init__()

            self.yang_name = "optics"
            self.yang_parent_name = "performance-management"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("optics-ports", ("optics_ports", PerformanceManagement.Optics.OpticsPorts))])
            self._leafs = OrderedDict()

            self.optics_ports = PerformanceManagement.Optics.OpticsPorts()
            self.optics_ports.parent = self
            self._children_name_map["optics_ports"] = "optics-ports"
            self._segment_path = lambda: "optics"
            self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(PerformanceManagement.Optics, [], name, value)


        class OpticsPorts(Entity):
            """
            Port performance data
            
            .. attribute:: optics_port
            
            	Port performance data
            	**type**\: list of  		 :py:class:`OpticsPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort>`
            
            

            """

            _prefix = 'pmengine-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(PerformanceManagement.Optics.OpticsPorts, self).__init__()

                self.yang_name = "optics-ports"
                self.yang_parent_name = "optics"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("optics-port", ("optics_port", PerformanceManagement.Optics.OpticsPorts.OpticsPort))])
                self._leafs = OrderedDict()

                self.optics_port = YList(self)
                self._segment_path = lambda: "optics-ports"
                self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management/optics/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(PerformanceManagement.Optics.OpticsPorts, [], name, value)


            class OpticsPort(Entity):
                """
                Port performance data
                
                .. attribute:: name  (key)
                
                	Port name
                	**type**\: str
                
                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                
                .. attribute:: optics_current
                
                	port current performance data
                	**type**\:  :py:class:`OpticsCurrent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort, self).__init__()

                    self.yang_name = "optics-port"
                    self.yang_parent_name = "optics-ports"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("optics-current", ("optics_current", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ])
                    self.name = None

                    self.optics_current = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent()
                    self.optics_current.parent = self
                    self._children_name_map["optics_current"] = "optics-current"
                    self._segment_path = lambda: "optics-port" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management/optics/optics-ports/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort, ['name'], name, value)


                class OpticsCurrent(Entity):
                    """
                    port current performance data
                    
                    .. attribute:: optics_hour24
                    
                    	port current performance data
                    	**type**\:  :py:class:`OpticsHour24 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24>`
                    
                    .. attribute:: optics_minute15
                    
                    	port current performance data
                    	**type**\:  :py:class:`OpticsMinute15 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15>`
                    
                    .. attribute:: optics_second30
                    
                    	port current performance data
                    	**type**\:  :py:class:`OpticsSecond30 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent, self).__init__()

                        self.yang_name = "optics-current"
                        self.yang_parent_name = "optics-port"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("optics-hour24", ("optics_hour24", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24)), ("optics-minute15", ("optics_minute15", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15)), ("optics-second30", ("optics_second30", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30))])
                        self._leafs = OrderedDict()

                        self.optics_hour24 = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24()
                        self.optics_hour24.parent = self
                        self._children_name_map["optics_hour24"] = "optics-hour24"

                        self.optics_minute15 = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15()
                        self.optics_minute15.parent = self
                        self._children_name_map["optics_minute15"] = "optics-minute15"

                        self.optics_second30 = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30()
                        self.optics_second30.parent = self
                        self._children_name_map["optics_second30"] = "optics-second30"
                        self._segment_path = lambda: "optics-current"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent, [], name, value)


                    class OpticsHour24(Entity):
                        """
                        port current performance data
                        
                        .. attribute:: optics_hour24_optics
                        
                        	port 24 hour performance data
                        	**type**\:  :py:class:`OpticsHour24Optics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics>`
                        
                        .. attribute:: optics_hour24fecs
                        
                        	port current performance data
                        	**type**\:  :py:class:`OpticsHour24fecs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24fecs>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24, self).__init__()

                            self.yang_name = "optics-hour24"
                            self.yang_parent_name = "optics-current"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("optics-hour24-optics", ("optics_hour24_optics", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics)), ("optics-hour24fecs", ("optics_hour24fecs", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24fecs))])
                            self._leafs = OrderedDict()

                            self.optics_hour24_optics = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics()
                            self.optics_hour24_optics.parent = self
                            self._children_name_map["optics_hour24_optics"] = "optics-hour24-optics"

                            self.optics_hour24fecs = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24fecs()
                            self.optics_hour24fecs.parent = self
                            self._children_name_map["optics_hour24fecs"] = "optics-hour24fecs"
                            self._segment_path = lambda: "optics-hour24"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24, [], name, value)


                        class OpticsHour24Optics(Entity):
                            """
                            port 24 hour performance data
                            
                            .. attribute:: optics_hour24_optic
                            
                            	port 24 hour optics performance data
                            	**type**\: list of  		 :py:class:`OpticsHour24Optic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics, self).__init__()

                                self.yang_name = "optics-hour24-optics"
                                self.yang_parent_name = "optics-hour24"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("optics-hour24-optic", ("optics_hour24_optic", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic))])
                                self._leafs = OrderedDict()

                                self.optics_hour24_optic = YList(self)
                                self._segment_path = lambda: "optics-hour24-optics"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics, [], name, value)


                            class OpticsHour24Optic(Entity):
                                """
                                port 24 hour optics performance data
                                
                                .. attribute:: number  (key)
                                
                                	channel number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lbc
                                
                                	LBC
                                	**type**\:  :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Lbc>`
                                
                                .. attribute:: lbc_pc
                                
                                	LBC in percentage
                                	**type**\:  :py:class:`LbcPc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.LbcPc>`
                                
                                .. attribute:: opt
                                
                                	OPT
                                	**type**\:  :py:class:`Opt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Opt>`
                                
                                .. attribute:: opr
                                
                                	OPR
                                	**type**\:  :py:class:`Opr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Opr>`
                                
                                .. attribute:: cd
                                
                                	Chromatic Dispersion
                                	**type**\:  :py:class:`Cd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Cd>`
                                
                                .. attribute:: dgd
                                
                                	Differential group Delay
                                	**type**\:  :py:class:`Dgd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Dgd>`
                                
                                .. attribute:: pmd
                                
                                	Polarization Mode Dispersion
                                	**type**\:  :py:class:`Pmd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Pmd>`
                                
                                .. attribute:: osnr
                                
                                	Optical Signal to Noise Ratio
                                	**type**\:  :py:class:`Osnr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Osnr>`
                                
                                .. attribute:: center_wavelength
                                
                                	Center Wavelength/Frequency
                                	**type**\:  :py:class:`CenterWavelength <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.CenterWavelength>`
                                
                                .. attribute:: pdl
                                
                                	Polarization Dependent Loss
                                	**type**\:  :py:class:`Pdl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Pdl>`
                                
                                .. attribute:: pcr
                                
                                	Polarization Change Rate
                                	**type**\:  :py:class:`Pcr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Pcr>`
                                
                                .. attribute:: pn
                                
                                	Phase Noise
                                	**type**\:  :py:class:`Pn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Pn>`
                                
                                .. attribute:: rx_sig_pow
                                
                                	Rx signal power
                                	**type**\:  :py:class:`RxSigPow <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.RxSigPow>`
                                
                                .. attribute:: low_sig_freq_off
                                
                                	low freq sig off
                                	**type**\:  :py:class:`LowSigFreqOff <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.LowSigFreqOff>`
                                
                                .. attribute:: ampli_gain
                                
                                	Ampli Gain
                                	**type**\:  :py:class:`AmpliGain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.AmpliGain>`
                                
                                .. attribute:: ampli_gain_tilt
                                
                                	Ampli Gain Tilt
                                	**type**\:  :py:class:`AmpliGainTilt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.AmpliGainTilt>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic, self).__init__()

                                    self.yang_name = "optics-hour24-optic"
                                    self.yang_parent_name = "optics-hour24-optics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("lbc", ("lbc", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Lbc)), ("lbc-pc", ("lbc_pc", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.LbcPc)), ("opt", ("opt", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Opt)), ("opr", ("opr", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Opr)), ("cd", ("cd", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Cd)), ("dgd", ("dgd", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Dgd)), ("pmd", ("pmd", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Pmd)), ("osnr", ("osnr", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Osnr)), ("center-wavelength", ("center_wavelength", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.CenterWavelength)), ("pdl", ("pdl", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Pdl)), ("pcr", ("pcr", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Pcr)), ("pn", ("pn", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Pn)), ("rx-sig-pow", ("rx_sig_pow", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.RxSigPow)), ("low-sig-freq-off", ("low_sig_freq_off", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.LowSigFreqOff)), ("ampli-gain", ("ampli_gain", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.AmpliGain)), ("ampli-gain-tilt", ("ampli_gain_tilt", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.AmpliGainTilt))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                        ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                    ])
                                    self.number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear24_hr_time = None
                                    self.sec30_support = None

                                    self.lbc = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Lbc()
                                    self.lbc.parent = self
                                    self._children_name_map["lbc"] = "lbc"

                                    self.lbc_pc = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.LbcPc()
                                    self.lbc_pc.parent = self
                                    self._children_name_map["lbc_pc"] = "lbc-pc"

                                    self.opt = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Opt()
                                    self.opt.parent = self
                                    self._children_name_map["opt"] = "opt"

                                    self.opr = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Opr()
                                    self.opr.parent = self
                                    self._children_name_map["opr"] = "opr"

                                    self.cd = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Cd()
                                    self.cd.parent = self
                                    self._children_name_map["cd"] = "cd"

                                    self.dgd = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Dgd()
                                    self.dgd.parent = self
                                    self._children_name_map["dgd"] = "dgd"

                                    self.pmd = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Pmd()
                                    self.pmd.parent = self
                                    self._children_name_map["pmd"] = "pmd"

                                    self.osnr = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Osnr()
                                    self.osnr.parent = self
                                    self._children_name_map["osnr"] = "osnr"

                                    self.center_wavelength = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.CenterWavelength()
                                    self.center_wavelength.parent = self
                                    self._children_name_map["center_wavelength"] = "center-wavelength"

                                    self.pdl = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Pdl()
                                    self.pdl.parent = self
                                    self._children_name_map["pdl"] = "pdl"

                                    self.pcr = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Pcr()
                                    self.pcr.parent = self
                                    self._children_name_map["pcr"] = "pcr"

                                    self.pn = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Pn()
                                    self.pn.parent = self
                                    self._children_name_map["pn"] = "pn"

                                    self.rx_sig_pow = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.RxSigPow()
                                    self.rx_sig_pow.parent = self
                                    self._children_name_map["rx_sig_pow"] = "rx-sig-pow"

                                    self.low_sig_freq_off = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.LowSigFreqOff()
                                    self.low_sig_freq_off.parent = self
                                    self._children_name_map["low_sig_freq_off"] = "low-sig-freq-off"

                                    self.ampli_gain = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.AmpliGain()
                                    self.ampli_gain.parent = self
                                    self._children_name_map["ampli_gain"] = "ampli-gain"

                                    self.ampli_gain_tilt = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.AmpliGainTilt()
                                    self.ampli_gain_tilt.parent = self
                                    self._children_name_map["ampli_gain_tilt"] = "ampli-gain-tilt"
                                    self._segment_path = lambda: "optics-hour24-optic" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                class Lbc(Entity):
                                    """
                                    LBC
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Lbc, self).__init__()

                                        self.yang_name = "lbc"
                                        self.yang_parent_name = "optics-hour24-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.int32, 'minimum'), ['int'])),
                                            ('average', (YLeaf(YType.int32, 'average'), ['int'])),
                                            ('maximum', (YLeaf(YType.int32, 'maximum'), ['int'])),
                                            ('minimum_threshold', (YLeaf(YType.int32, 'minimum-threshold'), ['int'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.int32, 'maximum-threshold'), ['int'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "lbc"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Lbc, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class LbcPc(Entity):
                                    """
                                    LBC in percentage
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.LbcPc, self).__init__()

                                        self.yang_name = "lbc-pc"
                                        self.yang_parent_name = "optics-hour24-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "lbc-pc"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.LbcPc, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class Opt(Entity):
                                    """
                                    OPT
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Opt, self).__init__()

                                        self.yang_name = "opt"
                                        self.yang_parent_name = "optics-hour24-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "opt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Opt, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class Opr(Entity):
                                    """
                                    OPR
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Opr, self).__init__()

                                        self.yang_name = "opr"
                                        self.yang_parent_name = "optics-hour24-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "opr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Opr, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class Cd(Entity):
                                    """
                                    Chromatic Dispersion
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Cd, self).__init__()

                                        self.yang_name = "cd"
                                        self.yang_parent_name = "optics-hour24-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.int32, 'minimum'), ['int'])),
                                            ('average', (YLeaf(YType.int32, 'average'), ['int'])),
                                            ('maximum', (YLeaf(YType.int32, 'maximum'), ['int'])),
                                            ('minimum_threshold', (YLeaf(YType.int32, 'minimum-threshold'), ['int'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.int32, 'maximum-threshold'), ['int'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "cd"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Cd, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class Dgd(Entity):
                                    """
                                    Differential group Delay
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Dgd, self).__init__()

                                        self.yang_name = "dgd"
                                        self.yang_parent_name = "optics-hour24-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "dgd"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Dgd, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class Pmd(Entity):
                                    """
                                    Polarization Mode Dispersion
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Pmd, self).__init__()

                                        self.yang_name = "pmd"
                                        self.yang_parent_name = "optics-hour24-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "pmd"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Pmd, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class Osnr(Entity):
                                    """
                                    Optical Signal to Noise Ratio
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Osnr, self).__init__()

                                        self.yang_name = "osnr"
                                        self.yang_parent_name = "optics-hour24-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "osnr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Osnr, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class CenterWavelength(Entity):
                                    """
                                    Center Wavelength/Frequency
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.CenterWavelength, self).__init__()

                                        self.yang_name = "center-wavelength"
                                        self.yang_parent_name = "optics-hour24-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "center-wavelength"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.CenterWavelength, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class Pdl(Entity):
                                    """
                                    Polarization Dependent Loss
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Pdl, self).__init__()

                                        self.yang_name = "pdl"
                                        self.yang_parent_name = "optics-hour24-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "pdl"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Pdl, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class Pcr(Entity):
                                    """
                                    Polarization Change Rate
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Pcr, self).__init__()

                                        self.yang_name = "pcr"
                                        self.yang_parent_name = "optics-hour24-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "pcr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Pcr, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class Pn(Entity):
                                    """
                                    Phase Noise
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Pn, self).__init__()

                                        self.yang_name = "pn"
                                        self.yang_parent_name = "optics-hour24-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "pn"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Pn, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class RxSigPow(Entity):
                                    """
                                    Rx signal power
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.RxSigPow, self).__init__()

                                        self.yang_name = "rx-sig-pow"
                                        self.yang_parent_name = "optics-hour24-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "rx-sig-pow"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.RxSigPow, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class LowSigFreqOff(Entity):
                                    """
                                    low freq sig off
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.LowSigFreqOff, self).__init__()

                                        self.yang_name = "low-sig-freq-off"
                                        self.yang_parent_name = "optics-hour24-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.int32, 'minimum'), ['int'])),
                                            ('average', (YLeaf(YType.int32, 'average'), ['int'])),
                                            ('maximum', (YLeaf(YType.int32, 'maximum'), ['int'])),
                                            ('minimum_threshold', (YLeaf(YType.int32, 'minimum-threshold'), ['int'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.int32, 'maximum-threshold'), ['int'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "low-sig-freq-off"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.LowSigFreqOff, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class AmpliGain(Entity):
                                    """
                                    Ampli Gain
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.AmpliGain, self).__init__()

                                        self.yang_name = "ampli-gain"
                                        self.yang_parent_name = "optics-hour24-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "ampli-gain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.AmpliGain, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class AmpliGainTilt(Entity):
                                    """
                                    Ampli Gain Tilt
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.AmpliGainTilt, self).__init__()

                                        self.yang_name = "ampli-gain-tilt"
                                        self.yang_parent_name = "optics-hour24-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "ampli-gain-tilt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.AmpliGainTilt, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                        class OpticsHour24fecs(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: optics_hour24fec
                            
                            	port 24 hour fec performance data
                            	**type**\: list of  		 :py:class:`OpticsHour24fec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24fecs.OpticsHour24fec>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24fecs, self).__init__()

                                self.yang_name = "optics-hour24fecs"
                                self.yang_parent_name = "optics-hour24"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("optics-hour24fec", ("optics_hour24fec", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24fecs.OpticsHour24fec))])
                                self._leafs = OrderedDict()

                                self.optics_hour24fec = YList(self)
                                self._segment_path = lambda: "optics-hour24fecs"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24fecs, [], name, value)


                            class OpticsHour24fec(Entity):
                                """
                                port 24 hour fec performance data
                                
                                .. attribute:: number  (key)
                                
                                	channel number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ec_bits
                                
                                	EC BITS
                                	**type**\:  :py:class:`EcBits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24fecs.OpticsHour24fec.EcBits>`
                                
                                .. attribute:: uc_words
                                
                                	UC WORDS
                                	**type**\:  :py:class:`UcWords <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24fecs.OpticsHour24fec.UcWords>`
                                
                                .. attribute:: pre_fec_ber
                                
                                	Pre FEC BER
                                	**type**\:  :py:class:`PreFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24fecs.OpticsHour24fec.PreFecBer>`
                                
                                .. attribute:: post_fec_ber
                                
                                	Post FEC BER
                                	**type**\:  :py:class:`PostFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24fecs.OpticsHour24fec.PostFecBer>`
                                
                                .. attribute:: q
                                
                                	Q
                                	**type**\:  :py:class:`Q <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24fecs.OpticsHour24fec.Q>`
                                
                                .. attribute:: qmargin
                                
                                	Q Margin
                                	**type**\:  :py:class:`Qmargin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24fecs.OpticsHour24fec.Qmargin>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24fecs.OpticsHour24fec, self).__init__()

                                    self.yang_name = "optics-hour24fec"
                                    self.yang_parent_name = "optics-hour24fecs"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("ec-bits", ("ec_bits", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24fecs.OpticsHour24fec.EcBits)), ("uc-words", ("uc_words", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24fecs.OpticsHour24fec.UcWords)), ("pre-fec-ber", ("pre_fec_ber", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24fecs.OpticsHour24fec.PreFecBer)), ("post-fec-ber", ("post_fec_ber", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24fecs.OpticsHour24fec.PostFecBer)), ("q", ("q", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24fecs.OpticsHour24fec.Q)), ("qmargin", ("qmargin", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24fecs.OpticsHour24fec.Qmargin))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                        ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                    ])
                                    self.number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear24_hr_time = None
                                    self.sec30_support = None

                                    self.ec_bits = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24fecs.OpticsHour24fec.EcBits()
                                    self.ec_bits.parent = self
                                    self._children_name_map["ec_bits"] = "ec-bits"

                                    self.uc_words = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24fecs.OpticsHour24fec.UcWords()
                                    self.uc_words.parent = self
                                    self._children_name_map["uc_words"] = "uc-words"

                                    self.pre_fec_ber = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24fecs.OpticsHour24fec.PreFecBer()
                                    self.pre_fec_ber.parent = self
                                    self._children_name_map["pre_fec_ber"] = "pre-fec-ber"

                                    self.post_fec_ber = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24fecs.OpticsHour24fec.PostFecBer()
                                    self.post_fec_ber.parent = self
                                    self._children_name_map["post_fec_ber"] = "post-fec-ber"

                                    self.q = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24fecs.OpticsHour24fec.Q()
                                    self.q.parent = self
                                    self._children_name_map["q"] = "q"

                                    self.qmargin = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24fecs.OpticsHour24fec.Qmargin()
                                    self.qmargin.parent = self
                                    self._children_name_map["qmargin"] = "qmargin"
                                    self._segment_path = lambda: "optics-hour24fec" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24fecs.OpticsHour24fec, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                class EcBits(Entity):
                                    """
                                    EC BITS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24fecs.OpticsHour24fec.EcBits, self).__init__()

                                        self.yang_name = "ec-bits"
                                        self.yang_parent_name = "optics-hour24fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ec-bits"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24fecs.OpticsHour24fec.EcBits, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class UcWords(Entity):
                                    """
                                    UC WORDS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24fecs.OpticsHour24fec.UcWords, self).__init__()

                                        self.yang_name = "uc-words"
                                        self.yang_parent_name = "optics-hour24fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "uc-words"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24fecs.OpticsHour24fec.UcWords, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class PreFecBer(Entity):
                                    """
                                    Pre FEC BER
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24fecs.OpticsHour24fec.PreFecBer, self).__init__()

                                        self.yang_name = "pre-fec-ber"
                                        self.yang_parent_name = "optics-hour24fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.maximum_tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "pre-fec-ber"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24fecs.OpticsHour24fec.PreFecBer, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                class PostFecBer(Entity):
                                    """
                                    Post FEC BER
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24fecs.OpticsHour24fec.PostFecBer, self).__init__()

                                        self.yang_name = "post-fec-ber"
                                        self.yang_parent_name = "optics-hour24fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.maximum_tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "post-fec-ber"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24fecs.OpticsHour24fec.PostFecBer, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                class Q(Entity):
                                    """
                                    Q
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24fecs.OpticsHour24fec.Q, self).__init__()

                                        self.yang_name = "q"
                                        self.yang_parent_name = "optics-hour24fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.maximum_tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "q"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24fecs.OpticsHour24fec.Q, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                class Qmargin(Entity):
                                    """
                                    Q Margin
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24fecs.OpticsHour24fec.Qmargin, self).__init__()

                                        self.yang_name = "qmargin"
                                        self.yang_parent_name = "optics-hour24fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.maximum_tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "qmargin"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24fecs.OpticsHour24fec.Qmargin, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                    class OpticsMinute15(Entity):
                        """
                        port current performance data
                        
                        .. attribute:: optics_minute15_optics
                        
                        	port current performance data
                        	**type**\:  :py:class:`OpticsMinute15Optics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics>`
                        
                        .. attribute:: optics_minute15fecs
                        
                        	port current performance data
                        	**type**\:  :py:class:`OpticsMinute15fecs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15fecs>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15, self).__init__()

                            self.yang_name = "optics-minute15"
                            self.yang_parent_name = "optics-current"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("optics-minute15-optics", ("optics_minute15_optics", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics)), ("optics-minute15fecs", ("optics_minute15fecs", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15fecs))])
                            self._leafs = OrderedDict()

                            self.optics_minute15_optics = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics()
                            self.optics_minute15_optics.parent = self
                            self._children_name_map["optics_minute15_optics"] = "optics-minute15-optics"

                            self.optics_minute15fecs = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15fecs()
                            self.optics_minute15fecs.parent = self
                            self._children_name_map["optics_minute15fecs"] = "optics-minute15fecs"
                            self._segment_path = lambda: "optics-minute15"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15, [], name, value)


                        class OpticsMinute15Optics(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: optics_minute15_optic
                            
                            	port 15\-minute optics performance data
                            	**type**\: list of  		 :py:class:`OpticsMinute15Optic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics, self).__init__()

                                self.yang_name = "optics-minute15-optics"
                                self.yang_parent_name = "optics-minute15"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("optics-minute15-optic", ("optics_minute15_optic", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic))])
                                self._leafs = OrderedDict()

                                self.optics_minute15_optic = YList(self)
                                self._segment_path = lambda: "optics-minute15-optics"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics, [], name, value)


                            class OpticsMinute15Optic(Entity):
                                """
                                port 15\-minute optics performance data
                                
                                .. attribute:: number  (key)
                                
                                	channel number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lbc
                                
                                	LBC
                                	**type**\:  :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Lbc>`
                                
                                .. attribute:: lbc_pc
                                
                                	LBC in percentage
                                	**type**\:  :py:class:`LbcPc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.LbcPc>`
                                
                                .. attribute:: opt
                                
                                	OPT
                                	**type**\:  :py:class:`Opt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Opt>`
                                
                                .. attribute:: opr
                                
                                	OPR
                                	**type**\:  :py:class:`Opr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Opr>`
                                
                                .. attribute:: cd
                                
                                	Chromatic Dispersion
                                	**type**\:  :py:class:`Cd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Cd>`
                                
                                .. attribute:: dgd
                                
                                	Differential group Delay
                                	**type**\:  :py:class:`Dgd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Dgd>`
                                
                                .. attribute:: pmd
                                
                                	Polarization Mode Dispersion
                                	**type**\:  :py:class:`Pmd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Pmd>`
                                
                                .. attribute:: osnr
                                
                                	Optical Signal to Noise Ratio
                                	**type**\:  :py:class:`Osnr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Osnr>`
                                
                                .. attribute:: center_wavelength
                                
                                	Center Wavelength/Frequency
                                	**type**\:  :py:class:`CenterWavelength <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.CenterWavelength>`
                                
                                .. attribute:: pdl
                                
                                	Polarization Dependent Loss
                                	**type**\:  :py:class:`Pdl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Pdl>`
                                
                                .. attribute:: pcr
                                
                                	Polarization Change Rate
                                	**type**\:  :py:class:`Pcr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Pcr>`
                                
                                .. attribute:: pn
                                
                                	Phase Noise
                                	**type**\:  :py:class:`Pn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Pn>`
                                
                                .. attribute:: rx_sig_pow
                                
                                	Rx signal power
                                	**type**\:  :py:class:`RxSigPow <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.RxSigPow>`
                                
                                .. attribute:: low_sig_freq_off
                                
                                	low freq sig off
                                	**type**\:  :py:class:`LowSigFreqOff <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.LowSigFreqOff>`
                                
                                .. attribute:: ampli_gain
                                
                                	Ampli Gain
                                	**type**\:  :py:class:`AmpliGain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.AmpliGain>`
                                
                                .. attribute:: ampli_gain_tilt
                                
                                	Ampli Gain Tilt
                                	**type**\:  :py:class:`AmpliGainTilt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.AmpliGainTilt>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic, self).__init__()

                                    self.yang_name = "optics-minute15-optic"
                                    self.yang_parent_name = "optics-minute15-optics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("lbc", ("lbc", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Lbc)), ("lbc-pc", ("lbc_pc", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.LbcPc)), ("opt", ("opt", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Opt)), ("opr", ("opr", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Opr)), ("cd", ("cd", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Cd)), ("dgd", ("dgd", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Dgd)), ("pmd", ("pmd", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Pmd)), ("osnr", ("osnr", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Osnr)), ("center-wavelength", ("center_wavelength", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.CenterWavelength)), ("pdl", ("pdl", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Pdl)), ("pcr", ("pcr", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Pcr)), ("pn", ("pn", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Pn)), ("rx-sig-pow", ("rx_sig_pow", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.RxSigPow)), ("low-sig-freq-off", ("low_sig_freq_off", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.LowSigFreqOff)), ("ampli-gain", ("ampli_gain", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.AmpliGain)), ("ampli-gain-tilt", ("ampli_gain_tilt", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.AmpliGainTilt))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                        ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                    ])
                                    self.number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear24_hr_time = None
                                    self.sec30_support = None

                                    self.lbc = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Lbc()
                                    self.lbc.parent = self
                                    self._children_name_map["lbc"] = "lbc"

                                    self.lbc_pc = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.LbcPc()
                                    self.lbc_pc.parent = self
                                    self._children_name_map["lbc_pc"] = "lbc-pc"

                                    self.opt = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Opt()
                                    self.opt.parent = self
                                    self._children_name_map["opt"] = "opt"

                                    self.opr = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Opr()
                                    self.opr.parent = self
                                    self._children_name_map["opr"] = "opr"

                                    self.cd = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Cd()
                                    self.cd.parent = self
                                    self._children_name_map["cd"] = "cd"

                                    self.dgd = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Dgd()
                                    self.dgd.parent = self
                                    self._children_name_map["dgd"] = "dgd"

                                    self.pmd = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Pmd()
                                    self.pmd.parent = self
                                    self._children_name_map["pmd"] = "pmd"

                                    self.osnr = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Osnr()
                                    self.osnr.parent = self
                                    self._children_name_map["osnr"] = "osnr"

                                    self.center_wavelength = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.CenterWavelength()
                                    self.center_wavelength.parent = self
                                    self._children_name_map["center_wavelength"] = "center-wavelength"

                                    self.pdl = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Pdl()
                                    self.pdl.parent = self
                                    self._children_name_map["pdl"] = "pdl"

                                    self.pcr = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Pcr()
                                    self.pcr.parent = self
                                    self._children_name_map["pcr"] = "pcr"

                                    self.pn = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Pn()
                                    self.pn.parent = self
                                    self._children_name_map["pn"] = "pn"

                                    self.rx_sig_pow = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.RxSigPow()
                                    self.rx_sig_pow.parent = self
                                    self._children_name_map["rx_sig_pow"] = "rx-sig-pow"

                                    self.low_sig_freq_off = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.LowSigFreqOff()
                                    self.low_sig_freq_off.parent = self
                                    self._children_name_map["low_sig_freq_off"] = "low-sig-freq-off"

                                    self.ampli_gain = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.AmpliGain()
                                    self.ampli_gain.parent = self
                                    self._children_name_map["ampli_gain"] = "ampli-gain"

                                    self.ampli_gain_tilt = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.AmpliGainTilt()
                                    self.ampli_gain_tilt.parent = self
                                    self._children_name_map["ampli_gain_tilt"] = "ampli-gain-tilt"
                                    self._segment_path = lambda: "optics-minute15-optic" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                class Lbc(Entity):
                                    """
                                    LBC
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Lbc, self).__init__()

                                        self.yang_name = "lbc"
                                        self.yang_parent_name = "optics-minute15-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.int32, 'minimum'), ['int'])),
                                            ('average', (YLeaf(YType.int32, 'average'), ['int'])),
                                            ('maximum', (YLeaf(YType.int32, 'maximum'), ['int'])),
                                            ('minimum_threshold', (YLeaf(YType.int32, 'minimum-threshold'), ['int'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.int32, 'maximum-threshold'), ['int'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "lbc"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Lbc, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class LbcPc(Entity):
                                    """
                                    LBC in percentage
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.LbcPc, self).__init__()

                                        self.yang_name = "lbc-pc"
                                        self.yang_parent_name = "optics-minute15-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "lbc-pc"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.LbcPc, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class Opt(Entity):
                                    """
                                    OPT
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Opt, self).__init__()

                                        self.yang_name = "opt"
                                        self.yang_parent_name = "optics-minute15-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "opt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Opt, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class Opr(Entity):
                                    """
                                    OPR
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Opr, self).__init__()

                                        self.yang_name = "opr"
                                        self.yang_parent_name = "optics-minute15-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "opr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Opr, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class Cd(Entity):
                                    """
                                    Chromatic Dispersion
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Cd, self).__init__()

                                        self.yang_name = "cd"
                                        self.yang_parent_name = "optics-minute15-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.int32, 'minimum'), ['int'])),
                                            ('average', (YLeaf(YType.int32, 'average'), ['int'])),
                                            ('maximum', (YLeaf(YType.int32, 'maximum'), ['int'])),
                                            ('minimum_threshold', (YLeaf(YType.int32, 'minimum-threshold'), ['int'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.int32, 'maximum-threshold'), ['int'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "cd"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Cd, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class Dgd(Entity):
                                    """
                                    Differential group Delay
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Dgd, self).__init__()

                                        self.yang_name = "dgd"
                                        self.yang_parent_name = "optics-minute15-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "dgd"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Dgd, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class Pmd(Entity):
                                    """
                                    Polarization Mode Dispersion
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Pmd, self).__init__()

                                        self.yang_name = "pmd"
                                        self.yang_parent_name = "optics-minute15-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "pmd"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Pmd, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class Osnr(Entity):
                                    """
                                    Optical Signal to Noise Ratio
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Osnr, self).__init__()

                                        self.yang_name = "osnr"
                                        self.yang_parent_name = "optics-minute15-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "osnr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Osnr, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class CenterWavelength(Entity):
                                    """
                                    Center Wavelength/Frequency
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.CenterWavelength, self).__init__()

                                        self.yang_name = "center-wavelength"
                                        self.yang_parent_name = "optics-minute15-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "center-wavelength"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.CenterWavelength, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class Pdl(Entity):
                                    """
                                    Polarization Dependent Loss
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Pdl, self).__init__()

                                        self.yang_name = "pdl"
                                        self.yang_parent_name = "optics-minute15-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "pdl"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Pdl, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class Pcr(Entity):
                                    """
                                    Polarization Change Rate
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Pcr, self).__init__()

                                        self.yang_name = "pcr"
                                        self.yang_parent_name = "optics-minute15-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "pcr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Pcr, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class Pn(Entity):
                                    """
                                    Phase Noise
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Pn, self).__init__()

                                        self.yang_name = "pn"
                                        self.yang_parent_name = "optics-minute15-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "pn"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Pn, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class RxSigPow(Entity):
                                    """
                                    Rx signal power
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.RxSigPow, self).__init__()

                                        self.yang_name = "rx-sig-pow"
                                        self.yang_parent_name = "optics-minute15-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "rx-sig-pow"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.RxSigPow, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class LowSigFreqOff(Entity):
                                    """
                                    low freq sig off
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.LowSigFreqOff, self).__init__()

                                        self.yang_name = "low-sig-freq-off"
                                        self.yang_parent_name = "optics-minute15-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.int32, 'minimum'), ['int'])),
                                            ('average', (YLeaf(YType.int32, 'average'), ['int'])),
                                            ('maximum', (YLeaf(YType.int32, 'maximum'), ['int'])),
                                            ('minimum_threshold', (YLeaf(YType.int32, 'minimum-threshold'), ['int'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.int32, 'maximum-threshold'), ['int'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "low-sig-freq-off"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.LowSigFreqOff, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class AmpliGain(Entity):
                                    """
                                    Ampli Gain
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.AmpliGain, self).__init__()

                                        self.yang_name = "ampli-gain"
                                        self.yang_parent_name = "optics-minute15-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "ampli-gain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.AmpliGain, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class AmpliGainTilt(Entity):
                                    """
                                    Ampli Gain Tilt
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.AmpliGainTilt, self).__init__()

                                        self.yang_name = "ampli-gain-tilt"
                                        self.yang_parent_name = "optics-minute15-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "ampli-gain-tilt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.AmpliGainTilt, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                        class OpticsMinute15fecs(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: optics_minute15fec
                            
                            	port 15\-minute fec performance data
                            	**type**\: list of  		 :py:class:`OpticsMinute15fec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15fecs.OpticsMinute15fec>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15fecs, self).__init__()

                                self.yang_name = "optics-minute15fecs"
                                self.yang_parent_name = "optics-minute15"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("optics-minute15fec", ("optics_minute15fec", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15fecs.OpticsMinute15fec))])
                                self._leafs = OrderedDict()

                                self.optics_minute15fec = YList(self)
                                self._segment_path = lambda: "optics-minute15fecs"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15fecs, [], name, value)


                            class OpticsMinute15fec(Entity):
                                """
                                port 15\-minute fec performance data
                                
                                .. attribute:: number  (key)
                                
                                	channel number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ec_bits
                                
                                	EC BITS
                                	**type**\:  :py:class:`EcBits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15fecs.OpticsMinute15fec.EcBits>`
                                
                                .. attribute:: uc_words
                                
                                	UC WORDS
                                	**type**\:  :py:class:`UcWords <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15fecs.OpticsMinute15fec.UcWords>`
                                
                                .. attribute:: pre_fec_ber
                                
                                	Pre FEC BER
                                	**type**\:  :py:class:`PreFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15fecs.OpticsMinute15fec.PreFecBer>`
                                
                                .. attribute:: post_fec_ber
                                
                                	Post FEC BER
                                	**type**\:  :py:class:`PostFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15fecs.OpticsMinute15fec.PostFecBer>`
                                
                                .. attribute:: q
                                
                                	Q
                                	**type**\:  :py:class:`Q <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15fecs.OpticsMinute15fec.Q>`
                                
                                .. attribute:: qmargin
                                
                                	Q Margin
                                	**type**\:  :py:class:`Qmargin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15fecs.OpticsMinute15fec.Qmargin>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15fecs.OpticsMinute15fec, self).__init__()

                                    self.yang_name = "optics-minute15fec"
                                    self.yang_parent_name = "optics-minute15fecs"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("ec-bits", ("ec_bits", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15fecs.OpticsMinute15fec.EcBits)), ("uc-words", ("uc_words", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15fecs.OpticsMinute15fec.UcWords)), ("pre-fec-ber", ("pre_fec_ber", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15fecs.OpticsMinute15fec.PreFecBer)), ("post-fec-ber", ("post_fec_ber", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15fecs.OpticsMinute15fec.PostFecBer)), ("q", ("q", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15fecs.OpticsMinute15fec.Q)), ("qmargin", ("qmargin", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15fecs.OpticsMinute15fec.Qmargin))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                        ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                    ])
                                    self.number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear24_hr_time = None
                                    self.sec30_support = None

                                    self.ec_bits = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15fecs.OpticsMinute15fec.EcBits()
                                    self.ec_bits.parent = self
                                    self._children_name_map["ec_bits"] = "ec-bits"

                                    self.uc_words = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15fecs.OpticsMinute15fec.UcWords()
                                    self.uc_words.parent = self
                                    self._children_name_map["uc_words"] = "uc-words"

                                    self.pre_fec_ber = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15fecs.OpticsMinute15fec.PreFecBer()
                                    self.pre_fec_ber.parent = self
                                    self._children_name_map["pre_fec_ber"] = "pre-fec-ber"

                                    self.post_fec_ber = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15fecs.OpticsMinute15fec.PostFecBer()
                                    self.post_fec_ber.parent = self
                                    self._children_name_map["post_fec_ber"] = "post-fec-ber"

                                    self.q = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15fecs.OpticsMinute15fec.Q()
                                    self.q.parent = self
                                    self._children_name_map["q"] = "q"

                                    self.qmargin = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15fecs.OpticsMinute15fec.Qmargin()
                                    self.qmargin.parent = self
                                    self._children_name_map["qmargin"] = "qmargin"
                                    self._segment_path = lambda: "optics-minute15fec" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15fecs.OpticsMinute15fec, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                class EcBits(Entity):
                                    """
                                    EC BITS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15fecs.OpticsMinute15fec.EcBits, self).__init__()

                                        self.yang_name = "ec-bits"
                                        self.yang_parent_name = "optics-minute15fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ec-bits"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15fecs.OpticsMinute15fec.EcBits, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class UcWords(Entity):
                                    """
                                    UC WORDS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15fecs.OpticsMinute15fec.UcWords, self).__init__()

                                        self.yang_name = "uc-words"
                                        self.yang_parent_name = "optics-minute15fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "uc-words"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15fecs.OpticsMinute15fec.UcWords, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class PreFecBer(Entity):
                                    """
                                    Pre FEC BER
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15fecs.OpticsMinute15fec.PreFecBer, self).__init__()

                                        self.yang_name = "pre-fec-ber"
                                        self.yang_parent_name = "optics-minute15fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.maximum_tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "pre-fec-ber"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15fecs.OpticsMinute15fec.PreFecBer, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                class PostFecBer(Entity):
                                    """
                                    Post FEC BER
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15fecs.OpticsMinute15fec.PostFecBer, self).__init__()

                                        self.yang_name = "post-fec-ber"
                                        self.yang_parent_name = "optics-minute15fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.maximum_tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "post-fec-ber"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15fecs.OpticsMinute15fec.PostFecBer, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                class Q(Entity):
                                    """
                                    Q
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15fecs.OpticsMinute15fec.Q, self).__init__()

                                        self.yang_name = "q"
                                        self.yang_parent_name = "optics-minute15fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.maximum_tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "q"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15fecs.OpticsMinute15fec.Q, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                class Qmargin(Entity):
                                    """
                                    Q Margin
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15fecs.OpticsMinute15fec.Qmargin, self).__init__()

                                        self.yang_name = "qmargin"
                                        self.yang_parent_name = "optics-minute15fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.maximum_tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "qmargin"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15fecs.OpticsMinute15fec.Qmargin, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                    class OpticsSecond30(Entity):
                        """
                        port current performance data
                        
                        .. attribute:: optics_second30fecs
                        
                        	port current performance data
                        	**type**\:  :py:class:`OpticsSecond30fecs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30fecs>`
                        
                        .. attribute:: optics_second30_optics
                        
                        	port current performance data
                        	**type**\:  :py:class:`OpticsSecond30Optics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30, self).__init__()

                            self.yang_name = "optics-second30"
                            self.yang_parent_name = "optics-current"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("optics-second30fecs", ("optics_second30fecs", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30fecs)), ("optics-second30-optics", ("optics_second30_optics", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics))])
                            self._leafs = OrderedDict()

                            self.optics_second30fecs = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30fecs()
                            self.optics_second30fecs.parent = self
                            self._children_name_map["optics_second30fecs"] = "optics-second30fecs"

                            self.optics_second30_optics = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics()
                            self.optics_second30_optics.parent = self
                            self._children_name_map["optics_second30_optics"] = "optics-second30-optics"
                            self._segment_path = lambda: "optics-second30"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30, [], name, value)


                        class OpticsSecond30fecs(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: optics_second30fec
                            
                            	port 30\-second fec performance data
                            	**type**\: list of  		 :py:class:`OpticsSecond30fec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30fecs.OpticsSecond30fec>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30fecs, self).__init__()

                                self.yang_name = "optics-second30fecs"
                                self.yang_parent_name = "optics-second30"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("optics-second30fec", ("optics_second30fec", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30fecs.OpticsSecond30fec))])
                                self._leafs = OrderedDict()

                                self.optics_second30fec = YList(self)
                                self._segment_path = lambda: "optics-second30fecs"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30fecs, [], name, value)


                            class OpticsSecond30fec(Entity):
                                """
                                port 30\-second fec performance data
                                
                                .. attribute:: number  (key)
                                
                                	channel number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ec_bits
                                
                                	EC BITS
                                	**type**\:  :py:class:`EcBits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30fecs.OpticsSecond30fec.EcBits>`
                                
                                .. attribute:: uc_words
                                
                                	UC WORDS
                                	**type**\:  :py:class:`UcWords <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30fecs.OpticsSecond30fec.UcWords>`
                                
                                .. attribute:: pre_fec_ber
                                
                                	Pre FEC BER
                                	**type**\:  :py:class:`PreFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30fecs.OpticsSecond30fec.PreFecBer>`
                                
                                .. attribute:: post_fec_ber
                                
                                	Post FEC BER
                                	**type**\:  :py:class:`PostFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30fecs.OpticsSecond30fec.PostFecBer>`
                                
                                .. attribute:: q
                                
                                	Q
                                	**type**\:  :py:class:`Q <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30fecs.OpticsSecond30fec.Q>`
                                
                                .. attribute:: qmargin
                                
                                	Q Margin
                                	**type**\:  :py:class:`Qmargin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30fecs.OpticsSecond30fec.Qmargin>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30fecs.OpticsSecond30fec, self).__init__()

                                    self.yang_name = "optics-second30fec"
                                    self.yang_parent_name = "optics-second30fecs"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("ec-bits", ("ec_bits", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30fecs.OpticsSecond30fec.EcBits)), ("uc-words", ("uc_words", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30fecs.OpticsSecond30fec.UcWords)), ("pre-fec-ber", ("pre_fec_ber", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30fecs.OpticsSecond30fec.PreFecBer)), ("post-fec-ber", ("post_fec_ber", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30fecs.OpticsSecond30fec.PostFecBer)), ("q", ("q", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30fecs.OpticsSecond30fec.Q)), ("qmargin", ("qmargin", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30fecs.OpticsSecond30fec.Qmargin))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                        ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                    ])
                                    self.number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear24_hr_time = None
                                    self.sec30_support = None

                                    self.ec_bits = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30fecs.OpticsSecond30fec.EcBits()
                                    self.ec_bits.parent = self
                                    self._children_name_map["ec_bits"] = "ec-bits"

                                    self.uc_words = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30fecs.OpticsSecond30fec.UcWords()
                                    self.uc_words.parent = self
                                    self._children_name_map["uc_words"] = "uc-words"

                                    self.pre_fec_ber = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30fecs.OpticsSecond30fec.PreFecBer()
                                    self.pre_fec_ber.parent = self
                                    self._children_name_map["pre_fec_ber"] = "pre-fec-ber"

                                    self.post_fec_ber = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30fecs.OpticsSecond30fec.PostFecBer()
                                    self.post_fec_ber.parent = self
                                    self._children_name_map["post_fec_ber"] = "post-fec-ber"

                                    self.q = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30fecs.OpticsSecond30fec.Q()
                                    self.q.parent = self
                                    self._children_name_map["q"] = "q"

                                    self.qmargin = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30fecs.OpticsSecond30fec.Qmargin()
                                    self.qmargin.parent = self
                                    self._children_name_map["qmargin"] = "qmargin"
                                    self._segment_path = lambda: "optics-second30fec" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30fecs.OpticsSecond30fec, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                class EcBits(Entity):
                                    """
                                    EC BITS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30fecs.OpticsSecond30fec.EcBits, self).__init__()

                                        self.yang_name = "ec-bits"
                                        self.yang_parent_name = "optics-second30fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ec-bits"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30fecs.OpticsSecond30fec.EcBits, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class UcWords(Entity):
                                    """
                                    UC WORDS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30fecs.OpticsSecond30fec.UcWords, self).__init__()

                                        self.yang_name = "uc-words"
                                        self.yang_parent_name = "optics-second30fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "uc-words"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30fecs.OpticsSecond30fec.UcWords, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class PreFecBer(Entity):
                                    """
                                    Pre FEC BER
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30fecs.OpticsSecond30fec.PreFecBer, self).__init__()

                                        self.yang_name = "pre-fec-ber"
                                        self.yang_parent_name = "optics-second30fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.maximum_tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "pre-fec-ber"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30fecs.OpticsSecond30fec.PreFecBer, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                class PostFecBer(Entity):
                                    """
                                    Post FEC BER
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30fecs.OpticsSecond30fec.PostFecBer, self).__init__()

                                        self.yang_name = "post-fec-ber"
                                        self.yang_parent_name = "optics-second30fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.maximum_tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "post-fec-ber"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30fecs.OpticsSecond30fec.PostFecBer, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                class Q(Entity):
                                    """
                                    Q
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30fecs.OpticsSecond30fec.Q, self).__init__()

                                        self.yang_name = "q"
                                        self.yang_parent_name = "optics-second30fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.maximum_tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "q"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30fecs.OpticsSecond30fec.Q, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                class Qmargin(Entity):
                                    """
                                    Q Margin
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30fecs.OpticsSecond30fec.Qmargin, self).__init__()

                                        self.yang_name = "qmargin"
                                        self.yang_parent_name = "optics-second30fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.maximum_tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "qmargin"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30fecs.OpticsSecond30fec.Qmargin, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                        class OpticsSecond30Optics(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: optics_second30_optic
                            
                            	port 30\-second optics performance data
                            	**type**\: list of  		 :py:class:`OpticsSecond30Optic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics, self).__init__()

                                self.yang_name = "optics-second30-optics"
                                self.yang_parent_name = "optics-second30"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("optics-second30-optic", ("optics_second30_optic", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic))])
                                self._leafs = OrderedDict()

                                self.optics_second30_optic = YList(self)
                                self._segment_path = lambda: "optics-second30-optics"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics, [], name, value)


                            class OpticsSecond30Optic(Entity):
                                """
                                port 30\-second optics performance data
                                
                                .. attribute:: number  (key)
                                
                                	channel number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lbc
                                
                                	LBC
                                	**type**\:  :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Lbc>`
                                
                                .. attribute:: lbc_pc
                                
                                	LBC in percentage
                                	**type**\:  :py:class:`LbcPc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.LbcPc>`
                                
                                .. attribute:: opt
                                
                                	OPT
                                	**type**\:  :py:class:`Opt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Opt>`
                                
                                .. attribute:: opr
                                
                                	OPR
                                	**type**\:  :py:class:`Opr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Opr>`
                                
                                .. attribute:: cd
                                
                                	Chromatic Dispersion
                                	**type**\:  :py:class:`Cd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Cd>`
                                
                                .. attribute:: dgd
                                
                                	Differential group Delay
                                	**type**\:  :py:class:`Dgd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Dgd>`
                                
                                .. attribute:: pmd
                                
                                	Polarization Mode Dispersion
                                	**type**\:  :py:class:`Pmd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Pmd>`
                                
                                .. attribute:: osnr
                                
                                	Optical Signal to Noise Ratio
                                	**type**\:  :py:class:`Osnr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Osnr>`
                                
                                .. attribute:: center_wavelength
                                
                                	Center Wavelength/Frequency
                                	**type**\:  :py:class:`CenterWavelength <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.CenterWavelength>`
                                
                                .. attribute:: pdl
                                
                                	Polarization Dependent Loss
                                	**type**\:  :py:class:`Pdl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Pdl>`
                                
                                .. attribute:: pcr
                                
                                	Polarization Change Rate
                                	**type**\:  :py:class:`Pcr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Pcr>`
                                
                                .. attribute:: pn
                                
                                	Phase Noise
                                	**type**\:  :py:class:`Pn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Pn>`
                                
                                .. attribute:: rx_sig_pow
                                
                                	Rx signal power
                                	**type**\:  :py:class:`RxSigPow <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.RxSigPow>`
                                
                                .. attribute:: low_sig_freq_off
                                
                                	low freq sig off
                                	**type**\:  :py:class:`LowSigFreqOff <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.LowSigFreqOff>`
                                
                                .. attribute:: ampli_gain
                                
                                	Ampli Gain
                                	**type**\:  :py:class:`AmpliGain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.AmpliGain>`
                                
                                .. attribute:: ampli_gain_tilt
                                
                                	Ampli Gain Tilt
                                	**type**\:  :py:class:`AmpliGainTilt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.AmpliGainTilt>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic, self).__init__()

                                    self.yang_name = "optics-second30-optic"
                                    self.yang_parent_name = "optics-second30-optics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("lbc", ("lbc", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Lbc)), ("lbc-pc", ("lbc_pc", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.LbcPc)), ("opt", ("opt", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Opt)), ("opr", ("opr", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Opr)), ("cd", ("cd", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Cd)), ("dgd", ("dgd", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Dgd)), ("pmd", ("pmd", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Pmd)), ("osnr", ("osnr", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Osnr)), ("center-wavelength", ("center_wavelength", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.CenterWavelength)), ("pdl", ("pdl", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Pdl)), ("pcr", ("pcr", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Pcr)), ("pn", ("pn", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Pn)), ("rx-sig-pow", ("rx_sig_pow", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.RxSigPow)), ("low-sig-freq-off", ("low_sig_freq_off", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.LowSigFreqOff)), ("ampli-gain", ("ampli_gain", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.AmpliGain)), ("ampli-gain-tilt", ("ampli_gain_tilt", PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.AmpliGainTilt))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                        ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                    ])
                                    self.number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear24_hr_time = None
                                    self.sec30_support = None

                                    self.lbc = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Lbc()
                                    self.lbc.parent = self
                                    self._children_name_map["lbc"] = "lbc"

                                    self.lbc_pc = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.LbcPc()
                                    self.lbc_pc.parent = self
                                    self._children_name_map["lbc_pc"] = "lbc-pc"

                                    self.opt = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Opt()
                                    self.opt.parent = self
                                    self._children_name_map["opt"] = "opt"

                                    self.opr = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Opr()
                                    self.opr.parent = self
                                    self._children_name_map["opr"] = "opr"

                                    self.cd = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Cd()
                                    self.cd.parent = self
                                    self._children_name_map["cd"] = "cd"

                                    self.dgd = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Dgd()
                                    self.dgd.parent = self
                                    self._children_name_map["dgd"] = "dgd"

                                    self.pmd = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Pmd()
                                    self.pmd.parent = self
                                    self._children_name_map["pmd"] = "pmd"

                                    self.osnr = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Osnr()
                                    self.osnr.parent = self
                                    self._children_name_map["osnr"] = "osnr"

                                    self.center_wavelength = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.CenterWavelength()
                                    self.center_wavelength.parent = self
                                    self._children_name_map["center_wavelength"] = "center-wavelength"

                                    self.pdl = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Pdl()
                                    self.pdl.parent = self
                                    self._children_name_map["pdl"] = "pdl"

                                    self.pcr = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Pcr()
                                    self.pcr.parent = self
                                    self._children_name_map["pcr"] = "pcr"

                                    self.pn = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Pn()
                                    self.pn.parent = self
                                    self._children_name_map["pn"] = "pn"

                                    self.rx_sig_pow = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.RxSigPow()
                                    self.rx_sig_pow.parent = self
                                    self._children_name_map["rx_sig_pow"] = "rx-sig-pow"

                                    self.low_sig_freq_off = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.LowSigFreqOff()
                                    self.low_sig_freq_off.parent = self
                                    self._children_name_map["low_sig_freq_off"] = "low-sig-freq-off"

                                    self.ampli_gain = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.AmpliGain()
                                    self.ampli_gain.parent = self
                                    self._children_name_map["ampli_gain"] = "ampli-gain"

                                    self.ampli_gain_tilt = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.AmpliGainTilt()
                                    self.ampli_gain_tilt.parent = self
                                    self._children_name_map["ampli_gain_tilt"] = "ampli-gain-tilt"
                                    self._segment_path = lambda: "optics-second30-optic" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                class Lbc(Entity):
                                    """
                                    LBC
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Lbc, self).__init__()

                                        self.yang_name = "lbc"
                                        self.yang_parent_name = "optics-second30-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.int32, 'minimum'), ['int'])),
                                            ('average', (YLeaf(YType.int32, 'average'), ['int'])),
                                            ('maximum', (YLeaf(YType.int32, 'maximum'), ['int'])),
                                            ('minimum_threshold', (YLeaf(YType.int32, 'minimum-threshold'), ['int'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.int32, 'maximum-threshold'), ['int'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "lbc"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Lbc, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class LbcPc(Entity):
                                    """
                                    LBC in percentage
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.LbcPc, self).__init__()

                                        self.yang_name = "lbc-pc"
                                        self.yang_parent_name = "optics-second30-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "lbc-pc"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.LbcPc, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class Opt(Entity):
                                    """
                                    OPT
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Opt, self).__init__()

                                        self.yang_name = "opt"
                                        self.yang_parent_name = "optics-second30-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "opt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Opt, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class Opr(Entity):
                                    """
                                    OPR
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Opr, self).__init__()

                                        self.yang_name = "opr"
                                        self.yang_parent_name = "optics-second30-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "opr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Opr, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class Cd(Entity):
                                    """
                                    Chromatic Dispersion
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Cd, self).__init__()

                                        self.yang_name = "cd"
                                        self.yang_parent_name = "optics-second30-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.int32, 'minimum'), ['int'])),
                                            ('average', (YLeaf(YType.int32, 'average'), ['int'])),
                                            ('maximum', (YLeaf(YType.int32, 'maximum'), ['int'])),
                                            ('minimum_threshold', (YLeaf(YType.int32, 'minimum-threshold'), ['int'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.int32, 'maximum-threshold'), ['int'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "cd"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Cd, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class Dgd(Entity):
                                    """
                                    Differential group Delay
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Dgd, self).__init__()

                                        self.yang_name = "dgd"
                                        self.yang_parent_name = "optics-second30-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "dgd"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Dgd, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class Pmd(Entity):
                                    """
                                    Polarization Mode Dispersion
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Pmd, self).__init__()

                                        self.yang_name = "pmd"
                                        self.yang_parent_name = "optics-second30-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "pmd"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Pmd, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class Osnr(Entity):
                                    """
                                    Optical Signal to Noise Ratio
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Osnr, self).__init__()

                                        self.yang_name = "osnr"
                                        self.yang_parent_name = "optics-second30-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "osnr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Osnr, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class CenterWavelength(Entity):
                                    """
                                    Center Wavelength/Frequency
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.CenterWavelength, self).__init__()

                                        self.yang_name = "center-wavelength"
                                        self.yang_parent_name = "optics-second30-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "center-wavelength"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.CenterWavelength, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class Pdl(Entity):
                                    """
                                    Polarization Dependent Loss
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Pdl, self).__init__()

                                        self.yang_name = "pdl"
                                        self.yang_parent_name = "optics-second30-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "pdl"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Pdl, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class Pcr(Entity):
                                    """
                                    Polarization Change Rate
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Pcr, self).__init__()

                                        self.yang_name = "pcr"
                                        self.yang_parent_name = "optics-second30-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "pcr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Pcr, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class Pn(Entity):
                                    """
                                    Phase Noise
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Pn, self).__init__()

                                        self.yang_name = "pn"
                                        self.yang_parent_name = "optics-second30-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "pn"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Pn, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class RxSigPow(Entity):
                                    """
                                    Rx signal power
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.RxSigPow, self).__init__()

                                        self.yang_name = "rx-sig-pow"
                                        self.yang_parent_name = "optics-second30-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "rx-sig-pow"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.RxSigPow, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class LowSigFreqOff(Entity):
                                    """
                                    low freq sig off
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.LowSigFreqOff, self).__init__()

                                        self.yang_name = "low-sig-freq-off"
                                        self.yang_parent_name = "optics-second30-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.int32, 'minimum'), ['int'])),
                                            ('average', (YLeaf(YType.int32, 'average'), ['int'])),
                                            ('maximum', (YLeaf(YType.int32, 'maximum'), ['int'])),
                                            ('minimum_threshold', (YLeaf(YType.int32, 'minimum-threshold'), ['int'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.int32, 'maximum-threshold'), ['int'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "low-sig-freq-off"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.LowSigFreqOff, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class AmpliGain(Entity):
                                    """
                                    Ampli Gain
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.AmpliGain, self).__init__()

                                        self.yang_name = "ampli-gain"
                                        self.yang_parent_name = "optics-second30-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "ampli-gain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.AmpliGain, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class AmpliGainTilt(Entity):
                                    """
                                    Ampli Gain Tilt
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.AmpliGainTilt, self).__init__()

                                        self.yang_name = "ampli-gain-tilt"
                                        self.yang_parent_name = "optics-second30-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "ampli-gain-tilt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.AmpliGainTilt, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


    class Sts(Entity):
        """
        STS controller performance data
        
        .. attribute:: sts_ports
        
        	Port performance data
        	**type**\:  :py:class:`StsPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts>`
        
        

        """

        _prefix = 'pmengine-oper'
        _revision = '2017-09-07'

        def __init__(self):
            super(PerformanceManagement.Sts, self).__init__()

            self.yang_name = "sts"
            self.yang_parent_name = "performance-management"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("sts-ports", ("sts_ports", PerformanceManagement.Sts.StsPorts))])
            self._leafs = OrderedDict()

            self.sts_ports = PerformanceManagement.Sts.StsPorts()
            self.sts_ports.parent = self
            self._children_name_map["sts_ports"] = "sts-ports"
            self._segment_path = lambda: "sts"
            self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(PerformanceManagement.Sts, [], name, value)


        class StsPorts(Entity):
            """
            Port performance data
            
            .. attribute:: sts_port
            
            	Port performance data
            	**type**\: list of  		 :py:class:`StsPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort>`
            
            

            """

            _prefix = 'pmengine-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(PerformanceManagement.Sts.StsPorts, self).__init__()

                self.yang_name = "sts-ports"
                self.yang_parent_name = "sts"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("sts-port", ("sts_port", PerformanceManagement.Sts.StsPorts.StsPort))])
                self._leafs = OrderedDict()

                self.sts_port = YList(self)
                self._segment_path = lambda: "sts-ports"
                self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management/sts/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(PerformanceManagement.Sts.StsPorts, [], name, value)


            class StsPort(Entity):
                """
                Port performance data
                
                .. attribute:: name  (key)
                
                	Port name
                	**type**\: str
                
                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                
                .. attribute:: sts_current
                
                	port current performance data
                	**type**\:  :py:class:`StsCurrent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(PerformanceManagement.Sts.StsPorts.StsPort, self).__init__()

                    self.yang_name = "sts-port"
                    self.yang_parent_name = "sts-ports"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("sts-current", ("sts_current", PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ])
                    self.name = None

                    self.sts_current = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent()
                    self.sts_current.parent = self
                    self._children_name_map["sts_current"] = "sts-current"
                    self._segment_path = lambda: "sts-port" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management/sts/sts-ports/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(PerformanceManagement.Sts.StsPorts.StsPort, ['name'], name, value)


                class StsCurrent(Entity):
                    """
                    port current performance data
                    
                    .. attribute:: sts_minute15
                    
                    	port current performance data
                    	**type**\:  :py:class:`StsMinute15 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15>`
                    
                    .. attribute:: sts_hour24
                    
                    	port current performance data
                    	**type**\:  :py:class:`StsHour24 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent, self).__init__()

                        self.yang_name = "sts-current"
                        self.yang_parent_name = "sts-port"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("sts-minute15", ("sts_minute15", PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15)), ("sts-hour24", ("sts_hour24", PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24))])
                        self._leafs = OrderedDict()

                        self.sts_minute15 = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15()
                        self.sts_minute15.parent = self
                        self._children_name_map["sts_minute15"] = "sts-minute15"

                        self.sts_hour24 = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24()
                        self.sts_hour24.parent = self
                        self._children_name_map["sts_hour24"] = "sts-hour24"
                        self._segment_path = lambda: "sts-current"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent, [], name, value)


                    class StsMinute15(Entity):
                        """
                        port current performance data
                        
                        .. attribute:: sts_minute15_paths
                        
                        	port current performance data
                        	**type**\:  :py:class:`StsMinute15Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15, self).__init__()

                            self.yang_name = "sts-minute15"
                            self.yang_parent_name = "sts-current"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("sts-minute15-paths", ("sts_minute15_paths", PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths))])
                            self._leafs = OrderedDict()

                            self.sts_minute15_paths = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths()
                            self.sts_minute15_paths.parent = self
                            self._children_name_map["sts_minute15_paths"] = "sts-minute15-paths"
                            self._segment_path = lambda: "sts-minute15"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15, [], name, value)


                        class StsMinute15Paths(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: sts_minute15_path
                            
                            	port 15\-minute Path performance data
                            	**type**\: list of  		 :py:class:`StsMinute15Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths, self).__init__()

                                self.yang_name = "sts-minute15-paths"
                                self.yang_parent_name = "sts-minute15"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("sts-minute15-path", ("sts_minute15_path", PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path))])
                                self._leafs = OrderedDict()

                                self.sts_minute15_path = YList(self)
                                self._segment_path = lambda: "sts-minute15-paths"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths, [], name, value)


                            class StsMinute15Path(Entity):
                                """
                                port 15\-minute Path performance data
                                
                                .. attribute:: number  (key)
                                
                                	channel number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path
                                
                                	PATH
                                	**type**\:  :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path>`
                                
                                .. attribute:: fe_path
                                
                                	Far End PATH
                                	**type**\:  :py:class:`FePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.FePath>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path, self).__init__()

                                    self.yang_name = "sts-minute15-path"
                                    self.yang_parent_name = "sts-minute15-paths"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("path", ("path", PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path)), ("fe-path", ("fe_path", PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.FePath))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                    ])
                                    self.number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None

                                    self.path = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path()
                                    self.path.parent = self
                                    self._children_name_map["path"] = "path"

                                    self.fe_path = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.FePath()
                                    self.fe_path.parent = self
                                    self._children_name_map["fe_path"] = "fe-path"
                                    self._segment_path = lambda: "sts-minute15-path" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear24_hr_time'], name, value)


                                class Path(Entity):
                                    """
                                    PATH
                                    
                                    .. attribute:: path_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:  :py:class:`PathESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path.PathESs>`
                                    
                                    .. attribute:: path_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:  :py:class:`PathSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path.PathSeSs>`
                                    
                                    .. attribute:: path_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:  :py:class:`PathCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path.PathCVs>`
                                    
                                    .. attribute:: path_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\:  :py:class:`PathUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path.PathUaSs>`
                                    
                                    .. attribute:: path_width
                                    
                                    	Indicates the type of the SONET/SDH Path
                                    	**type**\:  :py:class:`PmSonetPathWidthEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmSonetPathWidthEnum>`
                                    
                                    .. attribute:: path_status
                                    
                                    	 status of the interface
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path, self).__init__()

                                        self.yang_name = "path"
                                        self.yang_parent_name = "sts-minute15-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("path-e-ss", ("path_e_ss", PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path.PathESs)), ("path-se-ss", ("path_se_ss", PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path.PathSeSs)), ("path-c-vs", ("path_c_vs", PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path.PathCVs)), ("path-ua-ss", ("path_ua_ss", PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path.PathUaSs))])
                                        self._leafs = OrderedDict([
                                            ('path_width', (YLeaf(YType.enumeration, 'path-width'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper', 'PmSonetPathWidthEnum', '')])),
                                            ('path_status', (YLeaf(YType.int32, 'path-status'), ['int'])),
                                        ])
                                        self.path_width = None
                                        self.path_status = None

                                        self.path_e_ss = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path.PathESs()
                                        self.path_e_ss.parent = self
                                        self._children_name_map["path_e_ss"] = "path-e-ss"

                                        self.path_se_ss = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path.PathSeSs()
                                        self.path_se_ss.parent = self
                                        self._children_name_map["path_se_ss"] = "path-se-ss"

                                        self.path_c_vs = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path.PathCVs()
                                        self.path_c_vs.parent = self
                                        self._children_name_map["path_c_vs"] = "path-c-vs"

                                        self.path_ua_ss = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path.PathUaSs()
                                        self.path_ua_ss.parent = self
                                        self._children_name_map["path_ua_ss"] = "path-ua-ss"
                                        self._segment_path = lambda: "path"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path, ['path_width', 'path_status'], name, value)


                                    class PathESs(Entity):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path.PathESs, self).__init__()

                                            self.yang_name = "path-e-ss"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "path-e-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path.PathESs, ['data', 'threshold', 'tca_report'], name, value)


                                    class PathSeSs(Entity):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path.PathSeSs, self).__init__()

                                            self.yang_name = "path-se-ss"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "path-se-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path.PathSeSs, ['data', 'threshold', 'tca_report'], name, value)


                                    class PathCVs(Entity):
                                        """
                                        The number of Coding Violations
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path.PathCVs, self).__init__()

                                            self.yang_name = "path-c-vs"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "path-c-vs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path.PathCVs, ['data', 'threshold', 'tca_report'], name, value)


                                    class PathUaSs(Entity):
                                        """
                                        The number of Unavailable Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path.PathUaSs, self).__init__()

                                            self.yang_name = "path-ua-ss"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "path-ua-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path.PathUaSs, ['data', 'threshold', 'tca_report'], name, value)


                                class FePath(Entity):
                                    """
                                    Far End PATH
                                    
                                    .. attribute:: far_end_path_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: far_end_path_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: far_end_path_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: far_end_path_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.FePath, self).__init__()

                                        self.yang_name = "fe-path"
                                        self.yang_parent_name = "sts-minute15-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('far_end_path_e_ss', (YLeaf(YType.uint32, 'far-end-path-e-ss'), ['int'])),
                                            ('far_end_path_se_ss', (YLeaf(YType.uint32, 'far-end-path-se-ss'), ['int'])),
                                            ('far_end_path_c_vs', (YLeaf(YType.uint32, 'far-end-path-c-vs'), ['int'])),
                                            ('far_end_path_ua_ss', (YLeaf(YType.uint32, 'far-end-path-ua-ss'), ['int'])),
                                        ])
                                        self.far_end_path_e_ss = None
                                        self.far_end_path_se_ss = None
                                        self.far_end_path_c_vs = None
                                        self.far_end_path_ua_ss = None
                                        self._segment_path = lambda: "fe-path"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.FePath, ['far_end_path_e_ss', 'far_end_path_se_ss', 'far_end_path_c_vs', 'far_end_path_ua_ss'], name, value)


                    class StsHour24(Entity):
                        """
                        port current performance data
                        
                        .. attribute:: sts_hour24_paths
                        
                        	port current performance data
                        	**type**\:  :py:class:`StsHour24Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24, self).__init__()

                            self.yang_name = "sts-hour24"
                            self.yang_parent_name = "sts-current"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("sts-hour24-paths", ("sts_hour24_paths", PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths))])
                            self._leafs = OrderedDict()

                            self.sts_hour24_paths = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths()
                            self.sts_hour24_paths.parent = self
                            self._children_name_map["sts_hour24_paths"] = "sts-hour24-paths"
                            self._segment_path = lambda: "sts-hour24"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24, [], name, value)


                        class StsHour24Paths(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: sts_hour24_path
                            
                            	port 24 hour Path performance data
                            	**type**\: list of  		 :py:class:`StsHour24Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths, self).__init__()

                                self.yang_name = "sts-hour24-paths"
                                self.yang_parent_name = "sts-hour24"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("sts-hour24-path", ("sts_hour24_path", PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path))])
                                self._leafs = OrderedDict()

                                self.sts_hour24_path = YList(self)
                                self._segment_path = lambda: "sts-hour24-paths"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths, [], name, value)


                            class StsHour24Path(Entity):
                                """
                                port 24 hour Path performance data
                                
                                .. attribute:: number  (key)
                                
                                	channel number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path
                                
                                	PATH
                                	**type**\:  :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path>`
                                
                                .. attribute:: fe_path
                                
                                	Far End PATH
                                	**type**\:  :py:class:`FePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.FePath>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path, self).__init__()

                                    self.yang_name = "sts-hour24-path"
                                    self.yang_parent_name = "sts-hour24-paths"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("path", ("path", PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path)), ("fe-path", ("fe_path", PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.FePath))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                    ])
                                    self.number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None

                                    self.path = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path()
                                    self.path.parent = self
                                    self._children_name_map["path"] = "path"

                                    self.fe_path = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.FePath()
                                    self.fe_path.parent = self
                                    self._children_name_map["fe_path"] = "fe-path"
                                    self._segment_path = lambda: "sts-hour24-path" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear24_hr_time'], name, value)


                                class Path(Entity):
                                    """
                                    PATH
                                    
                                    .. attribute:: path_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:  :py:class:`PathESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path.PathESs>`
                                    
                                    .. attribute:: path_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:  :py:class:`PathSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path.PathSeSs>`
                                    
                                    .. attribute:: path_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:  :py:class:`PathCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path.PathCVs>`
                                    
                                    .. attribute:: path_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\:  :py:class:`PathUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path.PathUaSs>`
                                    
                                    .. attribute:: path_width
                                    
                                    	Indicates the type of the SONET/SDH Path
                                    	**type**\:  :py:class:`PmSonetPathWidthEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmSonetPathWidthEnum>`
                                    
                                    .. attribute:: path_status
                                    
                                    	 status of the interface
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path, self).__init__()

                                        self.yang_name = "path"
                                        self.yang_parent_name = "sts-hour24-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("path-e-ss", ("path_e_ss", PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path.PathESs)), ("path-se-ss", ("path_se_ss", PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path.PathSeSs)), ("path-c-vs", ("path_c_vs", PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path.PathCVs)), ("path-ua-ss", ("path_ua_ss", PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path.PathUaSs))])
                                        self._leafs = OrderedDict([
                                            ('path_width', (YLeaf(YType.enumeration, 'path-width'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper', 'PmSonetPathWidthEnum', '')])),
                                            ('path_status', (YLeaf(YType.int32, 'path-status'), ['int'])),
                                        ])
                                        self.path_width = None
                                        self.path_status = None

                                        self.path_e_ss = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path.PathESs()
                                        self.path_e_ss.parent = self
                                        self._children_name_map["path_e_ss"] = "path-e-ss"

                                        self.path_se_ss = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path.PathSeSs()
                                        self.path_se_ss.parent = self
                                        self._children_name_map["path_se_ss"] = "path-se-ss"

                                        self.path_c_vs = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path.PathCVs()
                                        self.path_c_vs.parent = self
                                        self._children_name_map["path_c_vs"] = "path-c-vs"

                                        self.path_ua_ss = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path.PathUaSs()
                                        self.path_ua_ss.parent = self
                                        self._children_name_map["path_ua_ss"] = "path-ua-ss"
                                        self._segment_path = lambda: "path"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path, ['path_width', 'path_status'], name, value)


                                    class PathESs(Entity):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path.PathESs, self).__init__()

                                            self.yang_name = "path-e-ss"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "path-e-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path.PathESs, ['data', 'threshold', 'tca_report'], name, value)


                                    class PathSeSs(Entity):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path.PathSeSs, self).__init__()

                                            self.yang_name = "path-se-ss"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "path-se-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path.PathSeSs, ['data', 'threshold', 'tca_report'], name, value)


                                    class PathCVs(Entity):
                                        """
                                        The number of Coding Violations
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path.PathCVs, self).__init__()

                                            self.yang_name = "path-c-vs"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "path-c-vs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path.PathCVs, ['data', 'threshold', 'tca_report'], name, value)


                                    class PathUaSs(Entity):
                                        """
                                        The number of Unavailable Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path.PathUaSs, self).__init__()

                                            self.yang_name = "path-ua-ss"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "path-ua-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path.PathUaSs, ['data', 'threshold', 'tca_report'], name, value)


                                class FePath(Entity):
                                    """
                                    Far End PATH
                                    
                                    .. attribute:: far_end_path_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: far_end_path_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: far_end_path_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: far_end_path_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.FePath, self).__init__()

                                        self.yang_name = "fe-path"
                                        self.yang_parent_name = "sts-hour24-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('far_end_path_e_ss', (YLeaf(YType.uint32, 'far-end-path-e-ss'), ['int'])),
                                            ('far_end_path_se_ss', (YLeaf(YType.uint32, 'far-end-path-se-ss'), ['int'])),
                                            ('far_end_path_c_vs', (YLeaf(YType.uint32, 'far-end-path-c-vs'), ['int'])),
                                            ('far_end_path_ua_ss', (YLeaf(YType.uint32, 'far-end-path-ua-ss'), ['int'])),
                                        ])
                                        self.far_end_path_e_ss = None
                                        self.far_end_path_se_ss = None
                                        self.far_end_path_c_vs = None
                                        self.far_end_path_ua_ss = None
                                        self._segment_path = lambda: "fe-path"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.FePath, ['far_end_path_e_ss', 'far_end_path_se_ss', 'far_end_path_c_vs', 'far_end_path_ua_ss'], name, value)


    class Dwdm(Entity):
        """
        DWDM controller performance data
        
        .. attribute:: dwdm_ports
        
        	Port performance data
        	**type**\:  :py:class:`DwdmPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts>`
        
        

        """

        _prefix = 'pmengine-oper'
        _revision = '2017-09-07'

        def __init__(self):
            super(PerformanceManagement.Dwdm, self).__init__()

            self.yang_name = "dwdm"
            self.yang_parent_name = "performance-management"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("dwdm-ports", ("dwdm_ports", PerformanceManagement.Dwdm.DwdmPorts))])
            self._leafs = OrderedDict()

            self.dwdm_ports = PerformanceManagement.Dwdm.DwdmPorts()
            self.dwdm_ports.parent = self
            self._children_name_map["dwdm_ports"] = "dwdm-ports"
            self._segment_path = lambda: "dwdm"
            self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(PerformanceManagement.Dwdm, [], name, value)


        class DwdmPorts(Entity):
            """
            Port performance data
            
            .. attribute:: dwdm_port
            
            	Port performance data
            	**type**\: list of  		 :py:class:`DwdmPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort>`
            
            

            """

            _prefix = 'pmengine-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(PerformanceManagement.Dwdm.DwdmPorts, self).__init__()

                self.yang_name = "dwdm-ports"
                self.yang_parent_name = "dwdm"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("dwdm-port", ("dwdm_port", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort))])
                self._leafs = OrderedDict()

                self.dwdm_port = YList(self)
                self._segment_path = lambda: "dwdm-ports"
                self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management/dwdm/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts, [], name, value)


            class DwdmPort(Entity):
                """
                Port performance data
                
                .. attribute:: name  (key)
                
                	Port name
                	**type**\: str
                
                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                
                .. attribute:: dwdm_current
                
                	port current performance data
                	**type**\:  :py:class:`DwdmCurrent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort, self).__init__()

                    self.yang_name = "dwdm-port"
                    self.yang_parent_name = "dwdm-ports"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("dwdm-current", ("dwdm_current", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ])
                    self.name = None

                    self.dwdm_current = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent()
                    self.dwdm_current.parent = self
                    self._children_name_map["dwdm_current"] = "dwdm-current"
                    self._segment_path = lambda: "dwdm-port" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management/dwdm/dwdm-ports/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort, ['name'], name, value)


                class DwdmCurrent(Entity):
                    """
                    port current performance data
                    
                    .. attribute:: dwdm_minute15
                    
                    	port current performance data
                    	**type**\:  :py:class:`DwdmMinute15 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15>`
                    
                    .. attribute:: dwdm_hour24
                    
                    	port current performance data
                    	**type**\:  :py:class:`DwdmHour24 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent, self).__init__()

                        self.yang_name = "dwdm-current"
                        self.yang_parent_name = "dwdm-port"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dwdm-minute15", ("dwdm_minute15", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15)), ("dwdm-hour24", ("dwdm_hour24", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24))])
                        self._leafs = OrderedDict()

                        self.dwdm_minute15 = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15()
                        self.dwdm_minute15.parent = self
                        self._children_name_map["dwdm_minute15"] = "dwdm-minute15"

                        self.dwdm_hour24 = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24()
                        self.dwdm_hour24.parent = self
                        self._children_name_map["dwdm_hour24"] = "dwdm-hour24"
                        self._segment_path = lambda: "dwdm-current"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent, [], name, value)


                    class DwdmMinute15(Entity):
                        """
                        port current performance data
                        
                        .. attribute:: dwdm_minute15fecs
                        
                        	port current performance data
                        	**type**\:  :py:class:`DwdmMinute15fecs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15fecs>`
                        
                        .. attribute:: dwdm_minute15_optics
                        
                        	port current performance data
                        	**type**\:  :py:class:`DwdmMinute15Optics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics>`
                        
                        .. attribute:: dwdm_minute15otns
                        
                        	port current performance data
                        	**type**\:  :py:class:`DwdmMinute15otns <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15, self).__init__()

                            self.yang_name = "dwdm-minute15"
                            self.yang_parent_name = "dwdm-current"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("dwdm-minute15fecs", ("dwdm_minute15fecs", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15fecs)), ("dwdm-minute15-optics", ("dwdm_minute15_optics", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics)), ("dwdm-minute15otns", ("dwdm_minute15otns", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns))])
                            self._leafs = OrderedDict()

                            self.dwdm_minute15fecs = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15fecs()
                            self.dwdm_minute15fecs.parent = self
                            self._children_name_map["dwdm_minute15fecs"] = "dwdm-minute15fecs"

                            self.dwdm_minute15_optics = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics()
                            self.dwdm_minute15_optics.parent = self
                            self._children_name_map["dwdm_minute15_optics"] = "dwdm-minute15-optics"

                            self.dwdm_minute15otns = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns()
                            self.dwdm_minute15otns.parent = self
                            self._children_name_map["dwdm_minute15otns"] = "dwdm-minute15otns"
                            self._segment_path = lambda: "dwdm-minute15"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15, [], name, value)


                        class DwdmMinute15fecs(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: dwdm_minute15fec
                            
                            	port 15\-minute fec performance data
                            	**type**\: list of  		 :py:class:`DwdmMinute15fec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15fecs.DwdmMinute15fec>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15fecs, self).__init__()

                                self.yang_name = "dwdm-minute15fecs"
                                self.yang_parent_name = "dwdm-minute15"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dwdm-minute15fec", ("dwdm_minute15fec", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15fecs.DwdmMinute15fec))])
                                self._leafs = OrderedDict()

                                self.dwdm_minute15fec = YList(self)
                                self._segment_path = lambda: "dwdm-minute15fecs"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15fecs, [], name, value)


                            class DwdmMinute15fec(Entity):
                                """
                                port 15\-minute fec performance data
                                
                                .. attribute:: number  (key)
                                
                                	channel number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ec_bits
                                
                                	EC BITS
                                	**type**\:  :py:class:`EcBits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15fecs.DwdmMinute15fec.EcBits>`
                                
                                .. attribute:: uc_words
                                
                                	UC WORDS
                                	**type**\:  :py:class:`UcWords <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15fecs.DwdmMinute15fec.UcWords>`
                                
                                .. attribute:: pre_fec_ber
                                
                                	Pre FEC BER
                                	**type**\:  :py:class:`PreFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15fecs.DwdmMinute15fec.PreFecBer>`
                                
                                .. attribute:: post_fec_ber
                                
                                	Post FEC BER
                                	**type**\:  :py:class:`PostFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15fecs.DwdmMinute15fec.PostFecBer>`
                                
                                .. attribute:: q
                                
                                	Q
                                	**type**\:  :py:class:`Q <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15fecs.DwdmMinute15fec.Q>`
                                
                                .. attribute:: qmargin
                                
                                	Q Margin
                                	**type**\:  :py:class:`Qmargin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15fecs.DwdmMinute15fec.Qmargin>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15fecs.DwdmMinute15fec, self).__init__()

                                    self.yang_name = "dwdm-minute15fec"
                                    self.yang_parent_name = "dwdm-minute15fecs"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("ec-bits", ("ec_bits", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15fecs.DwdmMinute15fec.EcBits)), ("uc-words", ("uc_words", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15fecs.DwdmMinute15fec.UcWords)), ("pre-fec-ber", ("pre_fec_ber", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15fecs.DwdmMinute15fec.PreFecBer)), ("post-fec-ber", ("post_fec_ber", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15fecs.DwdmMinute15fec.PostFecBer)), ("q", ("q", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15fecs.DwdmMinute15fec.Q)), ("qmargin", ("qmargin", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15fecs.DwdmMinute15fec.Qmargin))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                        ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                    ])
                                    self.number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear24_hr_time = None
                                    self.sec30_support = None

                                    self.ec_bits = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15fecs.DwdmMinute15fec.EcBits()
                                    self.ec_bits.parent = self
                                    self._children_name_map["ec_bits"] = "ec-bits"

                                    self.uc_words = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15fecs.DwdmMinute15fec.UcWords()
                                    self.uc_words.parent = self
                                    self._children_name_map["uc_words"] = "uc-words"

                                    self.pre_fec_ber = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15fecs.DwdmMinute15fec.PreFecBer()
                                    self.pre_fec_ber.parent = self
                                    self._children_name_map["pre_fec_ber"] = "pre-fec-ber"

                                    self.post_fec_ber = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15fecs.DwdmMinute15fec.PostFecBer()
                                    self.post_fec_ber.parent = self
                                    self._children_name_map["post_fec_ber"] = "post-fec-ber"

                                    self.q = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15fecs.DwdmMinute15fec.Q()
                                    self.q.parent = self
                                    self._children_name_map["q"] = "q"

                                    self.qmargin = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15fecs.DwdmMinute15fec.Qmargin()
                                    self.qmargin.parent = self
                                    self._children_name_map["qmargin"] = "qmargin"
                                    self._segment_path = lambda: "dwdm-minute15fec" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15fecs.DwdmMinute15fec, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                class EcBits(Entity):
                                    """
                                    EC BITS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15fecs.DwdmMinute15fec.EcBits, self).__init__()

                                        self.yang_name = "ec-bits"
                                        self.yang_parent_name = "dwdm-minute15fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ec-bits"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15fecs.DwdmMinute15fec.EcBits, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class UcWords(Entity):
                                    """
                                    UC WORDS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15fecs.DwdmMinute15fec.UcWords, self).__init__()

                                        self.yang_name = "uc-words"
                                        self.yang_parent_name = "dwdm-minute15fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "uc-words"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15fecs.DwdmMinute15fec.UcWords, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class PreFecBer(Entity):
                                    """
                                    Pre FEC BER
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15fecs.DwdmMinute15fec.PreFecBer, self).__init__()

                                        self.yang_name = "pre-fec-ber"
                                        self.yang_parent_name = "dwdm-minute15fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.maximum_tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "pre-fec-ber"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15fecs.DwdmMinute15fec.PreFecBer, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                class PostFecBer(Entity):
                                    """
                                    Post FEC BER
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15fecs.DwdmMinute15fec.PostFecBer, self).__init__()

                                        self.yang_name = "post-fec-ber"
                                        self.yang_parent_name = "dwdm-minute15fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.maximum_tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "post-fec-ber"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15fecs.DwdmMinute15fec.PostFecBer, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                class Q(Entity):
                                    """
                                    Q
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15fecs.DwdmMinute15fec.Q, self).__init__()

                                        self.yang_name = "q"
                                        self.yang_parent_name = "dwdm-minute15fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.maximum_tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "q"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15fecs.DwdmMinute15fec.Q, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                class Qmargin(Entity):
                                    """
                                    Q Margin
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15fecs.DwdmMinute15fec.Qmargin, self).__init__()

                                        self.yang_name = "qmargin"
                                        self.yang_parent_name = "dwdm-minute15fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.maximum_tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "qmargin"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15fecs.DwdmMinute15fec.Qmargin, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                        class DwdmMinute15Optics(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: dwdm_minute15_optic
                            
                            	port 15\-minute optics performance data
                            	**type**\: list of  		 :py:class:`DwdmMinute15Optic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics, self).__init__()

                                self.yang_name = "dwdm-minute15-optics"
                                self.yang_parent_name = "dwdm-minute15"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dwdm-minute15-optic", ("dwdm_minute15_optic", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic))])
                                self._leafs = OrderedDict()

                                self.dwdm_minute15_optic = YList(self)
                                self._segment_path = lambda: "dwdm-minute15-optics"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics, [], name, value)


                            class DwdmMinute15Optic(Entity):
                                """
                                port 15\-minute optics performance data
                                
                                .. attribute:: number  (key)
                                
                                	channel number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lbc
                                
                                	LBC
                                	**type**\:  :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Lbc>`
                                
                                .. attribute:: lbc_pc
                                
                                	LBC in percentage
                                	**type**\:  :py:class:`LbcPc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.LbcPc>`
                                
                                .. attribute:: opt
                                
                                	OPT
                                	**type**\:  :py:class:`Opt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Opt>`
                                
                                .. attribute:: opr
                                
                                	OPR
                                	**type**\:  :py:class:`Opr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Opr>`
                                
                                .. attribute:: cd
                                
                                	Chromatic Dispersion
                                	**type**\:  :py:class:`Cd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Cd>`
                                
                                .. attribute:: dgd
                                
                                	Differential group Delay
                                	**type**\:  :py:class:`Dgd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Dgd>`
                                
                                .. attribute:: pmd
                                
                                	Polarization Mode Dispersion
                                	**type**\:  :py:class:`Pmd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Pmd>`
                                
                                .. attribute:: osnr
                                
                                	Optical Signal to Noise Ratio
                                	**type**\:  :py:class:`Osnr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Osnr>`
                                
                                .. attribute:: center_wavelength
                                
                                	Center Wavelength/Frequency
                                	**type**\:  :py:class:`CenterWavelength <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.CenterWavelength>`
                                
                                .. attribute:: pdl
                                
                                	Polarization Dependent Loss
                                	**type**\:  :py:class:`Pdl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Pdl>`
                                
                                .. attribute:: pcr
                                
                                	Polarization Change Rate
                                	**type**\:  :py:class:`Pcr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Pcr>`
                                
                                .. attribute:: pn
                                
                                	Phase Noise
                                	**type**\:  :py:class:`Pn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Pn>`
                                
                                .. attribute:: rx_sig_pow
                                
                                	Rx signal power
                                	**type**\:  :py:class:`RxSigPow <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.RxSigPow>`
                                
                                .. attribute:: low_sig_freq_off
                                
                                	low freq sig off
                                	**type**\:  :py:class:`LowSigFreqOff <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.LowSigFreqOff>`
                                
                                .. attribute:: ampli_gain
                                
                                	Ampli Gain
                                	**type**\:  :py:class:`AmpliGain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.AmpliGain>`
                                
                                .. attribute:: ampli_gain_tilt
                                
                                	Ampli Gain Tilt
                                	**type**\:  :py:class:`AmpliGainTilt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.AmpliGainTilt>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic, self).__init__()

                                    self.yang_name = "dwdm-minute15-optic"
                                    self.yang_parent_name = "dwdm-minute15-optics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("lbc", ("lbc", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Lbc)), ("lbc-pc", ("lbc_pc", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.LbcPc)), ("opt", ("opt", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Opt)), ("opr", ("opr", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Opr)), ("cd", ("cd", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Cd)), ("dgd", ("dgd", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Dgd)), ("pmd", ("pmd", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Pmd)), ("osnr", ("osnr", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Osnr)), ("center-wavelength", ("center_wavelength", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.CenterWavelength)), ("pdl", ("pdl", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Pdl)), ("pcr", ("pcr", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Pcr)), ("pn", ("pn", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Pn)), ("rx-sig-pow", ("rx_sig_pow", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.RxSigPow)), ("low-sig-freq-off", ("low_sig_freq_off", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.LowSigFreqOff)), ("ampli-gain", ("ampli_gain", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.AmpliGain)), ("ampli-gain-tilt", ("ampli_gain_tilt", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.AmpliGainTilt))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                        ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                    ])
                                    self.number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear24_hr_time = None
                                    self.sec30_support = None

                                    self.lbc = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Lbc()
                                    self.lbc.parent = self
                                    self._children_name_map["lbc"] = "lbc"

                                    self.lbc_pc = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.LbcPc()
                                    self.lbc_pc.parent = self
                                    self._children_name_map["lbc_pc"] = "lbc-pc"

                                    self.opt = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Opt()
                                    self.opt.parent = self
                                    self._children_name_map["opt"] = "opt"

                                    self.opr = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Opr()
                                    self.opr.parent = self
                                    self._children_name_map["opr"] = "opr"

                                    self.cd = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Cd()
                                    self.cd.parent = self
                                    self._children_name_map["cd"] = "cd"

                                    self.dgd = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Dgd()
                                    self.dgd.parent = self
                                    self._children_name_map["dgd"] = "dgd"

                                    self.pmd = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Pmd()
                                    self.pmd.parent = self
                                    self._children_name_map["pmd"] = "pmd"

                                    self.osnr = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Osnr()
                                    self.osnr.parent = self
                                    self._children_name_map["osnr"] = "osnr"

                                    self.center_wavelength = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.CenterWavelength()
                                    self.center_wavelength.parent = self
                                    self._children_name_map["center_wavelength"] = "center-wavelength"

                                    self.pdl = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Pdl()
                                    self.pdl.parent = self
                                    self._children_name_map["pdl"] = "pdl"

                                    self.pcr = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Pcr()
                                    self.pcr.parent = self
                                    self._children_name_map["pcr"] = "pcr"

                                    self.pn = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Pn()
                                    self.pn.parent = self
                                    self._children_name_map["pn"] = "pn"

                                    self.rx_sig_pow = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.RxSigPow()
                                    self.rx_sig_pow.parent = self
                                    self._children_name_map["rx_sig_pow"] = "rx-sig-pow"

                                    self.low_sig_freq_off = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.LowSigFreqOff()
                                    self.low_sig_freq_off.parent = self
                                    self._children_name_map["low_sig_freq_off"] = "low-sig-freq-off"

                                    self.ampli_gain = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.AmpliGain()
                                    self.ampli_gain.parent = self
                                    self._children_name_map["ampli_gain"] = "ampli-gain"

                                    self.ampli_gain_tilt = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.AmpliGainTilt()
                                    self.ampli_gain_tilt.parent = self
                                    self._children_name_map["ampli_gain_tilt"] = "ampli-gain-tilt"
                                    self._segment_path = lambda: "dwdm-minute15-optic" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                class Lbc(Entity):
                                    """
                                    LBC
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Lbc, self).__init__()

                                        self.yang_name = "lbc"
                                        self.yang_parent_name = "dwdm-minute15-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.int32, 'minimum'), ['int'])),
                                            ('average', (YLeaf(YType.int32, 'average'), ['int'])),
                                            ('maximum', (YLeaf(YType.int32, 'maximum'), ['int'])),
                                            ('minimum_threshold', (YLeaf(YType.int32, 'minimum-threshold'), ['int'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.int32, 'maximum-threshold'), ['int'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "lbc"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Lbc, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class LbcPc(Entity):
                                    """
                                    LBC in percentage
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.LbcPc, self).__init__()

                                        self.yang_name = "lbc-pc"
                                        self.yang_parent_name = "dwdm-minute15-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "lbc-pc"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.LbcPc, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class Opt(Entity):
                                    """
                                    OPT
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Opt, self).__init__()

                                        self.yang_name = "opt"
                                        self.yang_parent_name = "dwdm-minute15-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "opt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Opt, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class Opr(Entity):
                                    """
                                    OPR
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Opr, self).__init__()

                                        self.yang_name = "opr"
                                        self.yang_parent_name = "dwdm-minute15-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "opr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Opr, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class Cd(Entity):
                                    """
                                    Chromatic Dispersion
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Cd, self).__init__()

                                        self.yang_name = "cd"
                                        self.yang_parent_name = "dwdm-minute15-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.int32, 'minimum'), ['int'])),
                                            ('average', (YLeaf(YType.int32, 'average'), ['int'])),
                                            ('maximum', (YLeaf(YType.int32, 'maximum'), ['int'])),
                                            ('minimum_threshold', (YLeaf(YType.int32, 'minimum-threshold'), ['int'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.int32, 'maximum-threshold'), ['int'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "cd"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Cd, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class Dgd(Entity):
                                    """
                                    Differential group Delay
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Dgd, self).__init__()

                                        self.yang_name = "dgd"
                                        self.yang_parent_name = "dwdm-minute15-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "dgd"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Dgd, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class Pmd(Entity):
                                    """
                                    Polarization Mode Dispersion
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Pmd, self).__init__()

                                        self.yang_name = "pmd"
                                        self.yang_parent_name = "dwdm-minute15-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "pmd"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Pmd, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class Osnr(Entity):
                                    """
                                    Optical Signal to Noise Ratio
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Osnr, self).__init__()

                                        self.yang_name = "osnr"
                                        self.yang_parent_name = "dwdm-minute15-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "osnr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Osnr, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class CenterWavelength(Entity):
                                    """
                                    Center Wavelength/Frequency
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.CenterWavelength, self).__init__()

                                        self.yang_name = "center-wavelength"
                                        self.yang_parent_name = "dwdm-minute15-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "center-wavelength"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.CenterWavelength, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class Pdl(Entity):
                                    """
                                    Polarization Dependent Loss
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Pdl, self).__init__()

                                        self.yang_name = "pdl"
                                        self.yang_parent_name = "dwdm-minute15-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "pdl"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Pdl, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class Pcr(Entity):
                                    """
                                    Polarization Change Rate
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Pcr, self).__init__()

                                        self.yang_name = "pcr"
                                        self.yang_parent_name = "dwdm-minute15-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "pcr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Pcr, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class Pn(Entity):
                                    """
                                    Phase Noise
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Pn, self).__init__()

                                        self.yang_name = "pn"
                                        self.yang_parent_name = "dwdm-minute15-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "pn"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Pn, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class RxSigPow(Entity):
                                    """
                                    Rx signal power
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.RxSigPow, self).__init__()

                                        self.yang_name = "rx-sig-pow"
                                        self.yang_parent_name = "dwdm-minute15-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "rx-sig-pow"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.RxSigPow, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class LowSigFreqOff(Entity):
                                    """
                                    low freq sig off
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.LowSigFreqOff, self).__init__()

                                        self.yang_name = "low-sig-freq-off"
                                        self.yang_parent_name = "dwdm-minute15-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.int32, 'minimum'), ['int'])),
                                            ('average', (YLeaf(YType.int32, 'average'), ['int'])),
                                            ('maximum', (YLeaf(YType.int32, 'maximum'), ['int'])),
                                            ('minimum_threshold', (YLeaf(YType.int32, 'minimum-threshold'), ['int'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.int32, 'maximum-threshold'), ['int'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "low-sig-freq-off"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.LowSigFreqOff, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class AmpliGain(Entity):
                                    """
                                    Ampli Gain
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.AmpliGain, self).__init__()

                                        self.yang_name = "ampli-gain"
                                        self.yang_parent_name = "dwdm-minute15-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "ampli-gain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.AmpliGain, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class AmpliGainTilt(Entity):
                                    """
                                    Ampli Gain Tilt
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.AmpliGainTilt, self).__init__()

                                        self.yang_name = "ampli-gain-tilt"
                                        self.yang_parent_name = "dwdm-minute15-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "ampli-gain-tilt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.AmpliGainTilt, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                        class DwdmMinute15otns(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: dwdm_minute15otn
                            
                            	port 15\-minute otn performance data
                            	**type**\: list of  		 :py:class:`DwdmMinute15otn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns, self).__init__()

                                self.yang_name = "dwdm-minute15otns"
                                self.yang_parent_name = "dwdm-minute15"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dwdm-minute15otn", ("dwdm_minute15otn", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn))])
                                self._leafs = OrderedDict()

                                self.dwdm_minute15otn = YList(self)
                                self._segment_path = lambda: "dwdm-minute15otns"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns, [], name, value)


                            class DwdmMinute15otn(Entity):
                                """
                                port 15\-minute otn performance data
                                
                                .. attribute:: number  (key)
                                
                                	channel number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lbc
                                
                                	LBC
                                	**type**\:  :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.Lbc>`
                                
                                .. attribute:: es_ne
                                
                                	ES SM NE
                                	**type**\:  :py:class:`EsNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.EsNe>`
                                
                                .. attribute:: esr_ne
                                
                                	ESR PM NE
                                	**type**\:  :py:class:`EsrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.EsrNe>`
                                
                                .. attribute:: ses_ne
                                
                                	SES SM NE
                                	**type**\:  :py:class:`SesNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.SesNe>`
                                
                                .. attribute:: sesr_ne
                                
                                	SESR SM NE
                                	**type**\:  :py:class:`SesrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.SesrNe>`
                                
                                .. attribute:: uas_ne
                                
                                	UAS SM NE
                                	**type**\:  :py:class:`UasNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.UasNe>`
                                
                                .. attribute:: bbe_ne
                                
                                	BBE SM NE
                                	**type**\:  :py:class:`BbeNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.BbeNe>`
                                
                                .. attribute:: bber_ne
                                
                                	BBER SM NE
                                	**type**\:  :py:class:`BberNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.BberNe>`
                                
                                .. attribute:: fc_ne
                                
                                	FC SM NE
                                	**type**\:  :py:class:`FcNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.FcNe>`
                                
                                .. attribute:: es_fe
                                
                                	ES SM FE
                                	**type**\:  :py:class:`EsFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.EsFe>`
                                
                                .. attribute:: esr_fe
                                
                                	ESR PM FE
                                	**type**\:  :py:class:`EsrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.EsrFe>`
                                
                                .. attribute:: ses_fe
                                
                                	SES SM FE
                                	**type**\:  :py:class:`SesFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.SesFe>`
                                
                                .. attribute:: sesr_fe
                                
                                	SESR SM FE
                                	**type**\:  :py:class:`SesrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.SesrFe>`
                                
                                .. attribute:: uas_fe
                                
                                	UAS SM FE
                                	**type**\:  :py:class:`UasFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.UasFe>`
                                
                                .. attribute:: bbe_fe
                                
                                	BBE SM FE
                                	**type**\:  :py:class:`BbeFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.BbeFe>`
                                
                                .. attribute:: bber_fe
                                
                                	BBER SM FE
                                	**type**\:  :py:class:`BberFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.BberFe>`
                                
                                .. attribute:: fc_fe
                                
                                	FC SM FE
                                	**type**\:  :py:class:`FcFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.FcFe>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn, self).__init__()

                                    self.yang_name = "dwdm-minute15otn"
                                    self.yang_parent_name = "dwdm-minute15otns"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("lbc", ("lbc", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.Lbc)), ("es-ne", ("es_ne", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.EsNe)), ("esr-ne", ("esr_ne", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.EsrNe)), ("ses-ne", ("ses_ne", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.SesNe)), ("sesr-ne", ("sesr_ne", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.SesrNe)), ("uas-ne", ("uas_ne", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.UasNe)), ("bbe-ne", ("bbe_ne", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.BbeNe)), ("bber-ne", ("bber_ne", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.BberNe)), ("fc-ne", ("fc_ne", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.FcNe)), ("es-fe", ("es_fe", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.EsFe)), ("esr-fe", ("esr_fe", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.EsrFe)), ("ses-fe", ("ses_fe", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.SesFe)), ("sesr-fe", ("sesr_fe", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.SesrFe)), ("uas-fe", ("uas_fe", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.UasFe)), ("bbe-fe", ("bbe_fe", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.BbeFe)), ("bber-fe", ("bber_fe", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.BberFe)), ("fc-fe", ("fc_fe", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.FcFe))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                        ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                    ])
                                    self.number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear24_hr_time = None
                                    self.sec30_support = None

                                    self.lbc = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.Lbc()
                                    self.lbc.parent = self
                                    self._children_name_map["lbc"] = "lbc"

                                    self.es_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.EsNe()
                                    self.es_ne.parent = self
                                    self._children_name_map["es_ne"] = "es-ne"

                                    self.esr_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.EsrNe()
                                    self.esr_ne.parent = self
                                    self._children_name_map["esr_ne"] = "esr-ne"

                                    self.ses_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.SesNe()
                                    self.ses_ne.parent = self
                                    self._children_name_map["ses_ne"] = "ses-ne"

                                    self.sesr_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.SesrNe()
                                    self.sesr_ne.parent = self
                                    self._children_name_map["sesr_ne"] = "sesr-ne"

                                    self.uas_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.UasNe()
                                    self.uas_ne.parent = self
                                    self._children_name_map["uas_ne"] = "uas-ne"

                                    self.bbe_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.BbeNe()
                                    self.bbe_ne.parent = self
                                    self._children_name_map["bbe_ne"] = "bbe-ne"

                                    self.bber_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.BberNe()
                                    self.bber_ne.parent = self
                                    self._children_name_map["bber_ne"] = "bber-ne"

                                    self.fc_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.FcNe()
                                    self.fc_ne.parent = self
                                    self._children_name_map["fc_ne"] = "fc-ne"

                                    self.es_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.EsFe()
                                    self.es_fe.parent = self
                                    self._children_name_map["es_fe"] = "es-fe"

                                    self.esr_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.EsrFe()
                                    self.esr_fe.parent = self
                                    self._children_name_map["esr_fe"] = "esr-fe"

                                    self.ses_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.SesFe()
                                    self.ses_fe.parent = self
                                    self._children_name_map["ses_fe"] = "ses-fe"

                                    self.sesr_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.SesrFe()
                                    self.sesr_fe.parent = self
                                    self._children_name_map["sesr_fe"] = "sesr-fe"

                                    self.uas_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.UasFe()
                                    self.uas_fe.parent = self
                                    self._children_name_map["uas_fe"] = "uas-fe"

                                    self.bbe_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.BbeFe()
                                    self.bbe_fe.parent = self
                                    self._children_name_map["bbe_fe"] = "bbe-fe"

                                    self.bber_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.BberFe()
                                    self.bber_fe.parent = self
                                    self._children_name_map["bber_fe"] = "bber-fe"

                                    self.fc_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.FcFe()
                                    self.fc_fe.parent = self
                                    self._children_name_map["fc_fe"] = "fc-fe"
                                    self._segment_path = lambda: "dwdm-minute15otn" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                class Lbc(Entity):
                                    """
                                    LBC
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.Lbc, self).__init__()

                                        self.yang_name = "lbc"
                                        self.yang_parent_name = "dwdm-minute15otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "lbc"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.Lbc, ['data', 'threshold', 'tca_report'], name, value)


                                class EsNe(Entity):
                                    """
                                    ES SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.EsNe, self).__init__()

                                        self.yang_name = "es-ne"
                                        self.yang_parent_name = "dwdm-minute15otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "es-ne"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.EsNe, ['data', 'threshold', 'tca_report'], name, value)


                                class EsrNe(Entity):
                                    """
                                    ESR PM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: str
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.EsrNe, self).__init__()

                                        self.yang_name = "esr-ne"
                                        self.yang_parent_name = "dwdm-minute15otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "esr-ne"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.EsrNe, ['data', 'threshold', 'tca_report'], name, value)


                                class SesNe(Entity):
                                    """
                                    SES SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.SesNe, self).__init__()

                                        self.yang_name = "ses-ne"
                                        self.yang_parent_name = "dwdm-minute15otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "ses-ne"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.SesNe, ['data', 'threshold', 'tca_report'], name, value)


                                class SesrNe(Entity):
                                    """
                                    SESR SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: str
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.SesrNe, self).__init__()

                                        self.yang_name = "sesr-ne"
                                        self.yang_parent_name = "dwdm-minute15otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "sesr-ne"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.SesrNe, ['data', 'threshold', 'tca_report'], name, value)


                                class UasNe(Entity):
                                    """
                                    UAS SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.UasNe, self).__init__()

                                        self.yang_name = "uas-ne"
                                        self.yang_parent_name = "dwdm-minute15otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "uas-ne"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.UasNe, ['data', 'threshold', 'tca_report'], name, value)


                                class BbeNe(Entity):
                                    """
                                    BBE SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.BbeNe, self).__init__()

                                        self.yang_name = "bbe-ne"
                                        self.yang_parent_name = "dwdm-minute15otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "bbe-ne"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.BbeNe, ['data', 'threshold', 'tca_report'], name, value)


                                class BberNe(Entity):
                                    """
                                    BBER SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: str
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.BberNe, self).__init__()

                                        self.yang_name = "bber-ne"
                                        self.yang_parent_name = "dwdm-minute15otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "bber-ne"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.BberNe, ['data', 'threshold', 'tca_report'], name, value)


                                class FcNe(Entity):
                                    """
                                    FC SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.FcNe, self).__init__()

                                        self.yang_name = "fc-ne"
                                        self.yang_parent_name = "dwdm-minute15otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "fc-ne"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.FcNe, ['data', 'threshold', 'tca_report'], name, value)


                                class EsFe(Entity):
                                    """
                                    ES SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.EsFe, self).__init__()

                                        self.yang_name = "es-fe"
                                        self.yang_parent_name = "dwdm-minute15otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "es-fe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.EsFe, ['data', 'threshold', 'tca_report'], name, value)


                                class EsrFe(Entity):
                                    """
                                    ESR PM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: str
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.EsrFe, self).__init__()

                                        self.yang_name = "esr-fe"
                                        self.yang_parent_name = "dwdm-minute15otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "esr-fe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.EsrFe, ['data', 'threshold', 'tca_report'], name, value)


                                class SesFe(Entity):
                                    """
                                    SES SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.SesFe, self).__init__()

                                        self.yang_name = "ses-fe"
                                        self.yang_parent_name = "dwdm-minute15otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "ses-fe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.SesFe, ['data', 'threshold', 'tca_report'], name, value)


                                class SesrFe(Entity):
                                    """
                                    SESR SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: str
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.SesrFe, self).__init__()

                                        self.yang_name = "sesr-fe"
                                        self.yang_parent_name = "dwdm-minute15otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "sesr-fe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.SesrFe, ['data', 'threshold', 'tca_report'], name, value)


                                class UasFe(Entity):
                                    """
                                    UAS SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.UasFe, self).__init__()

                                        self.yang_name = "uas-fe"
                                        self.yang_parent_name = "dwdm-minute15otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "uas-fe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.UasFe, ['data', 'threshold', 'tca_report'], name, value)


                                class BbeFe(Entity):
                                    """
                                    BBE SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.BbeFe, self).__init__()

                                        self.yang_name = "bbe-fe"
                                        self.yang_parent_name = "dwdm-minute15otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "bbe-fe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.BbeFe, ['data', 'threshold', 'tca_report'], name, value)


                                class BberFe(Entity):
                                    """
                                    BBER SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: str
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.BberFe, self).__init__()

                                        self.yang_name = "bber-fe"
                                        self.yang_parent_name = "dwdm-minute15otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "bber-fe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.BberFe, ['data', 'threshold', 'tca_report'], name, value)


                                class FcFe(Entity):
                                    """
                                    FC SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.FcFe, self).__init__()

                                        self.yang_name = "fc-fe"
                                        self.yang_parent_name = "dwdm-minute15otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "fc-fe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15otns.DwdmMinute15otn.FcFe, ['data', 'threshold', 'tca_report'], name, value)


                    class DwdmHour24(Entity):
                        """
                        port current performance data
                        
                        .. attribute:: dwdm_hour24_optics
                        
                        	port 24 hour performance data
                        	**type**\:  :py:class:`DwdmHour24Optics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics>`
                        
                        .. attribute:: dwdm_hour24fecs
                        
                        	port current performance data
                        	**type**\:  :py:class:`DwdmHour24fecs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24fecs>`
                        
                        .. attribute:: dwdm_hour24otns
                        
                        	port 24 hour performance data
                        	**type**\:  :py:class:`DwdmHour24otns <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24, self).__init__()

                            self.yang_name = "dwdm-hour24"
                            self.yang_parent_name = "dwdm-current"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("dwdm-hour24-optics", ("dwdm_hour24_optics", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics)), ("dwdm-hour24fecs", ("dwdm_hour24fecs", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24fecs)), ("dwdm-hour24otns", ("dwdm_hour24otns", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns))])
                            self._leafs = OrderedDict()

                            self.dwdm_hour24_optics = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics()
                            self.dwdm_hour24_optics.parent = self
                            self._children_name_map["dwdm_hour24_optics"] = "dwdm-hour24-optics"

                            self.dwdm_hour24fecs = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24fecs()
                            self.dwdm_hour24fecs.parent = self
                            self._children_name_map["dwdm_hour24fecs"] = "dwdm-hour24fecs"

                            self.dwdm_hour24otns = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns()
                            self.dwdm_hour24otns.parent = self
                            self._children_name_map["dwdm_hour24otns"] = "dwdm-hour24otns"
                            self._segment_path = lambda: "dwdm-hour24"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24, [], name, value)


                        class DwdmHour24Optics(Entity):
                            """
                            port 24 hour performance data
                            
                            .. attribute:: dwdm_hour24_optic
                            
                            	port 24 hour optics performance data
                            	**type**\: list of  		 :py:class:`DwdmHour24Optic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics, self).__init__()

                                self.yang_name = "dwdm-hour24-optics"
                                self.yang_parent_name = "dwdm-hour24"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dwdm-hour24-optic", ("dwdm_hour24_optic", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic))])
                                self._leafs = OrderedDict()

                                self.dwdm_hour24_optic = YList(self)
                                self._segment_path = lambda: "dwdm-hour24-optics"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics, [], name, value)


                            class DwdmHour24Optic(Entity):
                                """
                                port 24 hour optics performance data
                                
                                .. attribute:: number  (key)
                                
                                	channel number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lbc
                                
                                	LBC
                                	**type**\:  :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Lbc>`
                                
                                .. attribute:: lbc_pc
                                
                                	LBC in percentage
                                	**type**\:  :py:class:`LbcPc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.LbcPc>`
                                
                                .. attribute:: opt
                                
                                	OPT
                                	**type**\:  :py:class:`Opt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Opt>`
                                
                                .. attribute:: opr
                                
                                	OPR
                                	**type**\:  :py:class:`Opr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Opr>`
                                
                                .. attribute:: cd
                                
                                	Chromatic Dispersion
                                	**type**\:  :py:class:`Cd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Cd>`
                                
                                .. attribute:: dgd
                                
                                	Differential group Delay
                                	**type**\:  :py:class:`Dgd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Dgd>`
                                
                                .. attribute:: pmd
                                
                                	Polarization Mode Dispersion
                                	**type**\:  :py:class:`Pmd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Pmd>`
                                
                                .. attribute:: osnr
                                
                                	Optical Signal to Noise Ratio
                                	**type**\:  :py:class:`Osnr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Osnr>`
                                
                                .. attribute:: center_wavelength
                                
                                	Center Wavelength/Frequency
                                	**type**\:  :py:class:`CenterWavelength <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.CenterWavelength>`
                                
                                .. attribute:: pdl
                                
                                	Polarization Dependent Loss
                                	**type**\:  :py:class:`Pdl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Pdl>`
                                
                                .. attribute:: pcr
                                
                                	Polarization Change Rate
                                	**type**\:  :py:class:`Pcr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Pcr>`
                                
                                .. attribute:: pn
                                
                                	Phase Noise
                                	**type**\:  :py:class:`Pn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Pn>`
                                
                                .. attribute:: rx_sig_pow
                                
                                	Rx signal power
                                	**type**\:  :py:class:`RxSigPow <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.RxSigPow>`
                                
                                .. attribute:: low_sig_freq_off
                                
                                	low freq sig off
                                	**type**\:  :py:class:`LowSigFreqOff <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.LowSigFreqOff>`
                                
                                .. attribute:: ampli_gain
                                
                                	Ampli Gain
                                	**type**\:  :py:class:`AmpliGain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.AmpliGain>`
                                
                                .. attribute:: ampli_gain_tilt
                                
                                	Ampli Gain Tilt
                                	**type**\:  :py:class:`AmpliGainTilt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.AmpliGainTilt>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic, self).__init__()

                                    self.yang_name = "dwdm-hour24-optic"
                                    self.yang_parent_name = "dwdm-hour24-optics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("lbc", ("lbc", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Lbc)), ("lbc-pc", ("lbc_pc", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.LbcPc)), ("opt", ("opt", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Opt)), ("opr", ("opr", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Opr)), ("cd", ("cd", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Cd)), ("dgd", ("dgd", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Dgd)), ("pmd", ("pmd", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Pmd)), ("osnr", ("osnr", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Osnr)), ("center-wavelength", ("center_wavelength", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.CenterWavelength)), ("pdl", ("pdl", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Pdl)), ("pcr", ("pcr", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Pcr)), ("pn", ("pn", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Pn)), ("rx-sig-pow", ("rx_sig_pow", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.RxSigPow)), ("low-sig-freq-off", ("low_sig_freq_off", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.LowSigFreqOff)), ("ampli-gain", ("ampli_gain", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.AmpliGain)), ("ampli-gain-tilt", ("ampli_gain_tilt", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.AmpliGainTilt))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                        ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                    ])
                                    self.number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear24_hr_time = None
                                    self.sec30_support = None

                                    self.lbc = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Lbc()
                                    self.lbc.parent = self
                                    self._children_name_map["lbc"] = "lbc"

                                    self.lbc_pc = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.LbcPc()
                                    self.lbc_pc.parent = self
                                    self._children_name_map["lbc_pc"] = "lbc-pc"

                                    self.opt = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Opt()
                                    self.opt.parent = self
                                    self._children_name_map["opt"] = "opt"

                                    self.opr = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Opr()
                                    self.opr.parent = self
                                    self._children_name_map["opr"] = "opr"

                                    self.cd = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Cd()
                                    self.cd.parent = self
                                    self._children_name_map["cd"] = "cd"

                                    self.dgd = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Dgd()
                                    self.dgd.parent = self
                                    self._children_name_map["dgd"] = "dgd"

                                    self.pmd = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Pmd()
                                    self.pmd.parent = self
                                    self._children_name_map["pmd"] = "pmd"

                                    self.osnr = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Osnr()
                                    self.osnr.parent = self
                                    self._children_name_map["osnr"] = "osnr"

                                    self.center_wavelength = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.CenterWavelength()
                                    self.center_wavelength.parent = self
                                    self._children_name_map["center_wavelength"] = "center-wavelength"

                                    self.pdl = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Pdl()
                                    self.pdl.parent = self
                                    self._children_name_map["pdl"] = "pdl"

                                    self.pcr = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Pcr()
                                    self.pcr.parent = self
                                    self._children_name_map["pcr"] = "pcr"

                                    self.pn = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Pn()
                                    self.pn.parent = self
                                    self._children_name_map["pn"] = "pn"

                                    self.rx_sig_pow = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.RxSigPow()
                                    self.rx_sig_pow.parent = self
                                    self._children_name_map["rx_sig_pow"] = "rx-sig-pow"

                                    self.low_sig_freq_off = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.LowSigFreqOff()
                                    self.low_sig_freq_off.parent = self
                                    self._children_name_map["low_sig_freq_off"] = "low-sig-freq-off"

                                    self.ampli_gain = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.AmpliGain()
                                    self.ampli_gain.parent = self
                                    self._children_name_map["ampli_gain"] = "ampli-gain"

                                    self.ampli_gain_tilt = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.AmpliGainTilt()
                                    self.ampli_gain_tilt.parent = self
                                    self._children_name_map["ampli_gain_tilt"] = "ampli-gain-tilt"
                                    self._segment_path = lambda: "dwdm-hour24-optic" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                class Lbc(Entity):
                                    """
                                    LBC
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Lbc, self).__init__()

                                        self.yang_name = "lbc"
                                        self.yang_parent_name = "dwdm-hour24-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.int32, 'minimum'), ['int'])),
                                            ('average', (YLeaf(YType.int32, 'average'), ['int'])),
                                            ('maximum', (YLeaf(YType.int32, 'maximum'), ['int'])),
                                            ('minimum_threshold', (YLeaf(YType.int32, 'minimum-threshold'), ['int'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.int32, 'maximum-threshold'), ['int'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "lbc"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Lbc, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class LbcPc(Entity):
                                    """
                                    LBC in percentage
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.LbcPc, self).__init__()

                                        self.yang_name = "lbc-pc"
                                        self.yang_parent_name = "dwdm-hour24-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "lbc-pc"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.LbcPc, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class Opt(Entity):
                                    """
                                    OPT
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Opt, self).__init__()

                                        self.yang_name = "opt"
                                        self.yang_parent_name = "dwdm-hour24-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "opt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Opt, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class Opr(Entity):
                                    """
                                    OPR
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Opr, self).__init__()

                                        self.yang_name = "opr"
                                        self.yang_parent_name = "dwdm-hour24-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "opr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Opr, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class Cd(Entity):
                                    """
                                    Chromatic Dispersion
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Cd, self).__init__()

                                        self.yang_name = "cd"
                                        self.yang_parent_name = "dwdm-hour24-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.int32, 'minimum'), ['int'])),
                                            ('average', (YLeaf(YType.int32, 'average'), ['int'])),
                                            ('maximum', (YLeaf(YType.int32, 'maximum'), ['int'])),
                                            ('minimum_threshold', (YLeaf(YType.int32, 'minimum-threshold'), ['int'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.int32, 'maximum-threshold'), ['int'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "cd"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Cd, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class Dgd(Entity):
                                    """
                                    Differential group Delay
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Dgd, self).__init__()

                                        self.yang_name = "dgd"
                                        self.yang_parent_name = "dwdm-hour24-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "dgd"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Dgd, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class Pmd(Entity):
                                    """
                                    Polarization Mode Dispersion
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Pmd, self).__init__()

                                        self.yang_name = "pmd"
                                        self.yang_parent_name = "dwdm-hour24-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "pmd"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Pmd, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class Osnr(Entity):
                                    """
                                    Optical Signal to Noise Ratio
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Osnr, self).__init__()

                                        self.yang_name = "osnr"
                                        self.yang_parent_name = "dwdm-hour24-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "osnr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Osnr, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class CenterWavelength(Entity):
                                    """
                                    Center Wavelength/Frequency
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.CenterWavelength, self).__init__()

                                        self.yang_name = "center-wavelength"
                                        self.yang_parent_name = "dwdm-hour24-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "center-wavelength"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.CenterWavelength, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class Pdl(Entity):
                                    """
                                    Polarization Dependent Loss
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Pdl, self).__init__()

                                        self.yang_name = "pdl"
                                        self.yang_parent_name = "dwdm-hour24-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "pdl"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Pdl, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class Pcr(Entity):
                                    """
                                    Polarization Change Rate
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Pcr, self).__init__()

                                        self.yang_name = "pcr"
                                        self.yang_parent_name = "dwdm-hour24-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "pcr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Pcr, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class Pn(Entity):
                                    """
                                    Phase Noise
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Pn, self).__init__()

                                        self.yang_name = "pn"
                                        self.yang_parent_name = "dwdm-hour24-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "pn"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Pn, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class RxSigPow(Entity):
                                    """
                                    Rx signal power
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.RxSigPow, self).__init__()

                                        self.yang_name = "rx-sig-pow"
                                        self.yang_parent_name = "dwdm-hour24-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "rx-sig-pow"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.RxSigPow, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class LowSigFreqOff(Entity):
                                    """
                                    low freq sig off
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.LowSigFreqOff, self).__init__()

                                        self.yang_name = "low-sig-freq-off"
                                        self.yang_parent_name = "dwdm-hour24-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.int32, 'minimum'), ['int'])),
                                            ('average', (YLeaf(YType.int32, 'average'), ['int'])),
                                            ('maximum', (YLeaf(YType.int32, 'maximum'), ['int'])),
                                            ('minimum_threshold', (YLeaf(YType.int32, 'minimum-threshold'), ['int'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.int32, 'maximum-threshold'), ['int'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "low-sig-freq-off"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.LowSigFreqOff, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class AmpliGain(Entity):
                                    """
                                    Ampli Gain
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.AmpliGain, self).__init__()

                                        self.yang_name = "ampli-gain"
                                        self.yang_parent_name = "dwdm-hour24-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "ampli-gain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.AmpliGain, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                class AmpliGainTilt(Entity):
                                    """
                                    Ampli Gain Tilt
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_min_thresh
                                    
                                    	minimunthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: configured_max_thresh
                                    
                                    	maximumthreshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.AmpliGainTilt, self).__init__()

                                        self.yang_name = "ampli-gain-tilt"
                                        self.yang_parent_name = "dwdm-hour24-optic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                        ])
                                        self.valid = None
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.configured_min_thresh = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.configured_max_thresh = None
                                        self.maximum_tca_report = None
                                        self._segment_path = lambda: "ampli-gain-tilt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.AmpliGainTilt, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                        class DwdmHour24fecs(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: dwdm_hour24fec
                            
                            	port 24 hour fec performance data
                            	**type**\: list of  		 :py:class:`DwdmHour24fec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24fecs.DwdmHour24fec>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24fecs, self).__init__()

                                self.yang_name = "dwdm-hour24fecs"
                                self.yang_parent_name = "dwdm-hour24"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dwdm-hour24fec", ("dwdm_hour24fec", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24fecs.DwdmHour24fec))])
                                self._leafs = OrderedDict()

                                self.dwdm_hour24fec = YList(self)
                                self._segment_path = lambda: "dwdm-hour24fecs"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24fecs, [], name, value)


                            class DwdmHour24fec(Entity):
                                """
                                port 24 hour fec performance data
                                
                                .. attribute:: number  (key)
                                
                                	channel number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ec_bits
                                
                                	EC BITS
                                	**type**\:  :py:class:`EcBits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24fecs.DwdmHour24fec.EcBits>`
                                
                                .. attribute:: uc_words
                                
                                	UC WORDS
                                	**type**\:  :py:class:`UcWords <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24fecs.DwdmHour24fec.UcWords>`
                                
                                .. attribute:: pre_fec_ber
                                
                                	Pre FEC BER
                                	**type**\:  :py:class:`PreFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24fecs.DwdmHour24fec.PreFecBer>`
                                
                                .. attribute:: post_fec_ber
                                
                                	Post FEC BER
                                	**type**\:  :py:class:`PostFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24fecs.DwdmHour24fec.PostFecBer>`
                                
                                .. attribute:: q
                                
                                	Q
                                	**type**\:  :py:class:`Q <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24fecs.DwdmHour24fec.Q>`
                                
                                .. attribute:: qmargin
                                
                                	Q Margin
                                	**type**\:  :py:class:`Qmargin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24fecs.DwdmHour24fec.Qmargin>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24fecs.DwdmHour24fec, self).__init__()

                                    self.yang_name = "dwdm-hour24fec"
                                    self.yang_parent_name = "dwdm-hour24fecs"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("ec-bits", ("ec_bits", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24fecs.DwdmHour24fec.EcBits)), ("uc-words", ("uc_words", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24fecs.DwdmHour24fec.UcWords)), ("pre-fec-ber", ("pre_fec_ber", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24fecs.DwdmHour24fec.PreFecBer)), ("post-fec-ber", ("post_fec_ber", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24fecs.DwdmHour24fec.PostFecBer)), ("q", ("q", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24fecs.DwdmHour24fec.Q)), ("qmargin", ("qmargin", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24fecs.DwdmHour24fec.Qmargin))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                        ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                    ])
                                    self.number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear24_hr_time = None
                                    self.sec30_support = None

                                    self.ec_bits = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24fecs.DwdmHour24fec.EcBits()
                                    self.ec_bits.parent = self
                                    self._children_name_map["ec_bits"] = "ec-bits"

                                    self.uc_words = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24fecs.DwdmHour24fec.UcWords()
                                    self.uc_words.parent = self
                                    self._children_name_map["uc_words"] = "uc-words"

                                    self.pre_fec_ber = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24fecs.DwdmHour24fec.PreFecBer()
                                    self.pre_fec_ber.parent = self
                                    self._children_name_map["pre_fec_ber"] = "pre-fec-ber"

                                    self.post_fec_ber = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24fecs.DwdmHour24fec.PostFecBer()
                                    self.post_fec_ber.parent = self
                                    self._children_name_map["post_fec_ber"] = "post-fec-ber"

                                    self.q = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24fecs.DwdmHour24fec.Q()
                                    self.q.parent = self
                                    self._children_name_map["q"] = "q"

                                    self.qmargin = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24fecs.DwdmHour24fec.Qmargin()
                                    self.qmargin.parent = self
                                    self._children_name_map["qmargin"] = "qmargin"
                                    self._segment_path = lambda: "dwdm-hour24fec" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24fecs.DwdmHour24fec, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                class EcBits(Entity):
                                    """
                                    EC BITS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24fecs.DwdmHour24fec.EcBits, self).__init__()

                                        self.yang_name = "ec-bits"
                                        self.yang_parent_name = "dwdm-hour24fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ec-bits"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24fecs.DwdmHour24fec.EcBits, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class UcWords(Entity):
                                    """
                                    UC WORDS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24fecs.DwdmHour24fec.UcWords, self).__init__()

                                        self.yang_name = "uc-words"
                                        self.yang_parent_name = "dwdm-hour24fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "uc-words"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24fecs.DwdmHour24fec.UcWords, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class PreFecBer(Entity):
                                    """
                                    Pre FEC BER
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24fecs.DwdmHour24fec.PreFecBer, self).__init__()

                                        self.yang_name = "pre-fec-ber"
                                        self.yang_parent_name = "dwdm-hour24fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.maximum_tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "pre-fec-ber"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24fecs.DwdmHour24fec.PreFecBer, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                class PostFecBer(Entity):
                                    """
                                    Post FEC BER
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24fecs.DwdmHour24fec.PostFecBer, self).__init__()

                                        self.yang_name = "post-fec-ber"
                                        self.yang_parent_name = "dwdm-hour24fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.maximum_tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "post-fec-ber"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24fecs.DwdmHour24fec.PostFecBer, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                class Q(Entity):
                                    """
                                    Q
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24fecs.DwdmHour24fec.Q, self).__init__()

                                        self.yang_name = "q"
                                        self.yang_parent_name = "dwdm-hour24fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.maximum_tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "q"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24fecs.DwdmHour24fec.Q, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                class Qmargin(Entity):
                                    """
                                    Q Margin
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24fecs.DwdmHour24fec.Qmargin, self).__init__()

                                        self.yang_name = "qmargin"
                                        self.yang_parent_name = "dwdm-hour24fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.maximum_tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "qmargin"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24fecs.DwdmHour24fec.Qmargin, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                        class DwdmHour24otns(Entity):
                            """
                            port 24 hour performance data
                            
                            .. attribute:: dwdm_hour24otn
                            
                            	port 24 hour otn performance data
                            	**type**\: list of  		 :py:class:`DwdmHour24otn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns, self).__init__()

                                self.yang_name = "dwdm-hour24otns"
                                self.yang_parent_name = "dwdm-hour24"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dwdm-hour24otn", ("dwdm_hour24otn", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn))])
                                self._leafs = OrderedDict()

                                self.dwdm_hour24otn = YList(self)
                                self._segment_path = lambda: "dwdm-hour24otns"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns, [], name, value)


                            class DwdmHour24otn(Entity):
                                """
                                port 24 hour otn performance data
                                
                                .. attribute:: number  (key)
                                
                                	channel number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lbc
                                
                                	LBC
                                	**type**\:  :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.Lbc>`
                                
                                .. attribute:: es_ne
                                
                                	ES SM NE
                                	**type**\:  :py:class:`EsNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.EsNe>`
                                
                                .. attribute:: esr_ne
                                
                                	ESR PM NE
                                	**type**\:  :py:class:`EsrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.EsrNe>`
                                
                                .. attribute:: ses_ne
                                
                                	SES SM NE
                                	**type**\:  :py:class:`SesNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.SesNe>`
                                
                                .. attribute:: sesr_ne
                                
                                	SESR SM NE
                                	**type**\:  :py:class:`SesrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.SesrNe>`
                                
                                .. attribute:: uas_ne
                                
                                	UAS SM NE
                                	**type**\:  :py:class:`UasNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.UasNe>`
                                
                                .. attribute:: bbe_ne
                                
                                	BBE SM NE
                                	**type**\:  :py:class:`BbeNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.BbeNe>`
                                
                                .. attribute:: bber_ne
                                
                                	BBER SM NE
                                	**type**\:  :py:class:`BberNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.BberNe>`
                                
                                .. attribute:: fc_ne
                                
                                	FC SM NE
                                	**type**\:  :py:class:`FcNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.FcNe>`
                                
                                .. attribute:: es_fe
                                
                                	ES SM FE
                                	**type**\:  :py:class:`EsFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.EsFe>`
                                
                                .. attribute:: esr_fe
                                
                                	ESR PM FE
                                	**type**\:  :py:class:`EsrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.EsrFe>`
                                
                                .. attribute:: ses_fe
                                
                                	SES SM FE
                                	**type**\:  :py:class:`SesFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.SesFe>`
                                
                                .. attribute:: sesr_fe
                                
                                	SESR SM FE
                                	**type**\:  :py:class:`SesrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.SesrFe>`
                                
                                .. attribute:: uas_fe
                                
                                	UAS SM FE
                                	**type**\:  :py:class:`UasFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.UasFe>`
                                
                                .. attribute:: bbe_fe
                                
                                	BBE SM FE
                                	**type**\:  :py:class:`BbeFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.BbeFe>`
                                
                                .. attribute:: bber_fe
                                
                                	BBER SM FE
                                	**type**\:  :py:class:`BberFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.BberFe>`
                                
                                .. attribute:: fc_fe
                                
                                	FC SM FE
                                	**type**\:  :py:class:`FcFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.FcFe>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn, self).__init__()

                                    self.yang_name = "dwdm-hour24otn"
                                    self.yang_parent_name = "dwdm-hour24otns"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("lbc", ("lbc", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.Lbc)), ("es-ne", ("es_ne", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.EsNe)), ("esr-ne", ("esr_ne", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.EsrNe)), ("ses-ne", ("ses_ne", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.SesNe)), ("sesr-ne", ("sesr_ne", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.SesrNe)), ("uas-ne", ("uas_ne", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.UasNe)), ("bbe-ne", ("bbe_ne", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.BbeNe)), ("bber-ne", ("bber_ne", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.BberNe)), ("fc-ne", ("fc_ne", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.FcNe)), ("es-fe", ("es_fe", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.EsFe)), ("esr-fe", ("esr_fe", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.EsrFe)), ("ses-fe", ("ses_fe", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.SesFe)), ("sesr-fe", ("sesr_fe", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.SesrFe)), ("uas-fe", ("uas_fe", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.UasFe)), ("bbe-fe", ("bbe_fe", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.BbeFe)), ("bber-fe", ("bber_fe", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.BberFe)), ("fc-fe", ("fc_fe", PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.FcFe))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                        ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                    ])
                                    self.number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear24_hr_time = None
                                    self.sec30_support = None

                                    self.lbc = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.Lbc()
                                    self.lbc.parent = self
                                    self._children_name_map["lbc"] = "lbc"

                                    self.es_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.EsNe()
                                    self.es_ne.parent = self
                                    self._children_name_map["es_ne"] = "es-ne"

                                    self.esr_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.EsrNe()
                                    self.esr_ne.parent = self
                                    self._children_name_map["esr_ne"] = "esr-ne"

                                    self.ses_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.SesNe()
                                    self.ses_ne.parent = self
                                    self._children_name_map["ses_ne"] = "ses-ne"

                                    self.sesr_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.SesrNe()
                                    self.sesr_ne.parent = self
                                    self._children_name_map["sesr_ne"] = "sesr-ne"

                                    self.uas_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.UasNe()
                                    self.uas_ne.parent = self
                                    self._children_name_map["uas_ne"] = "uas-ne"

                                    self.bbe_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.BbeNe()
                                    self.bbe_ne.parent = self
                                    self._children_name_map["bbe_ne"] = "bbe-ne"

                                    self.bber_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.BberNe()
                                    self.bber_ne.parent = self
                                    self._children_name_map["bber_ne"] = "bber-ne"

                                    self.fc_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.FcNe()
                                    self.fc_ne.parent = self
                                    self._children_name_map["fc_ne"] = "fc-ne"

                                    self.es_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.EsFe()
                                    self.es_fe.parent = self
                                    self._children_name_map["es_fe"] = "es-fe"

                                    self.esr_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.EsrFe()
                                    self.esr_fe.parent = self
                                    self._children_name_map["esr_fe"] = "esr-fe"

                                    self.ses_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.SesFe()
                                    self.ses_fe.parent = self
                                    self._children_name_map["ses_fe"] = "ses-fe"

                                    self.sesr_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.SesrFe()
                                    self.sesr_fe.parent = self
                                    self._children_name_map["sesr_fe"] = "sesr-fe"

                                    self.uas_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.UasFe()
                                    self.uas_fe.parent = self
                                    self._children_name_map["uas_fe"] = "uas-fe"

                                    self.bbe_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.BbeFe()
                                    self.bbe_fe.parent = self
                                    self._children_name_map["bbe_fe"] = "bbe-fe"

                                    self.bber_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.BberFe()
                                    self.bber_fe.parent = self
                                    self._children_name_map["bber_fe"] = "bber-fe"

                                    self.fc_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.FcFe()
                                    self.fc_fe.parent = self
                                    self._children_name_map["fc_fe"] = "fc-fe"
                                    self._segment_path = lambda: "dwdm-hour24otn" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                class Lbc(Entity):
                                    """
                                    LBC
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.Lbc, self).__init__()

                                        self.yang_name = "lbc"
                                        self.yang_parent_name = "dwdm-hour24otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "lbc"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.Lbc, ['data', 'threshold', 'tca_report'], name, value)


                                class EsNe(Entity):
                                    """
                                    ES SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.EsNe, self).__init__()

                                        self.yang_name = "es-ne"
                                        self.yang_parent_name = "dwdm-hour24otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "es-ne"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.EsNe, ['data', 'threshold', 'tca_report'], name, value)


                                class EsrNe(Entity):
                                    """
                                    ESR PM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: str
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.EsrNe, self).__init__()

                                        self.yang_name = "esr-ne"
                                        self.yang_parent_name = "dwdm-hour24otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "esr-ne"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.EsrNe, ['data', 'threshold', 'tca_report'], name, value)


                                class SesNe(Entity):
                                    """
                                    SES SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.SesNe, self).__init__()

                                        self.yang_name = "ses-ne"
                                        self.yang_parent_name = "dwdm-hour24otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "ses-ne"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.SesNe, ['data', 'threshold', 'tca_report'], name, value)


                                class SesrNe(Entity):
                                    """
                                    SESR SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: str
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.SesrNe, self).__init__()

                                        self.yang_name = "sesr-ne"
                                        self.yang_parent_name = "dwdm-hour24otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "sesr-ne"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.SesrNe, ['data', 'threshold', 'tca_report'], name, value)


                                class UasNe(Entity):
                                    """
                                    UAS SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.UasNe, self).__init__()

                                        self.yang_name = "uas-ne"
                                        self.yang_parent_name = "dwdm-hour24otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "uas-ne"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.UasNe, ['data', 'threshold', 'tca_report'], name, value)


                                class BbeNe(Entity):
                                    """
                                    BBE SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.BbeNe, self).__init__()

                                        self.yang_name = "bbe-ne"
                                        self.yang_parent_name = "dwdm-hour24otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "bbe-ne"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.BbeNe, ['data', 'threshold', 'tca_report'], name, value)


                                class BberNe(Entity):
                                    """
                                    BBER SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: str
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.BberNe, self).__init__()

                                        self.yang_name = "bber-ne"
                                        self.yang_parent_name = "dwdm-hour24otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "bber-ne"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.BberNe, ['data', 'threshold', 'tca_report'], name, value)


                                class FcNe(Entity):
                                    """
                                    FC SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.FcNe, self).__init__()

                                        self.yang_name = "fc-ne"
                                        self.yang_parent_name = "dwdm-hour24otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "fc-ne"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.FcNe, ['data', 'threshold', 'tca_report'], name, value)


                                class EsFe(Entity):
                                    """
                                    ES SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.EsFe, self).__init__()

                                        self.yang_name = "es-fe"
                                        self.yang_parent_name = "dwdm-hour24otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "es-fe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.EsFe, ['data', 'threshold', 'tca_report'], name, value)


                                class EsrFe(Entity):
                                    """
                                    ESR PM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: str
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.EsrFe, self).__init__()

                                        self.yang_name = "esr-fe"
                                        self.yang_parent_name = "dwdm-hour24otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "esr-fe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.EsrFe, ['data', 'threshold', 'tca_report'], name, value)


                                class SesFe(Entity):
                                    """
                                    SES SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.SesFe, self).__init__()

                                        self.yang_name = "ses-fe"
                                        self.yang_parent_name = "dwdm-hour24otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "ses-fe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.SesFe, ['data', 'threshold', 'tca_report'], name, value)


                                class SesrFe(Entity):
                                    """
                                    SESR SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: str
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.SesrFe, self).__init__()

                                        self.yang_name = "sesr-fe"
                                        self.yang_parent_name = "dwdm-hour24otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "sesr-fe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.SesrFe, ['data', 'threshold', 'tca_report'], name, value)


                                class UasFe(Entity):
                                    """
                                    UAS SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.UasFe, self).__init__()

                                        self.yang_name = "uas-fe"
                                        self.yang_parent_name = "dwdm-hour24otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "uas-fe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.UasFe, ['data', 'threshold', 'tca_report'], name, value)


                                class BbeFe(Entity):
                                    """
                                    BBE SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.BbeFe, self).__init__()

                                        self.yang_name = "bbe-fe"
                                        self.yang_parent_name = "dwdm-hour24otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "bbe-fe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.BbeFe, ['data', 'threshold', 'tca_report'], name, value)


                                class BberFe(Entity):
                                    """
                                    BBER SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: str
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.BberFe, self).__init__()

                                        self.yang_name = "bber-fe"
                                        self.yang_parent_name = "dwdm-hour24otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "bber-fe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.BberFe, ['data', 'threshold', 'tca_report'], name, value)


                                class FcFe(Entity):
                                    """
                                    FC SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.FcFe, self).__init__()

                                        self.yang_name = "fc-fe"
                                        self.yang_parent_name = "dwdm-hour24otn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "fc-fe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24otns.DwdmHour24otn.FcFe, ['data', 'threshold', 'tca_report'], name, value)


    class Oc(Entity):
        """
        OC controller performance data
        
        .. attribute:: oc_ports
        
        	Port performance data
        	**type**\:  :py:class:`OcPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts>`
        
        

        """

        _prefix = 'pmengine-oper'
        _revision = '2017-09-07'

        def __init__(self):
            super(PerformanceManagement.Oc, self).__init__()

            self.yang_name = "oc"
            self.yang_parent_name = "performance-management"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("oc-ports", ("oc_ports", PerformanceManagement.Oc.OcPorts))])
            self._leafs = OrderedDict()

            self.oc_ports = PerformanceManagement.Oc.OcPorts()
            self.oc_ports.parent = self
            self._children_name_map["oc_ports"] = "oc-ports"
            self._segment_path = lambda: "oc"
            self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(PerformanceManagement.Oc, [], name, value)


        class OcPorts(Entity):
            """
            Port performance data
            
            .. attribute:: oc_port
            
            	Port performance data
            	**type**\: list of  		 :py:class:`OcPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort>`
            
            

            """

            _prefix = 'pmengine-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(PerformanceManagement.Oc.OcPorts, self).__init__()

                self.yang_name = "oc-ports"
                self.yang_parent_name = "oc"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("oc-port", ("oc_port", PerformanceManagement.Oc.OcPorts.OcPort))])
                self._leafs = OrderedDict()

                self.oc_port = YList(self)
                self._segment_path = lambda: "oc-ports"
                self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management/oc/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(PerformanceManagement.Oc.OcPorts, [], name, value)


            class OcPort(Entity):
                """
                Port performance data
                
                .. attribute:: name  (key)
                
                	Port name
                	**type**\: str
                
                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                
                .. attribute:: oc_current
                
                	port current performance data
                	**type**\:  :py:class:`OcCurrent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(PerformanceManagement.Oc.OcPorts.OcPort, self).__init__()

                    self.yang_name = "oc-port"
                    self.yang_parent_name = "oc-ports"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("oc-current", ("oc_current", PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ])
                    self.name = None

                    self.oc_current = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent()
                    self.oc_current.parent = self
                    self._children_name_map["oc_current"] = "oc-current"
                    self._segment_path = lambda: "oc-port" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management/oc/oc-ports/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(PerformanceManagement.Oc.OcPorts.OcPort, ['name'], name, value)


                class OcCurrent(Entity):
                    """
                    port current performance data
                    
                    .. attribute:: oc_hour24
                    
                    	port current performance data
                    	**type**\:  :py:class:`OcHour24 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24>`
                    
                    .. attribute:: oc_minute15
                    
                    	port current performance data
                    	**type**\:  :py:class:`OcMinute15 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent, self).__init__()

                        self.yang_name = "oc-current"
                        self.yang_parent_name = "oc-port"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("oc-hour24", ("oc_hour24", PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24)), ("oc-minute15", ("oc_minute15", PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15))])
                        self._leafs = OrderedDict()

                        self.oc_hour24 = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24()
                        self.oc_hour24.parent = self
                        self._children_name_map["oc_hour24"] = "oc-hour24"

                        self.oc_minute15 = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15()
                        self.oc_minute15.parent = self
                        self._children_name_map["oc_minute15"] = "oc-minute15"
                        self._segment_path = lambda: "oc-current"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent, [], name, value)


                    class OcHour24(Entity):
                        """
                        port current performance data
                        
                        .. attribute:: oc_hour24ocns
                        
                        	port current performance data
                        	**type**\:  :py:class:`OcHour24ocns <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24, self).__init__()

                            self.yang_name = "oc-hour24"
                            self.yang_parent_name = "oc-current"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("oc-hour24ocns", ("oc_hour24ocns", PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns))])
                            self._leafs = OrderedDict()

                            self.oc_hour24ocns = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns()
                            self.oc_hour24ocns.parent = self
                            self._children_name_map["oc_hour24ocns"] = "oc-hour24ocns"
                            self._segment_path = lambda: "oc-hour24"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24, [], name, value)


                        class OcHour24ocns(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: oc_hour24ocn
                            
                            	port 24 hour ocn performance data
                            	**type**\: list of  		 :py:class:`OcHour24ocn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns, self).__init__()

                                self.yang_name = "oc-hour24ocns"
                                self.yang_parent_name = "oc-hour24"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("oc-hour24ocn", ("oc_hour24ocn", PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn))])
                                self._leafs = OrderedDict()

                                self.oc_hour24ocn = YList(self)
                                self._segment_path = lambda: "oc-hour24ocns"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns, [], name, value)


                            class OcHour24ocn(Entity):
                                """
                                port 24 hour ocn performance data
                                
                                .. attribute:: number  (key)
                                
                                	channel number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: section
                                
                                	SECTION
                                	**type**\:  :py:class:`Section <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.Section>`
                                
                                .. attribute:: line
                                
                                	LINE
                                	**type**\:  :py:class:`Line <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.Line>`
                                
                                .. attribute:: fe_line
                                
                                	FarEnd LINE
                                	**type**\:  :py:class:`FeLine <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.FeLine>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn, self).__init__()

                                    self.yang_name = "oc-hour24ocn"
                                    self.yang_parent_name = "oc-hour24ocns"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("section", ("section", PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.Section)), ("line", ("line", PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.Line)), ("fe-line", ("fe_line", PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.FeLine))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                    ])
                                    self.number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None

                                    self.section = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.Section()
                                    self.section.parent = self
                                    self._children_name_map["section"] = "section"

                                    self.line = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.Line()
                                    self.line.parent = self
                                    self._children_name_map["line"] = "line"

                                    self.fe_line = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.FeLine()
                                    self.fe_line.parent = self
                                    self._children_name_map["fe_line"] = "fe-line"
                                    self._segment_path = lambda: "oc-hour24ocn" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear24_hr_time'], name, value)


                                class Section(Entity):
                                    """
                                    SECTION
                                    
                                    .. attribute:: section_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:  :py:class:`SectionESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.Section.SectionESs>`
                                    
                                    .. attribute:: section_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:  :py:class:`SectionSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.Section.SectionSeSs>`
                                    
                                    .. attribute:: section_sef_ss
                                    
                                    	The number of Severely Errored Framing Seconds
                                    	**type**\:  :py:class:`SectionSefSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.Section.SectionSefSs>`
                                    
                                    .. attribute:: section_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:  :py:class:`SectionCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.Section.SectionCVs>`
                                    
                                    .. attribute:: section_status
                                    
                                    	 status of the interface
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.Section, self).__init__()

                                        self.yang_name = "section"
                                        self.yang_parent_name = "oc-hour24ocn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("section-e-ss", ("section_e_ss", PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.Section.SectionESs)), ("section-se-ss", ("section_se_ss", PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.Section.SectionSeSs)), ("section-sef-ss", ("section_sef_ss", PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.Section.SectionSefSs)), ("section-c-vs", ("section_c_vs", PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.Section.SectionCVs))])
                                        self._leafs = OrderedDict([
                                            ('section_status', (YLeaf(YType.int32, 'section-status'), ['int'])),
                                        ])
                                        self.section_status = None

                                        self.section_e_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.Section.SectionESs()
                                        self.section_e_ss.parent = self
                                        self._children_name_map["section_e_ss"] = "section-e-ss"

                                        self.section_se_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.Section.SectionSeSs()
                                        self.section_se_ss.parent = self
                                        self._children_name_map["section_se_ss"] = "section-se-ss"

                                        self.section_sef_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.Section.SectionSefSs()
                                        self.section_sef_ss.parent = self
                                        self._children_name_map["section_sef_ss"] = "section-sef-ss"

                                        self.section_c_vs = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.Section.SectionCVs()
                                        self.section_c_vs.parent = self
                                        self._children_name_map["section_c_vs"] = "section-c-vs"
                                        self._segment_path = lambda: "section"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.Section, ['section_status'], name, value)


                                    class SectionESs(Entity):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.Section.SectionESs, self).__init__()

                                            self.yang_name = "section-e-ss"
                                            self.yang_parent_name = "section"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "section-e-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.Section.SectionESs, ['data', 'threshold', 'tca_report'], name, value)


                                    class SectionSeSs(Entity):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.Section.SectionSeSs, self).__init__()

                                            self.yang_name = "section-se-ss"
                                            self.yang_parent_name = "section"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "section-se-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.Section.SectionSeSs, ['data', 'threshold', 'tca_report'], name, value)


                                    class SectionSefSs(Entity):
                                        """
                                        The number of Severely Errored Framing Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.Section.SectionSefSs, self).__init__()

                                            self.yang_name = "section-sef-ss"
                                            self.yang_parent_name = "section"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "section-sef-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.Section.SectionSefSs, ['data', 'threshold', 'tca_report'], name, value)


                                    class SectionCVs(Entity):
                                        """
                                        The number of Coding Violations
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.Section.SectionCVs, self).__init__()

                                            self.yang_name = "section-c-vs"
                                            self.yang_parent_name = "section"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "section-c-vs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.Section.SectionCVs, ['data', 'threshold', 'tca_report'], name, value)


                                class Line(Entity):
                                    """
                                    LINE
                                    
                                    .. attribute:: line_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:  :py:class:`LineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.Line.LineESs>`
                                    
                                    .. attribute:: line_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:  :py:class:`LineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.Line.LineSeSs>`
                                    
                                    .. attribute:: line_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:  :py:class:`LineCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.Line.LineCVs>`
                                    
                                    .. attribute:: line_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\:  :py:class:`LineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.Line.LineUaSs>`
                                    
                                    .. attribute:: line_fc_ls
                                    
                                    	The number of Failure counts Seconds
                                    	**type**\:  :py:class:`LineFcLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.Line.LineFcLs>`
                                    
                                    .. attribute:: line_status
                                    
                                    	 status of the interface
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.Line, self).__init__()

                                        self.yang_name = "line"
                                        self.yang_parent_name = "oc-hour24ocn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("line-e-ss", ("line_e_ss", PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.Line.LineESs)), ("line-se-ss", ("line_se_ss", PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.Line.LineSeSs)), ("line-c-vs", ("line_c_vs", PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.Line.LineCVs)), ("line-ua-ss", ("line_ua_ss", PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.Line.LineUaSs)), ("line-fc-ls", ("line_fc_ls", PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.Line.LineFcLs))])
                                        self._leafs = OrderedDict([
                                            ('line_status', (YLeaf(YType.int32, 'line-status'), ['int'])),
                                        ])
                                        self.line_status = None

                                        self.line_e_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.Line.LineESs()
                                        self.line_e_ss.parent = self
                                        self._children_name_map["line_e_ss"] = "line-e-ss"

                                        self.line_se_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.Line.LineSeSs()
                                        self.line_se_ss.parent = self
                                        self._children_name_map["line_se_ss"] = "line-se-ss"

                                        self.line_c_vs = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.Line.LineCVs()
                                        self.line_c_vs.parent = self
                                        self._children_name_map["line_c_vs"] = "line-c-vs"

                                        self.line_ua_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.Line.LineUaSs()
                                        self.line_ua_ss.parent = self
                                        self._children_name_map["line_ua_ss"] = "line-ua-ss"

                                        self.line_fc_ls = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.Line.LineFcLs()
                                        self.line_fc_ls.parent = self
                                        self._children_name_map["line_fc_ls"] = "line-fc-ls"
                                        self._segment_path = lambda: "line"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.Line, ['line_status'], name, value)


                                    class LineESs(Entity):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.Line.LineESs, self).__init__()

                                            self.yang_name = "line-e-ss"
                                            self.yang_parent_name = "line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "line-e-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.Line.LineESs, ['data', 'threshold', 'tca_report'], name, value)


                                    class LineSeSs(Entity):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.Line.LineSeSs, self).__init__()

                                            self.yang_name = "line-se-ss"
                                            self.yang_parent_name = "line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "line-se-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.Line.LineSeSs, ['data', 'threshold', 'tca_report'], name, value)


                                    class LineCVs(Entity):
                                        """
                                        The number of Coding Violations
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.Line.LineCVs, self).__init__()

                                            self.yang_name = "line-c-vs"
                                            self.yang_parent_name = "line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "line-c-vs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.Line.LineCVs, ['data', 'threshold', 'tca_report'], name, value)


                                    class LineUaSs(Entity):
                                        """
                                        The number of Unavailable Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.Line.LineUaSs, self).__init__()

                                            self.yang_name = "line-ua-ss"
                                            self.yang_parent_name = "line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "line-ua-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.Line.LineUaSs, ['data', 'threshold', 'tca_report'], name, value)


                                    class LineFcLs(Entity):
                                        """
                                        The number of Failure counts Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.Line.LineFcLs, self).__init__()

                                            self.yang_name = "line-fc-ls"
                                            self.yang_parent_name = "line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "line-fc-ls"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.Line.LineFcLs, ['data', 'threshold', 'tca_report'], name, value)


                                class FeLine(Entity):
                                    """
                                    FarEnd LINE
                                    
                                    .. attribute:: far_end_line_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:  :py:class:`FarEndLineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.FeLine.FarEndLineESs>`
                                    
                                    .. attribute:: far_end_line_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:  :py:class:`FarEndLineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.FeLine.FarEndLineSeSs>`
                                    
                                    .. attribute:: far_end_line_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:  :py:class:`FarEndLineCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.FeLine.FarEndLineCVs>`
                                    
                                    .. attribute:: far_end_line_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\:  :py:class:`FarEndLineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.FeLine.FarEndLineUaSs>`
                                    
                                    .. attribute:: far_end_line_fc_ls
                                    
                                    	The number of Failure counts Seconds
                                    	**type**\:  :py:class:`FarEndLineFcLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.FeLine.FarEndLineFcLs>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.FeLine, self).__init__()

                                        self.yang_name = "fe-line"
                                        self.yang_parent_name = "oc-hour24ocn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("far-end-line-e-ss", ("far_end_line_e_ss", PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.FeLine.FarEndLineESs)), ("far-end-line-se-ss", ("far_end_line_se_ss", PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.FeLine.FarEndLineSeSs)), ("far-end-line-c-vs", ("far_end_line_c_vs", PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.FeLine.FarEndLineCVs)), ("far-end-line-ua-ss", ("far_end_line_ua_ss", PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.FeLine.FarEndLineUaSs)), ("far-end-line-fc-ls", ("far_end_line_fc_ls", PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.FeLine.FarEndLineFcLs))])
                                        self._leafs = OrderedDict()

                                        self.far_end_line_e_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.FeLine.FarEndLineESs()
                                        self.far_end_line_e_ss.parent = self
                                        self._children_name_map["far_end_line_e_ss"] = "far-end-line-e-ss"

                                        self.far_end_line_se_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.FeLine.FarEndLineSeSs()
                                        self.far_end_line_se_ss.parent = self
                                        self._children_name_map["far_end_line_se_ss"] = "far-end-line-se-ss"

                                        self.far_end_line_c_vs = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.FeLine.FarEndLineCVs()
                                        self.far_end_line_c_vs.parent = self
                                        self._children_name_map["far_end_line_c_vs"] = "far-end-line-c-vs"

                                        self.far_end_line_ua_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.FeLine.FarEndLineUaSs()
                                        self.far_end_line_ua_ss.parent = self
                                        self._children_name_map["far_end_line_ua_ss"] = "far-end-line-ua-ss"

                                        self.far_end_line_fc_ls = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.FeLine.FarEndLineFcLs()
                                        self.far_end_line_fc_ls.parent = self
                                        self._children_name_map["far_end_line_fc_ls"] = "far-end-line-fc-ls"
                                        self._segment_path = lambda: "fe-line"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.FeLine, [], name, value)


                                    class FarEndLineESs(Entity):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.FeLine.FarEndLineESs, self).__init__()

                                            self.yang_name = "far-end-line-e-ss"
                                            self.yang_parent_name = "fe-line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "far-end-line-e-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.FeLine.FarEndLineESs, ['data', 'threshold', 'tca_report'], name, value)


                                    class FarEndLineSeSs(Entity):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.FeLine.FarEndLineSeSs, self).__init__()

                                            self.yang_name = "far-end-line-se-ss"
                                            self.yang_parent_name = "fe-line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "far-end-line-se-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.FeLine.FarEndLineSeSs, ['data', 'threshold', 'tca_report'], name, value)


                                    class FarEndLineCVs(Entity):
                                        """
                                        The number of Coding Violations
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.FeLine.FarEndLineCVs, self).__init__()

                                            self.yang_name = "far-end-line-c-vs"
                                            self.yang_parent_name = "fe-line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "far-end-line-c-vs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.FeLine.FarEndLineCVs, ['data', 'threshold', 'tca_report'], name, value)


                                    class FarEndLineUaSs(Entity):
                                        """
                                        The number of Unavailable Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.FeLine.FarEndLineUaSs, self).__init__()

                                            self.yang_name = "far-end-line-ua-ss"
                                            self.yang_parent_name = "fe-line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "far-end-line-ua-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.FeLine.FarEndLineUaSs, ['data', 'threshold', 'tca_report'], name, value)


                                    class FarEndLineFcLs(Entity):
                                        """
                                        The number of Failure counts Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.FeLine.FarEndLineFcLs, self).__init__()

                                            self.yang_name = "far-end-line-fc-ls"
                                            self.yang_parent_name = "fe-line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "far-end-line-fc-ls"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24ocns.OcHour24ocn.FeLine.FarEndLineFcLs, ['data', 'threshold', 'tca_report'], name, value)


                    class OcMinute15(Entity):
                        """
                        port current performance data
                        
                        .. attribute:: oc_minute15ocns
                        
                        	port current performance data
                        	**type**\:  :py:class:`OcMinute15ocns <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15, self).__init__()

                            self.yang_name = "oc-minute15"
                            self.yang_parent_name = "oc-current"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("oc-minute15ocns", ("oc_minute15ocns", PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns))])
                            self._leafs = OrderedDict()

                            self.oc_minute15ocns = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns()
                            self.oc_minute15ocns.parent = self
                            self._children_name_map["oc_minute15ocns"] = "oc-minute15ocns"
                            self._segment_path = lambda: "oc-minute15"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15, [], name, value)


                        class OcMinute15ocns(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: oc_minute15ocn
                            
                            	port 15\-minute ocn performance data
                            	**type**\: list of  		 :py:class:`OcMinute15ocn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns, self).__init__()

                                self.yang_name = "oc-minute15ocns"
                                self.yang_parent_name = "oc-minute15"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("oc-minute15ocn", ("oc_minute15ocn", PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn))])
                                self._leafs = OrderedDict()

                                self.oc_minute15ocn = YList(self)
                                self._segment_path = lambda: "oc-minute15ocns"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns, [], name, value)


                            class OcMinute15ocn(Entity):
                                """
                                port 15\-minute ocn performance data
                                
                                .. attribute:: number  (key)
                                
                                	channel number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: section
                                
                                	SECTION
                                	**type**\:  :py:class:`Section <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.Section>`
                                
                                .. attribute:: line
                                
                                	LINE
                                	**type**\:  :py:class:`Line <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.Line>`
                                
                                .. attribute:: fe_line
                                
                                	FarEnd LINE
                                	**type**\:  :py:class:`FeLine <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.FeLine>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn, self).__init__()

                                    self.yang_name = "oc-minute15ocn"
                                    self.yang_parent_name = "oc-minute15ocns"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("section", ("section", PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.Section)), ("line", ("line", PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.Line)), ("fe-line", ("fe_line", PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.FeLine))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                    ])
                                    self.number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None

                                    self.section = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.Section()
                                    self.section.parent = self
                                    self._children_name_map["section"] = "section"

                                    self.line = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.Line()
                                    self.line.parent = self
                                    self._children_name_map["line"] = "line"

                                    self.fe_line = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.FeLine()
                                    self.fe_line.parent = self
                                    self._children_name_map["fe_line"] = "fe-line"
                                    self._segment_path = lambda: "oc-minute15ocn" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear24_hr_time'], name, value)


                                class Section(Entity):
                                    """
                                    SECTION
                                    
                                    .. attribute:: section_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:  :py:class:`SectionESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.Section.SectionESs>`
                                    
                                    .. attribute:: section_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:  :py:class:`SectionSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.Section.SectionSeSs>`
                                    
                                    .. attribute:: section_sef_ss
                                    
                                    	The number of Severely Errored Framing Seconds
                                    	**type**\:  :py:class:`SectionSefSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.Section.SectionSefSs>`
                                    
                                    .. attribute:: section_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:  :py:class:`SectionCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.Section.SectionCVs>`
                                    
                                    .. attribute:: section_status
                                    
                                    	 status of the interface
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.Section, self).__init__()

                                        self.yang_name = "section"
                                        self.yang_parent_name = "oc-minute15ocn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("section-e-ss", ("section_e_ss", PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.Section.SectionESs)), ("section-se-ss", ("section_se_ss", PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.Section.SectionSeSs)), ("section-sef-ss", ("section_sef_ss", PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.Section.SectionSefSs)), ("section-c-vs", ("section_c_vs", PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.Section.SectionCVs))])
                                        self._leafs = OrderedDict([
                                            ('section_status', (YLeaf(YType.int32, 'section-status'), ['int'])),
                                        ])
                                        self.section_status = None

                                        self.section_e_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.Section.SectionESs()
                                        self.section_e_ss.parent = self
                                        self._children_name_map["section_e_ss"] = "section-e-ss"

                                        self.section_se_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.Section.SectionSeSs()
                                        self.section_se_ss.parent = self
                                        self._children_name_map["section_se_ss"] = "section-se-ss"

                                        self.section_sef_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.Section.SectionSefSs()
                                        self.section_sef_ss.parent = self
                                        self._children_name_map["section_sef_ss"] = "section-sef-ss"

                                        self.section_c_vs = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.Section.SectionCVs()
                                        self.section_c_vs.parent = self
                                        self._children_name_map["section_c_vs"] = "section-c-vs"
                                        self._segment_path = lambda: "section"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.Section, ['section_status'], name, value)


                                    class SectionESs(Entity):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.Section.SectionESs, self).__init__()

                                            self.yang_name = "section-e-ss"
                                            self.yang_parent_name = "section"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "section-e-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.Section.SectionESs, ['data', 'threshold', 'tca_report'], name, value)


                                    class SectionSeSs(Entity):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.Section.SectionSeSs, self).__init__()

                                            self.yang_name = "section-se-ss"
                                            self.yang_parent_name = "section"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "section-se-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.Section.SectionSeSs, ['data', 'threshold', 'tca_report'], name, value)


                                    class SectionSefSs(Entity):
                                        """
                                        The number of Severely Errored Framing Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.Section.SectionSefSs, self).__init__()

                                            self.yang_name = "section-sef-ss"
                                            self.yang_parent_name = "section"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "section-sef-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.Section.SectionSefSs, ['data', 'threshold', 'tca_report'], name, value)


                                    class SectionCVs(Entity):
                                        """
                                        The number of Coding Violations
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.Section.SectionCVs, self).__init__()

                                            self.yang_name = "section-c-vs"
                                            self.yang_parent_name = "section"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "section-c-vs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.Section.SectionCVs, ['data', 'threshold', 'tca_report'], name, value)


                                class Line(Entity):
                                    """
                                    LINE
                                    
                                    .. attribute:: line_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:  :py:class:`LineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.Line.LineESs>`
                                    
                                    .. attribute:: line_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:  :py:class:`LineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.Line.LineSeSs>`
                                    
                                    .. attribute:: line_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:  :py:class:`LineCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.Line.LineCVs>`
                                    
                                    .. attribute:: line_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\:  :py:class:`LineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.Line.LineUaSs>`
                                    
                                    .. attribute:: line_fc_ls
                                    
                                    	The number of Failure counts Seconds
                                    	**type**\:  :py:class:`LineFcLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.Line.LineFcLs>`
                                    
                                    .. attribute:: line_status
                                    
                                    	 status of the interface
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.Line, self).__init__()

                                        self.yang_name = "line"
                                        self.yang_parent_name = "oc-minute15ocn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("line-e-ss", ("line_e_ss", PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.Line.LineESs)), ("line-se-ss", ("line_se_ss", PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.Line.LineSeSs)), ("line-c-vs", ("line_c_vs", PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.Line.LineCVs)), ("line-ua-ss", ("line_ua_ss", PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.Line.LineUaSs)), ("line-fc-ls", ("line_fc_ls", PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.Line.LineFcLs))])
                                        self._leafs = OrderedDict([
                                            ('line_status', (YLeaf(YType.int32, 'line-status'), ['int'])),
                                        ])
                                        self.line_status = None

                                        self.line_e_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.Line.LineESs()
                                        self.line_e_ss.parent = self
                                        self._children_name_map["line_e_ss"] = "line-e-ss"

                                        self.line_se_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.Line.LineSeSs()
                                        self.line_se_ss.parent = self
                                        self._children_name_map["line_se_ss"] = "line-se-ss"

                                        self.line_c_vs = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.Line.LineCVs()
                                        self.line_c_vs.parent = self
                                        self._children_name_map["line_c_vs"] = "line-c-vs"

                                        self.line_ua_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.Line.LineUaSs()
                                        self.line_ua_ss.parent = self
                                        self._children_name_map["line_ua_ss"] = "line-ua-ss"

                                        self.line_fc_ls = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.Line.LineFcLs()
                                        self.line_fc_ls.parent = self
                                        self._children_name_map["line_fc_ls"] = "line-fc-ls"
                                        self._segment_path = lambda: "line"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.Line, ['line_status'], name, value)


                                    class LineESs(Entity):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.Line.LineESs, self).__init__()

                                            self.yang_name = "line-e-ss"
                                            self.yang_parent_name = "line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "line-e-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.Line.LineESs, ['data', 'threshold', 'tca_report'], name, value)


                                    class LineSeSs(Entity):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.Line.LineSeSs, self).__init__()

                                            self.yang_name = "line-se-ss"
                                            self.yang_parent_name = "line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "line-se-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.Line.LineSeSs, ['data', 'threshold', 'tca_report'], name, value)


                                    class LineCVs(Entity):
                                        """
                                        The number of Coding Violations
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.Line.LineCVs, self).__init__()

                                            self.yang_name = "line-c-vs"
                                            self.yang_parent_name = "line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "line-c-vs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.Line.LineCVs, ['data', 'threshold', 'tca_report'], name, value)


                                    class LineUaSs(Entity):
                                        """
                                        The number of Unavailable Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.Line.LineUaSs, self).__init__()

                                            self.yang_name = "line-ua-ss"
                                            self.yang_parent_name = "line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "line-ua-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.Line.LineUaSs, ['data', 'threshold', 'tca_report'], name, value)


                                    class LineFcLs(Entity):
                                        """
                                        The number of Failure counts Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.Line.LineFcLs, self).__init__()

                                            self.yang_name = "line-fc-ls"
                                            self.yang_parent_name = "line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "line-fc-ls"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.Line.LineFcLs, ['data', 'threshold', 'tca_report'], name, value)


                                class FeLine(Entity):
                                    """
                                    FarEnd LINE
                                    
                                    .. attribute:: far_end_line_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:  :py:class:`FarEndLineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.FeLine.FarEndLineESs>`
                                    
                                    .. attribute:: far_end_line_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:  :py:class:`FarEndLineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.FeLine.FarEndLineSeSs>`
                                    
                                    .. attribute:: far_end_line_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:  :py:class:`FarEndLineCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.FeLine.FarEndLineCVs>`
                                    
                                    .. attribute:: far_end_line_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\:  :py:class:`FarEndLineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.FeLine.FarEndLineUaSs>`
                                    
                                    .. attribute:: far_end_line_fc_ls
                                    
                                    	The number of Failure counts Seconds
                                    	**type**\:  :py:class:`FarEndLineFcLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.FeLine.FarEndLineFcLs>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.FeLine, self).__init__()

                                        self.yang_name = "fe-line"
                                        self.yang_parent_name = "oc-minute15ocn"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("far-end-line-e-ss", ("far_end_line_e_ss", PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.FeLine.FarEndLineESs)), ("far-end-line-se-ss", ("far_end_line_se_ss", PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.FeLine.FarEndLineSeSs)), ("far-end-line-c-vs", ("far_end_line_c_vs", PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.FeLine.FarEndLineCVs)), ("far-end-line-ua-ss", ("far_end_line_ua_ss", PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.FeLine.FarEndLineUaSs)), ("far-end-line-fc-ls", ("far_end_line_fc_ls", PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.FeLine.FarEndLineFcLs))])
                                        self._leafs = OrderedDict()

                                        self.far_end_line_e_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.FeLine.FarEndLineESs()
                                        self.far_end_line_e_ss.parent = self
                                        self._children_name_map["far_end_line_e_ss"] = "far-end-line-e-ss"

                                        self.far_end_line_se_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.FeLine.FarEndLineSeSs()
                                        self.far_end_line_se_ss.parent = self
                                        self._children_name_map["far_end_line_se_ss"] = "far-end-line-se-ss"

                                        self.far_end_line_c_vs = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.FeLine.FarEndLineCVs()
                                        self.far_end_line_c_vs.parent = self
                                        self._children_name_map["far_end_line_c_vs"] = "far-end-line-c-vs"

                                        self.far_end_line_ua_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.FeLine.FarEndLineUaSs()
                                        self.far_end_line_ua_ss.parent = self
                                        self._children_name_map["far_end_line_ua_ss"] = "far-end-line-ua-ss"

                                        self.far_end_line_fc_ls = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.FeLine.FarEndLineFcLs()
                                        self.far_end_line_fc_ls.parent = self
                                        self._children_name_map["far_end_line_fc_ls"] = "far-end-line-fc-ls"
                                        self._segment_path = lambda: "fe-line"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.FeLine, [], name, value)


                                    class FarEndLineESs(Entity):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.FeLine.FarEndLineESs, self).__init__()

                                            self.yang_name = "far-end-line-e-ss"
                                            self.yang_parent_name = "fe-line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "far-end-line-e-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.FeLine.FarEndLineESs, ['data', 'threshold', 'tca_report'], name, value)


                                    class FarEndLineSeSs(Entity):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.FeLine.FarEndLineSeSs, self).__init__()

                                            self.yang_name = "far-end-line-se-ss"
                                            self.yang_parent_name = "fe-line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "far-end-line-se-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.FeLine.FarEndLineSeSs, ['data', 'threshold', 'tca_report'], name, value)


                                    class FarEndLineCVs(Entity):
                                        """
                                        The number of Coding Violations
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.FeLine.FarEndLineCVs, self).__init__()

                                            self.yang_name = "far-end-line-c-vs"
                                            self.yang_parent_name = "fe-line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "far-end-line-c-vs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.FeLine.FarEndLineCVs, ['data', 'threshold', 'tca_report'], name, value)


                                    class FarEndLineUaSs(Entity):
                                        """
                                        The number of Unavailable Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.FeLine.FarEndLineUaSs, self).__init__()

                                            self.yang_name = "far-end-line-ua-ss"
                                            self.yang_parent_name = "fe-line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "far-end-line-ua-ss"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.FeLine.FarEndLineUaSs, ['data', 'threshold', 'tca_report'], name, value)


                                    class FarEndLineFcLs(Entity):
                                        """
                                        The number of Failure counts Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.FeLine.FarEndLineFcLs, self).__init__()

                                            self.yang_name = "far-end-line-fc-ls"
                                            self.yang_parent_name = "fe-line"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ])
                                            self.data = None
                                            self.threshold = None
                                            self.tca_report = None
                                            self._segment_path = lambda: "far-end-line-fc-ls"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15ocns.OcMinute15ocn.FeLine.FarEndLineFcLs, ['data', 'threshold', 'tca_report'], name, value)


    class Ethernet(Entity):
        """
        EHERNET controller performance data
        
        .. attribute:: ethernet_ports
        
        	Port performance data
        	**type**\:  :py:class:`EthernetPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts>`
        
        

        """

        _prefix = 'pmengine-oper'
        _revision = '2017-09-07'

        def __init__(self):
            super(PerformanceManagement.Ethernet, self).__init__()

            self.yang_name = "ethernet"
            self.yang_parent_name = "performance-management"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("ethernet-ports", ("ethernet_ports", PerformanceManagement.Ethernet.EthernetPorts))])
            self._leafs = OrderedDict()

            self.ethernet_ports = PerformanceManagement.Ethernet.EthernetPorts()
            self.ethernet_ports.parent = self
            self._children_name_map["ethernet_ports"] = "ethernet-ports"
            self._segment_path = lambda: "ethernet"
            self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(PerformanceManagement.Ethernet, [], name, value)


        class EthernetPorts(Entity):
            """
            Port performance data
            
            .. attribute:: ethernet_port
            
            	Port performance data
            	**type**\: list of  		 :py:class:`EthernetPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort>`
            
            

            """

            _prefix = 'pmengine-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(PerformanceManagement.Ethernet.EthernetPorts, self).__init__()

                self.yang_name = "ethernet-ports"
                self.yang_parent_name = "ethernet"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("ethernet-port", ("ethernet_port", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort))])
                self._leafs = OrderedDict()

                self.ethernet_port = YList(self)
                self._segment_path = lambda: "ethernet-ports"
                self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management/ethernet/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts, [], name, value)


            class EthernetPort(Entity):
                """
                Port performance data
                
                .. attribute:: name  (key)
                
                	Port name
                	**type**\: str
                
                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                
                .. attribute:: ethernet_current
                
                	port current performance data
                	**type**\:  :py:class:`EthernetCurrent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort, self).__init__()

                    self.yang_name = "ethernet-port"
                    self.yang_parent_name = "ethernet-ports"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("ethernet-current", ("ethernet_current", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ])
                    self.name = None

                    self.ethernet_current = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent()
                    self.ethernet_current.parent = self
                    self._children_name_map["ethernet_current"] = "ethernet-current"
                    self._segment_path = lambda: "ethernet-port" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management/ethernet/ethernet-ports/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort, ['name'], name, value)


                class EthernetCurrent(Entity):
                    """
                    port current performance data
                    
                    .. attribute:: ethernet_second30
                    
                    	port current performance data
                    	**type**\:  :py:class:`EthernetSecond30 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30>`
                    
                    .. attribute:: ethernet_hour24
                    
                    	port current performance data
                    	**type**\:  :py:class:`EthernetHour24 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24>`
                    
                    .. attribute:: minute15
                    
                    	port current performance data
                    	**type**\:  :py:class:`Minute15 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent, self).__init__()

                        self.yang_name = "ethernet-current"
                        self.yang_parent_name = "ethernet-port"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ethernet-second30", ("ethernet_second30", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30)), ("ethernet-hour24", ("ethernet_hour24", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24)), ("minute15", ("minute15", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15))])
                        self._leafs = OrderedDict()

                        self.ethernet_second30 = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30()
                        self.ethernet_second30.parent = self
                        self._children_name_map["ethernet_second30"] = "ethernet-second30"

                        self.ethernet_hour24 = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24()
                        self.ethernet_hour24.parent = self
                        self._children_name_map["ethernet_hour24"] = "ethernet-hour24"

                        self.minute15 = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15()
                        self.minute15.parent = self
                        self._children_name_map["minute15"] = "minute15"
                        self._segment_path = lambda: "ethernet-current"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent, [], name, value)


                    class EthernetSecond30(Entity):
                        """
                        port current performance data
                        
                        .. attribute:: second30_fecs
                        
                        	ETHERNET port interval performance data
                        	**type**\:  :py:class:`Second30Fecs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Fecs>`
                        
                        .. attribute:: second30pcses
                        
                        	ETHERNET port interval performance data
                        	**type**\:  :py:class:`Second30pcses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30pcses>`
                        
                        .. attribute:: second30_ethers
                        
                        	ETHERNET port interval performance data
                        	**type**\:  :py:class:`Second30Ethers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30, self).__init__()

                            self.yang_name = "ethernet-second30"
                            self.yang_parent_name = "ethernet-current"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("second30-fecs", ("second30_fecs", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Fecs)), ("second30pcses", ("second30pcses", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30pcses)), ("second30-ethers", ("second30_ethers", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers))])
                            self._leafs = OrderedDict()

                            self.second30_fecs = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Fecs()
                            self.second30_fecs.parent = self
                            self._children_name_map["second30_fecs"] = "second30-fecs"

                            self.second30pcses = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30pcses()
                            self.second30pcses.parent = self
                            self._children_name_map["second30pcses"] = "second30pcses"

                            self.second30_ethers = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers()
                            self.second30_ethers.parent = self
                            self._children_name_map["second30_ethers"] = "second30-ethers"
                            self._segment_path = lambda: "ethernet-second30"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30, [], name, value)


                        class Second30Fecs(Entity):
                            """
                            ETHERNET port interval performance data
                            
                            .. attribute:: second30_fec
                            
                            	ETHERNET port 30 second fec performance data
                            	**type**\: list of  		 :py:class:`Second30Fec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Fecs.Second30Fec>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Fecs, self).__init__()

                                self.yang_name = "second30-fecs"
                                self.yang_parent_name = "ethernet-second30"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("second30-fec", ("second30_fec", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Fecs.Second30Fec))])
                                self._leafs = OrderedDict()

                                self.second30_fec = YList(self)
                                self._segment_path = lambda: "second30-fecs"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Fecs, [], name, value)


                            class Second30Fec(Entity):
                                """
                                ETHERNET port 30 second fec performance
                                data
                                
                                .. attribute:: slot_number  (key)
                                
                                	interval slot number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ec_bits
                                
                                	EC BITS
                                	**type**\:  :py:class:`EcBits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Fecs.Second30Fec.EcBits>`
                                
                                .. attribute:: uc_words
                                
                                	UC WORDS
                                	**type**\:  :py:class:`UcWords <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Fecs.Second30Fec.UcWords>`
                                
                                .. attribute:: pre_fec_ber
                                
                                	Pre FEC BER
                                	**type**\:  :py:class:`PreFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Fecs.Second30Fec.PreFecBer>`
                                
                                .. attribute:: post_fec_ber
                                
                                	Post FEC BER
                                	**type**\:  :py:class:`PostFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Fecs.Second30Fec.PostFecBer>`
                                
                                .. attribute:: q
                                
                                	Q
                                	**type**\:  :py:class:`Q <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Fecs.Second30Fec.Q>`
                                
                                .. attribute:: qmargin
                                
                                	Q Margin
                                	**type**\:  :py:class:`Qmargin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Fecs.Second30Fec.Qmargin>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Fecs.Second30Fec, self).__init__()

                                    self.yang_name = "second30-fec"
                                    self.yang_parent_name = "second30-fecs"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['slot_number']
                                    self._child_classes = OrderedDict([("ec-bits", ("ec_bits", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Fecs.Second30Fec.EcBits)), ("uc-words", ("uc_words", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Fecs.Second30Fec.UcWords)), ("pre-fec-ber", ("pre_fec_ber", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Fecs.Second30Fec.PreFecBer)), ("post-fec-ber", ("post_fec_ber", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Fecs.Second30Fec.PostFecBer)), ("q", ("q", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Fecs.Second30Fec.Q)), ("qmargin", ("qmargin", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Fecs.Second30Fec.Qmargin))])
                                    self._leafs = OrderedDict([
                                        ('slot_number', (YLeaf(YType.uint32, 'slot-number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                        ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                    ])
                                    self.slot_number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear24_hr_time = None
                                    self.sec30_support = None

                                    self.ec_bits = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Fecs.Second30Fec.EcBits()
                                    self.ec_bits.parent = self
                                    self._children_name_map["ec_bits"] = "ec-bits"

                                    self.uc_words = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Fecs.Second30Fec.UcWords()
                                    self.uc_words.parent = self
                                    self._children_name_map["uc_words"] = "uc-words"

                                    self.pre_fec_ber = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Fecs.Second30Fec.PreFecBer()
                                    self.pre_fec_ber.parent = self
                                    self._children_name_map["pre_fec_ber"] = "pre-fec-ber"

                                    self.post_fec_ber = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Fecs.Second30Fec.PostFecBer()
                                    self.post_fec_ber.parent = self
                                    self._children_name_map["post_fec_ber"] = "post-fec-ber"

                                    self.q = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Fecs.Second30Fec.Q()
                                    self.q.parent = self
                                    self._children_name_map["q"] = "q"

                                    self.qmargin = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Fecs.Second30Fec.Qmargin()
                                    self.qmargin.parent = self
                                    self._children_name_map["qmargin"] = "qmargin"
                                    self._segment_path = lambda: "second30-fec" + "[slot-number='" + str(self.slot_number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Fecs.Second30Fec, ['slot_number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                class EcBits(Entity):
                                    """
                                    EC BITS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Fecs.Second30Fec.EcBits, self).__init__()

                                        self.yang_name = "ec-bits"
                                        self.yang_parent_name = "second30-fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ec-bits"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Fecs.Second30Fec.EcBits, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class UcWords(Entity):
                                    """
                                    UC WORDS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Fecs.Second30Fec.UcWords, self).__init__()

                                        self.yang_name = "uc-words"
                                        self.yang_parent_name = "second30-fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "uc-words"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Fecs.Second30Fec.UcWords, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class PreFecBer(Entity):
                                    """
                                    Pre FEC BER
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Fecs.Second30Fec.PreFecBer, self).__init__()

                                        self.yang_name = "pre-fec-ber"
                                        self.yang_parent_name = "second30-fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.maximum_tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "pre-fec-ber"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Fecs.Second30Fec.PreFecBer, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                class PostFecBer(Entity):
                                    """
                                    Post FEC BER
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Fecs.Second30Fec.PostFecBer, self).__init__()

                                        self.yang_name = "post-fec-ber"
                                        self.yang_parent_name = "second30-fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.maximum_tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "post-fec-ber"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Fecs.Second30Fec.PostFecBer, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                class Q(Entity):
                                    """
                                    Q
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Fecs.Second30Fec.Q, self).__init__()

                                        self.yang_name = "q"
                                        self.yang_parent_name = "second30-fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.maximum_tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "q"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Fecs.Second30Fec.Q, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                class Qmargin(Entity):
                                    """
                                    Q Margin
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Fecs.Second30Fec.Qmargin, self).__init__()

                                        self.yang_name = "qmargin"
                                        self.yang_parent_name = "second30-fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.maximum_tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "qmargin"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Fecs.Second30Fec.Qmargin, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                        class Second30pcses(Entity):
                            """
                            ETHERNET port interval performance data
                            
                            .. attribute:: second30pcs
                            
                            	Ethernet port 30 second pcs  performance data
                            	**type**\: list of  		 :py:class:`Second30pcs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30pcses.Second30pcs>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30pcses, self).__init__()

                                self.yang_name = "second30pcses"
                                self.yang_parent_name = "ethernet-second30"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("second30pcs", ("second30pcs", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30pcses.Second30pcs))])
                                self._leafs = OrderedDict()

                                self.second30pcs = YList(self)
                                self._segment_path = lambda: "second30pcses"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30pcses, [], name, value)


                            class Second30pcs(Entity):
                                """
                                Ethernet port 30 second pcs  performance
                                data
                                
                                .. attribute:: slot_number  (key)
                                
                                	interval slot number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: bip
                                
                                	Bip 
                                	**type**\: list of  		 :py:class:`Bip <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30pcses.Second30pcs.Bip>`
                                
                                .. attribute:: frm_err
                                
                                	Frm Err
                                	**type**\: list of  		 :py:class:`FrmErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30pcses.Second30pcs.FrmErr>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30pcses.Second30pcs, self).__init__()

                                    self.yang_name = "second30pcs"
                                    self.yang_parent_name = "second30pcses"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['slot_number']
                                    self._child_classes = OrderedDict([("bip", ("bip", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30pcses.Second30pcs.Bip)), ("frm-err", ("frm_err", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30pcses.Second30pcs.FrmErr))])
                                    self._leafs = OrderedDict([
                                        ('slot_number', (YLeaf(YType.uint32, 'slot-number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                    ])
                                    self.slot_number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear24_hr_time = None

                                    self.bip = YList(self)
                                    self.frm_err = YList(self)
                                    self._segment_path = lambda: "second30pcs" + "[slot-number='" + str(self.slot_number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30pcses.Second30pcs, ['slot_number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time'], name, value)


                                class Bip(Entity):
                                    """
                                    Bip 
                                    
                                    .. attribute:: name
                                    
                                    	pcs param name
                                    	**type**\: str
                                    
                                    	**length:** 0..30
                                    
                                    .. attribute:: data
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30pcses.Second30pcs.Bip, self).__init__()

                                        self.yang_name = "bip"
                                        self.yang_parent_name = "second30pcs"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.name = None
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "bip"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30pcses.Second30pcs.Bip, ['name', 'data', 'threshold', 'tca_report'], name, value)


                                class FrmErr(Entity):
                                    """
                                    Frm Err
                                    
                                    .. attribute:: name
                                    
                                    	pcs param name
                                    	**type**\: str
                                    
                                    	**length:** 0..30
                                    
                                    .. attribute:: data
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30pcses.Second30pcs.FrmErr, self).__init__()

                                        self.yang_name = "frm-err"
                                        self.yang_parent_name = "second30pcs"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.name = None
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "frm-err"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30pcses.Second30pcs.FrmErr, ['name', 'data', 'threshold', 'tca_report'], name, value)


                        class Second30Ethers(Entity):
                            """
                            ETHERNET port interval performance data
                            
                            .. attribute:: second30_ether
                            
                            	ETHERNET port 30 second ether performance data
                            	**type**\: list of  		 :py:class:`Second30Ether <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers, self).__init__()

                                self.yang_name = "second30-ethers"
                                self.yang_parent_name = "ethernet-second30"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("second30-ether", ("second30_ether", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether))])
                                self._leafs = OrderedDict()

                                self.second30_ether = YList(self)
                                self._segment_path = lambda: "second30-ethers"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers, [], name, value)


                            class Second30Ether(Entity):
                                """
                                ETHERNET port 30 second ether performance
                                data
                                
                                .. attribute:: slot_number  (key)
                                
                                	interval slot number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rx_pkt
                                
                                	RX PKT
                                	**type**\:  :py:class:`RxPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.RxPkt>`
                                
                                .. attribute:: stat_pkt
                                
                                	STAT PKT
                                	**type**\:  :py:class:`StatPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.StatPkt>`
                                
                                .. attribute:: octet_stat
                                
                                	OCTET STAT
                                	**type**\:  :py:class:`OctetStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OctetStat>`
                                
                                .. attribute:: oversize_pkt_stat
                                
                                	OVERSIZE PKT
                                	**type**\:  :py:class:`OversizePktStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OversizePktStat>`
                                
                                .. attribute:: fcs_errors_stat
                                
                                	FCS ERR
                                	**type**\:  :py:class:`FcsErrorsStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.FcsErrorsStat>`
                                
                                .. attribute:: long_frames_stat
                                
                                	LONG FRAMES
                                	**type**\:  :py:class:`LongFramesStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.LongFramesStat>`
                                
                                .. attribute:: jabber_stat
                                
                                	JABBER STATS
                                	**type**\:  :py:class:`JabberStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.JabberStat>`
                                
                                .. attribute:: ether64_octets
                                
                                	SIXTY FOUR OCTET
                                	**type**\:  :py:class:`Ether64Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether64Octets>`
                                
                                .. attribute:: ether65127_octet
                                
                                	OCTET
                                	**type**\:  :py:class:`Ether65127Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether65127Octet>`
                                
                                .. attribute:: ether128255_octet
                                
                                	TFF OCTET
                                	**type**\:  :py:class:`Ether128255Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether128255Octet>`
                                
                                .. attribute:: ether256511_octet
                                
                                	FOO OCTET
                                	**type**\:  :py:class:`Ether256511Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether256511Octet>`
                                
                                .. attribute:: ether5121023_octet
                                
                                	OZTT OCTET
                                	**type**\:  :py:class:`Ether5121023Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether5121023Octet>`
                                
                                .. attribute:: ether10241518_octet
                                
                                	OFO OCTET
                                	**type**\:  :py:class:`Ether10241518Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether10241518Octet>`
                                
                                .. attribute:: in_ucast_pkt
                                
                                	IN UCAST
                                	**type**\:  :py:class:`InUcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InUcastPkt>`
                                
                                .. attribute:: in_mcast_pkt
                                
                                	IN MCAST
                                	**type**\:  :py:class:`InMcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InMcastPkt>`
                                
                                .. attribute:: in_bcast_pkt
                                
                                	IN BCAST
                                	**type**\:  :py:class:`InBcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InBcastPkt>`
                                
                                .. attribute:: out_ucast_pkt
                                
                                	OUT UCAST
                                	**type**\:  :py:class:`OutUcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutUcastPkt>`
                                
                                .. attribute:: out_bcast_pkt
                                
                                	OUT BCAST
                                	**type**\:  :py:class:`OutBcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutBcastPkt>`
                                
                                .. attribute:: out_mcast_pkt
                                
                                	OUT MCAST
                                	**type**\:  :py:class:`OutMcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutMcastPkt>`
                                
                                .. attribute:: tx_pkt
                                
                                	TX PKT
                                	**type**\:  :py:class:`TxPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxPkt>`
                                
                                .. attribute:: if_in_errors
                                
                                	IFIN ERRORS
                                	**type**\:  :py:class:`IfInErrors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.IfInErrors>`
                                
                                .. attribute:: if_in_octets
                                
                                	IFIN OCTETS
                                	**type**\:  :py:class:`IfInOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.IfInOctets>`
                                
                                .. attribute:: ether_stat_multicast_pkt
                                
                                	ETHER STAT MULTICAST PKT
                                	**type**\:  :py:class:`EtherStatMulticastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.EtherStatMulticastPkt>`
                                
                                .. attribute:: ether_stat_broadcast_pkt
                                
                                	ETHER STAT BROADCAST PKT
                                	**type**\:  :py:class:`EtherStatBroadcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.EtherStatBroadcastPkt>`
                                
                                .. attribute:: ether_stat_undersized_pkt
                                
                                	ETHER STAT UNDERSIZED PKT
                                	**type**\:  :py:class:`EtherStatUndersizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.EtherStatUndersizedPkt>`
                                
                                .. attribute:: out_octets
                                
                                	OUT OCTET
                                	**type**\:  :py:class:`OutOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutOctets>`
                                
                                .. attribute:: in_pause_frame
                                
                                	INPUT PAUSE FRAME
                                	**type**\:  :py:class:`InPauseFrame <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPauseFrame>`
                                
                                .. attribute:: in_good_bytes
                                
                                	INPUT GOOD BYTES
                                	**type**\:  :py:class:`InGoodBytes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InGoodBytes>`
                                
                                .. attribute:: in8021q_frames
                                
                                	INPUT 802 1Q FRAMES
                                	**type**\:  :py:class:`In8021qFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.In8021qFrames>`
                                
                                .. attribute:: in_pkts1519_max_octets
                                
                                	INPUT PKTS 1519MAX OCTETS
                                	**type**\:  :py:class:`InPkts1519MaxOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts1519MaxOctets>`
                                
                                .. attribute:: in_good_pkts
                                
                                	INPUT GOOD PKTS
                                	**type**\:  :py:class:`InGoodPkts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InGoodPkts>`
                                
                                .. attribute:: in_drop_overrun
                                
                                	INPUT DROP OVERRUN
                                	**type**\:  :py:class:`InDropOverrun <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropOverrun>`
                                
                                .. attribute:: in_drop_abort
                                
                                	INPUT DROP ABORT
                                	**type**\:  :py:class:`InDropAbort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropAbort>`
                                
                                .. attribute:: in_drop_invalid_vlan
                                
                                	INPUT DROP INVALID VLAN
                                	**type**\:  :py:class:`InDropInvalidVlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropInvalidVlan>`
                                
                                .. attribute:: in_drop_invalid_dmac
                                
                                	INPUT DROP INVALID DMAC
                                	**type**\:  :py:class:`InDropInvalidDmac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropInvalidDmac>`
                                
                                .. attribute:: in_drop_invalid_encap
                                
                                	INPUT DROP INVALID ENCAP
                                	**type**\:  :py:class:`InDropInvalidEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropInvalidEncap>`
                                
                                .. attribute:: in_drop_other
                                
                                	INPUT DROP OTHER
                                	**type**\:  :py:class:`InDropOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropOther>`
                                
                                .. attribute:: in_mib_giant
                                
                                	INPUT MIB GIANT
                                	**type**\:  :py:class:`InMibGiant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InMibGiant>`
                                
                                .. attribute:: in_mib_jabber
                                
                                	INPUT MIB JABBER
                                	**type**\:  :py:class:`InMibJabber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InMibJabber>`
                                
                                .. attribute:: in_mibcrc
                                
                                	IN MIB CRC
                                	**type**\:  :py:class:`InMibcrc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InMibcrc>`
                                
                                .. attribute:: in_error_collisions
                                
                                	IN ERROR COLLISIONS
                                	**type**\:  :py:class:`InErrorCollisions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorCollisions>`
                                
                                .. attribute:: in_error_symbol
                                
                                	IN ERROR SYMBOL
                                	**type**\:  :py:class:`InErrorSymbol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorSymbol>`
                                
                                .. attribute:: out_good_bytes
                                
                                	OUT GOOD BYTES
                                	**type**\:  :py:class:`OutGoodBytes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutGoodBytes>`
                                
                                .. attribute:: out8021q_frames
                                
                                	OUT 802 1Q FRAMES
                                	**type**\:  :py:class:`Out8021qFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Out8021qFrames>`
                                
                                .. attribute:: out_pause_frames
                                
                                	OUT PAUSE FRAMES
                                	**type**\:  :py:class:`OutPauseFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPauseFrames>`
                                
                                .. attribute:: out_pkts1519_max_octets
                                
                                	OUT PKTS 1519 MAX OCTETS
                                	**type**\:  :py:class:`OutPkts1519MaxOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts1519MaxOctets>`
                                
                                .. attribute:: out_good_pkts
                                
                                	OUT GOOD PKTS
                                	**type**\:  :py:class:`OutGoodPkts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutGoodPkts>`
                                
                                .. attribute:: out_drop_underrun
                                
                                	OUT DROP UNDERRUN
                                	**type**\:  :py:class:`OutDropUnderrun <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutDropUnderrun>`
                                
                                .. attribute:: out_drop_abort
                                
                                	OUT DROP ABORT
                                	**type**\:  :py:class:`OutDropAbort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutDropAbort>`
                                
                                .. attribute:: out_drop_other
                                
                                	OUT DROP OTHER
                                	**type**\:  :py:class:`OutDropOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutDropOther>`
                                
                                .. attribute:: out_error_other
                                
                                	OUT ERROR OTHER
                                	**type**\:  :py:class:`OutErrorOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutErrorOther>`
                                
                                .. attribute:: in_error_giant
                                
                                	IN ERROR GIANT
                                	**type**\:  :py:class:`InErrorGiant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorGiant>`
                                
                                .. attribute:: in_error_runt
                                
                                	IN ERROR RUNT
                                	**type**\:  :py:class:`InErrorRunt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorRunt>`
                                
                                .. attribute:: in_error_jabbers
                                
                                	IN ERROR JABBERS
                                	**type**\:  :py:class:`InErrorJabbers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorJabbers>`
                                
                                .. attribute:: in_error_fragments
                                
                                	IN ERROR FRAGMENTS
                                	**type**\:  :py:class:`InErrorFragments <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorFragments>`
                                
                                .. attribute:: in_error_other
                                
                                	IN ERROR OTHER
                                	**type**\:  :py:class:`InErrorOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorOther>`
                                
                                .. attribute:: in_pkt64_octet
                                
                                	IN PKT 64 OCTET
                                	**type**\:  :py:class:`InPkt64Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkt64Octet>`
                                
                                .. attribute:: in_pkts65_to127_octets
                                
                                	IN PKTS 65 127OCTETS
                                	**type**\:  :py:class:`InPkts65To127Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts65To127Octets>`
                                
                                .. attribute:: in_pkts128_to255_octets
                                
                                	IN PKTS 128 255 OCTETS
                                	**type**\:  :py:class:`InPkts128To255Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts128To255Octets>`
                                
                                .. attribute:: in_pkts256_to511_octets
                                
                                	IN PKTS 256 511 OCTETS
                                	**type**\:  :py:class:`InPkts256To511Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts256To511Octets>`
                                
                                .. attribute:: in_pkts512_to1023_octets
                                
                                	IN PKTS 512 1023 OCTETS
                                	**type**\:  :py:class:`InPkts512To1023Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts512To1023Octets>`
                                
                                .. attribute:: in_pkts1024_to1518_octets
                                
                                	IN PKTS 1024 1518 OCTETS
                                	**type**\:  :py:class:`InPkts1024To1518Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts1024To1518Octets>`
                                
                                .. attribute:: outpkt64octet
                                
                                	OUT PKT 64 OCTET
                                	**type**\:  :py:class:`Outpkt64octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Outpkt64octet>`
                                
                                .. attribute:: out_pkts65127_octets
                                
                                	OUT PKTS 65 127OCTETS
                                	**type**\:  :py:class:`OutPkts65127Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts65127Octets>`
                                
                                .. attribute:: out_pkts128255_octets
                                
                                	OUT PKTS 128 255 OCTETS
                                	**type**\:  :py:class:`OutPkts128255Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts128255Octets>`
                                
                                .. attribute:: out_pkts256511_octets
                                
                                	OUT PKTS 256 511 OCTETS
                                	**type**\:  :py:class:`OutPkts256511Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts256511Octets>`
                                
                                .. attribute:: out_pkts5121023_octets
                                
                                	OUT PKTS 512 1023 OCTETS
                                	**type**\:  :py:class:`OutPkts5121023Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts5121023Octets>`
                                
                                .. attribute:: out_pkts10241518_octets
                                
                                	OUT PKTS 1024 1518 OCTETS
                                	**type**\:  :py:class:`OutPkts10241518Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts10241518Octets>`
                                
                                .. attribute:: rx_util
                                
                                	Rx Utilization in Percent
                                	**type**\:  :py:class:`RxUtil <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.RxUtil>`
                                
                                .. attribute:: tx_util
                                
                                	Tx Utilization in Percent
                                	**type**\:  :py:class:`TxUtil <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxUtil>`
                                
                                .. attribute:: tx_undersized_pkt
                                
                                	TX Undersized Pkt
                                	**type**\:  :py:class:`TxUndersizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxUndersizedPkt>`
                                
                                .. attribute:: tx_oversized_pkt
                                
                                	TX Oversized Pkt
                                	**type**\:  :py:class:`TxOversizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxOversizedPkt>`
                                
                                .. attribute:: tx_fragments
                                
                                	TX Fragments
                                	**type**\:  :py:class:`TxFragments <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxFragments>`
                                
                                .. attribute:: tx_jabber
                                
                                	TX Jabber
                                	**type**\:  :py:class:`TxJabber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxJabber>`
                                
                                .. attribute:: tx_bad_fcs
                                
                                	TX Bad Fcs
                                	**type**\:  :py:class:`TxBadFcs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxBadFcs>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether, self).__init__()

                                    self.yang_name = "second30-ether"
                                    self.yang_parent_name = "second30-ethers"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['slot_number']
                                    self._child_classes = OrderedDict([("rx-pkt", ("rx_pkt", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.RxPkt)), ("stat-pkt", ("stat_pkt", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.StatPkt)), ("octet-stat", ("octet_stat", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OctetStat)), ("oversize-pkt-stat", ("oversize_pkt_stat", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OversizePktStat)), ("fcs-errors-stat", ("fcs_errors_stat", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.FcsErrorsStat)), ("long-frames-stat", ("long_frames_stat", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.LongFramesStat)), ("jabber-stat", ("jabber_stat", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.JabberStat)), ("ether64-octets", ("ether64_octets", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether64Octets)), ("ether65127-octet", ("ether65127_octet", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether65127Octet)), ("ether128255-octet", ("ether128255_octet", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether128255Octet)), ("ether256511-octet", ("ether256511_octet", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether256511Octet)), ("ether5121023-octet", ("ether5121023_octet", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether5121023Octet)), ("ether10241518-octet", ("ether10241518_octet", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether10241518Octet)), ("in-ucast-pkt", ("in_ucast_pkt", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InUcastPkt)), ("in-mcast-pkt", ("in_mcast_pkt", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InMcastPkt)), ("in-bcast-pkt", ("in_bcast_pkt", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InBcastPkt)), ("out-ucast-pkt", ("out_ucast_pkt", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutUcastPkt)), ("out-bcast-pkt", ("out_bcast_pkt", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutBcastPkt)), ("out-mcast-pkt", ("out_mcast_pkt", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutMcastPkt)), ("tx-pkt", ("tx_pkt", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxPkt)), ("if-in-errors", ("if_in_errors", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.IfInErrors)), ("if-in-octets", ("if_in_octets", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.IfInOctets)), ("ether-stat-multicast-pkt", ("ether_stat_multicast_pkt", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.EtherStatMulticastPkt)), ("ether-stat-broadcast-pkt", ("ether_stat_broadcast_pkt", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.EtherStatBroadcastPkt)), ("ether-stat-undersized-pkt", ("ether_stat_undersized_pkt", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.EtherStatUndersizedPkt)), ("out-octets", ("out_octets", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutOctets)), ("in-pause-frame", ("in_pause_frame", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPauseFrame)), ("in-good-bytes", ("in_good_bytes", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InGoodBytes)), ("in8021q-frames", ("in8021q_frames", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.In8021qFrames)), ("in-pkts1519-max-octets", ("in_pkts1519_max_octets", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts1519MaxOctets)), ("in-good-pkts", ("in_good_pkts", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InGoodPkts)), ("in-drop-overrun", ("in_drop_overrun", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropOverrun)), ("in-drop-abort", ("in_drop_abort", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropAbort)), ("in-drop-invalid-vlan", ("in_drop_invalid_vlan", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropInvalidVlan)), ("in-drop-invalid-dmac", ("in_drop_invalid_dmac", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropInvalidDmac)), ("in-drop-invalid-encap", ("in_drop_invalid_encap", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropInvalidEncap)), ("in-drop-other", ("in_drop_other", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropOther)), ("in-mib-giant", ("in_mib_giant", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InMibGiant)), ("in-mib-jabber", ("in_mib_jabber", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InMibJabber)), ("in-mibcrc", ("in_mibcrc", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InMibcrc)), ("in-error-collisions", ("in_error_collisions", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorCollisions)), ("in-error-symbol", ("in_error_symbol", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorSymbol)), ("out-good-bytes", ("out_good_bytes", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutGoodBytes)), ("out8021q-frames", ("out8021q_frames", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Out8021qFrames)), ("out-pause-frames", ("out_pause_frames", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPauseFrames)), ("out-pkts1519-max-octets", ("out_pkts1519_max_octets", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts1519MaxOctets)), ("out-good-pkts", ("out_good_pkts", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutGoodPkts)), ("out-drop-underrun", ("out_drop_underrun", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutDropUnderrun)), ("out-drop-abort", ("out_drop_abort", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutDropAbort)), ("out-drop-other", ("out_drop_other", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutDropOther)), ("out-error-other", ("out_error_other", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutErrorOther)), ("in-error-giant", ("in_error_giant", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorGiant)), ("in-error-runt", ("in_error_runt", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorRunt)), ("in-error-jabbers", ("in_error_jabbers", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorJabbers)), ("in-error-fragments", ("in_error_fragments", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorFragments)), ("in-error-other", ("in_error_other", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorOther)), ("in-pkt64-octet", ("in_pkt64_octet", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkt64Octet)), ("in-pkts65-to127-octets", ("in_pkts65_to127_octets", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts65To127Octets)), ("in-pkts128-to255-octets", ("in_pkts128_to255_octets", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts128To255Octets)), ("in-pkts256-to511-octets", ("in_pkts256_to511_octets", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts256To511Octets)), ("in-pkts512-to1023-octets", ("in_pkts512_to1023_octets", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts512To1023Octets)), ("in-pkts1024-to1518-octets", ("in_pkts1024_to1518_octets", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts1024To1518Octets)), ("outpkt64octet", ("outpkt64octet", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Outpkt64octet)), ("out-pkts65127-octets", ("out_pkts65127_octets", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts65127Octets)), ("out-pkts128255-octets", ("out_pkts128255_octets", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts128255Octets)), ("out-pkts256511-octets", ("out_pkts256511_octets", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts256511Octets)), ("out-pkts5121023-octets", ("out_pkts5121023_octets", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts5121023Octets)), ("out-pkts10241518-octets", ("out_pkts10241518_octets", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts10241518Octets)), ("rx-util", ("rx_util", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.RxUtil)), ("tx-util", ("tx_util", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxUtil)), ("tx-undersized-pkt", ("tx_undersized_pkt", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxUndersizedPkt)), ("tx-oversized-pkt", ("tx_oversized_pkt", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxOversizedPkt)), ("tx-fragments", ("tx_fragments", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxFragments)), ("tx-jabber", ("tx_jabber", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxJabber)), ("tx-bad-fcs", ("tx_bad_fcs", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxBadFcs))])
                                    self._leafs = OrderedDict([
                                        ('slot_number', (YLeaf(YType.uint32, 'slot-number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                        ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                    ])
                                    self.slot_number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None
                                    self.sec30_support = None

                                    self.rx_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.RxPkt()
                                    self.rx_pkt.parent = self
                                    self._children_name_map["rx_pkt"] = "rx-pkt"

                                    self.stat_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.StatPkt()
                                    self.stat_pkt.parent = self
                                    self._children_name_map["stat_pkt"] = "stat-pkt"

                                    self.octet_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OctetStat()
                                    self.octet_stat.parent = self
                                    self._children_name_map["octet_stat"] = "octet-stat"

                                    self.oversize_pkt_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OversizePktStat()
                                    self.oversize_pkt_stat.parent = self
                                    self._children_name_map["oversize_pkt_stat"] = "oversize-pkt-stat"

                                    self.fcs_errors_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.FcsErrorsStat()
                                    self.fcs_errors_stat.parent = self
                                    self._children_name_map["fcs_errors_stat"] = "fcs-errors-stat"

                                    self.long_frames_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.LongFramesStat()
                                    self.long_frames_stat.parent = self
                                    self._children_name_map["long_frames_stat"] = "long-frames-stat"

                                    self.jabber_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.JabberStat()
                                    self.jabber_stat.parent = self
                                    self._children_name_map["jabber_stat"] = "jabber-stat"

                                    self.ether64_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether64Octets()
                                    self.ether64_octets.parent = self
                                    self._children_name_map["ether64_octets"] = "ether64-octets"

                                    self.ether65127_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether65127Octet()
                                    self.ether65127_octet.parent = self
                                    self._children_name_map["ether65127_octet"] = "ether65127-octet"

                                    self.ether128255_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether128255Octet()
                                    self.ether128255_octet.parent = self
                                    self._children_name_map["ether128255_octet"] = "ether128255-octet"

                                    self.ether256511_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether256511Octet()
                                    self.ether256511_octet.parent = self
                                    self._children_name_map["ether256511_octet"] = "ether256511-octet"

                                    self.ether5121023_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether5121023Octet()
                                    self.ether5121023_octet.parent = self
                                    self._children_name_map["ether5121023_octet"] = "ether5121023-octet"

                                    self.ether10241518_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether10241518Octet()
                                    self.ether10241518_octet.parent = self
                                    self._children_name_map["ether10241518_octet"] = "ether10241518-octet"

                                    self.in_ucast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InUcastPkt()
                                    self.in_ucast_pkt.parent = self
                                    self._children_name_map["in_ucast_pkt"] = "in-ucast-pkt"

                                    self.in_mcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InMcastPkt()
                                    self.in_mcast_pkt.parent = self
                                    self._children_name_map["in_mcast_pkt"] = "in-mcast-pkt"

                                    self.in_bcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InBcastPkt()
                                    self.in_bcast_pkt.parent = self
                                    self._children_name_map["in_bcast_pkt"] = "in-bcast-pkt"

                                    self.out_ucast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutUcastPkt()
                                    self.out_ucast_pkt.parent = self
                                    self._children_name_map["out_ucast_pkt"] = "out-ucast-pkt"

                                    self.out_bcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutBcastPkt()
                                    self.out_bcast_pkt.parent = self
                                    self._children_name_map["out_bcast_pkt"] = "out-bcast-pkt"

                                    self.out_mcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutMcastPkt()
                                    self.out_mcast_pkt.parent = self
                                    self._children_name_map["out_mcast_pkt"] = "out-mcast-pkt"

                                    self.tx_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxPkt()
                                    self.tx_pkt.parent = self
                                    self._children_name_map["tx_pkt"] = "tx-pkt"

                                    self.if_in_errors = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.IfInErrors()
                                    self.if_in_errors.parent = self
                                    self._children_name_map["if_in_errors"] = "if-in-errors"

                                    self.if_in_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.IfInOctets()
                                    self.if_in_octets.parent = self
                                    self._children_name_map["if_in_octets"] = "if-in-octets"

                                    self.ether_stat_multicast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.EtherStatMulticastPkt()
                                    self.ether_stat_multicast_pkt.parent = self
                                    self._children_name_map["ether_stat_multicast_pkt"] = "ether-stat-multicast-pkt"

                                    self.ether_stat_broadcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.EtherStatBroadcastPkt()
                                    self.ether_stat_broadcast_pkt.parent = self
                                    self._children_name_map["ether_stat_broadcast_pkt"] = "ether-stat-broadcast-pkt"

                                    self.ether_stat_undersized_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.EtherStatUndersizedPkt()
                                    self.ether_stat_undersized_pkt.parent = self
                                    self._children_name_map["ether_stat_undersized_pkt"] = "ether-stat-undersized-pkt"

                                    self.out_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutOctets()
                                    self.out_octets.parent = self
                                    self._children_name_map["out_octets"] = "out-octets"

                                    self.in_pause_frame = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPauseFrame()
                                    self.in_pause_frame.parent = self
                                    self._children_name_map["in_pause_frame"] = "in-pause-frame"

                                    self.in_good_bytes = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InGoodBytes()
                                    self.in_good_bytes.parent = self
                                    self._children_name_map["in_good_bytes"] = "in-good-bytes"

                                    self.in8021q_frames = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.In8021qFrames()
                                    self.in8021q_frames.parent = self
                                    self._children_name_map["in8021q_frames"] = "in8021q-frames"

                                    self.in_pkts1519_max_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts1519MaxOctets()
                                    self.in_pkts1519_max_octets.parent = self
                                    self._children_name_map["in_pkts1519_max_octets"] = "in-pkts1519-max-octets"

                                    self.in_good_pkts = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InGoodPkts()
                                    self.in_good_pkts.parent = self
                                    self._children_name_map["in_good_pkts"] = "in-good-pkts"

                                    self.in_drop_overrun = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropOverrun()
                                    self.in_drop_overrun.parent = self
                                    self._children_name_map["in_drop_overrun"] = "in-drop-overrun"

                                    self.in_drop_abort = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropAbort()
                                    self.in_drop_abort.parent = self
                                    self._children_name_map["in_drop_abort"] = "in-drop-abort"

                                    self.in_drop_invalid_vlan = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropInvalidVlan()
                                    self.in_drop_invalid_vlan.parent = self
                                    self._children_name_map["in_drop_invalid_vlan"] = "in-drop-invalid-vlan"

                                    self.in_drop_invalid_dmac = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropInvalidDmac()
                                    self.in_drop_invalid_dmac.parent = self
                                    self._children_name_map["in_drop_invalid_dmac"] = "in-drop-invalid-dmac"

                                    self.in_drop_invalid_encap = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropInvalidEncap()
                                    self.in_drop_invalid_encap.parent = self
                                    self._children_name_map["in_drop_invalid_encap"] = "in-drop-invalid-encap"

                                    self.in_drop_other = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropOther()
                                    self.in_drop_other.parent = self
                                    self._children_name_map["in_drop_other"] = "in-drop-other"

                                    self.in_mib_giant = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InMibGiant()
                                    self.in_mib_giant.parent = self
                                    self._children_name_map["in_mib_giant"] = "in-mib-giant"

                                    self.in_mib_jabber = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InMibJabber()
                                    self.in_mib_jabber.parent = self
                                    self._children_name_map["in_mib_jabber"] = "in-mib-jabber"

                                    self.in_mibcrc = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InMibcrc()
                                    self.in_mibcrc.parent = self
                                    self._children_name_map["in_mibcrc"] = "in-mibcrc"

                                    self.in_error_collisions = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorCollisions()
                                    self.in_error_collisions.parent = self
                                    self._children_name_map["in_error_collisions"] = "in-error-collisions"

                                    self.in_error_symbol = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorSymbol()
                                    self.in_error_symbol.parent = self
                                    self._children_name_map["in_error_symbol"] = "in-error-symbol"

                                    self.out_good_bytes = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutGoodBytes()
                                    self.out_good_bytes.parent = self
                                    self._children_name_map["out_good_bytes"] = "out-good-bytes"

                                    self.out8021q_frames = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Out8021qFrames()
                                    self.out8021q_frames.parent = self
                                    self._children_name_map["out8021q_frames"] = "out8021q-frames"

                                    self.out_pause_frames = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPauseFrames()
                                    self.out_pause_frames.parent = self
                                    self._children_name_map["out_pause_frames"] = "out-pause-frames"

                                    self.out_pkts1519_max_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts1519MaxOctets()
                                    self.out_pkts1519_max_octets.parent = self
                                    self._children_name_map["out_pkts1519_max_octets"] = "out-pkts1519-max-octets"

                                    self.out_good_pkts = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutGoodPkts()
                                    self.out_good_pkts.parent = self
                                    self._children_name_map["out_good_pkts"] = "out-good-pkts"

                                    self.out_drop_underrun = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutDropUnderrun()
                                    self.out_drop_underrun.parent = self
                                    self._children_name_map["out_drop_underrun"] = "out-drop-underrun"

                                    self.out_drop_abort = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutDropAbort()
                                    self.out_drop_abort.parent = self
                                    self._children_name_map["out_drop_abort"] = "out-drop-abort"

                                    self.out_drop_other = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutDropOther()
                                    self.out_drop_other.parent = self
                                    self._children_name_map["out_drop_other"] = "out-drop-other"

                                    self.out_error_other = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutErrorOther()
                                    self.out_error_other.parent = self
                                    self._children_name_map["out_error_other"] = "out-error-other"

                                    self.in_error_giant = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorGiant()
                                    self.in_error_giant.parent = self
                                    self._children_name_map["in_error_giant"] = "in-error-giant"

                                    self.in_error_runt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorRunt()
                                    self.in_error_runt.parent = self
                                    self._children_name_map["in_error_runt"] = "in-error-runt"

                                    self.in_error_jabbers = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorJabbers()
                                    self.in_error_jabbers.parent = self
                                    self._children_name_map["in_error_jabbers"] = "in-error-jabbers"

                                    self.in_error_fragments = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorFragments()
                                    self.in_error_fragments.parent = self
                                    self._children_name_map["in_error_fragments"] = "in-error-fragments"

                                    self.in_error_other = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorOther()
                                    self.in_error_other.parent = self
                                    self._children_name_map["in_error_other"] = "in-error-other"

                                    self.in_pkt64_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkt64Octet()
                                    self.in_pkt64_octet.parent = self
                                    self._children_name_map["in_pkt64_octet"] = "in-pkt64-octet"

                                    self.in_pkts65_to127_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts65To127Octets()
                                    self.in_pkts65_to127_octets.parent = self
                                    self._children_name_map["in_pkts65_to127_octets"] = "in-pkts65-to127-octets"

                                    self.in_pkts128_to255_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts128To255Octets()
                                    self.in_pkts128_to255_octets.parent = self
                                    self._children_name_map["in_pkts128_to255_octets"] = "in-pkts128-to255-octets"

                                    self.in_pkts256_to511_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts256To511Octets()
                                    self.in_pkts256_to511_octets.parent = self
                                    self._children_name_map["in_pkts256_to511_octets"] = "in-pkts256-to511-octets"

                                    self.in_pkts512_to1023_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts512To1023Octets()
                                    self.in_pkts512_to1023_octets.parent = self
                                    self._children_name_map["in_pkts512_to1023_octets"] = "in-pkts512-to1023-octets"

                                    self.in_pkts1024_to1518_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts1024To1518Octets()
                                    self.in_pkts1024_to1518_octets.parent = self
                                    self._children_name_map["in_pkts1024_to1518_octets"] = "in-pkts1024-to1518-octets"

                                    self.outpkt64octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Outpkt64octet()
                                    self.outpkt64octet.parent = self
                                    self._children_name_map["outpkt64octet"] = "outpkt64octet"

                                    self.out_pkts65127_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts65127Octets()
                                    self.out_pkts65127_octets.parent = self
                                    self._children_name_map["out_pkts65127_octets"] = "out-pkts65127-octets"

                                    self.out_pkts128255_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts128255Octets()
                                    self.out_pkts128255_octets.parent = self
                                    self._children_name_map["out_pkts128255_octets"] = "out-pkts128255-octets"

                                    self.out_pkts256511_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts256511Octets()
                                    self.out_pkts256511_octets.parent = self
                                    self._children_name_map["out_pkts256511_octets"] = "out-pkts256511-octets"

                                    self.out_pkts5121023_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts5121023Octets()
                                    self.out_pkts5121023_octets.parent = self
                                    self._children_name_map["out_pkts5121023_octets"] = "out-pkts5121023-octets"

                                    self.out_pkts10241518_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts10241518Octets()
                                    self.out_pkts10241518_octets.parent = self
                                    self._children_name_map["out_pkts10241518_octets"] = "out-pkts10241518-octets"

                                    self.rx_util = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.RxUtil()
                                    self.rx_util.parent = self
                                    self._children_name_map["rx_util"] = "rx-util"

                                    self.tx_util = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxUtil()
                                    self.tx_util.parent = self
                                    self._children_name_map["tx_util"] = "tx-util"

                                    self.tx_undersized_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxUndersizedPkt()
                                    self.tx_undersized_pkt.parent = self
                                    self._children_name_map["tx_undersized_pkt"] = "tx-undersized-pkt"

                                    self.tx_oversized_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxOversizedPkt()
                                    self.tx_oversized_pkt.parent = self
                                    self._children_name_map["tx_oversized_pkt"] = "tx-oversized-pkt"

                                    self.tx_fragments = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxFragments()
                                    self.tx_fragments.parent = self
                                    self._children_name_map["tx_fragments"] = "tx-fragments"

                                    self.tx_jabber = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxJabber()
                                    self.tx_jabber.parent = self
                                    self._children_name_map["tx_jabber"] = "tx-jabber"

                                    self.tx_bad_fcs = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxBadFcs()
                                    self.tx_bad_fcs.parent = self
                                    self._children_name_map["tx_bad_fcs"] = "tx-bad-fcs"
                                    self._segment_path = lambda: "second30-ether" + "[slot-number='" + str(self.slot_number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether, ['slot_number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear30_sec_time', 'last_clear15_min_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                class RxPkt(Entity):
                                    """
                                    RX PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.RxPkt, self).__init__()

                                        self.yang_name = "rx-pkt"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "rx-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.RxPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class StatPkt(Entity):
                                    """
                                    STAT PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.StatPkt, self).__init__()

                                        self.yang_name = "stat-pkt"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "stat-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.StatPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OctetStat(Entity):
                                    """
                                    OCTET STAT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OctetStat, self).__init__()

                                        self.yang_name = "octet-stat"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "octet-stat"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OctetStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OversizePktStat(Entity):
                                    """
                                    OVERSIZE PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OversizePktStat, self).__init__()

                                        self.yang_name = "oversize-pkt-stat"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "oversize-pkt-stat"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OversizePktStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class FcsErrorsStat(Entity):
                                    """
                                    FCS ERR
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.FcsErrorsStat, self).__init__()

                                        self.yang_name = "fcs-errors-stat"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "fcs-errors-stat"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.FcsErrorsStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class LongFramesStat(Entity):
                                    """
                                    LONG FRAMES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.LongFramesStat, self).__init__()

                                        self.yang_name = "long-frames-stat"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "long-frames-stat"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.LongFramesStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class JabberStat(Entity):
                                    """
                                    JABBER STATS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.JabberStat, self).__init__()

                                        self.yang_name = "jabber-stat"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "jabber-stat"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.JabberStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class Ether64Octets(Entity):
                                    """
                                    SIXTY FOUR OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether64Octets, self).__init__()

                                        self.yang_name = "ether64-octets"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ether64-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether64Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class Ether65127Octet(Entity):
                                    """
                                    OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether65127Octet, self).__init__()

                                        self.yang_name = "ether65127-octet"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ether65127-octet"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether65127Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class Ether128255Octet(Entity):
                                    """
                                    TFF OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether128255Octet, self).__init__()

                                        self.yang_name = "ether128255-octet"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ether128255-octet"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether128255Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class Ether256511Octet(Entity):
                                    """
                                    FOO OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether256511Octet, self).__init__()

                                        self.yang_name = "ether256511-octet"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ether256511-octet"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether256511Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class Ether5121023Octet(Entity):
                                    """
                                    OZTT OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether5121023Octet, self).__init__()

                                        self.yang_name = "ether5121023-octet"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ether5121023-octet"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether5121023Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class Ether10241518Octet(Entity):
                                    """
                                    OFO OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether10241518Octet, self).__init__()

                                        self.yang_name = "ether10241518-octet"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ether10241518-octet"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether10241518Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InUcastPkt(Entity):
                                    """
                                    IN UCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InUcastPkt, self).__init__()

                                        self.yang_name = "in-ucast-pkt"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-ucast-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InUcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InMcastPkt(Entity):
                                    """
                                    IN MCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InMcastPkt, self).__init__()

                                        self.yang_name = "in-mcast-pkt"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-mcast-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InMcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InBcastPkt(Entity):
                                    """
                                    IN BCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InBcastPkt, self).__init__()

                                        self.yang_name = "in-bcast-pkt"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-bcast-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InBcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutUcastPkt(Entity):
                                    """
                                    OUT UCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutUcastPkt, self).__init__()

                                        self.yang_name = "out-ucast-pkt"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-ucast-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutUcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutBcastPkt(Entity):
                                    """
                                    OUT BCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutBcastPkt, self).__init__()

                                        self.yang_name = "out-bcast-pkt"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-bcast-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutBcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutMcastPkt(Entity):
                                    """
                                    OUT MCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutMcastPkt, self).__init__()

                                        self.yang_name = "out-mcast-pkt"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-mcast-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutMcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class TxPkt(Entity):
                                    """
                                    TX PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxPkt, self).__init__()

                                        self.yang_name = "tx-pkt"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "tx-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class IfInErrors(Entity):
                                    """
                                    IFIN ERRORS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.IfInErrors, self).__init__()

                                        self.yang_name = "if-in-errors"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "if-in-errors"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.IfInErrors, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class IfInOctets(Entity):
                                    """
                                    IFIN OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.IfInOctets, self).__init__()

                                        self.yang_name = "if-in-octets"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "if-in-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.IfInOctets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class EtherStatMulticastPkt(Entity):
                                    """
                                    ETHER STAT MULTICAST PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.EtherStatMulticastPkt, self).__init__()

                                        self.yang_name = "ether-stat-multicast-pkt"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ether-stat-multicast-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.EtherStatMulticastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class EtherStatBroadcastPkt(Entity):
                                    """
                                    ETHER STAT BROADCAST PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.EtherStatBroadcastPkt, self).__init__()

                                        self.yang_name = "ether-stat-broadcast-pkt"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ether-stat-broadcast-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.EtherStatBroadcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class EtherStatUndersizedPkt(Entity):
                                    """
                                    ETHER STAT UNDERSIZED PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.EtherStatUndersizedPkt, self).__init__()

                                        self.yang_name = "ether-stat-undersized-pkt"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ether-stat-undersized-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.EtherStatUndersizedPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutOctets(Entity):
                                    """
                                    OUT OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutOctets, self).__init__()

                                        self.yang_name = "out-octets"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutOctets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPauseFrame(Entity):
                                    """
                                    INPUT PAUSE FRAME
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPauseFrame, self).__init__()

                                        self.yang_name = "in-pause-frame"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pause-frame"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPauseFrame, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InGoodBytes(Entity):
                                    """
                                    INPUT GOOD BYTES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InGoodBytes, self).__init__()

                                        self.yang_name = "in-good-bytes"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-good-bytes"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InGoodBytes, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class In8021qFrames(Entity):
                                    """
                                    INPUT 802 1Q FRAMES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.In8021qFrames, self).__init__()

                                        self.yang_name = "in8021q-frames"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in8021q-frames"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.In8021qFrames, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPkts1519MaxOctets(Entity):
                                    """
                                    INPUT PKTS 1519MAX OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts1519MaxOctets, self).__init__()

                                        self.yang_name = "in-pkts1519-max-octets"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts1519-max-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts1519MaxOctets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InGoodPkts(Entity):
                                    """
                                    INPUT GOOD PKTS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InGoodPkts, self).__init__()

                                        self.yang_name = "in-good-pkts"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-good-pkts"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InGoodPkts, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InDropOverrun(Entity):
                                    """
                                    INPUT DROP OVERRUN
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropOverrun, self).__init__()

                                        self.yang_name = "in-drop-overrun"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-drop-overrun"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropOverrun, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InDropAbort(Entity):
                                    """
                                    INPUT DROP ABORT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropAbort, self).__init__()

                                        self.yang_name = "in-drop-abort"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-drop-abort"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropAbort, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InDropInvalidVlan(Entity):
                                    """
                                    INPUT DROP INVALID VLAN
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropInvalidVlan, self).__init__()

                                        self.yang_name = "in-drop-invalid-vlan"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-drop-invalid-vlan"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropInvalidVlan, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InDropInvalidDmac(Entity):
                                    """
                                    INPUT DROP INVALID DMAC
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropInvalidDmac, self).__init__()

                                        self.yang_name = "in-drop-invalid-dmac"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-drop-invalid-dmac"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropInvalidDmac, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InDropInvalidEncap(Entity):
                                    """
                                    INPUT DROP INVALID ENCAP
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropInvalidEncap, self).__init__()

                                        self.yang_name = "in-drop-invalid-encap"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-drop-invalid-encap"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropInvalidEncap, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InDropOther(Entity):
                                    """
                                    INPUT DROP OTHER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropOther, self).__init__()

                                        self.yang_name = "in-drop-other"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-drop-other"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropOther, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InMibGiant(Entity):
                                    """
                                    INPUT MIB GIANT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InMibGiant, self).__init__()

                                        self.yang_name = "in-mib-giant"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-mib-giant"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InMibGiant, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InMibJabber(Entity):
                                    """
                                    INPUT MIB JABBER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InMibJabber, self).__init__()

                                        self.yang_name = "in-mib-jabber"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-mib-jabber"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InMibJabber, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InMibcrc(Entity):
                                    """
                                    IN MIB CRC
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InMibcrc, self).__init__()

                                        self.yang_name = "in-mibcrc"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-mibcrc"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InMibcrc, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InErrorCollisions(Entity):
                                    """
                                    IN ERROR COLLISIONS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorCollisions, self).__init__()

                                        self.yang_name = "in-error-collisions"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-error-collisions"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorCollisions, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InErrorSymbol(Entity):
                                    """
                                    IN ERROR SYMBOL
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorSymbol, self).__init__()

                                        self.yang_name = "in-error-symbol"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-error-symbol"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorSymbol, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutGoodBytes(Entity):
                                    """
                                    OUT GOOD BYTES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutGoodBytes, self).__init__()

                                        self.yang_name = "out-good-bytes"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-good-bytes"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutGoodBytes, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class Out8021qFrames(Entity):
                                    """
                                    OUT 802 1Q FRAMES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Out8021qFrames, self).__init__()

                                        self.yang_name = "out8021q-frames"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out8021q-frames"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Out8021qFrames, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutPauseFrames(Entity):
                                    """
                                    OUT PAUSE FRAMES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPauseFrames, self).__init__()

                                        self.yang_name = "out-pause-frames"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-pause-frames"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPauseFrames, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutPkts1519MaxOctets(Entity):
                                    """
                                    OUT PKTS 1519 MAX OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts1519MaxOctets, self).__init__()

                                        self.yang_name = "out-pkts1519-max-octets"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-pkts1519-max-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts1519MaxOctets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutGoodPkts(Entity):
                                    """
                                    OUT GOOD PKTS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutGoodPkts, self).__init__()

                                        self.yang_name = "out-good-pkts"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-good-pkts"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutGoodPkts, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutDropUnderrun(Entity):
                                    """
                                    OUT DROP UNDERRUN
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutDropUnderrun, self).__init__()

                                        self.yang_name = "out-drop-underrun"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-drop-underrun"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutDropUnderrun, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutDropAbort(Entity):
                                    """
                                    OUT DROP ABORT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutDropAbort, self).__init__()

                                        self.yang_name = "out-drop-abort"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-drop-abort"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutDropAbort, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutDropOther(Entity):
                                    """
                                    OUT DROP OTHER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutDropOther, self).__init__()

                                        self.yang_name = "out-drop-other"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-drop-other"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutDropOther, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutErrorOther(Entity):
                                    """
                                    OUT ERROR OTHER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutErrorOther, self).__init__()

                                        self.yang_name = "out-error-other"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-error-other"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutErrorOther, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InErrorGiant(Entity):
                                    """
                                    IN ERROR GIANT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorGiant, self).__init__()

                                        self.yang_name = "in-error-giant"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-error-giant"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorGiant, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InErrorRunt(Entity):
                                    """
                                    IN ERROR RUNT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorRunt, self).__init__()

                                        self.yang_name = "in-error-runt"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-error-runt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorRunt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InErrorJabbers(Entity):
                                    """
                                    IN ERROR JABBERS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorJabbers, self).__init__()

                                        self.yang_name = "in-error-jabbers"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-error-jabbers"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorJabbers, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InErrorFragments(Entity):
                                    """
                                    IN ERROR FRAGMENTS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorFragments, self).__init__()

                                        self.yang_name = "in-error-fragments"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-error-fragments"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorFragments, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InErrorOther(Entity):
                                    """
                                    IN ERROR OTHER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorOther, self).__init__()

                                        self.yang_name = "in-error-other"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-error-other"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorOther, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPkt64Octet(Entity):
                                    """
                                    IN PKT 64 OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkt64Octet, self).__init__()

                                        self.yang_name = "in-pkt64-octet"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkt64-octet"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkt64Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPkts65To127Octets(Entity):
                                    """
                                    IN PKTS 65 127OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts65To127Octets, self).__init__()

                                        self.yang_name = "in-pkts65-to127-octets"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts65-to127-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts65To127Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPkts128To255Octets(Entity):
                                    """
                                    IN PKTS 128 255 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts128To255Octets, self).__init__()

                                        self.yang_name = "in-pkts128-to255-octets"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts128-to255-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts128To255Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPkts256To511Octets(Entity):
                                    """
                                    IN PKTS 256 511 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts256To511Octets, self).__init__()

                                        self.yang_name = "in-pkts256-to511-octets"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts256-to511-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts256To511Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPkts512To1023Octets(Entity):
                                    """
                                    IN PKTS 512 1023 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts512To1023Octets, self).__init__()

                                        self.yang_name = "in-pkts512-to1023-octets"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts512-to1023-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts512To1023Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPkts1024To1518Octets(Entity):
                                    """
                                    IN PKTS 1024 1518 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts1024To1518Octets, self).__init__()

                                        self.yang_name = "in-pkts1024-to1518-octets"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts1024-to1518-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts1024To1518Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class Outpkt64octet(Entity):
                                    """
                                    OUT PKT 64 OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Outpkt64octet, self).__init__()

                                        self.yang_name = "outpkt64octet"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "outpkt64octet"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Outpkt64octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutPkts65127Octets(Entity):
                                    """
                                    OUT PKTS 65 127OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts65127Octets, self).__init__()

                                        self.yang_name = "out-pkts65127-octets"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-pkts65127-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts65127Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutPkts128255Octets(Entity):
                                    """
                                    OUT PKTS 128 255 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts128255Octets, self).__init__()

                                        self.yang_name = "out-pkts128255-octets"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-pkts128255-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts128255Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutPkts256511Octets(Entity):
                                    """
                                    OUT PKTS 256 511 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts256511Octets, self).__init__()

                                        self.yang_name = "out-pkts256511-octets"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-pkts256511-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts256511Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutPkts5121023Octets(Entity):
                                    """
                                    OUT PKTS 512 1023 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts5121023Octets, self).__init__()

                                        self.yang_name = "out-pkts5121023-octets"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-pkts5121023-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts5121023Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutPkts10241518Octets(Entity):
                                    """
                                    OUT PKTS 1024 1518 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts10241518Octets, self).__init__()

                                        self.yang_name = "out-pkts10241518-octets"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-pkts10241518-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts10241518Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class RxUtil(Entity):
                                    """
                                    Rx Utilization in Percent
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: str
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.RxUtil, self).__init__()

                                        self.yang_name = "rx-util"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "rx-util"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.RxUtil, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class TxUtil(Entity):
                                    """
                                    Tx Utilization in Percent
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: str
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxUtil, self).__init__()

                                        self.yang_name = "tx-util"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "tx-util"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxUtil, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class TxUndersizedPkt(Entity):
                                    """
                                    TX Undersized Pkt
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxUndersizedPkt, self).__init__()

                                        self.yang_name = "tx-undersized-pkt"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "tx-undersized-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxUndersizedPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class TxOversizedPkt(Entity):
                                    """
                                    TX Oversized Pkt
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxOversizedPkt, self).__init__()

                                        self.yang_name = "tx-oversized-pkt"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "tx-oversized-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxOversizedPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class TxFragments(Entity):
                                    """
                                    TX Fragments
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxFragments, self).__init__()

                                        self.yang_name = "tx-fragments"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "tx-fragments"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxFragments, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class TxJabber(Entity):
                                    """
                                    TX Jabber
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxJabber, self).__init__()

                                        self.yang_name = "tx-jabber"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "tx-jabber"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxJabber, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class TxBadFcs(Entity):
                                    """
                                    TX Bad Fcs
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxBadFcs, self).__init__()

                                        self.yang_name = "tx-bad-fcs"
                                        self.yang_parent_name = "second30-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "tx-bad-fcs"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxBadFcs, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                    class EthernetHour24(Entity):
                        """
                        port current performance data
                        
                        .. attribute:: ethernet_hour24_ether_s
                        
                        	port current performance data
                        	**type**\:  :py:class:`EthernetHour24EtherS <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS>`
                        
                        .. attribute:: hour24pcses
                        
                        	port current performance data
                        	**type**\:  :py:class:`Hour24pcses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.Hour24pcses>`
                        
                        .. attribute:: ethernet_hour24fecs
                        
                        	port current performance data
                        	**type**\:  :py:class:`EthernetHour24fecs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24fecs>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24, self).__init__()

                            self.yang_name = "ethernet-hour24"
                            self.yang_parent_name = "ethernet-current"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ethernet-hour24-ether-s", ("ethernet_hour24_ether_s", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS)), ("hour24pcses", ("hour24pcses", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.Hour24pcses)), ("ethernet-hour24fecs", ("ethernet_hour24fecs", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24fecs))])
                            self._leafs = OrderedDict()

                            self.ethernet_hour24_ether_s = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS()
                            self.ethernet_hour24_ether_s.parent = self
                            self._children_name_map["ethernet_hour24_ether_s"] = "ethernet-hour24-ether-s"

                            self.hour24pcses = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.Hour24pcses()
                            self.hour24pcses.parent = self
                            self._children_name_map["hour24pcses"] = "hour24pcses"

                            self.ethernet_hour24fecs = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24fecs()
                            self.ethernet_hour24fecs.parent = self
                            self._children_name_map["ethernet_hour24fecs"] = "ethernet-hour24fecs"
                            self._segment_path = lambda: "ethernet-hour24"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24, [], name, value)


                        class EthernetHour24EtherS(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: ethernet_hour24_ether
                            
                            	port 24 hour ethernet performance data
                            	**type**\: list of  		 :py:class:`EthernetHour24Ether <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS, self).__init__()

                                self.yang_name = "ethernet-hour24-ether-s"
                                self.yang_parent_name = "ethernet-hour24"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ethernet-hour24-ether", ("ethernet_hour24_ether", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether))])
                                self._leafs = OrderedDict()

                                self.ethernet_hour24_ether = YList(self)
                                self._segment_path = lambda: "ethernet-hour24-ether-s"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS, [], name, value)


                            class EthernetHour24Ether(Entity):
                                """
                                port 24 hour ethernet performance data
                                
                                .. attribute:: number  (key)
                                
                                	channel number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rx_pkt
                                
                                	RX PKT
                                	**type**\:  :py:class:`RxPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.RxPkt>`
                                
                                .. attribute:: stat_pkt
                                
                                	STAT PKT
                                	**type**\:  :py:class:`StatPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.StatPkt>`
                                
                                .. attribute:: octet_stat
                                
                                	OCTET STAT
                                	**type**\:  :py:class:`OctetStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OctetStat>`
                                
                                .. attribute:: oversize_pkt_stat
                                
                                	OVERSIZE PKT
                                	**type**\:  :py:class:`OversizePktStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OversizePktStat>`
                                
                                .. attribute:: fcs_errors_stat
                                
                                	FCS ERR
                                	**type**\:  :py:class:`FcsErrorsStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.FcsErrorsStat>`
                                
                                .. attribute:: long_frames_stat
                                
                                	LONG FRAMES
                                	**type**\:  :py:class:`LongFramesStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.LongFramesStat>`
                                
                                .. attribute:: jabber_stat
                                
                                	JABBER STATS
                                	**type**\:  :py:class:`JabberStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.JabberStat>`
                                
                                .. attribute:: ether64_octets
                                
                                	SIXTY FOUR OCTET
                                	**type**\:  :py:class:`Ether64Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether64Octets>`
                                
                                .. attribute:: ether65127_octet
                                
                                	OCTET
                                	**type**\:  :py:class:`Ether65127Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether65127Octet>`
                                
                                .. attribute:: ether128255_octet
                                
                                	TFF OCTET
                                	**type**\:  :py:class:`Ether128255Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether128255Octet>`
                                
                                .. attribute:: ether256511_octet
                                
                                	FOO OCTET
                                	**type**\:  :py:class:`Ether256511Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether256511Octet>`
                                
                                .. attribute:: ether5121023_octet
                                
                                	OZTT OCTET
                                	**type**\:  :py:class:`Ether5121023Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether5121023Octet>`
                                
                                .. attribute:: ether10241518_octet
                                
                                	OFO OCTET
                                	**type**\:  :py:class:`Ether10241518Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether10241518Octet>`
                                
                                .. attribute:: in_ucast_pkt
                                
                                	IN UCAST
                                	**type**\:  :py:class:`InUcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InUcastPkt>`
                                
                                .. attribute:: in_mcast_pkt
                                
                                	IN MCAST
                                	**type**\:  :py:class:`InMcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InMcastPkt>`
                                
                                .. attribute:: in_bcast_pkt
                                
                                	IN BCAST
                                	**type**\:  :py:class:`InBcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InBcastPkt>`
                                
                                .. attribute:: out_ucast_pkt
                                
                                	OUT UCAST
                                	**type**\:  :py:class:`OutUcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutUcastPkt>`
                                
                                .. attribute:: out_bcast_pkt
                                
                                	OUT BCAST
                                	**type**\:  :py:class:`OutBcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutBcastPkt>`
                                
                                .. attribute:: out_mcast_pkt
                                
                                	OUT MCAST
                                	**type**\:  :py:class:`OutMcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutMcastPkt>`
                                
                                .. attribute:: tx_pkt
                                
                                	TX PKT
                                	**type**\:  :py:class:`TxPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxPkt>`
                                
                                .. attribute:: if_in_errors
                                
                                	IFIN ERRORS
                                	**type**\:  :py:class:`IfInErrors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.IfInErrors>`
                                
                                .. attribute:: if_in_octets
                                
                                	IFIN OCTETS
                                	**type**\:  :py:class:`IfInOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.IfInOctets>`
                                
                                .. attribute:: ether_stat_multicast_pkt
                                
                                	ETHER STAT MULTICAST PKT
                                	**type**\:  :py:class:`EtherStatMulticastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.EtherStatMulticastPkt>`
                                
                                .. attribute:: ether_stat_broadcast_pkt
                                
                                	ETHER STAT BROADCAST PKT
                                	**type**\:  :py:class:`EtherStatBroadcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.EtherStatBroadcastPkt>`
                                
                                .. attribute:: ether_stat_undersized_pkt
                                
                                	ETHER STAT UNDERSIZED PKT
                                	**type**\:  :py:class:`EtherStatUndersizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.EtherStatUndersizedPkt>`
                                
                                .. attribute:: out_octets
                                
                                	OUT OCTET
                                	**type**\:  :py:class:`OutOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutOctets>`
                                
                                .. attribute:: in_pause_frame
                                
                                	INPUT PAUSE FRAME
                                	**type**\:  :py:class:`InPauseFrame <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPauseFrame>`
                                
                                .. attribute:: in_good_bytes
                                
                                	INPUT GOOD BYTES
                                	**type**\:  :py:class:`InGoodBytes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InGoodBytes>`
                                
                                .. attribute:: in8021q_frames
                                
                                	INPUT 802 1Q FRAMES
                                	**type**\:  :py:class:`In8021qFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.In8021qFrames>`
                                
                                .. attribute:: in_pkts1519_max_octets
                                
                                	INPUT PKTS 1519MAX OCTETS
                                	**type**\:  :py:class:`InPkts1519MaxOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts1519MaxOctets>`
                                
                                .. attribute:: in_good_pkts
                                
                                	INPUT GOOD PKTS
                                	**type**\:  :py:class:`InGoodPkts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InGoodPkts>`
                                
                                .. attribute:: in_drop_overrun
                                
                                	INPUT DROP OVERRUN
                                	**type**\:  :py:class:`InDropOverrun <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropOverrun>`
                                
                                .. attribute:: in_drop_abort
                                
                                	INPUT DROP ABORT
                                	**type**\:  :py:class:`InDropAbort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropAbort>`
                                
                                .. attribute:: in_drop_invalid_vlan
                                
                                	INPUT DROP INVALID VLAN
                                	**type**\:  :py:class:`InDropInvalidVlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropInvalidVlan>`
                                
                                .. attribute:: in_drop_invalid_dmac
                                
                                	INPUT DROP INVALID DMAC
                                	**type**\:  :py:class:`InDropInvalidDmac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropInvalidDmac>`
                                
                                .. attribute:: in_drop_invalid_encap
                                
                                	INPUT DROP INVALID ENCAP
                                	**type**\:  :py:class:`InDropInvalidEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropInvalidEncap>`
                                
                                .. attribute:: in_drop_other
                                
                                	INPUT DROP OTHER
                                	**type**\:  :py:class:`InDropOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropOther>`
                                
                                .. attribute:: in_mib_giant
                                
                                	INPUT MIB GIANT
                                	**type**\:  :py:class:`InMibGiant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InMibGiant>`
                                
                                .. attribute:: in_mib_jabber
                                
                                	INPUT MIB JABBER
                                	**type**\:  :py:class:`InMibJabber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InMibJabber>`
                                
                                .. attribute:: in_mibcrc
                                
                                	IN MIB CRC
                                	**type**\:  :py:class:`InMibcrc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InMibcrc>`
                                
                                .. attribute:: in_error_collisions
                                
                                	IN ERROR COLLISIONS
                                	**type**\:  :py:class:`InErrorCollisions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorCollisions>`
                                
                                .. attribute:: in_error_symbol
                                
                                	IN ERROR SYMBOL
                                	**type**\:  :py:class:`InErrorSymbol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorSymbol>`
                                
                                .. attribute:: out_good_bytes
                                
                                	OUT GOOD BYTES
                                	**type**\:  :py:class:`OutGoodBytes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutGoodBytes>`
                                
                                .. attribute:: out8021q_frames
                                
                                	OUT 802 1Q FRAMES
                                	**type**\:  :py:class:`Out8021qFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Out8021qFrames>`
                                
                                .. attribute:: out_pause_frames
                                
                                	OUT PAUSE FRAMES
                                	**type**\:  :py:class:`OutPauseFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPauseFrames>`
                                
                                .. attribute:: out_pkts1519_max_octets
                                
                                	OUT PKTS 1519 MAX OCTETS
                                	**type**\:  :py:class:`OutPkts1519MaxOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts1519MaxOctets>`
                                
                                .. attribute:: out_good_pkts
                                
                                	OUT GOOD PKTS
                                	**type**\:  :py:class:`OutGoodPkts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutGoodPkts>`
                                
                                .. attribute:: out_drop_underrun
                                
                                	OUT DROP UNDERRUN
                                	**type**\:  :py:class:`OutDropUnderrun <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutDropUnderrun>`
                                
                                .. attribute:: out_drop_abort
                                
                                	OUT DROP ABORT
                                	**type**\:  :py:class:`OutDropAbort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutDropAbort>`
                                
                                .. attribute:: out_drop_other
                                
                                	OUT DROP OTHER
                                	**type**\:  :py:class:`OutDropOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutDropOther>`
                                
                                .. attribute:: out_error_other
                                
                                	OUT ERROR OTHER
                                	**type**\:  :py:class:`OutErrorOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutErrorOther>`
                                
                                .. attribute:: in_error_giant
                                
                                	IN ERROR GIANT
                                	**type**\:  :py:class:`InErrorGiant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorGiant>`
                                
                                .. attribute:: in_error_runt
                                
                                	IN ERROR RUNT
                                	**type**\:  :py:class:`InErrorRunt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorRunt>`
                                
                                .. attribute:: in_error_jabbers
                                
                                	IN ERROR JABBERS
                                	**type**\:  :py:class:`InErrorJabbers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorJabbers>`
                                
                                .. attribute:: in_error_fragments
                                
                                	IN ERROR FRAGMENTS
                                	**type**\:  :py:class:`InErrorFragments <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorFragments>`
                                
                                .. attribute:: in_error_other
                                
                                	IN ERROR OTHER
                                	**type**\:  :py:class:`InErrorOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorOther>`
                                
                                .. attribute:: in_pkt64_octet
                                
                                	IN PKT 64 OCTET
                                	**type**\:  :py:class:`InPkt64Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkt64Octet>`
                                
                                .. attribute:: in_pkts65_to127_octets
                                
                                	IN PKTS 65 127OCTETS
                                	**type**\:  :py:class:`InPkts65To127Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts65To127Octets>`
                                
                                .. attribute:: in_pkts128_to255_octets
                                
                                	IN PKTS 128 255 OCTETS
                                	**type**\:  :py:class:`InPkts128To255Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts128To255Octets>`
                                
                                .. attribute:: in_pkts256_to511_octets
                                
                                	IN PKTS 256 511 OCTETS
                                	**type**\:  :py:class:`InPkts256To511Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts256To511Octets>`
                                
                                .. attribute:: in_pkts512_to1023_octets
                                
                                	IN PKTS 512 1023 OCTETS
                                	**type**\:  :py:class:`InPkts512To1023Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts512To1023Octets>`
                                
                                .. attribute:: in_pkts1024_to1518_octets
                                
                                	IN PKTS 1024 1518 OCTETS
                                	**type**\:  :py:class:`InPkts1024To1518Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts1024To1518Octets>`
                                
                                .. attribute:: outpkt64octet
                                
                                	OUT PKT 64 OCTET
                                	**type**\:  :py:class:`Outpkt64octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Outpkt64octet>`
                                
                                .. attribute:: out_pkts65127_octets
                                
                                	OUT PKTS 65 127OCTETS
                                	**type**\:  :py:class:`OutPkts65127Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts65127Octets>`
                                
                                .. attribute:: out_pkts128255_octets
                                
                                	OUT PKTS 128 255 OCTETS
                                	**type**\:  :py:class:`OutPkts128255Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts128255Octets>`
                                
                                .. attribute:: out_pkts256511_octets
                                
                                	OUT PKTS 256 511 OCTETS
                                	**type**\:  :py:class:`OutPkts256511Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts256511Octets>`
                                
                                .. attribute:: out_pkts5121023_octets
                                
                                	OUT PKTS 512 1023 OCTETS
                                	**type**\:  :py:class:`OutPkts5121023Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts5121023Octets>`
                                
                                .. attribute:: out_pkts10241518_octets
                                
                                	OUT PKTS 1024 1518 OCTETS
                                	**type**\:  :py:class:`OutPkts10241518Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts10241518Octets>`
                                
                                .. attribute:: rx_util
                                
                                	Rx Utilization in Percent
                                	**type**\:  :py:class:`RxUtil <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.RxUtil>`
                                
                                .. attribute:: tx_util
                                
                                	Tx Utilization in Percent
                                	**type**\:  :py:class:`TxUtil <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxUtil>`
                                
                                .. attribute:: tx_undersized_pkt
                                
                                	TX Undersized Pkt
                                	**type**\:  :py:class:`TxUndersizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxUndersizedPkt>`
                                
                                .. attribute:: tx_oversized_pkt
                                
                                	TX Oversized Pkt
                                	**type**\:  :py:class:`TxOversizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxOversizedPkt>`
                                
                                .. attribute:: tx_fragments
                                
                                	TX Fragments
                                	**type**\:  :py:class:`TxFragments <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxFragments>`
                                
                                .. attribute:: tx_jabber
                                
                                	TX Jabber
                                	**type**\:  :py:class:`TxJabber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxJabber>`
                                
                                .. attribute:: tx_bad_fcs
                                
                                	TX Bad Fcs
                                	**type**\:  :py:class:`TxBadFcs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxBadFcs>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether, self).__init__()

                                    self.yang_name = "ethernet-hour24-ether"
                                    self.yang_parent_name = "ethernet-hour24-ether-s"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("rx-pkt", ("rx_pkt", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.RxPkt)), ("stat-pkt", ("stat_pkt", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.StatPkt)), ("octet-stat", ("octet_stat", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OctetStat)), ("oversize-pkt-stat", ("oversize_pkt_stat", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OversizePktStat)), ("fcs-errors-stat", ("fcs_errors_stat", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.FcsErrorsStat)), ("long-frames-stat", ("long_frames_stat", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.LongFramesStat)), ("jabber-stat", ("jabber_stat", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.JabberStat)), ("ether64-octets", ("ether64_octets", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether64Octets)), ("ether65127-octet", ("ether65127_octet", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether65127Octet)), ("ether128255-octet", ("ether128255_octet", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether128255Octet)), ("ether256511-octet", ("ether256511_octet", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether256511Octet)), ("ether5121023-octet", ("ether5121023_octet", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether5121023Octet)), ("ether10241518-octet", ("ether10241518_octet", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether10241518Octet)), ("in-ucast-pkt", ("in_ucast_pkt", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InUcastPkt)), ("in-mcast-pkt", ("in_mcast_pkt", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InMcastPkt)), ("in-bcast-pkt", ("in_bcast_pkt", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InBcastPkt)), ("out-ucast-pkt", ("out_ucast_pkt", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutUcastPkt)), ("out-bcast-pkt", ("out_bcast_pkt", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutBcastPkt)), ("out-mcast-pkt", ("out_mcast_pkt", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutMcastPkt)), ("tx-pkt", ("tx_pkt", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxPkt)), ("if-in-errors", ("if_in_errors", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.IfInErrors)), ("if-in-octets", ("if_in_octets", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.IfInOctets)), ("ether-stat-multicast-pkt", ("ether_stat_multicast_pkt", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.EtherStatMulticastPkt)), ("ether-stat-broadcast-pkt", ("ether_stat_broadcast_pkt", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.EtherStatBroadcastPkt)), ("ether-stat-undersized-pkt", ("ether_stat_undersized_pkt", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.EtherStatUndersizedPkt)), ("out-octets", ("out_octets", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutOctets)), ("in-pause-frame", ("in_pause_frame", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPauseFrame)), ("in-good-bytes", ("in_good_bytes", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InGoodBytes)), ("in8021q-frames", ("in8021q_frames", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.In8021qFrames)), ("in-pkts1519-max-octets", ("in_pkts1519_max_octets", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts1519MaxOctets)), ("in-good-pkts", ("in_good_pkts", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InGoodPkts)), ("in-drop-overrun", ("in_drop_overrun", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropOverrun)), ("in-drop-abort", ("in_drop_abort", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropAbort)), ("in-drop-invalid-vlan", ("in_drop_invalid_vlan", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropInvalidVlan)), ("in-drop-invalid-dmac", ("in_drop_invalid_dmac", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropInvalidDmac)), ("in-drop-invalid-encap", ("in_drop_invalid_encap", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropInvalidEncap)), ("in-drop-other", ("in_drop_other", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropOther)), ("in-mib-giant", ("in_mib_giant", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InMibGiant)), ("in-mib-jabber", ("in_mib_jabber", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InMibJabber)), ("in-mibcrc", ("in_mibcrc", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InMibcrc)), ("in-error-collisions", ("in_error_collisions", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorCollisions)), ("in-error-symbol", ("in_error_symbol", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorSymbol)), ("out-good-bytes", ("out_good_bytes", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutGoodBytes)), ("out8021q-frames", ("out8021q_frames", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Out8021qFrames)), ("out-pause-frames", ("out_pause_frames", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPauseFrames)), ("out-pkts1519-max-octets", ("out_pkts1519_max_octets", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts1519MaxOctets)), ("out-good-pkts", ("out_good_pkts", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutGoodPkts)), ("out-drop-underrun", ("out_drop_underrun", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutDropUnderrun)), ("out-drop-abort", ("out_drop_abort", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutDropAbort)), ("out-drop-other", ("out_drop_other", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutDropOther)), ("out-error-other", ("out_error_other", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutErrorOther)), ("in-error-giant", ("in_error_giant", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorGiant)), ("in-error-runt", ("in_error_runt", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorRunt)), ("in-error-jabbers", ("in_error_jabbers", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorJabbers)), ("in-error-fragments", ("in_error_fragments", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorFragments)), ("in-error-other", ("in_error_other", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorOther)), ("in-pkt64-octet", ("in_pkt64_octet", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkt64Octet)), ("in-pkts65-to127-octets", ("in_pkts65_to127_octets", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts65To127Octets)), ("in-pkts128-to255-octets", ("in_pkts128_to255_octets", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts128To255Octets)), ("in-pkts256-to511-octets", ("in_pkts256_to511_octets", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts256To511Octets)), ("in-pkts512-to1023-octets", ("in_pkts512_to1023_octets", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts512To1023Octets)), ("in-pkts1024-to1518-octets", ("in_pkts1024_to1518_octets", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts1024To1518Octets)), ("outpkt64octet", ("outpkt64octet", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Outpkt64octet)), ("out-pkts65127-octets", ("out_pkts65127_octets", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts65127Octets)), ("out-pkts128255-octets", ("out_pkts128255_octets", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts128255Octets)), ("out-pkts256511-octets", ("out_pkts256511_octets", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts256511Octets)), ("out-pkts5121023-octets", ("out_pkts5121023_octets", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts5121023Octets)), ("out-pkts10241518-octets", ("out_pkts10241518_octets", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts10241518Octets)), ("rx-util", ("rx_util", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.RxUtil)), ("tx-util", ("tx_util", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxUtil)), ("tx-undersized-pkt", ("tx_undersized_pkt", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxUndersizedPkt)), ("tx-oversized-pkt", ("tx_oversized_pkt", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxOversizedPkt)), ("tx-fragments", ("tx_fragments", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxFragments)), ("tx-jabber", ("tx_jabber", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxJabber)), ("tx-bad-fcs", ("tx_bad_fcs", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxBadFcs))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                        ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                    ])
                                    self.number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None
                                    self.sec30_support = None

                                    self.rx_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.RxPkt()
                                    self.rx_pkt.parent = self
                                    self._children_name_map["rx_pkt"] = "rx-pkt"

                                    self.stat_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.StatPkt()
                                    self.stat_pkt.parent = self
                                    self._children_name_map["stat_pkt"] = "stat-pkt"

                                    self.octet_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OctetStat()
                                    self.octet_stat.parent = self
                                    self._children_name_map["octet_stat"] = "octet-stat"

                                    self.oversize_pkt_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OversizePktStat()
                                    self.oversize_pkt_stat.parent = self
                                    self._children_name_map["oversize_pkt_stat"] = "oversize-pkt-stat"

                                    self.fcs_errors_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.FcsErrorsStat()
                                    self.fcs_errors_stat.parent = self
                                    self._children_name_map["fcs_errors_stat"] = "fcs-errors-stat"

                                    self.long_frames_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.LongFramesStat()
                                    self.long_frames_stat.parent = self
                                    self._children_name_map["long_frames_stat"] = "long-frames-stat"

                                    self.jabber_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.JabberStat()
                                    self.jabber_stat.parent = self
                                    self._children_name_map["jabber_stat"] = "jabber-stat"

                                    self.ether64_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether64Octets()
                                    self.ether64_octets.parent = self
                                    self._children_name_map["ether64_octets"] = "ether64-octets"

                                    self.ether65127_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether65127Octet()
                                    self.ether65127_octet.parent = self
                                    self._children_name_map["ether65127_octet"] = "ether65127-octet"

                                    self.ether128255_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether128255Octet()
                                    self.ether128255_octet.parent = self
                                    self._children_name_map["ether128255_octet"] = "ether128255-octet"

                                    self.ether256511_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether256511Octet()
                                    self.ether256511_octet.parent = self
                                    self._children_name_map["ether256511_octet"] = "ether256511-octet"

                                    self.ether5121023_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether5121023Octet()
                                    self.ether5121023_octet.parent = self
                                    self._children_name_map["ether5121023_octet"] = "ether5121023-octet"

                                    self.ether10241518_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether10241518Octet()
                                    self.ether10241518_octet.parent = self
                                    self._children_name_map["ether10241518_octet"] = "ether10241518-octet"

                                    self.in_ucast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InUcastPkt()
                                    self.in_ucast_pkt.parent = self
                                    self._children_name_map["in_ucast_pkt"] = "in-ucast-pkt"

                                    self.in_mcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InMcastPkt()
                                    self.in_mcast_pkt.parent = self
                                    self._children_name_map["in_mcast_pkt"] = "in-mcast-pkt"

                                    self.in_bcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InBcastPkt()
                                    self.in_bcast_pkt.parent = self
                                    self._children_name_map["in_bcast_pkt"] = "in-bcast-pkt"

                                    self.out_ucast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutUcastPkt()
                                    self.out_ucast_pkt.parent = self
                                    self._children_name_map["out_ucast_pkt"] = "out-ucast-pkt"

                                    self.out_bcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutBcastPkt()
                                    self.out_bcast_pkt.parent = self
                                    self._children_name_map["out_bcast_pkt"] = "out-bcast-pkt"

                                    self.out_mcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutMcastPkt()
                                    self.out_mcast_pkt.parent = self
                                    self._children_name_map["out_mcast_pkt"] = "out-mcast-pkt"

                                    self.tx_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxPkt()
                                    self.tx_pkt.parent = self
                                    self._children_name_map["tx_pkt"] = "tx-pkt"

                                    self.if_in_errors = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.IfInErrors()
                                    self.if_in_errors.parent = self
                                    self._children_name_map["if_in_errors"] = "if-in-errors"

                                    self.if_in_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.IfInOctets()
                                    self.if_in_octets.parent = self
                                    self._children_name_map["if_in_octets"] = "if-in-octets"

                                    self.ether_stat_multicast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.EtherStatMulticastPkt()
                                    self.ether_stat_multicast_pkt.parent = self
                                    self._children_name_map["ether_stat_multicast_pkt"] = "ether-stat-multicast-pkt"

                                    self.ether_stat_broadcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.EtherStatBroadcastPkt()
                                    self.ether_stat_broadcast_pkt.parent = self
                                    self._children_name_map["ether_stat_broadcast_pkt"] = "ether-stat-broadcast-pkt"

                                    self.ether_stat_undersized_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.EtherStatUndersizedPkt()
                                    self.ether_stat_undersized_pkt.parent = self
                                    self._children_name_map["ether_stat_undersized_pkt"] = "ether-stat-undersized-pkt"

                                    self.out_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutOctets()
                                    self.out_octets.parent = self
                                    self._children_name_map["out_octets"] = "out-octets"

                                    self.in_pause_frame = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPauseFrame()
                                    self.in_pause_frame.parent = self
                                    self._children_name_map["in_pause_frame"] = "in-pause-frame"

                                    self.in_good_bytes = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InGoodBytes()
                                    self.in_good_bytes.parent = self
                                    self._children_name_map["in_good_bytes"] = "in-good-bytes"

                                    self.in8021q_frames = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.In8021qFrames()
                                    self.in8021q_frames.parent = self
                                    self._children_name_map["in8021q_frames"] = "in8021q-frames"

                                    self.in_pkts1519_max_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts1519MaxOctets()
                                    self.in_pkts1519_max_octets.parent = self
                                    self._children_name_map["in_pkts1519_max_octets"] = "in-pkts1519-max-octets"

                                    self.in_good_pkts = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InGoodPkts()
                                    self.in_good_pkts.parent = self
                                    self._children_name_map["in_good_pkts"] = "in-good-pkts"

                                    self.in_drop_overrun = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropOverrun()
                                    self.in_drop_overrun.parent = self
                                    self._children_name_map["in_drop_overrun"] = "in-drop-overrun"

                                    self.in_drop_abort = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropAbort()
                                    self.in_drop_abort.parent = self
                                    self._children_name_map["in_drop_abort"] = "in-drop-abort"

                                    self.in_drop_invalid_vlan = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropInvalidVlan()
                                    self.in_drop_invalid_vlan.parent = self
                                    self._children_name_map["in_drop_invalid_vlan"] = "in-drop-invalid-vlan"

                                    self.in_drop_invalid_dmac = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropInvalidDmac()
                                    self.in_drop_invalid_dmac.parent = self
                                    self._children_name_map["in_drop_invalid_dmac"] = "in-drop-invalid-dmac"

                                    self.in_drop_invalid_encap = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropInvalidEncap()
                                    self.in_drop_invalid_encap.parent = self
                                    self._children_name_map["in_drop_invalid_encap"] = "in-drop-invalid-encap"

                                    self.in_drop_other = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropOther()
                                    self.in_drop_other.parent = self
                                    self._children_name_map["in_drop_other"] = "in-drop-other"

                                    self.in_mib_giant = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InMibGiant()
                                    self.in_mib_giant.parent = self
                                    self._children_name_map["in_mib_giant"] = "in-mib-giant"

                                    self.in_mib_jabber = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InMibJabber()
                                    self.in_mib_jabber.parent = self
                                    self._children_name_map["in_mib_jabber"] = "in-mib-jabber"

                                    self.in_mibcrc = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InMibcrc()
                                    self.in_mibcrc.parent = self
                                    self._children_name_map["in_mibcrc"] = "in-mibcrc"

                                    self.in_error_collisions = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorCollisions()
                                    self.in_error_collisions.parent = self
                                    self._children_name_map["in_error_collisions"] = "in-error-collisions"

                                    self.in_error_symbol = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorSymbol()
                                    self.in_error_symbol.parent = self
                                    self._children_name_map["in_error_symbol"] = "in-error-symbol"

                                    self.out_good_bytes = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutGoodBytes()
                                    self.out_good_bytes.parent = self
                                    self._children_name_map["out_good_bytes"] = "out-good-bytes"

                                    self.out8021q_frames = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Out8021qFrames()
                                    self.out8021q_frames.parent = self
                                    self._children_name_map["out8021q_frames"] = "out8021q-frames"

                                    self.out_pause_frames = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPauseFrames()
                                    self.out_pause_frames.parent = self
                                    self._children_name_map["out_pause_frames"] = "out-pause-frames"

                                    self.out_pkts1519_max_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts1519MaxOctets()
                                    self.out_pkts1519_max_octets.parent = self
                                    self._children_name_map["out_pkts1519_max_octets"] = "out-pkts1519-max-octets"

                                    self.out_good_pkts = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutGoodPkts()
                                    self.out_good_pkts.parent = self
                                    self._children_name_map["out_good_pkts"] = "out-good-pkts"

                                    self.out_drop_underrun = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutDropUnderrun()
                                    self.out_drop_underrun.parent = self
                                    self._children_name_map["out_drop_underrun"] = "out-drop-underrun"

                                    self.out_drop_abort = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutDropAbort()
                                    self.out_drop_abort.parent = self
                                    self._children_name_map["out_drop_abort"] = "out-drop-abort"

                                    self.out_drop_other = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutDropOther()
                                    self.out_drop_other.parent = self
                                    self._children_name_map["out_drop_other"] = "out-drop-other"

                                    self.out_error_other = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutErrorOther()
                                    self.out_error_other.parent = self
                                    self._children_name_map["out_error_other"] = "out-error-other"

                                    self.in_error_giant = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorGiant()
                                    self.in_error_giant.parent = self
                                    self._children_name_map["in_error_giant"] = "in-error-giant"

                                    self.in_error_runt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorRunt()
                                    self.in_error_runt.parent = self
                                    self._children_name_map["in_error_runt"] = "in-error-runt"

                                    self.in_error_jabbers = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorJabbers()
                                    self.in_error_jabbers.parent = self
                                    self._children_name_map["in_error_jabbers"] = "in-error-jabbers"

                                    self.in_error_fragments = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorFragments()
                                    self.in_error_fragments.parent = self
                                    self._children_name_map["in_error_fragments"] = "in-error-fragments"

                                    self.in_error_other = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorOther()
                                    self.in_error_other.parent = self
                                    self._children_name_map["in_error_other"] = "in-error-other"

                                    self.in_pkt64_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkt64Octet()
                                    self.in_pkt64_octet.parent = self
                                    self._children_name_map["in_pkt64_octet"] = "in-pkt64-octet"

                                    self.in_pkts65_to127_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts65To127Octets()
                                    self.in_pkts65_to127_octets.parent = self
                                    self._children_name_map["in_pkts65_to127_octets"] = "in-pkts65-to127-octets"

                                    self.in_pkts128_to255_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts128To255Octets()
                                    self.in_pkts128_to255_octets.parent = self
                                    self._children_name_map["in_pkts128_to255_octets"] = "in-pkts128-to255-octets"

                                    self.in_pkts256_to511_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts256To511Octets()
                                    self.in_pkts256_to511_octets.parent = self
                                    self._children_name_map["in_pkts256_to511_octets"] = "in-pkts256-to511-octets"

                                    self.in_pkts512_to1023_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts512To1023Octets()
                                    self.in_pkts512_to1023_octets.parent = self
                                    self._children_name_map["in_pkts512_to1023_octets"] = "in-pkts512-to1023-octets"

                                    self.in_pkts1024_to1518_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts1024To1518Octets()
                                    self.in_pkts1024_to1518_octets.parent = self
                                    self._children_name_map["in_pkts1024_to1518_octets"] = "in-pkts1024-to1518-octets"

                                    self.outpkt64octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Outpkt64octet()
                                    self.outpkt64octet.parent = self
                                    self._children_name_map["outpkt64octet"] = "outpkt64octet"

                                    self.out_pkts65127_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts65127Octets()
                                    self.out_pkts65127_octets.parent = self
                                    self._children_name_map["out_pkts65127_octets"] = "out-pkts65127-octets"

                                    self.out_pkts128255_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts128255Octets()
                                    self.out_pkts128255_octets.parent = self
                                    self._children_name_map["out_pkts128255_octets"] = "out-pkts128255-octets"

                                    self.out_pkts256511_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts256511Octets()
                                    self.out_pkts256511_octets.parent = self
                                    self._children_name_map["out_pkts256511_octets"] = "out-pkts256511-octets"

                                    self.out_pkts5121023_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts5121023Octets()
                                    self.out_pkts5121023_octets.parent = self
                                    self._children_name_map["out_pkts5121023_octets"] = "out-pkts5121023-octets"

                                    self.out_pkts10241518_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts10241518Octets()
                                    self.out_pkts10241518_octets.parent = self
                                    self._children_name_map["out_pkts10241518_octets"] = "out-pkts10241518-octets"

                                    self.rx_util = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.RxUtil()
                                    self.rx_util.parent = self
                                    self._children_name_map["rx_util"] = "rx-util"

                                    self.tx_util = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxUtil()
                                    self.tx_util.parent = self
                                    self._children_name_map["tx_util"] = "tx-util"

                                    self.tx_undersized_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxUndersizedPkt()
                                    self.tx_undersized_pkt.parent = self
                                    self._children_name_map["tx_undersized_pkt"] = "tx-undersized-pkt"

                                    self.tx_oversized_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxOversizedPkt()
                                    self.tx_oversized_pkt.parent = self
                                    self._children_name_map["tx_oversized_pkt"] = "tx-oversized-pkt"

                                    self.tx_fragments = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxFragments()
                                    self.tx_fragments.parent = self
                                    self._children_name_map["tx_fragments"] = "tx-fragments"

                                    self.tx_jabber = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxJabber()
                                    self.tx_jabber.parent = self
                                    self._children_name_map["tx_jabber"] = "tx-jabber"

                                    self.tx_bad_fcs = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxBadFcs()
                                    self.tx_bad_fcs.parent = self
                                    self._children_name_map["tx_bad_fcs"] = "tx-bad-fcs"
                                    self._segment_path = lambda: "ethernet-hour24-ether" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear30_sec_time', 'last_clear15_min_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                class RxPkt(Entity):
                                    """
                                    RX PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.RxPkt, self).__init__()

                                        self.yang_name = "rx-pkt"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "rx-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.RxPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class StatPkt(Entity):
                                    """
                                    STAT PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.StatPkt, self).__init__()

                                        self.yang_name = "stat-pkt"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "stat-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.StatPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OctetStat(Entity):
                                    """
                                    OCTET STAT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OctetStat, self).__init__()

                                        self.yang_name = "octet-stat"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "octet-stat"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OctetStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OversizePktStat(Entity):
                                    """
                                    OVERSIZE PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OversizePktStat, self).__init__()

                                        self.yang_name = "oversize-pkt-stat"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "oversize-pkt-stat"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OversizePktStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class FcsErrorsStat(Entity):
                                    """
                                    FCS ERR
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.FcsErrorsStat, self).__init__()

                                        self.yang_name = "fcs-errors-stat"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "fcs-errors-stat"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.FcsErrorsStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class LongFramesStat(Entity):
                                    """
                                    LONG FRAMES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.LongFramesStat, self).__init__()

                                        self.yang_name = "long-frames-stat"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "long-frames-stat"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.LongFramesStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class JabberStat(Entity):
                                    """
                                    JABBER STATS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.JabberStat, self).__init__()

                                        self.yang_name = "jabber-stat"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "jabber-stat"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.JabberStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class Ether64Octets(Entity):
                                    """
                                    SIXTY FOUR OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether64Octets, self).__init__()

                                        self.yang_name = "ether64-octets"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ether64-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether64Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class Ether65127Octet(Entity):
                                    """
                                    OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether65127Octet, self).__init__()

                                        self.yang_name = "ether65127-octet"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ether65127-octet"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether65127Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class Ether128255Octet(Entity):
                                    """
                                    TFF OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether128255Octet, self).__init__()

                                        self.yang_name = "ether128255-octet"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ether128255-octet"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether128255Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class Ether256511Octet(Entity):
                                    """
                                    FOO OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether256511Octet, self).__init__()

                                        self.yang_name = "ether256511-octet"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ether256511-octet"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether256511Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class Ether5121023Octet(Entity):
                                    """
                                    OZTT OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether5121023Octet, self).__init__()

                                        self.yang_name = "ether5121023-octet"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ether5121023-octet"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether5121023Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class Ether10241518Octet(Entity):
                                    """
                                    OFO OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether10241518Octet, self).__init__()

                                        self.yang_name = "ether10241518-octet"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ether10241518-octet"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether10241518Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InUcastPkt(Entity):
                                    """
                                    IN UCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InUcastPkt, self).__init__()

                                        self.yang_name = "in-ucast-pkt"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-ucast-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InUcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InMcastPkt(Entity):
                                    """
                                    IN MCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InMcastPkt, self).__init__()

                                        self.yang_name = "in-mcast-pkt"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-mcast-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InMcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InBcastPkt(Entity):
                                    """
                                    IN BCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InBcastPkt, self).__init__()

                                        self.yang_name = "in-bcast-pkt"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-bcast-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InBcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutUcastPkt(Entity):
                                    """
                                    OUT UCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutUcastPkt, self).__init__()

                                        self.yang_name = "out-ucast-pkt"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-ucast-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutUcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutBcastPkt(Entity):
                                    """
                                    OUT BCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutBcastPkt, self).__init__()

                                        self.yang_name = "out-bcast-pkt"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-bcast-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutBcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutMcastPkt(Entity):
                                    """
                                    OUT MCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutMcastPkt, self).__init__()

                                        self.yang_name = "out-mcast-pkt"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-mcast-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutMcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class TxPkt(Entity):
                                    """
                                    TX PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxPkt, self).__init__()

                                        self.yang_name = "tx-pkt"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "tx-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class IfInErrors(Entity):
                                    """
                                    IFIN ERRORS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.IfInErrors, self).__init__()

                                        self.yang_name = "if-in-errors"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "if-in-errors"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.IfInErrors, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class IfInOctets(Entity):
                                    """
                                    IFIN OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.IfInOctets, self).__init__()

                                        self.yang_name = "if-in-octets"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "if-in-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.IfInOctets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class EtherStatMulticastPkt(Entity):
                                    """
                                    ETHER STAT MULTICAST PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.EtherStatMulticastPkt, self).__init__()

                                        self.yang_name = "ether-stat-multicast-pkt"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ether-stat-multicast-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.EtherStatMulticastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class EtherStatBroadcastPkt(Entity):
                                    """
                                    ETHER STAT BROADCAST PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.EtherStatBroadcastPkt, self).__init__()

                                        self.yang_name = "ether-stat-broadcast-pkt"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ether-stat-broadcast-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.EtherStatBroadcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class EtherStatUndersizedPkt(Entity):
                                    """
                                    ETHER STAT UNDERSIZED PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.EtherStatUndersizedPkt, self).__init__()

                                        self.yang_name = "ether-stat-undersized-pkt"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ether-stat-undersized-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.EtherStatUndersizedPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutOctets(Entity):
                                    """
                                    OUT OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutOctets, self).__init__()

                                        self.yang_name = "out-octets"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutOctets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPauseFrame(Entity):
                                    """
                                    INPUT PAUSE FRAME
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPauseFrame, self).__init__()

                                        self.yang_name = "in-pause-frame"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pause-frame"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPauseFrame, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InGoodBytes(Entity):
                                    """
                                    INPUT GOOD BYTES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InGoodBytes, self).__init__()

                                        self.yang_name = "in-good-bytes"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-good-bytes"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InGoodBytes, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class In8021qFrames(Entity):
                                    """
                                    INPUT 802 1Q FRAMES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.In8021qFrames, self).__init__()

                                        self.yang_name = "in8021q-frames"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in8021q-frames"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.In8021qFrames, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPkts1519MaxOctets(Entity):
                                    """
                                    INPUT PKTS 1519MAX OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts1519MaxOctets, self).__init__()

                                        self.yang_name = "in-pkts1519-max-octets"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts1519-max-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts1519MaxOctets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InGoodPkts(Entity):
                                    """
                                    INPUT GOOD PKTS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InGoodPkts, self).__init__()

                                        self.yang_name = "in-good-pkts"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-good-pkts"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InGoodPkts, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InDropOverrun(Entity):
                                    """
                                    INPUT DROP OVERRUN
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropOverrun, self).__init__()

                                        self.yang_name = "in-drop-overrun"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-drop-overrun"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropOverrun, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InDropAbort(Entity):
                                    """
                                    INPUT DROP ABORT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropAbort, self).__init__()

                                        self.yang_name = "in-drop-abort"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-drop-abort"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropAbort, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InDropInvalidVlan(Entity):
                                    """
                                    INPUT DROP INVALID VLAN
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropInvalidVlan, self).__init__()

                                        self.yang_name = "in-drop-invalid-vlan"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-drop-invalid-vlan"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropInvalidVlan, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InDropInvalidDmac(Entity):
                                    """
                                    INPUT DROP INVALID DMAC
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropInvalidDmac, self).__init__()

                                        self.yang_name = "in-drop-invalid-dmac"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-drop-invalid-dmac"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropInvalidDmac, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InDropInvalidEncap(Entity):
                                    """
                                    INPUT DROP INVALID ENCAP
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropInvalidEncap, self).__init__()

                                        self.yang_name = "in-drop-invalid-encap"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-drop-invalid-encap"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropInvalidEncap, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InDropOther(Entity):
                                    """
                                    INPUT DROP OTHER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropOther, self).__init__()

                                        self.yang_name = "in-drop-other"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-drop-other"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropOther, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InMibGiant(Entity):
                                    """
                                    INPUT MIB GIANT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InMibGiant, self).__init__()

                                        self.yang_name = "in-mib-giant"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-mib-giant"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InMibGiant, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InMibJabber(Entity):
                                    """
                                    INPUT MIB JABBER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InMibJabber, self).__init__()

                                        self.yang_name = "in-mib-jabber"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-mib-jabber"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InMibJabber, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InMibcrc(Entity):
                                    """
                                    IN MIB CRC
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InMibcrc, self).__init__()

                                        self.yang_name = "in-mibcrc"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-mibcrc"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InMibcrc, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InErrorCollisions(Entity):
                                    """
                                    IN ERROR COLLISIONS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorCollisions, self).__init__()

                                        self.yang_name = "in-error-collisions"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-error-collisions"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorCollisions, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InErrorSymbol(Entity):
                                    """
                                    IN ERROR SYMBOL
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorSymbol, self).__init__()

                                        self.yang_name = "in-error-symbol"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-error-symbol"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorSymbol, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutGoodBytes(Entity):
                                    """
                                    OUT GOOD BYTES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutGoodBytes, self).__init__()

                                        self.yang_name = "out-good-bytes"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-good-bytes"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutGoodBytes, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class Out8021qFrames(Entity):
                                    """
                                    OUT 802 1Q FRAMES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Out8021qFrames, self).__init__()

                                        self.yang_name = "out8021q-frames"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out8021q-frames"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Out8021qFrames, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutPauseFrames(Entity):
                                    """
                                    OUT PAUSE FRAMES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPauseFrames, self).__init__()

                                        self.yang_name = "out-pause-frames"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-pause-frames"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPauseFrames, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutPkts1519MaxOctets(Entity):
                                    """
                                    OUT PKTS 1519 MAX OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts1519MaxOctets, self).__init__()

                                        self.yang_name = "out-pkts1519-max-octets"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-pkts1519-max-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts1519MaxOctets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutGoodPkts(Entity):
                                    """
                                    OUT GOOD PKTS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutGoodPkts, self).__init__()

                                        self.yang_name = "out-good-pkts"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-good-pkts"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutGoodPkts, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutDropUnderrun(Entity):
                                    """
                                    OUT DROP UNDERRUN
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutDropUnderrun, self).__init__()

                                        self.yang_name = "out-drop-underrun"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-drop-underrun"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutDropUnderrun, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutDropAbort(Entity):
                                    """
                                    OUT DROP ABORT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutDropAbort, self).__init__()

                                        self.yang_name = "out-drop-abort"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-drop-abort"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutDropAbort, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutDropOther(Entity):
                                    """
                                    OUT DROP OTHER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutDropOther, self).__init__()

                                        self.yang_name = "out-drop-other"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-drop-other"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutDropOther, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutErrorOther(Entity):
                                    """
                                    OUT ERROR OTHER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutErrorOther, self).__init__()

                                        self.yang_name = "out-error-other"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-error-other"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutErrorOther, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InErrorGiant(Entity):
                                    """
                                    IN ERROR GIANT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorGiant, self).__init__()

                                        self.yang_name = "in-error-giant"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-error-giant"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorGiant, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InErrorRunt(Entity):
                                    """
                                    IN ERROR RUNT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorRunt, self).__init__()

                                        self.yang_name = "in-error-runt"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-error-runt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorRunt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InErrorJabbers(Entity):
                                    """
                                    IN ERROR JABBERS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorJabbers, self).__init__()

                                        self.yang_name = "in-error-jabbers"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-error-jabbers"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorJabbers, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InErrorFragments(Entity):
                                    """
                                    IN ERROR FRAGMENTS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorFragments, self).__init__()

                                        self.yang_name = "in-error-fragments"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-error-fragments"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorFragments, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InErrorOther(Entity):
                                    """
                                    IN ERROR OTHER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorOther, self).__init__()

                                        self.yang_name = "in-error-other"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-error-other"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorOther, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPkt64Octet(Entity):
                                    """
                                    IN PKT 64 OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkt64Octet, self).__init__()

                                        self.yang_name = "in-pkt64-octet"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkt64-octet"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkt64Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPkts65To127Octets(Entity):
                                    """
                                    IN PKTS 65 127OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts65To127Octets, self).__init__()

                                        self.yang_name = "in-pkts65-to127-octets"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts65-to127-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts65To127Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPkts128To255Octets(Entity):
                                    """
                                    IN PKTS 128 255 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts128To255Octets, self).__init__()

                                        self.yang_name = "in-pkts128-to255-octets"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts128-to255-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts128To255Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPkts256To511Octets(Entity):
                                    """
                                    IN PKTS 256 511 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts256To511Octets, self).__init__()

                                        self.yang_name = "in-pkts256-to511-octets"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts256-to511-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts256To511Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPkts512To1023Octets(Entity):
                                    """
                                    IN PKTS 512 1023 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts512To1023Octets, self).__init__()

                                        self.yang_name = "in-pkts512-to1023-octets"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts512-to1023-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts512To1023Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPkts1024To1518Octets(Entity):
                                    """
                                    IN PKTS 1024 1518 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts1024To1518Octets, self).__init__()

                                        self.yang_name = "in-pkts1024-to1518-octets"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts1024-to1518-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts1024To1518Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class Outpkt64octet(Entity):
                                    """
                                    OUT PKT 64 OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Outpkt64octet, self).__init__()

                                        self.yang_name = "outpkt64octet"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "outpkt64octet"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Outpkt64octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutPkts65127Octets(Entity):
                                    """
                                    OUT PKTS 65 127OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts65127Octets, self).__init__()

                                        self.yang_name = "out-pkts65127-octets"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-pkts65127-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts65127Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutPkts128255Octets(Entity):
                                    """
                                    OUT PKTS 128 255 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts128255Octets, self).__init__()

                                        self.yang_name = "out-pkts128255-octets"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-pkts128255-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts128255Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutPkts256511Octets(Entity):
                                    """
                                    OUT PKTS 256 511 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts256511Octets, self).__init__()

                                        self.yang_name = "out-pkts256511-octets"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-pkts256511-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts256511Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutPkts5121023Octets(Entity):
                                    """
                                    OUT PKTS 512 1023 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts5121023Octets, self).__init__()

                                        self.yang_name = "out-pkts5121023-octets"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-pkts5121023-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts5121023Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutPkts10241518Octets(Entity):
                                    """
                                    OUT PKTS 1024 1518 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts10241518Octets, self).__init__()

                                        self.yang_name = "out-pkts10241518-octets"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-pkts10241518-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts10241518Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class RxUtil(Entity):
                                    """
                                    Rx Utilization in Percent
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: str
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.RxUtil, self).__init__()

                                        self.yang_name = "rx-util"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "rx-util"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.RxUtil, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class TxUtil(Entity):
                                    """
                                    Tx Utilization in Percent
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: str
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxUtil, self).__init__()

                                        self.yang_name = "tx-util"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "tx-util"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxUtil, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class TxUndersizedPkt(Entity):
                                    """
                                    TX Undersized Pkt
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxUndersizedPkt, self).__init__()

                                        self.yang_name = "tx-undersized-pkt"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "tx-undersized-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxUndersizedPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class TxOversizedPkt(Entity):
                                    """
                                    TX Oversized Pkt
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxOversizedPkt, self).__init__()

                                        self.yang_name = "tx-oversized-pkt"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "tx-oversized-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxOversizedPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class TxFragments(Entity):
                                    """
                                    TX Fragments
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxFragments, self).__init__()

                                        self.yang_name = "tx-fragments"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "tx-fragments"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxFragments, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class TxJabber(Entity):
                                    """
                                    TX Jabber
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxJabber, self).__init__()

                                        self.yang_name = "tx-jabber"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "tx-jabber"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxJabber, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class TxBadFcs(Entity):
                                    """
                                    TX Bad Fcs
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxBadFcs, self).__init__()

                                        self.yang_name = "tx-bad-fcs"
                                        self.yang_parent_name = "ethernet-hour24-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "tx-bad-fcs"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxBadFcs, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                        class Hour24pcses(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: hour24pcs
                            
                            	Ethernet port 24 hour pcs performance data
                            	**type**\: list of  		 :py:class:`Hour24pcs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.Hour24pcses.Hour24pcs>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.Hour24pcses, self).__init__()

                                self.yang_name = "hour24pcses"
                                self.yang_parent_name = "ethernet-hour24"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("hour24pcs", ("hour24pcs", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.Hour24pcses.Hour24pcs))])
                                self._leafs = OrderedDict()

                                self.hour24pcs = YList(self)
                                self._segment_path = lambda: "hour24pcses"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.Hour24pcses, [], name, value)


                            class Hour24pcs(Entity):
                                """
                                Ethernet port 24 hour pcs performance data
                                
                                .. attribute:: number  (key)
                                
                                	channel number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: bip
                                
                                	Bip 
                                	**type**\: list of  		 :py:class:`Bip <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.Hour24pcses.Hour24pcs.Bip>`
                                
                                .. attribute:: frm_err
                                
                                	Frm Err
                                	**type**\: list of  		 :py:class:`FrmErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.Hour24pcses.Hour24pcs.FrmErr>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.Hour24pcses.Hour24pcs, self).__init__()

                                    self.yang_name = "hour24pcs"
                                    self.yang_parent_name = "hour24pcses"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("bip", ("bip", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.Hour24pcses.Hour24pcs.Bip)), ("frm-err", ("frm_err", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.Hour24pcses.Hour24pcs.FrmErr))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                    ])
                                    self.number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear24_hr_time = None

                                    self.bip = YList(self)
                                    self.frm_err = YList(self)
                                    self._segment_path = lambda: "hour24pcs" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.Hour24pcses.Hour24pcs, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time'], name, value)


                                class Bip(Entity):
                                    """
                                    Bip 
                                    
                                    .. attribute:: name
                                    
                                    	pcs param name
                                    	**type**\: str
                                    
                                    	**length:** 0..30
                                    
                                    .. attribute:: data
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.Hour24pcses.Hour24pcs.Bip, self).__init__()

                                        self.yang_name = "bip"
                                        self.yang_parent_name = "hour24pcs"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.name = None
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "bip"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.Hour24pcses.Hour24pcs.Bip, ['name', 'data', 'threshold', 'tca_report'], name, value)


                                class FrmErr(Entity):
                                    """
                                    Frm Err
                                    
                                    .. attribute:: name
                                    
                                    	pcs param name
                                    	**type**\: str
                                    
                                    	**length:** 0..30
                                    
                                    .. attribute:: data
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.Hour24pcses.Hour24pcs.FrmErr, self).__init__()

                                        self.yang_name = "frm-err"
                                        self.yang_parent_name = "hour24pcs"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.name = None
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "frm-err"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.Hour24pcses.Hour24pcs.FrmErr, ['name', 'data', 'threshold', 'tca_report'], name, value)


                        class EthernetHour24fecs(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: ethernet_hour24fec
                            
                            	port 24 hour ethernet performance data
                            	**type**\: list of  		 :py:class:`EthernetHour24fec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24fecs.EthernetHour24fec>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24fecs, self).__init__()

                                self.yang_name = "ethernet-hour24fecs"
                                self.yang_parent_name = "ethernet-hour24"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ethernet-hour24fec", ("ethernet_hour24fec", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24fecs.EthernetHour24fec))])
                                self._leafs = OrderedDict()

                                self.ethernet_hour24fec = YList(self)
                                self._segment_path = lambda: "ethernet-hour24fecs"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24fecs, [], name, value)


                            class EthernetHour24fec(Entity):
                                """
                                port 24 hour ethernet performance data
                                
                                .. attribute:: number  (key)
                                
                                	channel number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ec_bits
                                
                                	EC BITS
                                	**type**\:  :py:class:`EcBits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24fecs.EthernetHour24fec.EcBits>`
                                
                                .. attribute:: uc_words
                                
                                	UC WORDS
                                	**type**\:  :py:class:`UcWords <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24fecs.EthernetHour24fec.UcWords>`
                                
                                .. attribute:: pre_fec_ber
                                
                                	Pre FEC BER
                                	**type**\:  :py:class:`PreFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24fecs.EthernetHour24fec.PreFecBer>`
                                
                                .. attribute:: post_fec_ber
                                
                                	Post FEC BER
                                	**type**\:  :py:class:`PostFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24fecs.EthernetHour24fec.PostFecBer>`
                                
                                .. attribute:: q
                                
                                	Q
                                	**type**\:  :py:class:`Q <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24fecs.EthernetHour24fec.Q>`
                                
                                .. attribute:: qmargin
                                
                                	Q Margin
                                	**type**\:  :py:class:`Qmargin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24fecs.EthernetHour24fec.Qmargin>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24fecs.EthernetHour24fec, self).__init__()

                                    self.yang_name = "ethernet-hour24fec"
                                    self.yang_parent_name = "ethernet-hour24fecs"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("ec-bits", ("ec_bits", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24fecs.EthernetHour24fec.EcBits)), ("uc-words", ("uc_words", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24fecs.EthernetHour24fec.UcWords)), ("pre-fec-ber", ("pre_fec_ber", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24fecs.EthernetHour24fec.PreFecBer)), ("post-fec-ber", ("post_fec_ber", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24fecs.EthernetHour24fec.PostFecBer)), ("q", ("q", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24fecs.EthernetHour24fec.Q)), ("qmargin", ("qmargin", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24fecs.EthernetHour24fec.Qmargin))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                        ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                    ])
                                    self.number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear24_hr_time = None
                                    self.sec30_support = None

                                    self.ec_bits = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24fecs.EthernetHour24fec.EcBits()
                                    self.ec_bits.parent = self
                                    self._children_name_map["ec_bits"] = "ec-bits"

                                    self.uc_words = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24fecs.EthernetHour24fec.UcWords()
                                    self.uc_words.parent = self
                                    self._children_name_map["uc_words"] = "uc-words"

                                    self.pre_fec_ber = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24fecs.EthernetHour24fec.PreFecBer()
                                    self.pre_fec_ber.parent = self
                                    self._children_name_map["pre_fec_ber"] = "pre-fec-ber"

                                    self.post_fec_ber = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24fecs.EthernetHour24fec.PostFecBer()
                                    self.post_fec_ber.parent = self
                                    self._children_name_map["post_fec_ber"] = "post-fec-ber"

                                    self.q = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24fecs.EthernetHour24fec.Q()
                                    self.q.parent = self
                                    self._children_name_map["q"] = "q"

                                    self.qmargin = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24fecs.EthernetHour24fec.Qmargin()
                                    self.qmargin.parent = self
                                    self._children_name_map["qmargin"] = "qmargin"
                                    self._segment_path = lambda: "ethernet-hour24fec" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24fecs.EthernetHour24fec, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                class EcBits(Entity):
                                    """
                                    EC BITS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24fecs.EthernetHour24fec.EcBits, self).__init__()

                                        self.yang_name = "ec-bits"
                                        self.yang_parent_name = "ethernet-hour24fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ec-bits"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24fecs.EthernetHour24fec.EcBits, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class UcWords(Entity):
                                    """
                                    UC WORDS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24fecs.EthernetHour24fec.UcWords, self).__init__()

                                        self.yang_name = "uc-words"
                                        self.yang_parent_name = "ethernet-hour24fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "uc-words"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24fecs.EthernetHour24fec.UcWords, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class PreFecBer(Entity):
                                    """
                                    Pre FEC BER
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24fecs.EthernetHour24fec.PreFecBer, self).__init__()

                                        self.yang_name = "pre-fec-ber"
                                        self.yang_parent_name = "ethernet-hour24fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.maximum_tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "pre-fec-ber"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24fecs.EthernetHour24fec.PreFecBer, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                class PostFecBer(Entity):
                                    """
                                    Post FEC BER
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24fecs.EthernetHour24fec.PostFecBer, self).__init__()

                                        self.yang_name = "post-fec-ber"
                                        self.yang_parent_name = "ethernet-hour24fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.maximum_tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "post-fec-ber"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24fecs.EthernetHour24fec.PostFecBer, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                class Q(Entity):
                                    """
                                    Q
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24fecs.EthernetHour24fec.Q, self).__init__()

                                        self.yang_name = "q"
                                        self.yang_parent_name = "ethernet-hour24fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.maximum_tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "q"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24fecs.EthernetHour24fec.Q, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                class Qmargin(Entity):
                                    """
                                    Q Margin
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24fecs.EthernetHour24fec.Qmargin, self).__init__()

                                        self.yang_name = "qmargin"
                                        self.yang_parent_name = "ethernet-hour24fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.maximum_tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "qmargin"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24fecs.EthernetHour24fec.Qmargin, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                    class Minute15(Entity):
                        """
                        port current performance data
                        
                        .. attribute:: minute15_fecs
                        
                        	ETHERNET port interval performance data
                        	**type**\:  :py:class:`Minute15Fecs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Fecs>`
                        
                        .. attribute:: minute15pcses
                        
                        	ETHERNET port interval performance data
                        	**type**\:  :py:class:`Minute15pcses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15pcses>`
                        
                        .. attribute:: minute15_ethers
                        
                        	ETHERNET port interval performance data
                        	**type**\:  :py:class:`Minute15Ethers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15, self).__init__()

                            self.yang_name = "minute15"
                            self.yang_parent_name = "ethernet-current"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("minute15-fecs", ("minute15_fecs", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Fecs)), ("minute15pcses", ("minute15pcses", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15pcses)), ("minute15-ethers", ("minute15_ethers", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers))])
                            self._leafs = OrderedDict()

                            self.minute15_fecs = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Fecs()
                            self.minute15_fecs.parent = self
                            self._children_name_map["minute15_fecs"] = "minute15-fecs"

                            self.minute15pcses = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15pcses()
                            self.minute15pcses.parent = self
                            self._children_name_map["minute15pcses"] = "minute15pcses"

                            self.minute15_ethers = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers()
                            self.minute15_ethers.parent = self
                            self._children_name_map["minute15_ethers"] = "minute15-ethers"
                            self._segment_path = lambda: "minute15"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15, [], name, value)


                        class Minute15Fecs(Entity):
                            """
                            ETHERNET port interval performance data
                            
                            .. attribute:: minute15_fec
                            
                            	ETHERNET port 15\-minute fec performance data
                            	**type**\: list of  		 :py:class:`Minute15Fec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Fecs.Minute15Fec>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Fecs, self).__init__()

                                self.yang_name = "minute15-fecs"
                                self.yang_parent_name = "minute15"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("minute15-fec", ("minute15_fec", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Fecs.Minute15Fec))])
                                self._leafs = OrderedDict()

                                self.minute15_fec = YList(self)
                                self._segment_path = lambda: "minute15-fecs"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Fecs, [], name, value)


                            class Minute15Fec(Entity):
                                """
                                ETHERNET port 15\-minute fec performance
                                data
                                
                                .. attribute:: slot_number  (key)
                                
                                	interval slot number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ec_bits
                                
                                	EC BITS
                                	**type**\:  :py:class:`EcBits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Fecs.Minute15Fec.EcBits>`
                                
                                .. attribute:: uc_words
                                
                                	UC WORDS
                                	**type**\:  :py:class:`UcWords <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Fecs.Minute15Fec.UcWords>`
                                
                                .. attribute:: pre_fec_ber
                                
                                	Pre FEC BER
                                	**type**\:  :py:class:`PreFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Fecs.Minute15Fec.PreFecBer>`
                                
                                .. attribute:: post_fec_ber
                                
                                	Post FEC BER
                                	**type**\:  :py:class:`PostFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Fecs.Minute15Fec.PostFecBer>`
                                
                                .. attribute:: q
                                
                                	Q
                                	**type**\:  :py:class:`Q <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Fecs.Minute15Fec.Q>`
                                
                                .. attribute:: qmargin
                                
                                	Q Margin
                                	**type**\:  :py:class:`Qmargin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Fecs.Minute15Fec.Qmargin>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Fecs.Minute15Fec, self).__init__()

                                    self.yang_name = "minute15-fec"
                                    self.yang_parent_name = "minute15-fecs"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['slot_number']
                                    self._child_classes = OrderedDict([("ec-bits", ("ec_bits", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Fecs.Minute15Fec.EcBits)), ("uc-words", ("uc_words", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Fecs.Minute15Fec.UcWords)), ("pre-fec-ber", ("pre_fec_ber", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Fecs.Minute15Fec.PreFecBer)), ("post-fec-ber", ("post_fec_ber", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Fecs.Minute15Fec.PostFecBer)), ("q", ("q", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Fecs.Minute15Fec.Q)), ("qmargin", ("qmargin", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Fecs.Minute15Fec.Qmargin))])
                                    self._leafs = OrderedDict([
                                        ('slot_number', (YLeaf(YType.uint32, 'slot-number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                        ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                    ])
                                    self.slot_number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear24_hr_time = None
                                    self.sec30_support = None

                                    self.ec_bits = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Fecs.Minute15Fec.EcBits()
                                    self.ec_bits.parent = self
                                    self._children_name_map["ec_bits"] = "ec-bits"

                                    self.uc_words = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Fecs.Minute15Fec.UcWords()
                                    self.uc_words.parent = self
                                    self._children_name_map["uc_words"] = "uc-words"

                                    self.pre_fec_ber = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Fecs.Minute15Fec.PreFecBer()
                                    self.pre_fec_ber.parent = self
                                    self._children_name_map["pre_fec_ber"] = "pre-fec-ber"

                                    self.post_fec_ber = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Fecs.Minute15Fec.PostFecBer()
                                    self.post_fec_ber.parent = self
                                    self._children_name_map["post_fec_ber"] = "post-fec-ber"

                                    self.q = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Fecs.Minute15Fec.Q()
                                    self.q.parent = self
                                    self._children_name_map["q"] = "q"

                                    self.qmargin = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Fecs.Minute15Fec.Qmargin()
                                    self.qmargin.parent = self
                                    self._children_name_map["qmargin"] = "qmargin"
                                    self._segment_path = lambda: "minute15-fec" + "[slot-number='" + str(self.slot_number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Fecs.Minute15Fec, ['slot_number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                class EcBits(Entity):
                                    """
                                    EC BITS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Fecs.Minute15Fec.EcBits, self).__init__()

                                        self.yang_name = "ec-bits"
                                        self.yang_parent_name = "minute15-fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ec-bits"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Fecs.Minute15Fec.EcBits, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class UcWords(Entity):
                                    """
                                    UC WORDS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Fecs.Minute15Fec.UcWords, self).__init__()

                                        self.yang_name = "uc-words"
                                        self.yang_parent_name = "minute15-fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "uc-words"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Fecs.Minute15Fec.UcWords, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class PreFecBer(Entity):
                                    """
                                    Pre FEC BER
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Fecs.Minute15Fec.PreFecBer, self).__init__()

                                        self.yang_name = "pre-fec-ber"
                                        self.yang_parent_name = "minute15-fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.maximum_tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "pre-fec-ber"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Fecs.Minute15Fec.PreFecBer, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                class PostFecBer(Entity):
                                    """
                                    Post FEC BER
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Fecs.Minute15Fec.PostFecBer, self).__init__()

                                        self.yang_name = "post-fec-ber"
                                        self.yang_parent_name = "minute15-fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.maximum_tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "post-fec-ber"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Fecs.Minute15Fec.PostFecBer, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                class Q(Entity):
                                    """
                                    Q
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Fecs.Minute15Fec.Q, self).__init__()

                                        self.yang_name = "q"
                                        self.yang_parent_name = "minute15-fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.maximum_tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "q"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Fecs.Minute15Fec.Q, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                class Qmargin(Entity):
                                    """
                                    Q Margin
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\: str
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\: str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\: str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\: bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\: str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Fecs.Minute15Fec.Qmargin, self).__init__()

                                        self.yang_name = "qmargin"
                                        self.yang_parent_name = "minute15-fec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                            ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                            ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                            ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                            ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                            ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                            ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.minimum = None
                                        self.average = None
                                        self.maximum = None
                                        self.minimum_threshold = None
                                        self.minimum_tca_report = None
                                        self.maximum_threshold = None
                                        self.maximum_tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "qmargin"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Fecs.Minute15Fec.Qmargin, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                        class Minute15pcses(Entity):
                            """
                            ETHERNET port interval performance data
                            
                            .. attribute:: minute15pcs
                            
                            	ETHERNET port 15\-minute pcs performance data
                            	**type**\: list of  		 :py:class:`Minute15pcs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15pcses.Minute15pcs>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15pcses, self).__init__()

                                self.yang_name = "minute15pcses"
                                self.yang_parent_name = "minute15"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("minute15pcs", ("minute15pcs", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15pcses.Minute15pcs))])
                                self._leafs = OrderedDict()

                                self.minute15pcs = YList(self)
                                self._segment_path = lambda: "minute15pcses"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15pcses, [], name, value)


                            class Minute15pcs(Entity):
                                """
                                ETHERNET port 15\-minute pcs performance
                                data
                                
                                .. attribute:: slot_number  (key)
                                
                                	interval slot number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: bip
                                
                                	Bip 
                                	**type**\: list of  		 :py:class:`Bip <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15pcses.Minute15pcs.Bip>`
                                
                                .. attribute:: frm_err
                                
                                	Frm Err
                                	**type**\: list of  		 :py:class:`FrmErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15pcses.Minute15pcs.FrmErr>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15pcses.Minute15pcs, self).__init__()

                                    self.yang_name = "minute15pcs"
                                    self.yang_parent_name = "minute15pcses"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['slot_number']
                                    self._child_classes = OrderedDict([("bip", ("bip", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15pcses.Minute15pcs.Bip)), ("frm-err", ("frm_err", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15pcses.Minute15pcs.FrmErr))])
                                    self._leafs = OrderedDict([
                                        ('slot_number', (YLeaf(YType.uint32, 'slot-number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                    ])
                                    self.slot_number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear24_hr_time = None

                                    self.bip = YList(self)
                                    self.frm_err = YList(self)
                                    self._segment_path = lambda: "minute15pcs" + "[slot-number='" + str(self.slot_number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15pcses.Minute15pcs, ['slot_number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time'], name, value)


                                class Bip(Entity):
                                    """
                                    Bip 
                                    
                                    .. attribute:: name
                                    
                                    	pcs param name
                                    	**type**\: str
                                    
                                    	**length:** 0..30
                                    
                                    .. attribute:: data
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15pcses.Minute15pcs.Bip, self).__init__()

                                        self.yang_name = "bip"
                                        self.yang_parent_name = "minute15pcs"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.name = None
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "bip"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15pcses.Minute15pcs.Bip, ['name', 'data', 'threshold', 'tca_report'], name, value)


                                class FrmErr(Entity):
                                    """
                                    Frm Err
                                    
                                    .. attribute:: name
                                    
                                    	pcs param name
                                    	**type**\: str
                                    
                                    	**length:** 0..30
                                    
                                    .. attribute:: data
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15pcses.Minute15pcs.FrmErr, self).__init__()

                                        self.yang_name = "frm-err"
                                        self.yang_parent_name = "minute15pcs"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                        ])
                                        self.name = None
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self._segment_path = lambda: "frm-err"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15pcses.Minute15pcs.FrmErr, ['name', 'data', 'threshold', 'tca_report'], name, value)


                        class Minute15Ethers(Entity):
                            """
                            ETHERNET port interval performance data
                            
                            .. attribute:: minute15_ether
                            
                            	ETHERNET port 15\-minute ether performance data
                            	**type**\: list of  		 :py:class:`Minute15Ether <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers, self).__init__()

                                self.yang_name = "minute15-ethers"
                                self.yang_parent_name = "minute15"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("minute15-ether", ("minute15_ether", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether))])
                                self._leafs = OrderedDict()

                                self.minute15_ether = YList(self)
                                self._segment_path = lambda: "minute15-ethers"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers, [], name, value)


                            class Minute15Ether(Entity):
                                """
                                ETHERNET port 15\-minute ether performance
                                data
                                
                                .. attribute:: slot_number  (key)
                                
                                	interval slot number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rx_pkt
                                
                                	RX PKT
                                	**type**\:  :py:class:`RxPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.RxPkt>`
                                
                                .. attribute:: stat_pkt
                                
                                	STAT PKT
                                	**type**\:  :py:class:`StatPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.StatPkt>`
                                
                                .. attribute:: octet_stat
                                
                                	OCTET STAT
                                	**type**\:  :py:class:`OctetStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OctetStat>`
                                
                                .. attribute:: oversize_pkt_stat
                                
                                	OVERSIZE PKT
                                	**type**\:  :py:class:`OversizePktStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OversizePktStat>`
                                
                                .. attribute:: fcs_errors_stat
                                
                                	FCS ERR
                                	**type**\:  :py:class:`FcsErrorsStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.FcsErrorsStat>`
                                
                                .. attribute:: long_frames_stat
                                
                                	LONG FRAMES
                                	**type**\:  :py:class:`LongFramesStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.LongFramesStat>`
                                
                                .. attribute:: jabber_stat
                                
                                	JABBER STATS
                                	**type**\:  :py:class:`JabberStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.JabberStat>`
                                
                                .. attribute:: ether64_octets
                                
                                	SIXTY FOUR OCTET
                                	**type**\:  :py:class:`Ether64Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether64Octets>`
                                
                                .. attribute:: ether65127_octet
                                
                                	OCTET
                                	**type**\:  :py:class:`Ether65127Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether65127Octet>`
                                
                                .. attribute:: ether128255_octet
                                
                                	TFF OCTET
                                	**type**\:  :py:class:`Ether128255Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether128255Octet>`
                                
                                .. attribute:: ether256511_octet
                                
                                	FOO OCTET
                                	**type**\:  :py:class:`Ether256511Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether256511Octet>`
                                
                                .. attribute:: ether5121023_octet
                                
                                	OZTT OCTET
                                	**type**\:  :py:class:`Ether5121023Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether5121023Octet>`
                                
                                .. attribute:: ether10241518_octet
                                
                                	OFO OCTET
                                	**type**\:  :py:class:`Ether10241518Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether10241518Octet>`
                                
                                .. attribute:: in_ucast_pkt
                                
                                	IN UCAST
                                	**type**\:  :py:class:`InUcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InUcastPkt>`
                                
                                .. attribute:: in_mcast_pkt
                                
                                	IN MCAST
                                	**type**\:  :py:class:`InMcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InMcastPkt>`
                                
                                .. attribute:: in_bcast_pkt
                                
                                	IN BCAST
                                	**type**\:  :py:class:`InBcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InBcastPkt>`
                                
                                .. attribute:: out_ucast_pkt
                                
                                	OUT UCAST
                                	**type**\:  :py:class:`OutUcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutUcastPkt>`
                                
                                .. attribute:: out_bcast_pkt
                                
                                	OUT BCAST
                                	**type**\:  :py:class:`OutBcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutBcastPkt>`
                                
                                .. attribute:: out_mcast_pkt
                                
                                	OUT MCAST
                                	**type**\:  :py:class:`OutMcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutMcastPkt>`
                                
                                .. attribute:: tx_pkt
                                
                                	TX PKT
                                	**type**\:  :py:class:`TxPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxPkt>`
                                
                                .. attribute:: if_in_errors
                                
                                	IFIN ERRORS
                                	**type**\:  :py:class:`IfInErrors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.IfInErrors>`
                                
                                .. attribute:: if_in_octets
                                
                                	IFIN OCTETS
                                	**type**\:  :py:class:`IfInOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.IfInOctets>`
                                
                                .. attribute:: ether_stat_multicast_pkt
                                
                                	ETHER STAT MULTICAST PKT
                                	**type**\:  :py:class:`EtherStatMulticastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.EtherStatMulticastPkt>`
                                
                                .. attribute:: ether_stat_broadcast_pkt
                                
                                	ETHER STAT BROADCAST PKT
                                	**type**\:  :py:class:`EtherStatBroadcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.EtherStatBroadcastPkt>`
                                
                                .. attribute:: ether_stat_undersized_pkt
                                
                                	ETHER STAT UNDERSIZED PKT
                                	**type**\:  :py:class:`EtherStatUndersizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.EtherStatUndersizedPkt>`
                                
                                .. attribute:: out_octets
                                
                                	OUT OCTET
                                	**type**\:  :py:class:`OutOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutOctets>`
                                
                                .. attribute:: in_pause_frame
                                
                                	INPUT PAUSE FRAME
                                	**type**\:  :py:class:`InPauseFrame <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPauseFrame>`
                                
                                .. attribute:: in_good_bytes
                                
                                	INPUT GOOD BYTES
                                	**type**\:  :py:class:`InGoodBytes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InGoodBytes>`
                                
                                .. attribute:: in8021q_frames
                                
                                	INPUT 802 1Q FRAMES
                                	**type**\:  :py:class:`In8021qFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.In8021qFrames>`
                                
                                .. attribute:: in_pkts1519_max_octets
                                
                                	INPUT PKTS 1519MAX OCTETS
                                	**type**\:  :py:class:`InPkts1519MaxOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts1519MaxOctets>`
                                
                                .. attribute:: in_good_pkts
                                
                                	INPUT GOOD PKTS
                                	**type**\:  :py:class:`InGoodPkts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InGoodPkts>`
                                
                                .. attribute:: in_drop_overrun
                                
                                	INPUT DROP OVERRUN
                                	**type**\:  :py:class:`InDropOverrun <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropOverrun>`
                                
                                .. attribute:: in_drop_abort
                                
                                	INPUT DROP ABORT
                                	**type**\:  :py:class:`InDropAbort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropAbort>`
                                
                                .. attribute:: in_drop_invalid_vlan
                                
                                	INPUT DROP INVALID VLAN
                                	**type**\:  :py:class:`InDropInvalidVlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropInvalidVlan>`
                                
                                .. attribute:: in_drop_invalid_dmac
                                
                                	INPUT DROP INVALID DMAC
                                	**type**\:  :py:class:`InDropInvalidDmac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropInvalidDmac>`
                                
                                .. attribute:: in_drop_invalid_encap
                                
                                	INPUT DROP INVALID ENCAP
                                	**type**\:  :py:class:`InDropInvalidEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropInvalidEncap>`
                                
                                .. attribute:: in_drop_other
                                
                                	INPUT DROP OTHER
                                	**type**\:  :py:class:`InDropOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropOther>`
                                
                                .. attribute:: in_mib_giant
                                
                                	INPUT MIB GIANT
                                	**type**\:  :py:class:`InMibGiant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InMibGiant>`
                                
                                .. attribute:: in_mib_jabber
                                
                                	INPUT MIB JABBER
                                	**type**\:  :py:class:`InMibJabber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InMibJabber>`
                                
                                .. attribute:: in_mibcrc
                                
                                	IN MIB CRC
                                	**type**\:  :py:class:`InMibcrc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InMibcrc>`
                                
                                .. attribute:: in_error_collisions
                                
                                	IN ERROR COLLISIONS
                                	**type**\:  :py:class:`InErrorCollisions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorCollisions>`
                                
                                .. attribute:: in_error_symbol
                                
                                	IN ERROR SYMBOL
                                	**type**\:  :py:class:`InErrorSymbol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorSymbol>`
                                
                                .. attribute:: out_good_bytes
                                
                                	OUT GOOD BYTES
                                	**type**\:  :py:class:`OutGoodBytes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutGoodBytes>`
                                
                                .. attribute:: out8021q_frames
                                
                                	OUT 802 1Q FRAMES
                                	**type**\:  :py:class:`Out8021qFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Out8021qFrames>`
                                
                                .. attribute:: out_pause_frames
                                
                                	OUT PAUSE FRAMES
                                	**type**\:  :py:class:`OutPauseFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPauseFrames>`
                                
                                .. attribute:: out_pkts1519_max_octets
                                
                                	OUT PKTS 1519 MAX OCTETS
                                	**type**\:  :py:class:`OutPkts1519MaxOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts1519MaxOctets>`
                                
                                .. attribute:: out_good_pkts
                                
                                	OUT GOOD PKTS
                                	**type**\:  :py:class:`OutGoodPkts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutGoodPkts>`
                                
                                .. attribute:: out_drop_underrun
                                
                                	OUT DROP UNDERRUN
                                	**type**\:  :py:class:`OutDropUnderrun <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutDropUnderrun>`
                                
                                .. attribute:: out_drop_abort
                                
                                	OUT DROP ABORT
                                	**type**\:  :py:class:`OutDropAbort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutDropAbort>`
                                
                                .. attribute:: out_drop_other
                                
                                	OUT DROP OTHER
                                	**type**\:  :py:class:`OutDropOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutDropOther>`
                                
                                .. attribute:: out_error_other
                                
                                	OUT ERROR OTHER
                                	**type**\:  :py:class:`OutErrorOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutErrorOther>`
                                
                                .. attribute:: in_error_giant
                                
                                	IN ERROR GIANT
                                	**type**\:  :py:class:`InErrorGiant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorGiant>`
                                
                                .. attribute:: in_error_runt
                                
                                	IN ERROR RUNT
                                	**type**\:  :py:class:`InErrorRunt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorRunt>`
                                
                                .. attribute:: in_error_jabbers
                                
                                	IN ERROR JABBERS
                                	**type**\:  :py:class:`InErrorJabbers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorJabbers>`
                                
                                .. attribute:: in_error_fragments
                                
                                	IN ERROR FRAGMENTS
                                	**type**\:  :py:class:`InErrorFragments <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorFragments>`
                                
                                .. attribute:: in_error_other
                                
                                	IN ERROR OTHER
                                	**type**\:  :py:class:`InErrorOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorOther>`
                                
                                .. attribute:: in_pkt64_octet
                                
                                	IN PKT 64 OCTET
                                	**type**\:  :py:class:`InPkt64Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkt64Octet>`
                                
                                .. attribute:: in_pkts65_to127_octets
                                
                                	IN PKTS 65 127OCTETS
                                	**type**\:  :py:class:`InPkts65To127Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts65To127Octets>`
                                
                                .. attribute:: in_pkts128_to255_octets
                                
                                	IN PKTS 128 255 OCTETS
                                	**type**\:  :py:class:`InPkts128To255Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts128To255Octets>`
                                
                                .. attribute:: in_pkts256_to511_octets
                                
                                	IN PKTS 256 511 OCTETS
                                	**type**\:  :py:class:`InPkts256To511Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts256To511Octets>`
                                
                                .. attribute:: in_pkts512_to1023_octets
                                
                                	IN PKTS 512 1023 OCTETS
                                	**type**\:  :py:class:`InPkts512To1023Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts512To1023Octets>`
                                
                                .. attribute:: in_pkts1024_to1518_octets
                                
                                	IN PKTS 1024 1518 OCTETS
                                	**type**\:  :py:class:`InPkts1024To1518Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts1024To1518Octets>`
                                
                                .. attribute:: outpkt64octet
                                
                                	OUT PKT 64 OCTET
                                	**type**\:  :py:class:`Outpkt64octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Outpkt64octet>`
                                
                                .. attribute:: out_pkts65127_octets
                                
                                	OUT PKTS 65 127OCTETS
                                	**type**\:  :py:class:`OutPkts65127Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts65127Octets>`
                                
                                .. attribute:: out_pkts128255_octets
                                
                                	OUT PKTS 128 255 OCTETS
                                	**type**\:  :py:class:`OutPkts128255Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts128255Octets>`
                                
                                .. attribute:: out_pkts256511_octets
                                
                                	OUT PKTS 256 511 OCTETS
                                	**type**\:  :py:class:`OutPkts256511Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts256511Octets>`
                                
                                .. attribute:: out_pkts5121023_octets
                                
                                	OUT PKTS 512 1023 OCTETS
                                	**type**\:  :py:class:`OutPkts5121023Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts5121023Octets>`
                                
                                .. attribute:: out_pkts10241518_octets
                                
                                	OUT PKTS 1024 1518 OCTETS
                                	**type**\:  :py:class:`OutPkts10241518Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts10241518Octets>`
                                
                                .. attribute:: rx_util
                                
                                	Rx Utilization in Percent
                                	**type**\:  :py:class:`RxUtil <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.RxUtil>`
                                
                                .. attribute:: tx_util
                                
                                	Tx Utilization in Percent
                                	**type**\:  :py:class:`TxUtil <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxUtil>`
                                
                                .. attribute:: tx_undersized_pkt
                                
                                	TX Undersized Pkt
                                	**type**\:  :py:class:`TxUndersizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxUndersizedPkt>`
                                
                                .. attribute:: tx_oversized_pkt
                                
                                	TX Oversized Pkt
                                	**type**\:  :py:class:`TxOversizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxOversizedPkt>`
                                
                                .. attribute:: tx_fragments
                                
                                	TX Fragments
                                	**type**\:  :py:class:`TxFragments <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxFragments>`
                                
                                .. attribute:: tx_jabber
                                
                                	TX Jabber
                                	**type**\:  :py:class:`TxJabber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxJabber>`
                                
                                .. attribute:: tx_bad_fcs
                                
                                	TX Bad Fcs
                                	**type**\:  :py:class:`TxBadFcs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxBadFcs>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\: bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\: str
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether, self).__init__()

                                    self.yang_name = "minute15-ether"
                                    self.yang_parent_name = "minute15-ethers"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['slot_number']
                                    self._child_classes = OrderedDict([("rx-pkt", ("rx_pkt", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.RxPkt)), ("stat-pkt", ("stat_pkt", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.StatPkt)), ("octet-stat", ("octet_stat", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OctetStat)), ("oversize-pkt-stat", ("oversize_pkt_stat", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OversizePktStat)), ("fcs-errors-stat", ("fcs_errors_stat", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.FcsErrorsStat)), ("long-frames-stat", ("long_frames_stat", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.LongFramesStat)), ("jabber-stat", ("jabber_stat", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.JabberStat)), ("ether64-octets", ("ether64_octets", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether64Octets)), ("ether65127-octet", ("ether65127_octet", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether65127Octet)), ("ether128255-octet", ("ether128255_octet", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether128255Octet)), ("ether256511-octet", ("ether256511_octet", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether256511Octet)), ("ether5121023-octet", ("ether5121023_octet", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether5121023Octet)), ("ether10241518-octet", ("ether10241518_octet", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether10241518Octet)), ("in-ucast-pkt", ("in_ucast_pkt", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InUcastPkt)), ("in-mcast-pkt", ("in_mcast_pkt", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InMcastPkt)), ("in-bcast-pkt", ("in_bcast_pkt", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InBcastPkt)), ("out-ucast-pkt", ("out_ucast_pkt", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutUcastPkt)), ("out-bcast-pkt", ("out_bcast_pkt", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutBcastPkt)), ("out-mcast-pkt", ("out_mcast_pkt", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutMcastPkt)), ("tx-pkt", ("tx_pkt", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxPkt)), ("if-in-errors", ("if_in_errors", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.IfInErrors)), ("if-in-octets", ("if_in_octets", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.IfInOctets)), ("ether-stat-multicast-pkt", ("ether_stat_multicast_pkt", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.EtherStatMulticastPkt)), ("ether-stat-broadcast-pkt", ("ether_stat_broadcast_pkt", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.EtherStatBroadcastPkt)), ("ether-stat-undersized-pkt", ("ether_stat_undersized_pkt", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.EtherStatUndersizedPkt)), ("out-octets", ("out_octets", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutOctets)), ("in-pause-frame", ("in_pause_frame", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPauseFrame)), ("in-good-bytes", ("in_good_bytes", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InGoodBytes)), ("in8021q-frames", ("in8021q_frames", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.In8021qFrames)), ("in-pkts1519-max-octets", ("in_pkts1519_max_octets", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts1519MaxOctets)), ("in-good-pkts", ("in_good_pkts", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InGoodPkts)), ("in-drop-overrun", ("in_drop_overrun", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropOverrun)), ("in-drop-abort", ("in_drop_abort", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropAbort)), ("in-drop-invalid-vlan", ("in_drop_invalid_vlan", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropInvalidVlan)), ("in-drop-invalid-dmac", ("in_drop_invalid_dmac", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropInvalidDmac)), ("in-drop-invalid-encap", ("in_drop_invalid_encap", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropInvalidEncap)), ("in-drop-other", ("in_drop_other", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropOther)), ("in-mib-giant", ("in_mib_giant", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InMibGiant)), ("in-mib-jabber", ("in_mib_jabber", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InMibJabber)), ("in-mibcrc", ("in_mibcrc", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InMibcrc)), ("in-error-collisions", ("in_error_collisions", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorCollisions)), ("in-error-symbol", ("in_error_symbol", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorSymbol)), ("out-good-bytes", ("out_good_bytes", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutGoodBytes)), ("out8021q-frames", ("out8021q_frames", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Out8021qFrames)), ("out-pause-frames", ("out_pause_frames", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPauseFrames)), ("out-pkts1519-max-octets", ("out_pkts1519_max_octets", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts1519MaxOctets)), ("out-good-pkts", ("out_good_pkts", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutGoodPkts)), ("out-drop-underrun", ("out_drop_underrun", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutDropUnderrun)), ("out-drop-abort", ("out_drop_abort", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutDropAbort)), ("out-drop-other", ("out_drop_other", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutDropOther)), ("out-error-other", ("out_error_other", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutErrorOther)), ("in-error-giant", ("in_error_giant", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorGiant)), ("in-error-runt", ("in_error_runt", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorRunt)), ("in-error-jabbers", ("in_error_jabbers", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorJabbers)), ("in-error-fragments", ("in_error_fragments", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorFragments)), ("in-error-other", ("in_error_other", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorOther)), ("in-pkt64-octet", ("in_pkt64_octet", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkt64Octet)), ("in-pkts65-to127-octets", ("in_pkts65_to127_octets", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts65To127Octets)), ("in-pkts128-to255-octets", ("in_pkts128_to255_octets", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts128To255Octets)), ("in-pkts256-to511-octets", ("in_pkts256_to511_octets", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts256To511Octets)), ("in-pkts512-to1023-octets", ("in_pkts512_to1023_octets", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts512To1023Octets)), ("in-pkts1024-to1518-octets", ("in_pkts1024_to1518_octets", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts1024To1518Octets)), ("outpkt64octet", ("outpkt64octet", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Outpkt64octet)), ("out-pkts65127-octets", ("out_pkts65127_octets", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts65127Octets)), ("out-pkts128255-octets", ("out_pkts128255_octets", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts128255Octets)), ("out-pkts256511-octets", ("out_pkts256511_octets", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts256511Octets)), ("out-pkts5121023-octets", ("out_pkts5121023_octets", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts5121023Octets)), ("out-pkts10241518-octets", ("out_pkts10241518_octets", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts10241518Octets)), ("rx-util", ("rx_util", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.RxUtil)), ("tx-util", ("tx_util", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxUtil)), ("tx-undersized-pkt", ("tx_undersized_pkt", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxUndersizedPkt)), ("tx-oversized-pkt", ("tx_oversized_pkt", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxOversizedPkt)), ("tx-fragments", ("tx_fragments", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxFragments)), ("tx-jabber", ("tx_jabber", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxJabber)), ("tx-bad-fcs", ("tx_bad_fcs", PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxBadFcs))])
                                    self._leafs = OrderedDict([
                                        ('slot_number', (YLeaf(YType.uint32, 'slot-number'), ['int'])),
                                        ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                        ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                        ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                        ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                        ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                        ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                    ])
                                    self.slot_number = None
                                    self.index = None
                                    self.valid = None
                                    self.timestamp = None
                                    self.last_clear_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None
                                    self.sec30_support = None

                                    self.rx_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.RxPkt()
                                    self.rx_pkt.parent = self
                                    self._children_name_map["rx_pkt"] = "rx-pkt"

                                    self.stat_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.StatPkt()
                                    self.stat_pkt.parent = self
                                    self._children_name_map["stat_pkt"] = "stat-pkt"

                                    self.octet_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OctetStat()
                                    self.octet_stat.parent = self
                                    self._children_name_map["octet_stat"] = "octet-stat"

                                    self.oversize_pkt_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OversizePktStat()
                                    self.oversize_pkt_stat.parent = self
                                    self._children_name_map["oversize_pkt_stat"] = "oversize-pkt-stat"

                                    self.fcs_errors_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.FcsErrorsStat()
                                    self.fcs_errors_stat.parent = self
                                    self._children_name_map["fcs_errors_stat"] = "fcs-errors-stat"

                                    self.long_frames_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.LongFramesStat()
                                    self.long_frames_stat.parent = self
                                    self._children_name_map["long_frames_stat"] = "long-frames-stat"

                                    self.jabber_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.JabberStat()
                                    self.jabber_stat.parent = self
                                    self._children_name_map["jabber_stat"] = "jabber-stat"

                                    self.ether64_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether64Octets()
                                    self.ether64_octets.parent = self
                                    self._children_name_map["ether64_octets"] = "ether64-octets"

                                    self.ether65127_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether65127Octet()
                                    self.ether65127_octet.parent = self
                                    self._children_name_map["ether65127_octet"] = "ether65127-octet"

                                    self.ether128255_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether128255Octet()
                                    self.ether128255_octet.parent = self
                                    self._children_name_map["ether128255_octet"] = "ether128255-octet"

                                    self.ether256511_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether256511Octet()
                                    self.ether256511_octet.parent = self
                                    self._children_name_map["ether256511_octet"] = "ether256511-octet"

                                    self.ether5121023_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether5121023Octet()
                                    self.ether5121023_octet.parent = self
                                    self._children_name_map["ether5121023_octet"] = "ether5121023-octet"

                                    self.ether10241518_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether10241518Octet()
                                    self.ether10241518_octet.parent = self
                                    self._children_name_map["ether10241518_octet"] = "ether10241518-octet"

                                    self.in_ucast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InUcastPkt()
                                    self.in_ucast_pkt.parent = self
                                    self._children_name_map["in_ucast_pkt"] = "in-ucast-pkt"

                                    self.in_mcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InMcastPkt()
                                    self.in_mcast_pkt.parent = self
                                    self._children_name_map["in_mcast_pkt"] = "in-mcast-pkt"

                                    self.in_bcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InBcastPkt()
                                    self.in_bcast_pkt.parent = self
                                    self._children_name_map["in_bcast_pkt"] = "in-bcast-pkt"

                                    self.out_ucast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutUcastPkt()
                                    self.out_ucast_pkt.parent = self
                                    self._children_name_map["out_ucast_pkt"] = "out-ucast-pkt"

                                    self.out_bcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutBcastPkt()
                                    self.out_bcast_pkt.parent = self
                                    self._children_name_map["out_bcast_pkt"] = "out-bcast-pkt"

                                    self.out_mcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutMcastPkt()
                                    self.out_mcast_pkt.parent = self
                                    self._children_name_map["out_mcast_pkt"] = "out-mcast-pkt"

                                    self.tx_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxPkt()
                                    self.tx_pkt.parent = self
                                    self._children_name_map["tx_pkt"] = "tx-pkt"

                                    self.if_in_errors = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.IfInErrors()
                                    self.if_in_errors.parent = self
                                    self._children_name_map["if_in_errors"] = "if-in-errors"

                                    self.if_in_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.IfInOctets()
                                    self.if_in_octets.parent = self
                                    self._children_name_map["if_in_octets"] = "if-in-octets"

                                    self.ether_stat_multicast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.EtherStatMulticastPkt()
                                    self.ether_stat_multicast_pkt.parent = self
                                    self._children_name_map["ether_stat_multicast_pkt"] = "ether-stat-multicast-pkt"

                                    self.ether_stat_broadcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.EtherStatBroadcastPkt()
                                    self.ether_stat_broadcast_pkt.parent = self
                                    self._children_name_map["ether_stat_broadcast_pkt"] = "ether-stat-broadcast-pkt"

                                    self.ether_stat_undersized_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.EtherStatUndersizedPkt()
                                    self.ether_stat_undersized_pkt.parent = self
                                    self._children_name_map["ether_stat_undersized_pkt"] = "ether-stat-undersized-pkt"

                                    self.out_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutOctets()
                                    self.out_octets.parent = self
                                    self._children_name_map["out_octets"] = "out-octets"

                                    self.in_pause_frame = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPauseFrame()
                                    self.in_pause_frame.parent = self
                                    self._children_name_map["in_pause_frame"] = "in-pause-frame"

                                    self.in_good_bytes = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InGoodBytes()
                                    self.in_good_bytes.parent = self
                                    self._children_name_map["in_good_bytes"] = "in-good-bytes"

                                    self.in8021q_frames = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.In8021qFrames()
                                    self.in8021q_frames.parent = self
                                    self._children_name_map["in8021q_frames"] = "in8021q-frames"

                                    self.in_pkts1519_max_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts1519MaxOctets()
                                    self.in_pkts1519_max_octets.parent = self
                                    self._children_name_map["in_pkts1519_max_octets"] = "in-pkts1519-max-octets"

                                    self.in_good_pkts = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InGoodPkts()
                                    self.in_good_pkts.parent = self
                                    self._children_name_map["in_good_pkts"] = "in-good-pkts"

                                    self.in_drop_overrun = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropOverrun()
                                    self.in_drop_overrun.parent = self
                                    self._children_name_map["in_drop_overrun"] = "in-drop-overrun"

                                    self.in_drop_abort = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropAbort()
                                    self.in_drop_abort.parent = self
                                    self._children_name_map["in_drop_abort"] = "in-drop-abort"

                                    self.in_drop_invalid_vlan = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropInvalidVlan()
                                    self.in_drop_invalid_vlan.parent = self
                                    self._children_name_map["in_drop_invalid_vlan"] = "in-drop-invalid-vlan"

                                    self.in_drop_invalid_dmac = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropInvalidDmac()
                                    self.in_drop_invalid_dmac.parent = self
                                    self._children_name_map["in_drop_invalid_dmac"] = "in-drop-invalid-dmac"

                                    self.in_drop_invalid_encap = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropInvalidEncap()
                                    self.in_drop_invalid_encap.parent = self
                                    self._children_name_map["in_drop_invalid_encap"] = "in-drop-invalid-encap"

                                    self.in_drop_other = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropOther()
                                    self.in_drop_other.parent = self
                                    self._children_name_map["in_drop_other"] = "in-drop-other"

                                    self.in_mib_giant = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InMibGiant()
                                    self.in_mib_giant.parent = self
                                    self._children_name_map["in_mib_giant"] = "in-mib-giant"

                                    self.in_mib_jabber = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InMibJabber()
                                    self.in_mib_jabber.parent = self
                                    self._children_name_map["in_mib_jabber"] = "in-mib-jabber"

                                    self.in_mibcrc = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InMibcrc()
                                    self.in_mibcrc.parent = self
                                    self._children_name_map["in_mibcrc"] = "in-mibcrc"

                                    self.in_error_collisions = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorCollisions()
                                    self.in_error_collisions.parent = self
                                    self._children_name_map["in_error_collisions"] = "in-error-collisions"

                                    self.in_error_symbol = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorSymbol()
                                    self.in_error_symbol.parent = self
                                    self._children_name_map["in_error_symbol"] = "in-error-symbol"

                                    self.out_good_bytes = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutGoodBytes()
                                    self.out_good_bytes.parent = self
                                    self._children_name_map["out_good_bytes"] = "out-good-bytes"

                                    self.out8021q_frames = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Out8021qFrames()
                                    self.out8021q_frames.parent = self
                                    self._children_name_map["out8021q_frames"] = "out8021q-frames"

                                    self.out_pause_frames = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPauseFrames()
                                    self.out_pause_frames.parent = self
                                    self._children_name_map["out_pause_frames"] = "out-pause-frames"

                                    self.out_pkts1519_max_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts1519MaxOctets()
                                    self.out_pkts1519_max_octets.parent = self
                                    self._children_name_map["out_pkts1519_max_octets"] = "out-pkts1519-max-octets"

                                    self.out_good_pkts = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutGoodPkts()
                                    self.out_good_pkts.parent = self
                                    self._children_name_map["out_good_pkts"] = "out-good-pkts"

                                    self.out_drop_underrun = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutDropUnderrun()
                                    self.out_drop_underrun.parent = self
                                    self._children_name_map["out_drop_underrun"] = "out-drop-underrun"

                                    self.out_drop_abort = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutDropAbort()
                                    self.out_drop_abort.parent = self
                                    self._children_name_map["out_drop_abort"] = "out-drop-abort"

                                    self.out_drop_other = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutDropOther()
                                    self.out_drop_other.parent = self
                                    self._children_name_map["out_drop_other"] = "out-drop-other"

                                    self.out_error_other = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutErrorOther()
                                    self.out_error_other.parent = self
                                    self._children_name_map["out_error_other"] = "out-error-other"

                                    self.in_error_giant = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorGiant()
                                    self.in_error_giant.parent = self
                                    self._children_name_map["in_error_giant"] = "in-error-giant"

                                    self.in_error_runt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorRunt()
                                    self.in_error_runt.parent = self
                                    self._children_name_map["in_error_runt"] = "in-error-runt"

                                    self.in_error_jabbers = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorJabbers()
                                    self.in_error_jabbers.parent = self
                                    self._children_name_map["in_error_jabbers"] = "in-error-jabbers"

                                    self.in_error_fragments = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorFragments()
                                    self.in_error_fragments.parent = self
                                    self._children_name_map["in_error_fragments"] = "in-error-fragments"

                                    self.in_error_other = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorOther()
                                    self.in_error_other.parent = self
                                    self._children_name_map["in_error_other"] = "in-error-other"

                                    self.in_pkt64_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkt64Octet()
                                    self.in_pkt64_octet.parent = self
                                    self._children_name_map["in_pkt64_octet"] = "in-pkt64-octet"

                                    self.in_pkts65_to127_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts65To127Octets()
                                    self.in_pkts65_to127_octets.parent = self
                                    self._children_name_map["in_pkts65_to127_octets"] = "in-pkts65-to127-octets"

                                    self.in_pkts128_to255_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts128To255Octets()
                                    self.in_pkts128_to255_octets.parent = self
                                    self._children_name_map["in_pkts128_to255_octets"] = "in-pkts128-to255-octets"

                                    self.in_pkts256_to511_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts256To511Octets()
                                    self.in_pkts256_to511_octets.parent = self
                                    self._children_name_map["in_pkts256_to511_octets"] = "in-pkts256-to511-octets"

                                    self.in_pkts512_to1023_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts512To1023Octets()
                                    self.in_pkts512_to1023_octets.parent = self
                                    self._children_name_map["in_pkts512_to1023_octets"] = "in-pkts512-to1023-octets"

                                    self.in_pkts1024_to1518_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts1024To1518Octets()
                                    self.in_pkts1024_to1518_octets.parent = self
                                    self._children_name_map["in_pkts1024_to1518_octets"] = "in-pkts1024-to1518-octets"

                                    self.outpkt64octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Outpkt64octet()
                                    self.outpkt64octet.parent = self
                                    self._children_name_map["outpkt64octet"] = "outpkt64octet"

                                    self.out_pkts65127_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts65127Octets()
                                    self.out_pkts65127_octets.parent = self
                                    self._children_name_map["out_pkts65127_octets"] = "out-pkts65127-octets"

                                    self.out_pkts128255_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts128255Octets()
                                    self.out_pkts128255_octets.parent = self
                                    self._children_name_map["out_pkts128255_octets"] = "out-pkts128255-octets"

                                    self.out_pkts256511_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts256511Octets()
                                    self.out_pkts256511_octets.parent = self
                                    self._children_name_map["out_pkts256511_octets"] = "out-pkts256511-octets"

                                    self.out_pkts5121023_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts5121023Octets()
                                    self.out_pkts5121023_octets.parent = self
                                    self._children_name_map["out_pkts5121023_octets"] = "out-pkts5121023-octets"

                                    self.out_pkts10241518_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts10241518Octets()
                                    self.out_pkts10241518_octets.parent = self
                                    self._children_name_map["out_pkts10241518_octets"] = "out-pkts10241518-octets"

                                    self.rx_util = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.RxUtil()
                                    self.rx_util.parent = self
                                    self._children_name_map["rx_util"] = "rx-util"

                                    self.tx_util = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxUtil()
                                    self.tx_util.parent = self
                                    self._children_name_map["tx_util"] = "tx-util"

                                    self.tx_undersized_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxUndersizedPkt()
                                    self.tx_undersized_pkt.parent = self
                                    self._children_name_map["tx_undersized_pkt"] = "tx-undersized-pkt"

                                    self.tx_oversized_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxOversizedPkt()
                                    self.tx_oversized_pkt.parent = self
                                    self._children_name_map["tx_oversized_pkt"] = "tx-oversized-pkt"

                                    self.tx_fragments = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxFragments()
                                    self.tx_fragments.parent = self
                                    self._children_name_map["tx_fragments"] = "tx-fragments"

                                    self.tx_jabber = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxJabber()
                                    self.tx_jabber.parent = self
                                    self._children_name_map["tx_jabber"] = "tx-jabber"

                                    self.tx_bad_fcs = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxBadFcs()
                                    self.tx_bad_fcs.parent = self
                                    self._children_name_map["tx_bad_fcs"] = "tx-bad-fcs"
                                    self._segment_path = lambda: "minute15-ether" + "[slot-number='" + str(self.slot_number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether, ['slot_number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear30_sec_time', 'last_clear15_min_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                class RxPkt(Entity):
                                    """
                                    RX PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.RxPkt, self).__init__()

                                        self.yang_name = "rx-pkt"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "rx-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.RxPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class StatPkt(Entity):
                                    """
                                    STAT PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.StatPkt, self).__init__()

                                        self.yang_name = "stat-pkt"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "stat-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.StatPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OctetStat(Entity):
                                    """
                                    OCTET STAT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OctetStat, self).__init__()

                                        self.yang_name = "octet-stat"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "octet-stat"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OctetStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OversizePktStat(Entity):
                                    """
                                    OVERSIZE PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OversizePktStat, self).__init__()

                                        self.yang_name = "oversize-pkt-stat"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "oversize-pkt-stat"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OversizePktStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class FcsErrorsStat(Entity):
                                    """
                                    FCS ERR
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.FcsErrorsStat, self).__init__()

                                        self.yang_name = "fcs-errors-stat"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "fcs-errors-stat"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.FcsErrorsStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class LongFramesStat(Entity):
                                    """
                                    LONG FRAMES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.LongFramesStat, self).__init__()

                                        self.yang_name = "long-frames-stat"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "long-frames-stat"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.LongFramesStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class JabberStat(Entity):
                                    """
                                    JABBER STATS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.JabberStat, self).__init__()

                                        self.yang_name = "jabber-stat"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "jabber-stat"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.JabberStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class Ether64Octets(Entity):
                                    """
                                    SIXTY FOUR OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether64Octets, self).__init__()

                                        self.yang_name = "ether64-octets"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ether64-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether64Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class Ether65127Octet(Entity):
                                    """
                                    OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether65127Octet, self).__init__()

                                        self.yang_name = "ether65127-octet"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ether65127-octet"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether65127Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class Ether128255Octet(Entity):
                                    """
                                    TFF OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether128255Octet, self).__init__()

                                        self.yang_name = "ether128255-octet"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ether128255-octet"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether128255Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class Ether256511Octet(Entity):
                                    """
                                    FOO OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether256511Octet, self).__init__()

                                        self.yang_name = "ether256511-octet"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ether256511-octet"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether256511Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class Ether5121023Octet(Entity):
                                    """
                                    OZTT OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether5121023Octet, self).__init__()

                                        self.yang_name = "ether5121023-octet"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ether5121023-octet"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether5121023Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class Ether10241518Octet(Entity):
                                    """
                                    OFO OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether10241518Octet, self).__init__()

                                        self.yang_name = "ether10241518-octet"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ether10241518-octet"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether10241518Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InUcastPkt(Entity):
                                    """
                                    IN UCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InUcastPkt, self).__init__()

                                        self.yang_name = "in-ucast-pkt"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-ucast-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InUcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InMcastPkt(Entity):
                                    """
                                    IN MCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InMcastPkt, self).__init__()

                                        self.yang_name = "in-mcast-pkt"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-mcast-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InMcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InBcastPkt(Entity):
                                    """
                                    IN BCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InBcastPkt, self).__init__()

                                        self.yang_name = "in-bcast-pkt"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-bcast-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InBcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutUcastPkt(Entity):
                                    """
                                    OUT UCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutUcastPkt, self).__init__()

                                        self.yang_name = "out-ucast-pkt"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-ucast-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutUcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutBcastPkt(Entity):
                                    """
                                    OUT BCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutBcastPkt, self).__init__()

                                        self.yang_name = "out-bcast-pkt"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-bcast-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutBcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutMcastPkt(Entity):
                                    """
                                    OUT MCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutMcastPkt, self).__init__()

                                        self.yang_name = "out-mcast-pkt"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-mcast-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutMcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class TxPkt(Entity):
                                    """
                                    TX PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxPkt, self).__init__()

                                        self.yang_name = "tx-pkt"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "tx-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class IfInErrors(Entity):
                                    """
                                    IFIN ERRORS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.IfInErrors, self).__init__()

                                        self.yang_name = "if-in-errors"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "if-in-errors"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.IfInErrors, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class IfInOctets(Entity):
                                    """
                                    IFIN OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.IfInOctets, self).__init__()

                                        self.yang_name = "if-in-octets"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "if-in-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.IfInOctets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class EtherStatMulticastPkt(Entity):
                                    """
                                    ETHER STAT MULTICAST PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.EtherStatMulticastPkt, self).__init__()

                                        self.yang_name = "ether-stat-multicast-pkt"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ether-stat-multicast-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.EtherStatMulticastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class EtherStatBroadcastPkt(Entity):
                                    """
                                    ETHER STAT BROADCAST PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.EtherStatBroadcastPkt, self).__init__()

                                        self.yang_name = "ether-stat-broadcast-pkt"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ether-stat-broadcast-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.EtherStatBroadcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class EtherStatUndersizedPkt(Entity):
                                    """
                                    ETHER STAT UNDERSIZED PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.EtherStatUndersizedPkt, self).__init__()

                                        self.yang_name = "ether-stat-undersized-pkt"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "ether-stat-undersized-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.EtherStatUndersizedPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutOctets(Entity):
                                    """
                                    OUT OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutOctets, self).__init__()

                                        self.yang_name = "out-octets"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutOctets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPauseFrame(Entity):
                                    """
                                    INPUT PAUSE FRAME
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPauseFrame, self).__init__()

                                        self.yang_name = "in-pause-frame"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pause-frame"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPauseFrame, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InGoodBytes(Entity):
                                    """
                                    INPUT GOOD BYTES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InGoodBytes, self).__init__()

                                        self.yang_name = "in-good-bytes"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-good-bytes"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InGoodBytes, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class In8021qFrames(Entity):
                                    """
                                    INPUT 802 1Q FRAMES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.In8021qFrames, self).__init__()

                                        self.yang_name = "in8021q-frames"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in8021q-frames"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.In8021qFrames, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPkts1519MaxOctets(Entity):
                                    """
                                    INPUT PKTS 1519MAX OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts1519MaxOctets, self).__init__()

                                        self.yang_name = "in-pkts1519-max-octets"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts1519-max-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts1519MaxOctets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InGoodPkts(Entity):
                                    """
                                    INPUT GOOD PKTS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InGoodPkts, self).__init__()

                                        self.yang_name = "in-good-pkts"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-good-pkts"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InGoodPkts, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InDropOverrun(Entity):
                                    """
                                    INPUT DROP OVERRUN
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropOverrun, self).__init__()

                                        self.yang_name = "in-drop-overrun"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-drop-overrun"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropOverrun, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InDropAbort(Entity):
                                    """
                                    INPUT DROP ABORT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropAbort, self).__init__()

                                        self.yang_name = "in-drop-abort"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-drop-abort"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropAbort, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InDropInvalidVlan(Entity):
                                    """
                                    INPUT DROP INVALID VLAN
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropInvalidVlan, self).__init__()

                                        self.yang_name = "in-drop-invalid-vlan"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-drop-invalid-vlan"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropInvalidVlan, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InDropInvalidDmac(Entity):
                                    """
                                    INPUT DROP INVALID DMAC
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropInvalidDmac, self).__init__()

                                        self.yang_name = "in-drop-invalid-dmac"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-drop-invalid-dmac"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropInvalidDmac, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InDropInvalidEncap(Entity):
                                    """
                                    INPUT DROP INVALID ENCAP
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropInvalidEncap, self).__init__()

                                        self.yang_name = "in-drop-invalid-encap"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-drop-invalid-encap"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropInvalidEncap, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InDropOther(Entity):
                                    """
                                    INPUT DROP OTHER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropOther, self).__init__()

                                        self.yang_name = "in-drop-other"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-drop-other"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropOther, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InMibGiant(Entity):
                                    """
                                    INPUT MIB GIANT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InMibGiant, self).__init__()

                                        self.yang_name = "in-mib-giant"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-mib-giant"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InMibGiant, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InMibJabber(Entity):
                                    """
                                    INPUT MIB JABBER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InMibJabber, self).__init__()

                                        self.yang_name = "in-mib-jabber"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-mib-jabber"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InMibJabber, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InMibcrc(Entity):
                                    """
                                    IN MIB CRC
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InMibcrc, self).__init__()

                                        self.yang_name = "in-mibcrc"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-mibcrc"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InMibcrc, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InErrorCollisions(Entity):
                                    """
                                    IN ERROR COLLISIONS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorCollisions, self).__init__()

                                        self.yang_name = "in-error-collisions"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-error-collisions"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorCollisions, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InErrorSymbol(Entity):
                                    """
                                    IN ERROR SYMBOL
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorSymbol, self).__init__()

                                        self.yang_name = "in-error-symbol"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-error-symbol"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorSymbol, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutGoodBytes(Entity):
                                    """
                                    OUT GOOD BYTES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutGoodBytes, self).__init__()

                                        self.yang_name = "out-good-bytes"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-good-bytes"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutGoodBytes, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class Out8021qFrames(Entity):
                                    """
                                    OUT 802 1Q FRAMES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Out8021qFrames, self).__init__()

                                        self.yang_name = "out8021q-frames"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out8021q-frames"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Out8021qFrames, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutPauseFrames(Entity):
                                    """
                                    OUT PAUSE FRAMES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPauseFrames, self).__init__()

                                        self.yang_name = "out-pause-frames"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-pause-frames"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPauseFrames, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutPkts1519MaxOctets(Entity):
                                    """
                                    OUT PKTS 1519 MAX OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts1519MaxOctets, self).__init__()

                                        self.yang_name = "out-pkts1519-max-octets"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-pkts1519-max-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts1519MaxOctets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutGoodPkts(Entity):
                                    """
                                    OUT GOOD PKTS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutGoodPkts, self).__init__()

                                        self.yang_name = "out-good-pkts"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-good-pkts"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutGoodPkts, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutDropUnderrun(Entity):
                                    """
                                    OUT DROP UNDERRUN
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutDropUnderrun, self).__init__()

                                        self.yang_name = "out-drop-underrun"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-drop-underrun"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutDropUnderrun, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutDropAbort(Entity):
                                    """
                                    OUT DROP ABORT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutDropAbort, self).__init__()

                                        self.yang_name = "out-drop-abort"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-drop-abort"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutDropAbort, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutDropOther(Entity):
                                    """
                                    OUT DROP OTHER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutDropOther, self).__init__()

                                        self.yang_name = "out-drop-other"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-drop-other"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutDropOther, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutErrorOther(Entity):
                                    """
                                    OUT ERROR OTHER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutErrorOther, self).__init__()

                                        self.yang_name = "out-error-other"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-error-other"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutErrorOther, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InErrorGiant(Entity):
                                    """
                                    IN ERROR GIANT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorGiant, self).__init__()

                                        self.yang_name = "in-error-giant"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-error-giant"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorGiant, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InErrorRunt(Entity):
                                    """
                                    IN ERROR RUNT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorRunt, self).__init__()

                                        self.yang_name = "in-error-runt"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-error-runt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorRunt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InErrorJabbers(Entity):
                                    """
                                    IN ERROR JABBERS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorJabbers, self).__init__()

                                        self.yang_name = "in-error-jabbers"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-error-jabbers"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorJabbers, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InErrorFragments(Entity):
                                    """
                                    IN ERROR FRAGMENTS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorFragments, self).__init__()

                                        self.yang_name = "in-error-fragments"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-error-fragments"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorFragments, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InErrorOther(Entity):
                                    """
                                    IN ERROR OTHER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorOther, self).__init__()

                                        self.yang_name = "in-error-other"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-error-other"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorOther, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPkt64Octet(Entity):
                                    """
                                    IN PKT 64 OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkt64Octet, self).__init__()

                                        self.yang_name = "in-pkt64-octet"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkt64-octet"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkt64Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPkts65To127Octets(Entity):
                                    """
                                    IN PKTS 65 127OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts65To127Octets, self).__init__()

                                        self.yang_name = "in-pkts65-to127-octets"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts65-to127-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts65To127Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPkts128To255Octets(Entity):
                                    """
                                    IN PKTS 128 255 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts128To255Octets, self).__init__()

                                        self.yang_name = "in-pkts128-to255-octets"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts128-to255-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts128To255Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPkts256To511Octets(Entity):
                                    """
                                    IN PKTS 256 511 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts256To511Octets, self).__init__()

                                        self.yang_name = "in-pkts256-to511-octets"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts256-to511-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts256To511Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPkts512To1023Octets(Entity):
                                    """
                                    IN PKTS 512 1023 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts512To1023Octets, self).__init__()

                                        self.yang_name = "in-pkts512-to1023-octets"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts512-to1023-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts512To1023Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class InPkts1024To1518Octets(Entity):
                                    """
                                    IN PKTS 1024 1518 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts1024To1518Octets, self).__init__()

                                        self.yang_name = "in-pkts1024-to1518-octets"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "in-pkts1024-to1518-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts1024To1518Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class Outpkt64octet(Entity):
                                    """
                                    OUT PKT 64 OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Outpkt64octet, self).__init__()

                                        self.yang_name = "outpkt64octet"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "outpkt64octet"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Outpkt64octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutPkts65127Octets(Entity):
                                    """
                                    OUT PKTS 65 127OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts65127Octets, self).__init__()

                                        self.yang_name = "out-pkts65127-octets"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-pkts65127-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts65127Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutPkts128255Octets(Entity):
                                    """
                                    OUT PKTS 128 255 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts128255Octets, self).__init__()

                                        self.yang_name = "out-pkts128255-octets"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-pkts128255-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts128255Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutPkts256511Octets(Entity):
                                    """
                                    OUT PKTS 256 511 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts256511Octets, self).__init__()

                                        self.yang_name = "out-pkts256511-octets"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-pkts256511-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts256511Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutPkts5121023Octets(Entity):
                                    """
                                    OUT PKTS 512 1023 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts5121023Octets, self).__init__()

                                        self.yang_name = "out-pkts5121023-octets"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-pkts5121023-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts5121023Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class OutPkts10241518Octets(Entity):
                                    """
                                    OUT PKTS 1024 1518 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts10241518Octets, self).__init__()

                                        self.yang_name = "out-pkts10241518-octets"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "out-pkts10241518-octets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts10241518Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class RxUtil(Entity):
                                    """
                                    Rx Utilization in Percent
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: str
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.RxUtil, self).__init__()

                                        self.yang_name = "rx-util"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "rx-util"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.RxUtil, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class TxUtil(Entity):
                                    """
                                    Tx Utilization in Percent
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: str
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxUtil, self).__init__()

                                        self.yang_name = "tx-util"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "tx-util"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxUtil, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class TxUndersizedPkt(Entity):
                                    """
                                    TX Undersized Pkt
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxUndersizedPkt, self).__init__()

                                        self.yang_name = "tx-undersized-pkt"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "tx-undersized-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxUndersizedPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class TxOversizedPkt(Entity):
                                    """
                                    TX Oversized Pkt
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxOversizedPkt, self).__init__()

                                        self.yang_name = "tx-oversized-pkt"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "tx-oversized-pkt"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxOversizedPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class TxFragments(Entity):
                                    """
                                    TX Fragments
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxFragments, self).__init__()

                                        self.yang_name = "tx-fragments"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "tx-fragments"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxFragments, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class TxJabber(Entity):
                                    """
                                    TX Jabber
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxJabber, self).__init__()

                                        self.yang_name = "tx-jabber"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "tx-jabber"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxJabber, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                class TxBadFcs(Entity):
                                    """
                                    TX Bad Fcs
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\: bool
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxBadFcs, self).__init__()

                                        self.yang_name = "tx-bad-fcs"
                                        self.yang_parent_name = "minute15-ether"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                            ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                            ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                        ])
                                        self.data = None
                                        self.threshold = None
                                        self.tca_report = None
                                        self.valid = None
                                        self._segment_path = lambda: "tx-bad-fcs"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxBadFcs, ['data', 'threshold', 'tca_report', 'valid'], name, value)

    def clone_ptr(self):
        self._top_entity = PerformanceManagement()
        return self._top_entity

class PerformanceManagementHistory(Entity):
    """
    performance management history
    
    .. attribute:: global_
    
    	global History performace data
    	**type**\:  :py:class:`Global <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global>`
    
    

    """

    _prefix = 'pmengine-oper'
    _revision = '2017-09-07'

    def __init__(self):
        super(PerformanceManagementHistory, self).__init__()
        self._top_entity = None

        self.yang_name = "performance-management-history"
        self.yang_parent_name = "Cisco-IOS-XR-pmengine-oper"
        self.is_top_level_class = True
        self.has_list_ancestor = False
        self.ylist_key_names = []
        self._child_classes = OrderedDict([("global", ("global_", PerformanceManagementHistory.Global))])
        self._leafs = OrderedDict()

        self.global_ = PerformanceManagementHistory.Global()
        self.global_.parent = self
        self._children_name_map["global_"] = "global"
        self._segment_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management-history"
        self._is_frozen = True

    def __setattr__(self, name, value):
        self._perform_setattr(PerformanceManagementHistory, [], name, value)


    class Global(Entity):
        """
        global History performace data
        
        .. attribute:: periodic
        
        	History performace data
        	**type**\:  :py:class:`Periodic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic>`
        
        

        """

        _prefix = 'pmengine-oper'
        _revision = '2017-09-07'

        def __init__(self):
            super(PerformanceManagementHistory.Global, self).__init__()

            self.yang_name = "global"
            self.yang_parent_name = "performance-management-history"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("periodic", ("periodic", PerformanceManagementHistory.Global.Periodic))])
            self._leafs = OrderedDict()

            self.periodic = PerformanceManagementHistory.Global.Periodic()
            self.periodic.parent = self
            self._children_name_map["periodic"] = "periodic"
            self._segment_path = lambda: "global"
            self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management-history/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(PerformanceManagementHistory.Global, [], name, value)


        class Periodic(Entity):
            """
            History performace data
            
            .. attribute:: sonet_history
            
            	SONET controller History performance data
            	**type**\:  :py:class:`SonetHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory>`
            
            .. attribute:: sts_history
            
            	STS controller History performance data
            	**type**\:  :py:class:`StsHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StsHistory>`
            
            .. attribute:: ethernet_history
            
            	EHERNET controller History performance data
            	**type**\:  :py:class:`EthernetHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory>`
            
            .. attribute:: dwdm_history
            
            	DWDM controller History performance data
            	**type**\:  :py:class:`DwdmHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory>`
            
            .. attribute:: stm_history
            
            	STM controller History performance data
            	**type**\:  :py:class:`StmHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory>`
            
            .. attribute:: macsec_history
            
            	MACSEC controller History performance data
            	**type**\:  :py:class:`MacsecHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory>`
            
            .. attribute:: odu_history
            
            	ODU controller History performance data
            	**type**\:  :py:class:`OduHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory>`
            
            .. attribute:: otu_history
            
            	OTU controller History performance data
            	**type**\:  :py:class:`OtuHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory>`
            
            .. attribute:: ho_vc_history
            
            	HO\_VC controller History performance data
            	**type**\:  :py:class:`HoVcHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.HoVcHistory>`
            
            .. attribute:: optics_history
            
            	OPTICS controller History performance data
            	**type**\:  :py:class:`OpticsHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory>`
            
            .. attribute:: oc_history
            
            	OC controller History performance data
            	**type**\:  :py:class:`OcHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OcHistory>`
            
            

            """

            _prefix = 'pmengine-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(PerformanceManagementHistory.Global.Periodic, self).__init__()

                self.yang_name = "periodic"
                self.yang_parent_name = "global"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("sonet-history", ("sonet_history", PerformanceManagementHistory.Global.Periodic.SonetHistory)), ("sts-history", ("sts_history", PerformanceManagementHistory.Global.Periodic.StsHistory)), ("ethernet-history", ("ethernet_history", PerformanceManagementHistory.Global.Periodic.EthernetHistory)), ("dwdm-history", ("dwdm_history", PerformanceManagementHistory.Global.Periodic.DwdmHistory)), ("stm-history", ("stm_history", PerformanceManagementHistory.Global.Periodic.StmHistory)), ("macsec-history", ("macsec_history", PerformanceManagementHistory.Global.Periodic.MacsecHistory)), ("odu-history", ("odu_history", PerformanceManagementHistory.Global.Periodic.OduHistory)), ("otu-history", ("otu_history", PerformanceManagementHistory.Global.Periodic.OtuHistory)), ("ho-vc-history", ("ho_vc_history", PerformanceManagementHistory.Global.Periodic.HoVcHistory)), ("optics-history", ("optics_history", PerformanceManagementHistory.Global.Periodic.OpticsHistory)), ("oc-history", ("oc_history", PerformanceManagementHistory.Global.Periodic.OcHistory))])
                self._leafs = OrderedDict()

                self.sonet_history = PerformanceManagementHistory.Global.Periodic.SonetHistory()
                self.sonet_history.parent = self
                self._children_name_map["sonet_history"] = "sonet-history"

                self.sts_history = PerformanceManagementHistory.Global.Periodic.StsHistory()
                self.sts_history.parent = self
                self._children_name_map["sts_history"] = "sts-history"

                self.ethernet_history = PerformanceManagementHistory.Global.Periodic.EthernetHistory()
                self.ethernet_history.parent = self
                self._children_name_map["ethernet_history"] = "ethernet-history"

                self.dwdm_history = PerformanceManagementHistory.Global.Periodic.DwdmHistory()
                self.dwdm_history.parent = self
                self._children_name_map["dwdm_history"] = "dwdm-history"

                self.stm_history = PerformanceManagementHistory.Global.Periodic.StmHistory()
                self.stm_history.parent = self
                self._children_name_map["stm_history"] = "stm-history"

                self.macsec_history = PerformanceManagementHistory.Global.Periodic.MacsecHistory()
                self.macsec_history.parent = self
                self._children_name_map["macsec_history"] = "macsec-history"

                self.odu_history = PerformanceManagementHistory.Global.Periodic.OduHistory()
                self.odu_history.parent = self
                self._children_name_map["odu_history"] = "odu-history"

                self.otu_history = PerformanceManagementHistory.Global.Periodic.OtuHistory()
                self.otu_history.parent = self
                self._children_name_map["otu_history"] = "otu-history"

                self.ho_vc_history = PerformanceManagementHistory.Global.Periodic.HoVcHistory()
                self.ho_vc_history.parent = self
                self._children_name_map["ho_vc_history"] = "ho-vc-history"

                self.optics_history = PerformanceManagementHistory.Global.Periodic.OpticsHistory()
                self.optics_history.parent = self
                self._children_name_map["optics_history"] = "optics-history"

                self.oc_history = PerformanceManagementHistory.Global.Periodic.OcHistory()
                self.oc_history.parent = self
                self._children_name_map["oc_history"] = "oc-history"
                self._segment_path = lambda: "periodic"
                self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(PerformanceManagementHistory.Global.Periodic, [], name, value)


            class SonetHistory(Entity):
                """
                SONET controller History performance data
                
                .. attribute:: sonet_port_histories
                
                	Port performance data
                	**type**\:  :py:class:`SonetPortHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(PerformanceManagementHistory.Global.Periodic.SonetHistory, self).__init__()

                    self.yang_name = "sonet-history"
                    self.yang_parent_name = "periodic"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("sonet-port-histories", ("sonet_port_histories", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories))])
                    self._leafs = OrderedDict()

                    self.sonet_port_histories = PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories()
                    self.sonet_port_histories.parent = self
                    self._children_name_map["sonet_port_histories"] = "sonet-port-histories"
                    self._segment_path = lambda: "sonet-history"
                    self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory, [], name, value)


                class SonetPortHistories(Entity):
                    """
                    Port performance data
                    
                    .. attribute:: sonet_port_history
                    
                    	Port performance data
                    	**type**\: list of  		 :py:class:`SonetPortHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories, self).__init__()

                        self.yang_name = "sonet-port-histories"
                        self.yang_parent_name = "sonet-history"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("sonet-port-history", ("sonet_port_history", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory))])
                        self._leafs = OrderedDict()

                        self.sonet_port_history = YList(self)
                        self._segment_path = lambda: "sonet-port-histories"
                        self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/sonet-history/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories, [], name, value)


                    class SonetPortHistory(Entity):
                        """
                        Port performance data
                        
                        .. attribute:: name  (key)
                        
                        	Port name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: sonet_minute15_history
                        
                        	port current performance data
                        	**type**\:  :py:class:`SonetMinute15History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History>`
                        
                        .. attribute:: sonet_hour24_history
                        
                        	port current performance data
                        	**type**\:  :py:class:`SonetHour24History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory, self).__init__()

                            self.yang_name = "sonet-port-history"
                            self.yang_parent_name = "sonet-port-histories"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("sonet-minute15-history", ("sonet_minute15_history", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History)), ("sonet-hour24-history", ("sonet_hour24_history", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None

                            self.sonet_minute15_history = PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History()
                            self.sonet_minute15_history.parent = self
                            self._children_name_map["sonet_minute15_history"] = "sonet-minute15-history"

                            self.sonet_hour24_history = PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History()
                            self.sonet_hour24_history.parent = self
                            self._children_name_map["sonet_hour24_history"] = "sonet-hour24-history"
                            self._segment_path = lambda: "sonet-port-history" + "[name='" + str(self.name) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/sonet-history/sonet-port-histories/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory, ['name'], name, value)


                        class SonetMinute15History(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: sonet_minute15ocn_histories
                            
                            	port current performance data
                            	**type**\:  :py:class:`SonetMinute15ocnHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories>`
                            
                            .. attribute:: sonet_minute15_path_histories
                            
                            	port current performance data
                            	**type**\:  :py:class:`SonetMinute15PathHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History, self).__init__()

                                self.yang_name = "sonet-minute15-history"
                                self.yang_parent_name = "sonet-port-history"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("sonet-minute15ocn-histories", ("sonet_minute15ocn_histories", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories)), ("sonet-minute15-path-histories", ("sonet_minute15_path_histories", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories))])
                                self._leafs = OrderedDict()

                                self.sonet_minute15ocn_histories = PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories()
                                self.sonet_minute15ocn_histories.parent = self
                                self._children_name_map["sonet_minute15ocn_histories"] = "sonet-minute15ocn-histories"

                                self.sonet_minute15_path_histories = PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories()
                                self.sonet_minute15_path_histories.parent = self
                                self._children_name_map["sonet_minute15_path_histories"] = "sonet-minute15-path-histories"
                                self._segment_path = lambda: "sonet-minute15-history"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History, [], name, value)


                            class SonetMinute15ocnHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: sonet_minute15ocn_history
                                
                                	port 15\-minute ocn performance data
                                	**type**\: list of  		 :py:class:`SonetMinute15ocnHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories, self).__init__()

                                    self.yang_name = "sonet-minute15ocn-histories"
                                    self.yang_parent_name = "sonet-minute15-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("sonet-minute15ocn-history", ("sonet_minute15ocn_history", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory))])
                                    self._leafs = OrderedDict()

                                    self.sonet_minute15ocn_history = YList(self)
                                    self._segment_path = lambda: "sonet-minute15ocn-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories, [], name, value)


                                class SonetMinute15ocnHistory(Entity):
                                    """
                                    port 15\-minute ocn performance data
                                    
                                    .. attribute:: number  (key)
                                    
                                    	channel number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sonet_minute15ocn_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`SonetMinute15ocnTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory, self).__init__()

                                        self.yang_name = "sonet-minute15ocn-history"
                                        self.yang_parent_name = "sonet-minute15ocn-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([("sonet-minute15ocn-time-line-instances", ("sonet_minute15ocn_time_line_instances", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ])
                                        self.number = None

                                        self.sonet_minute15ocn_time_line_instances = PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances()
                                        self.sonet_minute15ocn_time_line_instances.parent = self
                                        self._children_name_map["sonet_minute15ocn_time_line_instances"] = "sonet-minute15ocn-time-line-instances"
                                        self._segment_path = lambda: "sonet-minute15ocn-history" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory, ['number'], name, value)


                                    class SonetMinute15ocnTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: sonet_minute15ocn_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of  		 :py:class:`SonetMinute15ocnTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances, self).__init__()

                                            self.yang_name = "sonet-minute15ocn-time-line-instances"
                                            self.yang_parent_name = "sonet-minute15ocn-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("sonet-minute15ocn-time-line-instance", ("sonet_minute15ocn_time_line_instance", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.sonet_minute15ocn_time_line_instance = YList(self)
                                            self._segment_path = lambda: "sonet-minute15ocn-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances, [], name, value)


                                        class SonetMinute15ocnTimeLineInstance(Entity):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: section
                                            
                                            	SECTION
                                            	**type**\:  :py:class:`Section <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.Section>`
                                            
                                            .. attribute:: line
                                            
                                            	LINE
                                            	**type**\:  :py:class:`Line <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.Line>`
                                            
                                            .. attribute:: fe_line
                                            
                                            	FarEnd LINE
                                            	**type**\:  :py:class:`FeLine <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.FeLine>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance, self).__init__()

                                                self.yang_name = "sonet-minute15ocn-time-line-instance"
                                                self.yang_parent_name = "sonet-minute15ocn-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("section", ("section", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.Section)), ("line", ("line", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.Line)), ("fe-line", ("fe_line", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.FeLine))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None

                                                self.section = PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.Section()
                                                self.section.parent = self
                                                self._children_name_map["section"] = "section"

                                                self.line = PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.Line()
                                                self.line.parent = self
                                                self._children_name_map["line"] = "line"

                                                self.fe_line = PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.FeLine()
                                                self.fe_line.parent = self
                                                self._children_name_map["fe_line"] = "fe-line"
                                                self._segment_path = lambda: "sonet-minute15ocn-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear24_hr_time'], name, value)


                                            class Section(Entity):
                                                """
                                                SECTION
                                                
                                                .. attribute:: section_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:  :py:class:`SectionESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.Section.SectionESs>`
                                                
                                                .. attribute:: section_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:  :py:class:`SectionSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.Section.SectionSeSs>`
                                                
                                                .. attribute:: section_sef_ss
                                                
                                                	The number of Severely Errored Framing Seconds
                                                	**type**\:  :py:class:`SectionSefSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.Section.SectionSefSs>`
                                                
                                                .. attribute:: section_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:  :py:class:`SectionCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.Section.SectionCVs>`
                                                
                                                .. attribute:: section_status
                                                
                                                	 status of the interface
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.Section, self).__init__()

                                                    self.yang_name = "section"
                                                    self.yang_parent_name = "sonet-minute15ocn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("section-e-ss", ("section_e_ss", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.Section.SectionESs)), ("section-se-ss", ("section_se_ss", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.Section.SectionSeSs)), ("section-sef-ss", ("section_sef_ss", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.Section.SectionSefSs)), ("section-c-vs", ("section_c_vs", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.Section.SectionCVs))])
                                                    self._leafs = OrderedDict([
                                                        ('section_status', (YLeaf(YType.int32, 'section-status'), ['int'])),
                                                    ])
                                                    self.section_status = None

                                                    self.section_e_ss = PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.Section.SectionESs()
                                                    self.section_e_ss.parent = self
                                                    self._children_name_map["section_e_ss"] = "section-e-ss"

                                                    self.section_se_ss = PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.Section.SectionSeSs()
                                                    self.section_se_ss.parent = self
                                                    self._children_name_map["section_se_ss"] = "section-se-ss"

                                                    self.section_sef_ss = PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.Section.SectionSefSs()
                                                    self.section_sef_ss.parent = self
                                                    self._children_name_map["section_sef_ss"] = "section-sef-ss"

                                                    self.section_c_vs = PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.Section.SectionCVs()
                                                    self.section_c_vs.parent = self
                                                    self._children_name_map["section_c_vs"] = "section-c-vs"
                                                    self._segment_path = lambda: "section"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.Section, ['section_status'], name, value)


                                                class SectionESs(Entity):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.Section.SectionESs, self).__init__()

                                                        self.yang_name = "section-e-ss"
                                                        self.yang_parent_name = "section"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "section-e-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.Section.SectionESs, ['data', 'threshold', 'tca_report'], name, value)


                                                class SectionSeSs(Entity):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.Section.SectionSeSs, self).__init__()

                                                        self.yang_name = "section-se-ss"
                                                        self.yang_parent_name = "section"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "section-se-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.Section.SectionSeSs, ['data', 'threshold', 'tca_report'], name, value)


                                                class SectionSefSs(Entity):
                                                    """
                                                    The number of Severely Errored Framing Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.Section.SectionSefSs, self).__init__()

                                                        self.yang_name = "section-sef-ss"
                                                        self.yang_parent_name = "section"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "section-sef-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.Section.SectionSefSs, ['data', 'threshold', 'tca_report'], name, value)


                                                class SectionCVs(Entity):
                                                    """
                                                    The number of Coding Violations
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.Section.SectionCVs, self).__init__()

                                                        self.yang_name = "section-c-vs"
                                                        self.yang_parent_name = "section"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "section-c-vs"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.Section.SectionCVs, ['data', 'threshold', 'tca_report'], name, value)


                                            class Line(Entity):
                                                """
                                                LINE
                                                
                                                .. attribute:: line_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:  :py:class:`LineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.Line.LineESs>`
                                                
                                                .. attribute:: line_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:  :py:class:`LineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.Line.LineSeSs>`
                                                
                                                .. attribute:: line_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:  :py:class:`LineCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.Line.LineCVs>`
                                                
                                                .. attribute:: line_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\:  :py:class:`LineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.Line.LineUaSs>`
                                                
                                                .. attribute:: line_fc_ls
                                                
                                                	The number of Failure counts Seconds
                                                	**type**\:  :py:class:`LineFcLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.Line.LineFcLs>`
                                                
                                                .. attribute:: line_status
                                                
                                                	 status of the interface
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.Line, self).__init__()

                                                    self.yang_name = "line"
                                                    self.yang_parent_name = "sonet-minute15ocn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("line-e-ss", ("line_e_ss", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.Line.LineESs)), ("line-se-ss", ("line_se_ss", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.Line.LineSeSs)), ("line-c-vs", ("line_c_vs", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.Line.LineCVs)), ("line-ua-ss", ("line_ua_ss", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.Line.LineUaSs)), ("line-fc-ls", ("line_fc_ls", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.Line.LineFcLs))])
                                                    self._leafs = OrderedDict([
                                                        ('line_status', (YLeaf(YType.int32, 'line-status'), ['int'])),
                                                    ])
                                                    self.line_status = None

                                                    self.line_e_ss = PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.Line.LineESs()
                                                    self.line_e_ss.parent = self
                                                    self._children_name_map["line_e_ss"] = "line-e-ss"

                                                    self.line_se_ss = PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.Line.LineSeSs()
                                                    self.line_se_ss.parent = self
                                                    self._children_name_map["line_se_ss"] = "line-se-ss"

                                                    self.line_c_vs = PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.Line.LineCVs()
                                                    self.line_c_vs.parent = self
                                                    self._children_name_map["line_c_vs"] = "line-c-vs"

                                                    self.line_ua_ss = PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.Line.LineUaSs()
                                                    self.line_ua_ss.parent = self
                                                    self._children_name_map["line_ua_ss"] = "line-ua-ss"

                                                    self.line_fc_ls = PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.Line.LineFcLs()
                                                    self.line_fc_ls.parent = self
                                                    self._children_name_map["line_fc_ls"] = "line-fc-ls"
                                                    self._segment_path = lambda: "line"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.Line, ['line_status'], name, value)


                                                class LineESs(Entity):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.Line.LineESs, self).__init__()

                                                        self.yang_name = "line-e-ss"
                                                        self.yang_parent_name = "line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "line-e-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.Line.LineESs, ['data', 'threshold', 'tca_report'], name, value)


                                                class LineSeSs(Entity):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.Line.LineSeSs, self).__init__()

                                                        self.yang_name = "line-se-ss"
                                                        self.yang_parent_name = "line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "line-se-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.Line.LineSeSs, ['data', 'threshold', 'tca_report'], name, value)


                                                class LineCVs(Entity):
                                                    """
                                                    The number of Coding Violations
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.Line.LineCVs, self).__init__()

                                                        self.yang_name = "line-c-vs"
                                                        self.yang_parent_name = "line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "line-c-vs"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.Line.LineCVs, ['data', 'threshold', 'tca_report'], name, value)


                                                class LineUaSs(Entity):
                                                    """
                                                    The number of Unavailable Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.Line.LineUaSs, self).__init__()

                                                        self.yang_name = "line-ua-ss"
                                                        self.yang_parent_name = "line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "line-ua-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.Line.LineUaSs, ['data', 'threshold', 'tca_report'], name, value)


                                                class LineFcLs(Entity):
                                                    """
                                                    The number of Failure counts Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.Line.LineFcLs, self).__init__()

                                                        self.yang_name = "line-fc-ls"
                                                        self.yang_parent_name = "line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "line-fc-ls"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.Line.LineFcLs, ['data', 'threshold', 'tca_report'], name, value)


                                            class FeLine(Entity):
                                                """
                                                FarEnd LINE
                                                
                                                .. attribute:: far_end_line_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:  :py:class:`FarEndLineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.FeLine.FarEndLineESs>`
                                                
                                                .. attribute:: far_end_line_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:  :py:class:`FarEndLineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.FeLine.FarEndLineSeSs>`
                                                
                                                .. attribute:: far_end_line_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:  :py:class:`FarEndLineCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.FeLine.FarEndLineCVs>`
                                                
                                                .. attribute:: far_end_line_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\:  :py:class:`FarEndLineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.FeLine.FarEndLineUaSs>`
                                                
                                                .. attribute:: far_end_line_fc_ls
                                                
                                                	The number of Failure counts Seconds
                                                	**type**\:  :py:class:`FarEndLineFcLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.FeLine.FarEndLineFcLs>`
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.FeLine, self).__init__()

                                                    self.yang_name = "fe-line"
                                                    self.yang_parent_name = "sonet-minute15ocn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("far-end-line-e-ss", ("far_end_line_e_ss", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.FeLine.FarEndLineESs)), ("far-end-line-se-ss", ("far_end_line_se_ss", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.FeLine.FarEndLineSeSs)), ("far-end-line-c-vs", ("far_end_line_c_vs", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.FeLine.FarEndLineCVs)), ("far-end-line-ua-ss", ("far_end_line_ua_ss", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.FeLine.FarEndLineUaSs)), ("far-end-line-fc-ls", ("far_end_line_fc_ls", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.FeLine.FarEndLineFcLs))])
                                                    self._leafs = OrderedDict()

                                                    self.far_end_line_e_ss = PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.FeLine.FarEndLineESs()
                                                    self.far_end_line_e_ss.parent = self
                                                    self._children_name_map["far_end_line_e_ss"] = "far-end-line-e-ss"

                                                    self.far_end_line_se_ss = PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.FeLine.FarEndLineSeSs()
                                                    self.far_end_line_se_ss.parent = self
                                                    self._children_name_map["far_end_line_se_ss"] = "far-end-line-se-ss"

                                                    self.far_end_line_c_vs = PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.FeLine.FarEndLineCVs()
                                                    self.far_end_line_c_vs.parent = self
                                                    self._children_name_map["far_end_line_c_vs"] = "far-end-line-c-vs"

                                                    self.far_end_line_ua_ss = PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.FeLine.FarEndLineUaSs()
                                                    self.far_end_line_ua_ss.parent = self
                                                    self._children_name_map["far_end_line_ua_ss"] = "far-end-line-ua-ss"

                                                    self.far_end_line_fc_ls = PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.FeLine.FarEndLineFcLs()
                                                    self.far_end_line_fc_ls.parent = self
                                                    self._children_name_map["far_end_line_fc_ls"] = "far-end-line-fc-ls"
                                                    self._segment_path = lambda: "fe-line"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.FeLine, [], name, value)


                                                class FarEndLineESs(Entity):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.FeLine.FarEndLineESs, self).__init__()

                                                        self.yang_name = "far-end-line-e-ss"
                                                        self.yang_parent_name = "fe-line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "far-end-line-e-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.FeLine.FarEndLineESs, ['data', 'threshold', 'tca_report'], name, value)


                                                class FarEndLineSeSs(Entity):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.FeLine.FarEndLineSeSs, self).__init__()

                                                        self.yang_name = "far-end-line-se-ss"
                                                        self.yang_parent_name = "fe-line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "far-end-line-se-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.FeLine.FarEndLineSeSs, ['data', 'threshold', 'tca_report'], name, value)


                                                class FarEndLineCVs(Entity):
                                                    """
                                                    The number of Coding Violations
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.FeLine.FarEndLineCVs, self).__init__()

                                                        self.yang_name = "far-end-line-c-vs"
                                                        self.yang_parent_name = "fe-line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "far-end-line-c-vs"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.FeLine.FarEndLineCVs, ['data', 'threshold', 'tca_report'], name, value)


                                                class FarEndLineUaSs(Entity):
                                                    """
                                                    The number of Unavailable Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.FeLine.FarEndLineUaSs, self).__init__()

                                                        self.yang_name = "far-end-line-ua-ss"
                                                        self.yang_parent_name = "fe-line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "far-end-line-ua-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.FeLine.FarEndLineUaSs, ['data', 'threshold', 'tca_report'], name, value)


                                                class FarEndLineFcLs(Entity):
                                                    """
                                                    The number of Failure counts Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.FeLine.FarEndLineFcLs, self).__init__()

                                                        self.yang_name = "far-end-line-fc-ls"
                                                        self.yang_parent_name = "fe-line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "far-end-line-fc-ls"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15ocnHistories.SonetMinute15ocnHistory.SonetMinute15ocnTimeLineInstances.SonetMinute15ocnTimeLineInstance.FeLine.FarEndLineFcLs, ['data', 'threshold', 'tca_report'], name, value)


                            class SonetMinute15PathHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: sonet_minute15_path_history
                                
                                	port 15\-minute Path performance data
                                	**type**\: list of  		 :py:class:`SonetMinute15PathHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories, self).__init__()

                                    self.yang_name = "sonet-minute15-path-histories"
                                    self.yang_parent_name = "sonet-minute15-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("sonet-minute15-path-history", ("sonet_minute15_path_history", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory))])
                                    self._leafs = OrderedDict()

                                    self.sonet_minute15_path_history = YList(self)
                                    self._segment_path = lambda: "sonet-minute15-path-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories, [], name, value)


                                class SonetMinute15PathHistory(Entity):
                                    """
                                    port 15\-minute Path performance data
                                    
                                    .. attribute:: number  (key)
                                    
                                    	channel number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sonet_minute15_path_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`SonetMinute15PathTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory, self).__init__()

                                        self.yang_name = "sonet-minute15-path-history"
                                        self.yang_parent_name = "sonet-minute15-path-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([("sonet-minute15-path-time-line-instances", ("sonet_minute15_path_time_line_instances", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ])
                                        self.number = None

                                        self.sonet_minute15_path_time_line_instances = PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances()
                                        self.sonet_minute15_path_time_line_instances.parent = self
                                        self._children_name_map["sonet_minute15_path_time_line_instances"] = "sonet-minute15-path-time-line-instances"
                                        self._segment_path = lambda: "sonet-minute15-path-history" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory, ['number'], name, value)


                                    class SonetMinute15PathTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: sonet_minute15_path_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of  		 :py:class:`SonetMinute15PathTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances, self).__init__()

                                            self.yang_name = "sonet-minute15-path-time-line-instances"
                                            self.yang_parent_name = "sonet-minute15-path-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("sonet-minute15-path-time-line-instance", ("sonet_minute15_path_time_line_instance", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.sonet_minute15_path_time_line_instance = YList(self)
                                            self._segment_path = lambda: "sonet-minute15-path-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances, [], name, value)


                                        class SonetMinute15PathTimeLineInstance(Entity):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path
                                            
                                            	PATH
                                            	**type**\:  :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path>`
                                            
                                            .. attribute:: fe_path
                                            
                                            	Far End PATH
                                            	**type**\:  :py:class:`FePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.FePath>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance, self).__init__()

                                                self.yang_name = "sonet-minute15-path-time-line-instance"
                                                self.yang_parent_name = "sonet-minute15-path-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("path", ("path", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path)), ("fe-path", ("fe_path", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.FePath))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None

                                                self.path = PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path()
                                                self.path.parent = self
                                                self._children_name_map["path"] = "path"

                                                self.fe_path = PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.FePath()
                                                self.fe_path.parent = self
                                                self._children_name_map["fe_path"] = "fe-path"
                                                self._segment_path = lambda: "sonet-minute15-path-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear24_hr_time'], name, value)


                                            class Path(Entity):
                                                """
                                                PATH
                                                
                                                .. attribute:: path_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:  :py:class:`PathESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path.PathESs>`
                                                
                                                .. attribute:: path_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:  :py:class:`PathSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path.PathSeSs>`
                                                
                                                .. attribute:: path_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:  :py:class:`PathCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path.PathCVs>`
                                                
                                                .. attribute:: path_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\:  :py:class:`PathUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path.PathUaSs>`
                                                
                                                .. attribute:: path_width
                                                
                                                	Indicates the type of the SONET/SDH Path
                                                	**type**\:  :py:class:`PmSonetPathWidthEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmSonetPathWidthEnum>`
                                                
                                                .. attribute:: path_status
                                                
                                                	 status of the interface
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path, self).__init__()

                                                    self.yang_name = "path"
                                                    self.yang_parent_name = "sonet-minute15-path-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("path-e-ss", ("path_e_ss", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path.PathESs)), ("path-se-ss", ("path_se_ss", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path.PathSeSs)), ("path-c-vs", ("path_c_vs", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path.PathCVs)), ("path-ua-ss", ("path_ua_ss", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path.PathUaSs))])
                                                    self._leafs = OrderedDict([
                                                        ('path_width', (YLeaf(YType.enumeration, 'path-width'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper', 'PmSonetPathWidthEnum', '')])),
                                                        ('path_status', (YLeaf(YType.int32, 'path-status'), ['int'])),
                                                    ])
                                                    self.path_width = None
                                                    self.path_status = None

                                                    self.path_e_ss = PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path.PathESs()
                                                    self.path_e_ss.parent = self
                                                    self._children_name_map["path_e_ss"] = "path-e-ss"

                                                    self.path_se_ss = PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path.PathSeSs()
                                                    self.path_se_ss.parent = self
                                                    self._children_name_map["path_se_ss"] = "path-se-ss"

                                                    self.path_c_vs = PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path.PathCVs()
                                                    self.path_c_vs.parent = self
                                                    self._children_name_map["path_c_vs"] = "path-c-vs"

                                                    self.path_ua_ss = PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path.PathUaSs()
                                                    self.path_ua_ss.parent = self
                                                    self._children_name_map["path_ua_ss"] = "path-ua-ss"
                                                    self._segment_path = lambda: "path"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path, ['path_width', 'path_status'], name, value)


                                                class PathESs(Entity):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path.PathESs, self).__init__()

                                                        self.yang_name = "path-e-ss"
                                                        self.yang_parent_name = "path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "path-e-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path.PathESs, ['data', 'threshold', 'tca_report'], name, value)


                                                class PathSeSs(Entity):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path.PathSeSs, self).__init__()

                                                        self.yang_name = "path-se-ss"
                                                        self.yang_parent_name = "path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "path-se-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path.PathSeSs, ['data', 'threshold', 'tca_report'], name, value)


                                                class PathCVs(Entity):
                                                    """
                                                    The number of Coding Violations
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path.PathCVs, self).__init__()

                                                        self.yang_name = "path-c-vs"
                                                        self.yang_parent_name = "path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "path-c-vs"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path.PathCVs, ['data', 'threshold', 'tca_report'], name, value)


                                                class PathUaSs(Entity):
                                                    """
                                                    The number of Unavailable Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path.PathUaSs, self).__init__()

                                                        self.yang_name = "path-ua-ss"
                                                        self.yang_parent_name = "path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "path-ua-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path.PathUaSs, ['data', 'threshold', 'tca_report'], name, value)


                                            class FePath(Entity):
                                                """
                                                Far End PATH
                                                
                                                .. attribute:: far_end_path_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: far_end_path_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: far_end_path_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: far_end_path_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.FePath, self).__init__()

                                                    self.yang_name = "fe-path"
                                                    self.yang_parent_name = "sonet-minute15-path-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('far_end_path_e_ss', (YLeaf(YType.uint32, 'far-end-path-e-ss'), ['int'])),
                                                        ('far_end_path_se_ss', (YLeaf(YType.uint32, 'far-end-path-se-ss'), ['int'])),
                                                        ('far_end_path_c_vs', (YLeaf(YType.uint32, 'far-end-path-c-vs'), ['int'])),
                                                        ('far_end_path_ua_ss', (YLeaf(YType.uint32, 'far-end-path-ua-ss'), ['int'])),
                                                    ])
                                                    self.far_end_path_e_ss = None
                                                    self.far_end_path_se_ss = None
                                                    self.far_end_path_c_vs = None
                                                    self.far_end_path_ua_ss = None
                                                    self._segment_path = lambda: "fe-path"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.FePath, ['far_end_path_e_ss', 'far_end_path_se_ss', 'far_end_path_c_vs', 'far_end_path_ua_ss'], name, value)


                        class SonetHour24History(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: sonet_hour24_path_histories
                            
                            	port current performance data
                            	**type**\:  :py:class:`SonetHour24PathHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories>`
                            
                            .. attribute:: sonet_hour24ocn_histories
                            
                            	port current performance data
                            	**type**\:  :py:class:`SonetHour24ocnHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History, self).__init__()

                                self.yang_name = "sonet-hour24-history"
                                self.yang_parent_name = "sonet-port-history"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("sonet-hour24-path-histories", ("sonet_hour24_path_histories", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories)), ("sonet-hour24ocn-histories", ("sonet_hour24ocn_histories", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories))])
                                self._leafs = OrderedDict()

                                self.sonet_hour24_path_histories = PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories()
                                self.sonet_hour24_path_histories.parent = self
                                self._children_name_map["sonet_hour24_path_histories"] = "sonet-hour24-path-histories"

                                self.sonet_hour24ocn_histories = PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories()
                                self.sonet_hour24ocn_histories.parent = self
                                self._children_name_map["sonet_hour24ocn_histories"] = "sonet-hour24ocn-histories"
                                self._segment_path = lambda: "sonet-hour24-history"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History, [], name, value)


                            class SonetHour24PathHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: sonet_hour24_path_history
                                
                                	port 24 hour Path performance data
                                	**type**\: list of  		 :py:class:`SonetHour24PathHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories, self).__init__()

                                    self.yang_name = "sonet-hour24-path-histories"
                                    self.yang_parent_name = "sonet-hour24-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("sonet-hour24-path-history", ("sonet_hour24_path_history", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory))])
                                    self._leafs = OrderedDict()

                                    self.sonet_hour24_path_history = YList(self)
                                    self._segment_path = lambda: "sonet-hour24-path-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories, [], name, value)


                                class SonetHour24PathHistory(Entity):
                                    """
                                    port 24 hour Path performance data
                                    
                                    .. attribute:: number  (key)
                                    
                                    	channel number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sonet_hour24_path_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`SonetHour24PathTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory, self).__init__()

                                        self.yang_name = "sonet-hour24-path-history"
                                        self.yang_parent_name = "sonet-hour24-path-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([("sonet-hour24-path-time-line-instances", ("sonet_hour24_path_time_line_instances", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ])
                                        self.number = None

                                        self.sonet_hour24_path_time_line_instances = PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances()
                                        self.sonet_hour24_path_time_line_instances.parent = self
                                        self._children_name_map["sonet_hour24_path_time_line_instances"] = "sonet-hour24-path-time-line-instances"
                                        self._segment_path = lambda: "sonet-hour24-path-history" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory, ['number'], name, value)


                                    class SonetHour24PathTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: sonet_hour24_path_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of  		 :py:class:`SonetHour24PathTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances, self).__init__()

                                            self.yang_name = "sonet-hour24-path-time-line-instances"
                                            self.yang_parent_name = "sonet-hour24-path-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("sonet-hour24-path-time-line-instance", ("sonet_hour24_path_time_line_instance", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.sonet_hour24_path_time_line_instance = YList(self)
                                            self._segment_path = lambda: "sonet-hour24-path-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances, [], name, value)


                                        class SonetHour24PathTimeLineInstance(Entity):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path
                                            
                                            	PATH
                                            	**type**\:  :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path>`
                                            
                                            .. attribute:: fe_path
                                            
                                            	Far End PATH
                                            	**type**\:  :py:class:`FePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.FePath>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance, self).__init__()

                                                self.yang_name = "sonet-hour24-path-time-line-instance"
                                                self.yang_parent_name = "sonet-hour24-path-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("path", ("path", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path)), ("fe-path", ("fe_path", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.FePath))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None

                                                self.path = PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path()
                                                self.path.parent = self
                                                self._children_name_map["path"] = "path"

                                                self.fe_path = PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.FePath()
                                                self.fe_path.parent = self
                                                self._children_name_map["fe_path"] = "fe-path"
                                                self._segment_path = lambda: "sonet-hour24-path-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear24_hr_time'], name, value)


                                            class Path(Entity):
                                                """
                                                PATH
                                                
                                                .. attribute:: path_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:  :py:class:`PathESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path.PathESs>`
                                                
                                                .. attribute:: path_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:  :py:class:`PathSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path.PathSeSs>`
                                                
                                                .. attribute:: path_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:  :py:class:`PathCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path.PathCVs>`
                                                
                                                .. attribute:: path_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\:  :py:class:`PathUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path.PathUaSs>`
                                                
                                                .. attribute:: path_width
                                                
                                                	Indicates the type of the SONET/SDH Path
                                                	**type**\:  :py:class:`PmSonetPathWidthEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmSonetPathWidthEnum>`
                                                
                                                .. attribute:: path_status
                                                
                                                	 status of the interface
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path, self).__init__()

                                                    self.yang_name = "path"
                                                    self.yang_parent_name = "sonet-hour24-path-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("path-e-ss", ("path_e_ss", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path.PathESs)), ("path-se-ss", ("path_se_ss", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path.PathSeSs)), ("path-c-vs", ("path_c_vs", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path.PathCVs)), ("path-ua-ss", ("path_ua_ss", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path.PathUaSs))])
                                                    self._leafs = OrderedDict([
                                                        ('path_width', (YLeaf(YType.enumeration, 'path-width'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper', 'PmSonetPathWidthEnum', '')])),
                                                        ('path_status', (YLeaf(YType.int32, 'path-status'), ['int'])),
                                                    ])
                                                    self.path_width = None
                                                    self.path_status = None

                                                    self.path_e_ss = PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path.PathESs()
                                                    self.path_e_ss.parent = self
                                                    self._children_name_map["path_e_ss"] = "path-e-ss"

                                                    self.path_se_ss = PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path.PathSeSs()
                                                    self.path_se_ss.parent = self
                                                    self._children_name_map["path_se_ss"] = "path-se-ss"

                                                    self.path_c_vs = PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path.PathCVs()
                                                    self.path_c_vs.parent = self
                                                    self._children_name_map["path_c_vs"] = "path-c-vs"

                                                    self.path_ua_ss = PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path.PathUaSs()
                                                    self.path_ua_ss.parent = self
                                                    self._children_name_map["path_ua_ss"] = "path-ua-ss"
                                                    self._segment_path = lambda: "path"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path, ['path_width', 'path_status'], name, value)


                                                class PathESs(Entity):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path.PathESs, self).__init__()

                                                        self.yang_name = "path-e-ss"
                                                        self.yang_parent_name = "path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "path-e-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path.PathESs, ['data', 'threshold', 'tca_report'], name, value)


                                                class PathSeSs(Entity):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path.PathSeSs, self).__init__()

                                                        self.yang_name = "path-se-ss"
                                                        self.yang_parent_name = "path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "path-se-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path.PathSeSs, ['data', 'threshold', 'tca_report'], name, value)


                                                class PathCVs(Entity):
                                                    """
                                                    The number of Coding Violations
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path.PathCVs, self).__init__()

                                                        self.yang_name = "path-c-vs"
                                                        self.yang_parent_name = "path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "path-c-vs"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path.PathCVs, ['data', 'threshold', 'tca_report'], name, value)


                                                class PathUaSs(Entity):
                                                    """
                                                    The number of Unavailable Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path.PathUaSs, self).__init__()

                                                        self.yang_name = "path-ua-ss"
                                                        self.yang_parent_name = "path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "path-ua-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path.PathUaSs, ['data', 'threshold', 'tca_report'], name, value)


                                            class FePath(Entity):
                                                """
                                                Far End PATH
                                                
                                                .. attribute:: far_end_path_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: far_end_path_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: far_end_path_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: far_end_path_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.FePath, self).__init__()

                                                    self.yang_name = "fe-path"
                                                    self.yang_parent_name = "sonet-hour24-path-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('far_end_path_e_ss', (YLeaf(YType.uint32, 'far-end-path-e-ss'), ['int'])),
                                                        ('far_end_path_se_ss', (YLeaf(YType.uint32, 'far-end-path-se-ss'), ['int'])),
                                                        ('far_end_path_c_vs', (YLeaf(YType.uint32, 'far-end-path-c-vs'), ['int'])),
                                                        ('far_end_path_ua_ss', (YLeaf(YType.uint32, 'far-end-path-ua-ss'), ['int'])),
                                                    ])
                                                    self.far_end_path_e_ss = None
                                                    self.far_end_path_se_ss = None
                                                    self.far_end_path_c_vs = None
                                                    self.far_end_path_ua_ss = None
                                                    self._segment_path = lambda: "fe-path"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.FePath, ['far_end_path_e_ss', 'far_end_path_se_ss', 'far_end_path_c_vs', 'far_end_path_ua_ss'], name, value)


                            class SonetHour24ocnHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: sonet_hour24ocn_history
                                
                                	port 24 hour ocn performance data
                                	**type**\: list of  		 :py:class:`SonetHour24ocnHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories, self).__init__()

                                    self.yang_name = "sonet-hour24ocn-histories"
                                    self.yang_parent_name = "sonet-hour24-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("sonet-hour24ocn-history", ("sonet_hour24ocn_history", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory))])
                                    self._leafs = OrderedDict()

                                    self.sonet_hour24ocn_history = YList(self)
                                    self._segment_path = lambda: "sonet-hour24ocn-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories, [], name, value)


                                class SonetHour24ocnHistory(Entity):
                                    """
                                    port 24 hour ocn performance data
                                    
                                    .. attribute:: number  (key)
                                    
                                    	channel number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sonet_hour24ocn_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`SonetHour24ocnTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory, self).__init__()

                                        self.yang_name = "sonet-hour24ocn-history"
                                        self.yang_parent_name = "sonet-hour24ocn-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([("sonet-hour24ocn-time-line-instances", ("sonet_hour24ocn_time_line_instances", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ])
                                        self.number = None

                                        self.sonet_hour24ocn_time_line_instances = PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances()
                                        self.sonet_hour24ocn_time_line_instances.parent = self
                                        self._children_name_map["sonet_hour24ocn_time_line_instances"] = "sonet-hour24ocn-time-line-instances"
                                        self._segment_path = lambda: "sonet-hour24ocn-history" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory, ['number'], name, value)


                                    class SonetHour24ocnTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: sonet_hour24ocn_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of  		 :py:class:`SonetHour24ocnTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances, self).__init__()

                                            self.yang_name = "sonet-hour24ocn-time-line-instances"
                                            self.yang_parent_name = "sonet-hour24ocn-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("sonet-hour24ocn-time-line-instance", ("sonet_hour24ocn_time_line_instance", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.sonet_hour24ocn_time_line_instance = YList(self)
                                            self._segment_path = lambda: "sonet-hour24ocn-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances, [], name, value)


                                        class SonetHour24ocnTimeLineInstance(Entity):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: section
                                            
                                            	SECTION
                                            	**type**\:  :py:class:`Section <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.Section>`
                                            
                                            .. attribute:: line
                                            
                                            	LINE
                                            	**type**\:  :py:class:`Line <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.Line>`
                                            
                                            .. attribute:: fe_line
                                            
                                            	FarEnd LINE
                                            	**type**\:  :py:class:`FeLine <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.FeLine>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance, self).__init__()

                                                self.yang_name = "sonet-hour24ocn-time-line-instance"
                                                self.yang_parent_name = "sonet-hour24ocn-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("section", ("section", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.Section)), ("line", ("line", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.Line)), ("fe-line", ("fe_line", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.FeLine))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None

                                                self.section = PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.Section()
                                                self.section.parent = self
                                                self._children_name_map["section"] = "section"

                                                self.line = PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.Line()
                                                self.line.parent = self
                                                self._children_name_map["line"] = "line"

                                                self.fe_line = PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.FeLine()
                                                self.fe_line.parent = self
                                                self._children_name_map["fe_line"] = "fe-line"
                                                self._segment_path = lambda: "sonet-hour24ocn-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear24_hr_time'], name, value)


                                            class Section(Entity):
                                                """
                                                SECTION
                                                
                                                .. attribute:: section_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:  :py:class:`SectionESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.Section.SectionESs>`
                                                
                                                .. attribute:: section_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:  :py:class:`SectionSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.Section.SectionSeSs>`
                                                
                                                .. attribute:: section_sef_ss
                                                
                                                	The number of Severely Errored Framing Seconds
                                                	**type**\:  :py:class:`SectionSefSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.Section.SectionSefSs>`
                                                
                                                .. attribute:: section_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:  :py:class:`SectionCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.Section.SectionCVs>`
                                                
                                                .. attribute:: section_status
                                                
                                                	 status of the interface
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.Section, self).__init__()

                                                    self.yang_name = "section"
                                                    self.yang_parent_name = "sonet-hour24ocn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("section-e-ss", ("section_e_ss", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.Section.SectionESs)), ("section-se-ss", ("section_se_ss", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.Section.SectionSeSs)), ("section-sef-ss", ("section_sef_ss", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.Section.SectionSefSs)), ("section-c-vs", ("section_c_vs", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.Section.SectionCVs))])
                                                    self._leafs = OrderedDict([
                                                        ('section_status', (YLeaf(YType.int32, 'section-status'), ['int'])),
                                                    ])
                                                    self.section_status = None

                                                    self.section_e_ss = PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.Section.SectionESs()
                                                    self.section_e_ss.parent = self
                                                    self._children_name_map["section_e_ss"] = "section-e-ss"

                                                    self.section_se_ss = PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.Section.SectionSeSs()
                                                    self.section_se_ss.parent = self
                                                    self._children_name_map["section_se_ss"] = "section-se-ss"

                                                    self.section_sef_ss = PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.Section.SectionSefSs()
                                                    self.section_sef_ss.parent = self
                                                    self._children_name_map["section_sef_ss"] = "section-sef-ss"

                                                    self.section_c_vs = PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.Section.SectionCVs()
                                                    self.section_c_vs.parent = self
                                                    self._children_name_map["section_c_vs"] = "section-c-vs"
                                                    self._segment_path = lambda: "section"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.Section, ['section_status'], name, value)


                                                class SectionESs(Entity):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.Section.SectionESs, self).__init__()

                                                        self.yang_name = "section-e-ss"
                                                        self.yang_parent_name = "section"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "section-e-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.Section.SectionESs, ['data', 'threshold', 'tca_report'], name, value)


                                                class SectionSeSs(Entity):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.Section.SectionSeSs, self).__init__()

                                                        self.yang_name = "section-se-ss"
                                                        self.yang_parent_name = "section"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "section-se-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.Section.SectionSeSs, ['data', 'threshold', 'tca_report'], name, value)


                                                class SectionSefSs(Entity):
                                                    """
                                                    The number of Severely Errored Framing Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.Section.SectionSefSs, self).__init__()

                                                        self.yang_name = "section-sef-ss"
                                                        self.yang_parent_name = "section"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "section-sef-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.Section.SectionSefSs, ['data', 'threshold', 'tca_report'], name, value)


                                                class SectionCVs(Entity):
                                                    """
                                                    The number of Coding Violations
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.Section.SectionCVs, self).__init__()

                                                        self.yang_name = "section-c-vs"
                                                        self.yang_parent_name = "section"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "section-c-vs"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.Section.SectionCVs, ['data', 'threshold', 'tca_report'], name, value)


                                            class Line(Entity):
                                                """
                                                LINE
                                                
                                                .. attribute:: line_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:  :py:class:`LineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.Line.LineESs>`
                                                
                                                .. attribute:: line_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:  :py:class:`LineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.Line.LineSeSs>`
                                                
                                                .. attribute:: line_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:  :py:class:`LineCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.Line.LineCVs>`
                                                
                                                .. attribute:: line_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\:  :py:class:`LineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.Line.LineUaSs>`
                                                
                                                .. attribute:: line_fc_ls
                                                
                                                	The number of Failure counts Seconds
                                                	**type**\:  :py:class:`LineFcLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.Line.LineFcLs>`
                                                
                                                .. attribute:: line_status
                                                
                                                	 status of the interface
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.Line, self).__init__()

                                                    self.yang_name = "line"
                                                    self.yang_parent_name = "sonet-hour24ocn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("line-e-ss", ("line_e_ss", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.Line.LineESs)), ("line-se-ss", ("line_se_ss", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.Line.LineSeSs)), ("line-c-vs", ("line_c_vs", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.Line.LineCVs)), ("line-ua-ss", ("line_ua_ss", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.Line.LineUaSs)), ("line-fc-ls", ("line_fc_ls", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.Line.LineFcLs))])
                                                    self._leafs = OrderedDict([
                                                        ('line_status', (YLeaf(YType.int32, 'line-status'), ['int'])),
                                                    ])
                                                    self.line_status = None

                                                    self.line_e_ss = PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.Line.LineESs()
                                                    self.line_e_ss.parent = self
                                                    self._children_name_map["line_e_ss"] = "line-e-ss"

                                                    self.line_se_ss = PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.Line.LineSeSs()
                                                    self.line_se_ss.parent = self
                                                    self._children_name_map["line_se_ss"] = "line-se-ss"

                                                    self.line_c_vs = PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.Line.LineCVs()
                                                    self.line_c_vs.parent = self
                                                    self._children_name_map["line_c_vs"] = "line-c-vs"

                                                    self.line_ua_ss = PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.Line.LineUaSs()
                                                    self.line_ua_ss.parent = self
                                                    self._children_name_map["line_ua_ss"] = "line-ua-ss"

                                                    self.line_fc_ls = PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.Line.LineFcLs()
                                                    self.line_fc_ls.parent = self
                                                    self._children_name_map["line_fc_ls"] = "line-fc-ls"
                                                    self._segment_path = lambda: "line"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.Line, ['line_status'], name, value)


                                                class LineESs(Entity):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.Line.LineESs, self).__init__()

                                                        self.yang_name = "line-e-ss"
                                                        self.yang_parent_name = "line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "line-e-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.Line.LineESs, ['data', 'threshold', 'tca_report'], name, value)


                                                class LineSeSs(Entity):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.Line.LineSeSs, self).__init__()

                                                        self.yang_name = "line-se-ss"
                                                        self.yang_parent_name = "line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "line-se-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.Line.LineSeSs, ['data', 'threshold', 'tca_report'], name, value)


                                                class LineCVs(Entity):
                                                    """
                                                    The number of Coding Violations
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.Line.LineCVs, self).__init__()

                                                        self.yang_name = "line-c-vs"
                                                        self.yang_parent_name = "line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "line-c-vs"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.Line.LineCVs, ['data', 'threshold', 'tca_report'], name, value)


                                                class LineUaSs(Entity):
                                                    """
                                                    The number of Unavailable Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.Line.LineUaSs, self).__init__()

                                                        self.yang_name = "line-ua-ss"
                                                        self.yang_parent_name = "line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "line-ua-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.Line.LineUaSs, ['data', 'threshold', 'tca_report'], name, value)


                                                class LineFcLs(Entity):
                                                    """
                                                    The number of Failure counts Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.Line.LineFcLs, self).__init__()

                                                        self.yang_name = "line-fc-ls"
                                                        self.yang_parent_name = "line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "line-fc-ls"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.Line.LineFcLs, ['data', 'threshold', 'tca_report'], name, value)


                                            class FeLine(Entity):
                                                """
                                                FarEnd LINE
                                                
                                                .. attribute:: far_end_line_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:  :py:class:`FarEndLineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.FeLine.FarEndLineESs>`
                                                
                                                .. attribute:: far_end_line_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:  :py:class:`FarEndLineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.FeLine.FarEndLineSeSs>`
                                                
                                                .. attribute:: far_end_line_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:  :py:class:`FarEndLineCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.FeLine.FarEndLineCVs>`
                                                
                                                .. attribute:: far_end_line_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\:  :py:class:`FarEndLineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.FeLine.FarEndLineUaSs>`
                                                
                                                .. attribute:: far_end_line_fc_ls
                                                
                                                	The number of Failure counts Seconds
                                                	**type**\:  :py:class:`FarEndLineFcLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.FeLine.FarEndLineFcLs>`
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.FeLine, self).__init__()

                                                    self.yang_name = "fe-line"
                                                    self.yang_parent_name = "sonet-hour24ocn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("far-end-line-e-ss", ("far_end_line_e_ss", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.FeLine.FarEndLineESs)), ("far-end-line-se-ss", ("far_end_line_se_ss", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.FeLine.FarEndLineSeSs)), ("far-end-line-c-vs", ("far_end_line_c_vs", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.FeLine.FarEndLineCVs)), ("far-end-line-ua-ss", ("far_end_line_ua_ss", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.FeLine.FarEndLineUaSs)), ("far-end-line-fc-ls", ("far_end_line_fc_ls", PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.FeLine.FarEndLineFcLs))])
                                                    self._leafs = OrderedDict()

                                                    self.far_end_line_e_ss = PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.FeLine.FarEndLineESs()
                                                    self.far_end_line_e_ss.parent = self
                                                    self._children_name_map["far_end_line_e_ss"] = "far-end-line-e-ss"

                                                    self.far_end_line_se_ss = PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.FeLine.FarEndLineSeSs()
                                                    self.far_end_line_se_ss.parent = self
                                                    self._children_name_map["far_end_line_se_ss"] = "far-end-line-se-ss"

                                                    self.far_end_line_c_vs = PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.FeLine.FarEndLineCVs()
                                                    self.far_end_line_c_vs.parent = self
                                                    self._children_name_map["far_end_line_c_vs"] = "far-end-line-c-vs"

                                                    self.far_end_line_ua_ss = PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.FeLine.FarEndLineUaSs()
                                                    self.far_end_line_ua_ss.parent = self
                                                    self._children_name_map["far_end_line_ua_ss"] = "far-end-line-ua-ss"

                                                    self.far_end_line_fc_ls = PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.FeLine.FarEndLineFcLs()
                                                    self.far_end_line_fc_ls.parent = self
                                                    self._children_name_map["far_end_line_fc_ls"] = "far-end-line-fc-ls"
                                                    self._segment_path = lambda: "fe-line"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.FeLine, [], name, value)


                                                class FarEndLineESs(Entity):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.FeLine.FarEndLineESs, self).__init__()

                                                        self.yang_name = "far-end-line-e-ss"
                                                        self.yang_parent_name = "fe-line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "far-end-line-e-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.FeLine.FarEndLineESs, ['data', 'threshold', 'tca_report'], name, value)


                                                class FarEndLineSeSs(Entity):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.FeLine.FarEndLineSeSs, self).__init__()

                                                        self.yang_name = "far-end-line-se-ss"
                                                        self.yang_parent_name = "fe-line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "far-end-line-se-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.FeLine.FarEndLineSeSs, ['data', 'threshold', 'tca_report'], name, value)


                                                class FarEndLineCVs(Entity):
                                                    """
                                                    The number of Coding Violations
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.FeLine.FarEndLineCVs, self).__init__()

                                                        self.yang_name = "far-end-line-c-vs"
                                                        self.yang_parent_name = "fe-line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "far-end-line-c-vs"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.FeLine.FarEndLineCVs, ['data', 'threshold', 'tca_report'], name, value)


                                                class FarEndLineUaSs(Entity):
                                                    """
                                                    The number of Unavailable Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.FeLine.FarEndLineUaSs, self).__init__()

                                                        self.yang_name = "far-end-line-ua-ss"
                                                        self.yang_parent_name = "fe-line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "far-end-line-ua-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.FeLine.FarEndLineUaSs, ['data', 'threshold', 'tca_report'], name, value)


                                                class FarEndLineFcLs(Entity):
                                                    """
                                                    The number of Failure counts Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.FeLine.FarEndLineFcLs, self).__init__()

                                                        self.yang_name = "far-end-line-fc-ls"
                                                        self.yang_parent_name = "fe-line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "far-end-line-fc-ls"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24ocnHistories.SonetHour24ocnHistory.SonetHour24ocnTimeLineInstances.SonetHour24ocnTimeLineInstance.FeLine.FarEndLineFcLs, ['data', 'threshold', 'tca_report'], name, value)


            class StsHistory(Entity):
                """
                STS controller History performance data
                
                .. attribute:: sts_port_histories
                
                	Port performance data
                	**type**\:  :py:class:`StsPortHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(PerformanceManagementHistory.Global.Periodic.StsHistory, self).__init__()

                    self.yang_name = "sts-history"
                    self.yang_parent_name = "periodic"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("sts-port-histories", ("sts_port_histories", PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories))])
                    self._leafs = OrderedDict()

                    self.sts_port_histories = PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories()
                    self.sts_port_histories.parent = self
                    self._children_name_map["sts_port_histories"] = "sts-port-histories"
                    self._segment_path = lambda: "sts-history"
                    self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StsHistory, [], name, value)


                class StsPortHistories(Entity):
                    """
                    Port performance data
                    
                    .. attribute:: sts_port_history
                    
                    	Port performance data
                    	**type**\: list of  		 :py:class:`StsPortHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories, self).__init__()

                        self.yang_name = "sts-port-histories"
                        self.yang_parent_name = "sts-history"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("sts-port-history", ("sts_port_history", PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory))])
                        self._leafs = OrderedDict()

                        self.sts_port_history = YList(self)
                        self._segment_path = lambda: "sts-port-histories"
                        self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/sts-history/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories, [], name, value)


                    class StsPortHistory(Entity):
                        """
                        Port performance data
                        
                        .. attribute:: name  (key)
                        
                        	Port name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: sts_minute15_history
                        
                        	port current performance data
                        	**type**\:  :py:class:`StsMinute15History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History>`
                        
                        .. attribute:: sts_hour24_history
                        
                        	port current performance data
                        	**type**\:  :py:class:`StsHour24History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory, self).__init__()

                            self.yang_name = "sts-port-history"
                            self.yang_parent_name = "sts-port-histories"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("sts-minute15-history", ("sts_minute15_history", PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History)), ("sts-hour24-history", ("sts_hour24_history", PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None

                            self.sts_minute15_history = PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History()
                            self.sts_minute15_history.parent = self
                            self._children_name_map["sts_minute15_history"] = "sts-minute15-history"

                            self.sts_hour24_history = PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History()
                            self.sts_hour24_history.parent = self
                            self._children_name_map["sts_hour24_history"] = "sts-hour24-history"
                            self._segment_path = lambda: "sts-port-history" + "[name='" + str(self.name) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/sts-history/sts-port-histories/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory, ['name'], name, value)


                        class StsMinute15History(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: sts_minute15_path_histories
                            
                            	port current performance data
                            	**type**\:  :py:class:`StsMinute15PathHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History, self).__init__()

                                self.yang_name = "sts-minute15-history"
                                self.yang_parent_name = "sts-port-history"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("sts-minute15-path-histories", ("sts_minute15_path_histories", PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories))])
                                self._leafs = OrderedDict()

                                self.sts_minute15_path_histories = PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories()
                                self.sts_minute15_path_histories.parent = self
                                self._children_name_map["sts_minute15_path_histories"] = "sts-minute15-path-histories"
                                self._segment_path = lambda: "sts-minute15-history"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History, [], name, value)


                            class StsMinute15PathHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: sts_minute15_path_history
                                
                                	port 15\-minute Path performance data
                                	**type**\: list of  		 :py:class:`StsMinute15PathHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories, self).__init__()

                                    self.yang_name = "sts-minute15-path-histories"
                                    self.yang_parent_name = "sts-minute15-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("sts-minute15-path-history", ("sts_minute15_path_history", PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory))])
                                    self._leafs = OrderedDict()

                                    self.sts_minute15_path_history = YList(self)
                                    self._segment_path = lambda: "sts-minute15-path-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories, [], name, value)


                                class StsMinute15PathHistory(Entity):
                                    """
                                    port 15\-minute Path performance data
                                    
                                    .. attribute:: number  (key)
                                    
                                    	channel number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sts_minute15_path_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`StsMinute15PathTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory, self).__init__()

                                        self.yang_name = "sts-minute15-path-history"
                                        self.yang_parent_name = "sts-minute15-path-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([("sts-minute15-path-time-line-instances", ("sts_minute15_path_time_line_instances", PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ])
                                        self.number = None

                                        self.sts_minute15_path_time_line_instances = PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances()
                                        self.sts_minute15_path_time_line_instances.parent = self
                                        self._children_name_map["sts_minute15_path_time_line_instances"] = "sts-minute15-path-time-line-instances"
                                        self._segment_path = lambda: "sts-minute15-path-history" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory, ['number'], name, value)


                                    class StsMinute15PathTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: sts_minute15_path_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of  		 :py:class:`StsMinute15PathTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances, self).__init__()

                                            self.yang_name = "sts-minute15-path-time-line-instances"
                                            self.yang_parent_name = "sts-minute15-path-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("sts-minute15-path-time-line-instance", ("sts_minute15_path_time_line_instance", PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.sts_minute15_path_time_line_instance = YList(self)
                                            self._segment_path = lambda: "sts-minute15-path-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances, [], name, value)


                                        class StsMinute15PathTimeLineInstance(Entity):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path
                                            
                                            	PATH
                                            	**type**\:  :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path>`
                                            
                                            .. attribute:: fe_path
                                            
                                            	Far End PATH
                                            	**type**\:  :py:class:`FePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.FePath>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance, self).__init__()

                                                self.yang_name = "sts-minute15-path-time-line-instance"
                                                self.yang_parent_name = "sts-minute15-path-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("path", ("path", PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path)), ("fe-path", ("fe_path", PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.FePath))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None

                                                self.path = PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path()
                                                self.path.parent = self
                                                self._children_name_map["path"] = "path"

                                                self.fe_path = PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.FePath()
                                                self.fe_path.parent = self
                                                self._children_name_map["fe_path"] = "fe-path"
                                                self._segment_path = lambda: "sts-minute15-path-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear24_hr_time'], name, value)


                                            class Path(Entity):
                                                """
                                                PATH
                                                
                                                .. attribute:: path_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:  :py:class:`PathESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path.PathESs>`
                                                
                                                .. attribute:: path_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:  :py:class:`PathSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path.PathSeSs>`
                                                
                                                .. attribute:: path_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:  :py:class:`PathCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path.PathCVs>`
                                                
                                                .. attribute:: path_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\:  :py:class:`PathUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path.PathUaSs>`
                                                
                                                .. attribute:: path_width
                                                
                                                	Indicates the type of the SONET/SDH Path
                                                	**type**\:  :py:class:`PmSonetPathWidthEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmSonetPathWidthEnum>`
                                                
                                                .. attribute:: path_status
                                                
                                                	 status of the interface
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path, self).__init__()

                                                    self.yang_name = "path"
                                                    self.yang_parent_name = "sts-minute15-path-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("path-e-ss", ("path_e_ss", PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path.PathESs)), ("path-se-ss", ("path_se_ss", PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path.PathSeSs)), ("path-c-vs", ("path_c_vs", PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path.PathCVs)), ("path-ua-ss", ("path_ua_ss", PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path.PathUaSs))])
                                                    self._leafs = OrderedDict([
                                                        ('path_width', (YLeaf(YType.enumeration, 'path-width'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper', 'PmSonetPathWidthEnum', '')])),
                                                        ('path_status', (YLeaf(YType.int32, 'path-status'), ['int'])),
                                                    ])
                                                    self.path_width = None
                                                    self.path_status = None

                                                    self.path_e_ss = PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path.PathESs()
                                                    self.path_e_ss.parent = self
                                                    self._children_name_map["path_e_ss"] = "path-e-ss"

                                                    self.path_se_ss = PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path.PathSeSs()
                                                    self.path_se_ss.parent = self
                                                    self._children_name_map["path_se_ss"] = "path-se-ss"

                                                    self.path_c_vs = PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path.PathCVs()
                                                    self.path_c_vs.parent = self
                                                    self._children_name_map["path_c_vs"] = "path-c-vs"

                                                    self.path_ua_ss = PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path.PathUaSs()
                                                    self.path_ua_ss.parent = self
                                                    self._children_name_map["path_ua_ss"] = "path-ua-ss"
                                                    self._segment_path = lambda: "path"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path, ['path_width', 'path_status'], name, value)


                                                class PathESs(Entity):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path.PathESs, self).__init__()

                                                        self.yang_name = "path-e-ss"
                                                        self.yang_parent_name = "path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "path-e-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path.PathESs, ['data', 'threshold', 'tca_report'], name, value)


                                                class PathSeSs(Entity):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path.PathSeSs, self).__init__()

                                                        self.yang_name = "path-se-ss"
                                                        self.yang_parent_name = "path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "path-se-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path.PathSeSs, ['data', 'threshold', 'tca_report'], name, value)


                                                class PathCVs(Entity):
                                                    """
                                                    The number of Coding Violations
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path.PathCVs, self).__init__()

                                                        self.yang_name = "path-c-vs"
                                                        self.yang_parent_name = "path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "path-c-vs"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path.PathCVs, ['data', 'threshold', 'tca_report'], name, value)


                                                class PathUaSs(Entity):
                                                    """
                                                    The number of Unavailable Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path.PathUaSs, self).__init__()

                                                        self.yang_name = "path-ua-ss"
                                                        self.yang_parent_name = "path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "path-ua-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path.PathUaSs, ['data', 'threshold', 'tca_report'], name, value)


                                            class FePath(Entity):
                                                """
                                                Far End PATH
                                                
                                                .. attribute:: far_end_path_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: far_end_path_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: far_end_path_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: far_end_path_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.FePath, self).__init__()

                                                    self.yang_name = "fe-path"
                                                    self.yang_parent_name = "sts-minute15-path-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('far_end_path_e_ss', (YLeaf(YType.uint32, 'far-end-path-e-ss'), ['int'])),
                                                        ('far_end_path_se_ss', (YLeaf(YType.uint32, 'far-end-path-se-ss'), ['int'])),
                                                        ('far_end_path_c_vs', (YLeaf(YType.uint32, 'far-end-path-c-vs'), ['int'])),
                                                        ('far_end_path_ua_ss', (YLeaf(YType.uint32, 'far-end-path-ua-ss'), ['int'])),
                                                    ])
                                                    self.far_end_path_e_ss = None
                                                    self.far_end_path_se_ss = None
                                                    self.far_end_path_c_vs = None
                                                    self.far_end_path_ua_ss = None
                                                    self._segment_path = lambda: "fe-path"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.FePath, ['far_end_path_e_ss', 'far_end_path_se_ss', 'far_end_path_c_vs', 'far_end_path_ua_ss'], name, value)


                        class StsHour24History(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: sts_hour24_path_histories
                            
                            	port current performance data
                            	**type**\:  :py:class:`StsHour24PathHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History, self).__init__()

                                self.yang_name = "sts-hour24-history"
                                self.yang_parent_name = "sts-port-history"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("sts-hour24-path-histories", ("sts_hour24_path_histories", PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories))])
                                self._leafs = OrderedDict()

                                self.sts_hour24_path_histories = PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories()
                                self.sts_hour24_path_histories.parent = self
                                self._children_name_map["sts_hour24_path_histories"] = "sts-hour24-path-histories"
                                self._segment_path = lambda: "sts-hour24-history"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History, [], name, value)


                            class StsHour24PathHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: sts_hour24_path_history
                                
                                	port 24 hour Path performance data
                                	**type**\: list of  		 :py:class:`StsHour24PathHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories, self).__init__()

                                    self.yang_name = "sts-hour24-path-histories"
                                    self.yang_parent_name = "sts-hour24-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("sts-hour24-path-history", ("sts_hour24_path_history", PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory))])
                                    self._leafs = OrderedDict()

                                    self.sts_hour24_path_history = YList(self)
                                    self._segment_path = lambda: "sts-hour24-path-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories, [], name, value)


                                class StsHour24PathHistory(Entity):
                                    """
                                    port 24 hour Path performance data
                                    
                                    .. attribute:: number  (key)
                                    
                                    	channel number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sts_hour24_path_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`StsHour24PathTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory, self).__init__()

                                        self.yang_name = "sts-hour24-path-history"
                                        self.yang_parent_name = "sts-hour24-path-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([("sts-hour24-path-time-line-instances", ("sts_hour24_path_time_line_instances", PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ])
                                        self.number = None

                                        self.sts_hour24_path_time_line_instances = PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances()
                                        self.sts_hour24_path_time_line_instances.parent = self
                                        self._children_name_map["sts_hour24_path_time_line_instances"] = "sts-hour24-path-time-line-instances"
                                        self._segment_path = lambda: "sts-hour24-path-history" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory, ['number'], name, value)


                                    class StsHour24PathTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: sts_hour24_path_time_line_instance
                                        
                                        	port 15\-minute sts performance data
                                        	**type**\: list of  		 :py:class:`StsHour24PathTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances, self).__init__()

                                            self.yang_name = "sts-hour24-path-time-line-instances"
                                            self.yang_parent_name = "sts-hour24-path-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("sts-hour24-path-time-line-instance", ("sts_hour24_path_time_line_instance", PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.sts_hour24_path_time_line_instance = YList(self)
                                            self._segment_path = lambda: "sts-hour24-path-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances, [], name, value)


                                        class StsHour24PathTimeLineInstance(Entity):
                                            """
                                            port 15\-minute sts performance data
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path
                                            
                                            	PATH
                                            	**type**\:  :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path>`
                                            
                                            .. attribute:: fe_path
                                            
                                            	Far End PATH
                                            	**type**\:  :py:class:`FePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.FePath>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance, self).__init__()

                                                self.yang_name = "sts-hour24-path-time-line-instance"
                                                self.yang_parent_name = "sts-hour24-path-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("path", ("path", PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path)), ("fe-path", ("fe_path", PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.FePath))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None

                                                self.path = PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path()
                                                self.path.parent = self
                                                self._children_name_map["path"] = "path"

                                                self.fe_path = PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.FePath()
                                                self.fe_path.parent = self
                                                self._children_name_map["fe_path"] = "fe-path"
                                                self._segment_path = lambda: "sts-hour24-path-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear24_hr_time'], name, value)


                                            class Path(Entity):
                                                """
                                                PATH
                                                
                                                .. attribute:: path_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:  :py:class:`PathESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path.PathESs>`
                                                
                                                .. attribute:: path_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:  :py:class:`PathSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path.PathSeSs>`
                                                
                                                .. attribute:: path_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:  :py:class:`PathCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path.PathCVs>`
                                                
                                                .. attribute:: path_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\:  :py:class:`PathUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path.PathUaSs>`
                                                
                                                .. attribute:: path_width
                                                
                                                	Indicates the type of the SONET/SDH Path
                                                	**type**\:  :py:class:`PmSonetPathWidthEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmSonetPathWidthEnum>`
                                                
                                                .. attribute:: path_status
                                                
                                                	 status of the interface
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path, self).__init__()

                                                    self.yang_name = "path"
                                                    self.yang_parent_name = "sts-hour24-path-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("path-e-ss", ("path_e_ss", PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path.PathESs)), ("path-se-ss", ("path_se_ss", PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path.PathSeSs)), ("path-c-vs", ("path_c_vs", PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path.PathCVs)), ("path-ua-ss", ("path_ua_ss", PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path.PathUaSs))])
                                                    self._leafs = OrderedDict([
                                                        ('path_width', (YLeaf(YType.enumeration, 'path-width'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper', 'PmSonetPathWidthEnum', '')])),
                                                        ('path_status', (YLeaf(YType.int32, 'path-status'), ['int'])),
                                                    ])
                                                    self.path_width = None
                                                    self.path_status = None

                                                    self.path_e_ss = PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path.PathESs()
                                                    self.path_e_ss.parent = self
                                                    self._children_name_map["path_e_ss"] = "path-e-ss"

                                                    self.path_se_ss = PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path.PathSeSs()
                                                    self.path_se_ss.parent = self
                                                    self._children_name_map["path_se_ss"] = "path-se-ss"

                                                    self.path_c_vs = PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path.PathCVs()
                                                    self.path_c_vs.parent = self
                                                    self._children_name_map["path_c_vs"] = "path-c-vs"

                                                    self.path_ua_ss = PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path.PathUaSs()
                                                    self.path_ua_ss.parent = self
                                                    self._children_name_map["path_ua_ss"] = "path-ua-ss"
                                                    self._segment_path = lambda: "path"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path, ['path_width', 'path_status'], name, value)


                                                class PathESs(Entity):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path.PathESs, self).__init__()

                                                        self.yang_name = "path-e-ss"
                                                        self.yang_parent_name = "path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "path-e-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path.PathESs, ['data', 'threshold', 'tca_report'], name, value)


                                                class PathSeSs(Entity):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path.PathSeSs, self).__init__()

                                                        self.yang_name = "path-se-ss"
                                                        self.yang_parent_name = "path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "path-se-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path.PathSeSs, ['data', 'threshold', 'tca_report'], name, value)


                                                class PathCVs(Entity):
                                                    """
                                                    The number of Coding Violations
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path.PathCVs, self).__init__()

                                                        self.yang_name = "path-c-vs"
                                                        self.yang_parent_name = "path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "path-c-vs"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path.PathCVs, ['data', 'threshold', 'tca_report'], name, value)


                                                class PathUaSs(Entity):
                                                    """
                                                    The number of Unavailable Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path.PathUaSs, self).__init__()

                                                        self.yang_name = "path-ua-ss"
                                                        self.yang_parent_name = "path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "path-ua-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path.PathUaSs, ['data', 'threshold', 'tca_report'], name, value)


                                            class FePath(Entity):
                                                """
                                                Far End PATH
                                                
                                                .. attribute:: far_end_path_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: far_end_path_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: far_end_path_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: far_end_path_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.FePath, self).__init__()

                                                    self.yang_name = "fe-path"
                                                    self.yang_parent_name = "sts-hour24-path-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('far_end_path_e_ss', (YLeaf(YType.uint32, 'far-end-path-e-ss'), ['int'])),
                                                        ('far_end_path_se_ss', (YLeaf(YType.uint32, 'far-end-path-se-ss'), ['int'])),
                                                        ('far_end_path_c_vs', (YLeaf(YType.uint32, 'far-end-path-c-vs'), ['int'])),
                                                        ('far_end_path_ua_ss', (YLeaf(YType.uint32, 'far-end-path-ua-ss'), ['int'])),
                                                    ])
                                                    self.far_end_path_e_ss = None
                                                    self.far_end_path_se_ss = None
                                                    self.far_end_path_c_vs = None
                                                    self.far_end_path_ua_ss = None
                                                    self._segment_path = lambda: "fe-path"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.FePath, ['far_end_path_e_ss', 'far_end_path_se_ss', 'far_end_path_c_vs', 'far_end_path_ua_ss'], name, value)


            class EthernetHistory(Entity):
                """
                EHERNET controller History performance data
                
                .. attribute:: ethernet_port_histories
                
                	Port performance data
                	**type**\:  :py:class:`EthernetPortHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory, self).__init__()

                    self.yang_name = "ethernet-history"
                    self.yang_parent_name = "periodic"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ethernet-port-histories", ("ethernet_port_histories", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories))])
                    self._leafs = OrderedDict()

                    self.ethernet_port_histories = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories()
                    self.ethernet_port_histories.parent = self
                    self._children_name_map["ethernet_port_histories"] = "ethernet-port-histories"
                    self._segment_path = lambda: "ethernet-history"
                    self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory, [], name, value)


                class EthernetPortHistories(Entity):
                    """
                    Port performance data
                    
                    .. attribute:: ethernet_port_history
                    
                    	Port performance data
                    	**type**\: list of  		 :py:class:`EthernetPortHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories, self).__init__()

                        self.yang_name = "ethernet-port-histories"
                        self.yang_parent_name = "ethernet-history"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ethernet-port-history", ("ethernet_port_history", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory))])
                        self._leafs = OrderedDict()

                        self.ethernet_port_history = YList(self)
                        self._segment_path = lambda: "ethernet-port-histories"
                        self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/ethernet-history/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories, [], name, value)


                    class EthernetPortHistory(Entity):
                        """
                        Port performance data
                        
                        .. attribute:: name  (key)
                        
                        	Port name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: ethernet_second30_history
                        
                        	port current performance data
                        	**type**\:  :py:class:`EthernetSecond30History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History>`
                        
                        .. attribute:: ethernet_hour24_history
                        
                        	port current performance data
                        	**type**\:  :py:class:`EthernetHour24History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History>`
                        
                        .. attribute:: ethernet_minute15_history
                        
                        	port current performance data
                        	**type**\:  :py:class:`EthernetMinute15History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory, self).__init__()

                            self.yang_name = "ethernet-port-history"
                            self.yang_parent_name = "ethernet-port-histories"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("ethernet-second30-history", ("ethernet_second30_history", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History)), ("ethernet-hour24-history", ("ethernet_hour24_history", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History)), ("ethernet-minute15-history", ("ethernet_minute15_history", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None

                            self.ethernet_second30_history = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History()
                            self.ethernet_second30_history.parent = self
                            self._children_name_map["ethernet_second30_history"] = "ethernet-second30-history"

                            self.ethernet_hour24_history = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History()
                            self.ethernet_hour24_history.parent = self
                            self._children_name_map["ethernet_hour24_history"] = "ethernet-hour24-history"

                            self.ethernet_minute15_history = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History()
                            self.ethernet_minute15_history.parent = self
                            self._children_name_map["ethernet_minute15_history"] = "ethernet-minute15-history"
                            self._segment_path = lambda: "ethernet-port-history" + "[name='" + str(self.name) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/ethernet-history/ethernet-port-histories/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory, ['name'], name, value)


                        class EthernetSecond30History(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: second30pcs_histories
                            
                            	ETHERNET port interval performance data
                            	**type**\:  :py:class:`Second30pcsHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30pcsHistories>`
                            
                            .. attribute:: second30_ether_histories
                            
                            	ETHERNET port interval performance data
                            	**type**\:  :py:class:`Second30EtherHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories>`
                            
                            .. attribute:: second30_fec_histories
                            
                            	ETHERNET port interval performance data
                            	**type**\:  :py:class:`Second30FecHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30FecHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History, self).__init__()

                                self.yang_name = "ethernet-second30-history"
                                self.yang_parent_name = "ethernet-port-history"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("second30pcs-histories", ("second30pcs_histories", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30pcsHistories)), ("second30-ether-histories", ("second30_ether_histories", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories)), ("second30-fec-histories", ("second30_fec_histories", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30FecHistories))])
                                self._leafs = OrderedDict()

                                self.second30pcs_histories = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30pcsHistories()
                                self.second30pcs_histories.parent = self
                                self._children_name_map["second30pcs_histories"] = "second30pcs-histories"

                                self.second30_ether_histories = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories()
                                self.second30_ether_histories.parent = self
                                self._children_name_map["second30_ether_histories"] = "second30-ether-histories"

                                self.second30_fec_histories = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30FecHistories()
                                self.second30_fec_histories.parent = self
                                self._children_name_map["second30_fec_histories"] = "second30-fec-histories"
                                self._segment_path = lambda: "ethernet-second30-history"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History, [], name, value)


                            class Second30pcsHistories(Entity):
                                """
                                ETHERNET port interval performance data
                                
                                .. attribute:: second30pcs_history
                                
                                	ETHERNET port 30 sec pcs performance data
                                	**type**\: list of  		 :py:class:`Second30pcsHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30pcsHistories.Second30pcsHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30pcsHistories, self).__init__()

                                    self.yang_name = "second30pcs-histories"
                                    self.yang_parent_name = "ethernet-second30-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("second30pcs-history", ("second30pcs_history", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30pcsHistories.Second30pcsHistory))])
                                    self._leafs = OrderedDict()

                                    self.second30pcs_history = YList(self)
                                    self._segment_path = lambda: "second30pcs-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30pcsHistories, [], name, value)


                                class Second30pcsHistory(Entity):
                                    """
                                    ETHERNET port 30 sec pcs performance data
                                    
                                    .. attribute:: slot_number  (key)
                                    
                                    	interval slot number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: second30pcs_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`Second30pcsTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30pcsHistories.Second30pcsHistory.Second30pcsTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30pcsHistories.Second30pcsHistory, self).__init__()

                                        self.yang_name = "second30pcs-history"
                                        self.yang_parent_name = "second30pcs-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['slot_number']
                                        self._child_classes = OrderedDict([("second30pcs-time-line-instances", ("second30pcs_time_line_instances", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30pcsHistories.Second30pcsHistory.Second30pcsTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('slot_number', (YLeaf(YType.uint32, 'slot-number'), ['int'])),
                                        ])
                                        self.slot_number = None

                                        self.second30pcs_time_line_instances = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30pcsHistories.Second30pcsHistory.Second30pcsTimeLineInstances()
                                        self.second30pcs_time_line_instances.parent = self
                                        self._children_name_map["second30pcs_time_line_instances"] = "second30pcs-time-line-instances"
                                        self._segment_path = lambda: "second30pcs-history" + "[slot-number='" + str(self.slot_number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30pcsHistories.Second30pcsHistory, ['slot_number'], name, value)


                                    class Second30pcsTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: second30pcs_time_line_instance
                                        
                                        	port 30 sec pcs performance data
                                        	**type**\: list of  		 :py:class:`Second30pcsTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30pcsHistories.Second30pcsHistory.Second30pcsTimeLineInstances.Second30pcsTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30pcsHistories.Second30pcsHistory.Second30pcsTimeLineInstances, self).__init__()

                                            self.yang_name = "second30pcs-time-line-instances"
                                            self.yang_parent_name = "second30pcs-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("second30pcs-time-line-instance", ("second30pcs_time_line_instance", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30pcsHistories.Second30pcsHistory.Second30pcsTimeLineInstances.Second30pcsTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.second30pcs_time_line_instance = YList(self)
                                            self._segment_path = lambda: "second30pcs-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30pcsHistories.Second30pcsHistory.Second30pcsTimeLineInstances, [], name, value)


                                        class Second30pcsTimeLineInstance(Entity):
                                            """
                                            port 30 sec pcs performance data
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: bip
                                            
                                            	Bip 
                                            	**type**\: list of  		 :py:class:`Bip <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30pcsHistories.Second30pcsHistory.Second30pcsTimeLineInstances.Second30pcsTimeLineInstance.Bip>`
                                            
                                            .. attribute:: frm_err
                                            
                                            	Frm Err
                                            	**type**\: list of  		 :py:class:`FrmErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30pcsHistories.Second30pcsHistory.Second30pcsTimeLineInstances.Second30pcsTimeLineInstance.FrmErr>`
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30pcsHistories.Second30pcsHistory.Second30pcsTimeLineInstances.Second30pcsTimeLineInstance, self).__init__()

                                                self.yang_name = "second30pcs-time-line-instance"
                                                self.yang_parent_name = "second30pcs-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("bip", ("bip", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30pcsHistories.Second30pcsHistory.Second30pcsTimeLineInstances.Second30pcsTimeLineInstance.Bip)), ("frm-err", ("frm_err", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30pcsHistories.Second30pcsHistory.Second30pcsTimeLineInstances.Second30pcsTimeLineInstance.FrmErr))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear24_hr_time = None

                                                self.bip = YList(self)
                                                self.frm_err = YList(self)
                                                self._segment_path = lambda: "second30pcs-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30pcsHistories.Second30pcsHistory.Second30pcsTimeLineInstances.Second30pcsTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time'], name, value)


                                            class Bip(Entity):
                                                """
                                                Bip 
                                                
                                                .. attribute:: name
                                                
                                                	pcs param name
                                                	**type**\: str
                                                
                                                	**length:** 0..30
                                                
                                                .. attribute:: data
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30pcsHistories.Second30pcsHistory.Second30pcsTimeLineInstances.Second30pcsTimeLineInstance.Bip, self).__init__()

                                                    self.yang_name = "bip"
                                                    self.yang_parent_name = "second30pcs-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.name = None
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "bip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30pcsHistories.Second30pcsHistory.Second30pcsTimeLineInstances.Second30pcsTimeLineInstance.Bip, ['name', 'data', 'threshold', 'tca_report'], name, value)


                                            class FrmErr(Entity):
                                                """
                                                Frm Err
                                                
                                                .. attribute:: name
                                                
                                                	pcs param name
                                                	**type**\: str
                                                
                                                	**length:** 0..30
                                                
                                                .. attribute:: data
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30pcsHistories.Second30pcsHistory.Second30pcsTimeLineInstances.Second30pcsTimeLineInstance.FrmErr, self).__init__()

                                                    self.yang_name = "frm-err"
                                                    self.yang_parent_name = "second30pcs-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.name = None
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "frm-err"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30pcsHistories.Second30pcsHistory.Second30pcsTimeLineInstances.Second30pcsTimeLineInstance.FrmErr, ['name', 'data', 'threshold', 'tca_report'], name, value)


                            class Second30EtherHistories(Entity):
                                """
                                ETHERNET port interval performance data
                                
                                .. attribute:: second30_ether_history
                                
                                	ETHERNET port 30 sec ether performance data
                                	**type**\: list of  		 :py:class:`Second30EtherHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories, self).__init__()

                                    self.yang_name = "second30-ether-histories"
                                    self.yang_parent_name = "ethernet-second30-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("second30-ether-history", ("second30_ether_history", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory))])
                                    self._leafs = OrderedDict()

                                    self.second30_ether_history = YList(self)
                                    self._segment_path = lambda: "second30-ether-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories, [], name, value)


                                class Second30EtherHistory(Entity):
                                    """
                                    ETHERNET port 30 sec ether performance
                                    data
                                    
                                    .. attribute:: slot_number  (key)
                                    
                                    	interval slot number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: second30_ether_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`Second30EtherTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory, self).__init__()

                                        self.yang_name = "second30-ether-history"
                                        self.yang_parent_name = "second30-ether-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['slot_number']
                                        self._child_classes = OrderedDict([("second30-ether-time-line-instances", ("second30_ether_time_line_instances", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('slot_number', (YLeaf(YType.uint32, 'slot-number'), ['int'])),
                                        ])
                                        self.slot_number = None

                                        self.second30_ether_time_line_instances = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances()
                                        self.second30_ether_time_line_instances.parent = self
                                        self._children_name_map["second30_ether_time_line_instances"] = "second30-ether-time-line-instances"
                                        self._segment_path = lambda: "second30-ether-history" + "[slot-number='" + str(self.slot_number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory, ['slot_number'], name, value)


                                    class Second30EtherTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: second30_ether_time_line_instance
                                        
                                        	port 30 sec otn performance data
                                        	**type**\: list of  		 :py:class:`Second30EtherTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances, self).__init__()

                                            self.yang_name = "second30-ether-time-line-instances"
                                            self.yang_parent_name = "second30-ether-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("second30-ether-time-line-instance", ("second30_ether_time_line_instance", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.second30_ether_time_line_instance = YList(self)
                                            self._segment_path = lambda: "second30-ether-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances, [], name, value)


                                        class Second30EtherTimeLineInstance(Entity):
                                            """
                                            port 30 sec otn performance data
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rx_pkt
                                            
                                            	RX PKT
                                            	**type**\:  :py:class:`RxPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.RxPkt>`
                                            
                                            .. attribute:: stat_pkt
                                            
                                            	STAT PKT
                                            	**type**\:  :py:class:`StatPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.StatPkt>`
                                            
                                            .. attribute:: octet_stat
                                            
                                            	OCTET STAT
                                            	**type**\:  :py:class:`OctetStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OctetStat>`
                                            
                                            .. attribute:: oversize_pkt_stat
                                            
                                            	OVERSIZE PKT
                                            	**type**\:  :py:class:`OversizePktStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OversizePktStat>`
                                            
                                            .. attribute:: fcs_errors_stat
                                            
                                            	FCS ERR
                                            	**type**\:  :py:class:`FcsErrorsStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.FcsErrorsStat>`
                                            
                                            .. attribute:: long_frames_stat
                                            
                                            	LONG FRAMES
                                            	**type**\:  :py:class:`LongFramesStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.LongFramesStat>`
                                            
                                            .. attribute:: jabber_stat
                                            
                                            	JABBER STATS
                                            	**type**\:  :py:class:`JabberStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.JabberStat>`
                                            
                                            .. attribute:: ether64_octets
                                            
                                            	SIXTY FOUR OCTET
                                            	**type**\:  :py:class:`Ether64Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether64Octets>`
                                            
                                            .. attribute:: ether65127_octet
                                            
                                            	OCTET
                                            	**type**\:  :py:class:`Ether65127Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether65127Octet>`
                                            
                                            .. attribute:: ether128255_octet
                                            
                                            	TFF OCTET
                                            	**type**\:  :py:class:`Ether128255Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether128255Octet>`
                                            
                                            .. attribute:: ether256511_octet
                                            
                                            	FOO OCTET
                                            	**type**\:  :py:class:`Ether256511Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether256511Octet>`
                                            
                                            .. attribute:: ether5121023_octet
                                            
                                            	OZTT OCTET
                                            	**type**\:  :py:class:`Ether5121023Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether5121023Octet>`
                                            
                                            .. attribute:: ether10241518_octet
                                            
                                            	OFO OCTET
                                            	**type**\:  :py:class:`Ether10241518Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether10241518Octet>`
                                            
                                            .. attribute:: in_ucast_pkt
                                            
                                            	IN UCAST
                                            	**type**\:  :py:class:`InUcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InUcastPkt>`
                                            
                                            .. attribute:: in_mcast_pkt
                                            
                                            	IN MCAST
                                            	**type**\:  :py:class:`InMcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InMcastPkt>`
                                            
                                            .. attribute:: in_bcast_pkt
                                            
                                            	IN BCAST
                                            	**type**\:  :py:class:`InBcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InBcastPkt>`
                                            
                                            .. attribute:: out_ucast_pkt
                                            
                                            	OUT UCAST
                                            	**type**\:  :py:class:`OutUcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutUcastPkt>`
                                            
                                            .. attribute:: out_bcast_pkt
                                            
                                            	OUT BCAST
                                            	**type**\:  :py:class:`OutBcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutBcastPkt>`
                                            
                                            .. attribute:: out_mcast_pkt
                                            
                                            	OUT MCAST
                                            	**type**\:  :py:class:`OutMcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutMcastPkt>`
                                            
                                            .. attribute:: tx_pkt
                                            
                                            	TX PKT
                                            	**type**\:  :py:class:`TxPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxPkt>`
                                            
                                            .. attribute:: if_in_errors
                                            
                                            	IFIN ERRORS
                                            	**type**\:  :py:class:`IfInErrors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.IfInErrors>`
                                            
                                            .. attribute:: if_in_octets
                                            
                                            	IFIN OCTETS
                                            	**type**\:  :py:class:`IfInOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.IfInOctets>`
                                            
                                            .. attribute:: ether_stat_multicast_pkt
                                            
                                            	ETHER STAT MULTICAST PKT
                                            	**type**\:  :py:class:`EtherStatMulticastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.EtherStatMulticastPkt>`
                                            
                                            .. attribute:: ether_stat_broadcast_pkt
                                            
                                            	ETHER STAT BROADCAST PKT
                                            	**type**\:  :py:class:`EtherStatBroadcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.EtherStatBroadcastPkt>`
                                            
                                            .. attribute:: ether_stat_undersized_pkt
                                            
                                            	ETHER STAT UNDERSIZED PKT
                                            	**type**\:  :py:class:`EtherStatUndersizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.EtherStatUndersizedPkt>`
                                            
                                            .. attribute:: out_octets
                                            
                                            	OUT OCTET
                                            	**type**\:  :py:class:`OutOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutOctets>`
                                            
                                            .. attribute:: in_pause_frame
                                            
                                            	INPUT PAUSE FRAME
                                            	**type**\:  :py:class:`InPauseFrame <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPauseFrame>`
                                            
                                            .. attribute:: in_good_bytes
                                            
                                            	INPUT GOOD BYTES
                                            	**type**\:  :py:class:`InGoodBytes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InGoodBytes>`
                                            
                                            .. attribute:: in8021q_frames
                                            
                                            	INPUT 802 1Q FRAMES
                                            	**type**\:  :py:class:`In8021qFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.In8021qFrames>`
                                            
                                            .. attribute:: in_pkts1519_max_octets
                                            
                                            	INPUT PKTS 1519MAX OCTETS
                                            	**type**\:  :py:class:`InPkts1519MaxOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts1519MaxOctets>`
                                            
                                            .. attribute:: in_good_pkts
                                            
                                            	INPUT GOOD PKTS
                                            	**type**\:  :py:class:`InGoodPkts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InGoodPkts>`
                                            
                                            .. attribute:: in_drop_overrun
                                            
                                            	INPUT DROP OVERRUN
                                            	**type**\:  :py:class:`InDropOverrun <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropOverrun>`
                                            
                                            .. attribute:: in_drop_abort
                                            
                                            	INPUT DROP ABORT
                                            	**type**\:  :py:class:`InDropAbort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropAbort>`
                                            
                                            .. attribute:: in_drop_invalid_vlan
                                            
                                            	INPUT DROP INVALID VLAN
                                            	**type**\:  :py:class:`InDropInvalidVlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropInvalidVlan>`
                                            
                                            .. attribute:: in_drop_invalid_dmac
                                            
                                            	INPUT DROP INVALID DMAC
                                            	**type**\:  :py:class:`InDropInvalidDmac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropInvalidDmac>`
                                            
                                            .. attribute:: in_drop_invalid_encap
                                            
                                            	INPUT DROP INVALID ENCAP
                                            	**type**\:  :py:class:`InDropInvalidEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropInvalidEncap>`
                                            
                                            .. attribute:: in_drop_other
                                            
                                            	INPUT DROP OTHER
                                            	**type**\:  :py:class:`InDropOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropOther>`
                                            
                                            .. attribute:: in_mib_giant
                                            
                                            	INPUT MIB GIANT
                                            	**type**\:  :py:class:`InMibGiant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InMibGiant>`
                                            
                                            .. attribute:: in_mib_jabber
                                            
                                            	INPUT MIB JABBER
                                            	**type**\:  :py:class:`InMibJabber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InMibJabber>`
                                            
                                            .. attribute:: in_mibcrc
                                            
                                            	IN MIB CRC
                                            	**type**\:  :py:class:`InMibcrc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InMibcrc>`
                                            
                                            .. attribute:: in_error_collisions
                                            
                                            	IN ERROR COLLISIONS
                                            	**type**\:  :py:class:`InErrorCollisions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorCollisions>`
                                            
                                            .. attribute:: in_error_symbol
                                            
                                            	IN ERROR SYMBOL
                                            	**type**\:  :py:class:`InErrorSymbol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorSymbol>`
                                            
                                            .. attribute:: out_good_bytes
                                            
                                            	OUT GOOD BYTES
                                            	**type**\:  :py:class:`OutGoodBytes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutGoodBytes>`
                                            
                                            .. attribute:: out8021q_frames
                                            
                                            	OUT 802 1Q FRAMES
                                            	**type**\:  :py:class:`Out8021qFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Out8021qFrames>`
                                            
                                            .. attribute:: out_pause_frames
                                            
                                            	OUT PAUSE FRAMES
                                            	**type**\:  :py:class:`OutPauseFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPauseFrames>`
                                            
                                            .. attribute:: out_pkts1519_max_octets
                                            
                                            	OUT PKTS 1519 MAX OCTETS
                                            	**type**\:  :py:class:`OutPkts1519MaxOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts1519MaxOctets>`
                                            
                                            .. attribute:: out_good_pkts
                                            
                                            	OUT GOOD PKTS
                                            	**type**\:  :py:class:`OutGoodPkts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutGoodPkts>`
                                            
                                            .. attribute:: out_drop_underrun
                                            
                                            	OUT DROP UNDERRUN
                                            	**type**\:  :py:class:`OutDropUnderrun <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutDropUnderrun>`
                                            
                                            .. attribute:: out_drop_abort
                                            
                                            	OUT DROP ABORT
                                            	**type**\:  :py:class:`OutDropAbort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutDropAbort>`
                                            
                                            .. attribute:: out_drop_other
                                            
                                            	OUT DROP OTHER
                                            	**type**\:  :py:class:`OutDropOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutDropOther>`
                                            
                                            .. attribute:: out_error_other
                                            
                                            	OUT ERROR OTHER
                                            	**type**\:  :py:class:`OutErrorOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutErrorOther>`
                                            
                                            .. attribute:: in_error_giant
                                            
                                            	IN ERROR GIANT
                                            	**type**\:  :py:class:`InErrorGiant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorGiant>`
                                            
                                            .. attribute:: in_error_runt
                                            
                                            	IN ERROR RUNT
                                            	**type**\:  :py:class:`InErrorRunt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorRunt>`
                                            
                                            .. attribute:: in_error_jabbers
                                            
                                            	IN ERROR JABBERS
                                            	**type**\:  :py:class:`InErrorJabbers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorJabbers>`
                                            
                                            .. attribute:: in_error_fragments
                                            
                                            	IN ERROR FRAGMENTS
                                            	**type**\:  :py:class:`InErrorFragments <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorFragments>`
                                            
                                            .. attribute:: in_error_other
                                            
                                            	IN ERROR OTHER
                                            	**type**\:  :py:class:`InErrorOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorOther>`
                                            
                                            .. attribute:: in_pkt64_octet
                                            
                                            	IN PKT 64 OCTET
                                            	**type**\:  :py:class:`InPkt64Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkt64Octet>`
                                            
                                            .. attribute:: in_pkts65_to127_octets
                                            
                                            	IN PKTS 65 127OCTETS
                                            	**type**\:  :py:class:`InPkts65To127Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts65To127Octets>`
                                            
                                            .. attribute:: in_pkts128_to255_octets
                                            
                                            	IN PKTS 128 255 OCTETS
                                            	**type**\:  :py:class:`InPkts128To255Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts128To255Octets>`
                                            
                                            .. attribute:: in_pkts256_to511_octets
                                            
                                            	IN PKTS 256 511 OCTETS
                                            	**type**\:  :py:class:`InPkts256To511Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts256To511Octets>`
                                            
                                            .. attribute:: in_pkts512_to1023_octets
                                            
                                            	IN PKTS 512 1023 OCTETS
                                            	**type**\:  :py:class:`InPkts512To1023Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts512To1023Octets>`
                                            
                                            .. attribute:: in_pkts1024_to1518_octets
                                            
                                            	IN PKTS 1024 1518 OCTETS
                                            	**type**\:  :py:class:`InPkts1024To1518Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts1024To1518Octets>`
                                            
                                            .. attribute:: outpkt64octet
                                            
                                            	OUT PKT 64 OCTET
                                            	**type**\:  :py:class:`Outpkt64octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Outpkt64octet>`
                                            
                                            .. attribute:: out_pkts65127_octets
                                            
                                            	OUT PKTS 65 127OCTETS
                                            	**type**\:  :py:class:`OutPkts65127Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts65127Octets>`
                                            
                                            .. attribute:: out_pkts128255_octets
                                            
                                            	OUT PKTS 128 255 OCTETS
                                            	**type**\:  :py:class:`OutPkts128255Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts128255Octets>`
                                            
                                            .. attribute:: out_pkts256511_octets
                                            
                                            	OUT PKTS 256 511 OCTETS
                                            	**type**\:  :py:class:`OutPkts256511Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts256511Octets>`
                                            
                                            .. attribute:: out_pkts5121023_octets
                                            
                                            	OUT PKTS 512 1023 OCTETS
                                            	**type**\:  :py:class:`OutPkts5121023Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts5121023Octets>`
                                            
                                            .. attribute:: out_pkts10241518_octets
                                            
                                            	OUT PKTS 1024 1518 OCTETS
                                            	**type**\:  :py:class:`OutPkts10241518Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts10241518Octets>`
                                            
                                            .. attribute:: rx_util
                                            
                                            	Rx Utilization in Percent
                                            	**type**\:  :py:class:`RxUtil <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.RxUtil>`
                                            
                                            .. attribute:: tx_util
                                            
                                            	Tx Utilization in Percent
                                            	**type**\:  :py:class:`TxUtil <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxUtil>`
                                            
                                            .. attribute:: tx_undersized_pkt
                                            
                                            	TX Undersized Pkt
                                            	**type**\:  :py:class:`TxUndersizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxUndersizedPkt>`
                                            
                                            .. attribute:: tx_oversized_pkt
                                            
                                            	TX Oversized Pkt
                                            	**type**\:  :py:class:`TxOversizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxOversizedPkt>`
                                            
                                            .. attribute:: tx_fragments
                                            
                                            	TX Fragments
                                            	**type**\:  :py:class:`TxFragments <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxFragments>`
                                            
                                            .. attribute:: tx_jabber
                                            
                                            	TX Jabber
                                            	**type**\:  :py:class:`TxJabber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxJabber>`
                                            
                                            .. attribute:: tx_bad_fcs
                                            
                                            	TX Bad Fcs
                                            	**type**\:  :py:class:`TxBadFcs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxBadFcs>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance, self).__init__()

                                                self.yang_name = "second30-ether-time-line-instance"
                                                self.yang_parent_name = "second30-ether-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("rx-pkt", ("rx_pkt", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.RxPkt)), ("stat-pkt", ("stat_pkt", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.StatPkt)), ("octet-stat", ("octet_stat", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OctetStat)), ("oversize-pkt-stat", ("oversize_pkt_stat", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OversizePktStat)), ("fcs-errors-stat", ("fcs_errors_stat", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.FcsErrorsStat)), ("long-frames-stat", ("long_frames_stat", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.LongFramesStat)), ("jabber-stat", ("jabber_stat", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.JabberStat)), ("ether64-octets", ("ether64_octets", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether64Octets)), ("ether65127-octet", ("ether65127_octet", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether65127Octet)), ("ether128255-octet", ("ether128255_octet", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether128255Octet)), ("ether256511-octet", ("ether256511_octet", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether256511Octet)), ("ether5121023-octet", ("ether5121023_octet", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether5121023Octet)), ("ether10241518-octet", ("ether10241518_octet", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether10241518Octet)), ("in-ucast-pkt", ("in_ucast_pkt", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InUcastPkt)), ("in-mcast-pkt", ("in_mcast_pkt", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InMcastPkt)), ("in-bcast-pkt", ("in_bcast_pkt", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InBcastPkt)), ("out-ucast-pkt", ("out_ucast_pkt", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutUcastPkt)), ("out-bcast-pkt", ("out_bcast_pkt", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutBcastPkt)), ("out-mcast-pkt", ("out_mcast_pkt", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutMcastPkt)), ("tx-pkt", ("tx_pkt", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxPkt)), ("if-in-errors", ("if_in_errors", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.IfInErrors)), ("if-in-octets", ("if_in_octets", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.IfInOctets)), ("ether-stat-multicast-pkt", ("ether_stat_multicast_pkt", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.EtherStatMulticastPkt)), ("ether-stat-broadcast-pkt", ("ether_stat_broadcast_pkt", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.EtherStatBroadcastPkt)), ("ether-stat-undersized-pkt", ("ether_stat_undersized_pkt", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.EtherStatUndersizedPkt)), ("out-octets", ("out_octets", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutOctets)), ("in-pause-frame", ("in_pause_frame", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPauseFrame)), ("in-good-bytes", ("in_good_bytes", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InGoodBytes)), ("in8021q-frames", ("in8021q_frames", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.In8021qFrames)), ("in-pkts1519-max-octets", ("in_pkts1519_max_octets", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts1519MaxOctets)), ("in-good-pkts", ("in_good_pkts", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InGoodPkts)), ("in-drop-overrun", ("in_drop_overrun", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropOverrun)), ("in-drop-abort", ("in_drop_abort", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropAbort)), ("in-drop-invalid-vlan", ("in_drop_invalid_vlan", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropInvalidVlan)), ("in-drop-invalid-dmac", ("in_drop_invalid_dmac", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropInvalidDmac)), ("in-drop-invalid-encap", ("in_drop_invalid_encap", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropInvalidEncap)), ("in-drop-other", ("in_drop_other", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropOther)), ("in-mib-giant", ("in_mib_giant", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InMibGiant)), ("in-mib-jabber", ("in_mib_jabber", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InMibJabber)), ("in-mibcrc", ("in_mibcrc", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InMibcrc)), ("in-error-collisions", ("in_error_collisions", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorCollisions)), ("in-error-symbol", ("in_error_symbol", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorSymbol)), ("out-good-bytes", ("out_good_bytes", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutGoodBytes)), ("out8021q-frames", ("out8021q_frames", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Out8021qFrames)), ("out-pause-frames", ("out_pause_frames", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPauseFrames)), ("out-pkts1519-max-octets", ("out_pkts1519_max_octets", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts1519MaxOctets)), ("out-good-pkts", ("out_good_pkts", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutGoodPkts)), ("out-drop-underrun", ("out_drop_underrun", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutDropUnderrun)), ("out-drop-abort", ("out_drop_abort", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutDropAbort)), ("out-drop-other", ("out_drop_other", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutDropOther)), ("out-error-other", ("out_error_other", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutErrorOther)), ("in-error-giant", ("in_error_giant", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorGiant)), ("in-error-runt", ("in_error_runt", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorRunt)), ("in-error-jabbers", ("in_error_jabbers", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorJabbers)), ("in-error-fragments", ("in_error_fragments", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorFragments)), ("in-error-other", ("in_error_other", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorOther)), ("in-pkt64-octet", ("in_pkt64_octet", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkt64Octet)), ("in-pkts65-to127-octets", ("in_pkts65_to127_octets", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts65To127Octets)), ("in-pkts128-to255-octets", ("in_pkts128_to255_octets", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts128To255Octets)), ("in-pkts256-to511-octets", ("in_pkts256_to511_octets", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts256To511Octets)), ("in-pkts512-to1023-octets", ("in_pkts512_to1023_octets", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts512To1023Octets)), ("in-pkts1024-to1518-octets", ("in_pkts1024_to1518_octets", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts1024To1518Octets)), ("outpkt64octet", ("outpkt64octet", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Outpkt64octet)), ("out-pkts65127-octets", ("out_pkts65127_octets", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts65127Octets)), ("out-pkts128255-octets", ("out_pkts128255_octets", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts128255Octets)), ("out-pkts256511-octets", ("out_pkts256511_octets", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts256511Octets)), ("out-pkts5121023-octets", ("out_pkts5121023_octets", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts5121023Octets)), ("out-pkts10241518-octets", ("out_pkts10241518_octets", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts10241518Octets)), ("rx-util", ("rx_util", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.RxUtil)), ("tx-util", ("tx_util", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxUtil)), ("tx-undersized-pkt", ("tx_undersized_pkt", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxUndersizedPkt)), ("tx-oversized-pkt", ("tx_oversized_pkt", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxOversizedPkt)), ("tx-fragments", ("tx_fragments", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxFragments)), ("tx-jabber", ("tx_jabber", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxJabber)), ("tx-bad-fcs", ("tx_bad_fcs", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxBadFcs))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                    ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None
                                                self.sec30_support = None

                                                self.rx_pkt = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.RxPkt()
                                                self.rx_pkt.parent = self
                                                self._children_name_map["rx_pkt"] = "rx-pkt"

                                                self.stat_pkt = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.StatPkt()
                                                self.stat_pkt.parent = self
                                                self._children_name_map["stat_pkt"] = "stat-pkt"

                                                self.octet_stat = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OctetStat()
                                                self.octet_stat.parent = self
                                                self._children_name_map["octet_stat"] = "octet-stat"

                                                self.oversize_pkt_stat = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OversizePktStat()
                                                self.oversize_pkt_stat.parent = self
                                                self._children_name_map["oversize_pkt_stat"] = "oversize-pkt-stat"

                                                self.fcs_errors_stat = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.FcsErrorsStat()
                                                self.fcs_errors_stat.parent = self
                                                self._children_name_map["fcs_errors_stat"] = "fcs-errors-stat"

                                                self.long_frames_stat = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.LongFramesStat()
                                                self.long_frames_stat.parent = self
                                                self._children_name_map["long_frames_stat"] = "long-frames-stat"

                                                self.jabber_stat = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.JabberStat()
                                                self.jabber_stat.parent = self
                                                self._children_name_map["jabber_stat"] = "jabber-stat"

                                                self.ether64_octets = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether64Octets()
                                                self.ether64_octets.parent = self
                                                self._children_name_map["ether64_octets"] = "ether64-octets"

                                                self.ether65127_octet = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether65127Octet()
                                                self.ether65127_octet.parent = self
                                                self._children_name_map["ether65127_octet"] = "ether65127-octet"

                                                self.ether128255_octet = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether128255Octet()
                                                self.ether128255_octet.parent = self
                                                self._children_name_map["ether128255_octet"] = "ether128255-octet"

                                                self.ether256511_octet = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether256511Octet()
                                                self.ether256511_octet.parent = self
                                                self._children_name_map["ether256511_octet"] = "ether256511-octet"

                                                self.ether5121023_octet = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether5121023Octet()
                                                self.ether5121023_octet.parent = self
                                                self._children_name_map["ether5121023_octet"] = "ether5121023-octet"

                                                self.ether10241518_octet = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether10241518Octet()
                                                self.ether10241518_octet.parent = self
                                                self._children_name_map["ether10241518_octet"] = "ether10241518-octet"

                                                self.in_ucast_pkt = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InUcastPkt()
                                                self.in_ucast_pkt.parent = self
                                                self._children_name_map["in_ucast_pkt"] = "in-ucast-pkt"

                                                self.in_mcast_pkt = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InMcastPkt()
                                                self.in_mcast_pkt.parent = self
                                                self._children_name_map["in_mcast_pkt"] = "in-mcast-pkt"

                                                self.in_bcast_pkt = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InBcastPkt()
                                                self.in_bcast_pkt.parent = self
                                                self._children_name_map["in_bcast_pkt"] = "in-bcast-pkt"

                                                self.out_ucast_pkt = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutUcastPkt()
                                                self.out_ucast_pkt.parent = self
                                                self._children_name_map["out_ucast_pkt"] = "out-ucast-pkt"

                                                self.out_bcast_pkt = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutBcastPkt()
                                                self.out_bcast_pkt.parent = self
                                                self._children_name_map["out_bcast_pkt"] = "out-bcast-pkt"

                                                self.out_mcast_pkt = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutMcastPkt()
                                                self.out_mcast_pkt.parent = self
                                                self._children_name_map["out_mcast_pkt"] = "out-mcast-pkt"

                                                self.tx_pkt = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxPkt()
                                                self.tx_pkt.parent = self
                                                self._children_name_map["tx_pkt"] = "tx-pkt"

                                                self.if_in_errors = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.IfInErrors()
                                                self.if_in_errors.parent = self
                                                self._children_name_map["if_in_errors"] = "if-in-errors"

                                                self.if_in_octets = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.IfInOctets()
                                                self.if_in_octets.parent = self
                                                self._children_name_map["if_in_octets"] = "if-in-octets"

                                                self.ether_stat_multicast_pkt = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.EtherStatMulticastPkt()
                                                self.ether_stat_multicast_pkt.parent = self
                                                self._children_name_map["ether_stat_multicast_pkt"] = "ether-stat-multicast-pkt"

                                                self.ether_stat_broadcast_pkt = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.EtherStatBroadcastPkt()
                                                self.ether_stat_broadcast_pkt.parent = self
                                                self._children_name_map["ether_stat_broadcast_pkt"] = "ether-stat-broadcast-pkt"

                                                self.ether_stat_undersized_pkt = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.EtherStatUndersizedPkt()
                                                self.ether_stat_undersized_pkt.parent = self
                                                self._children_name_map["ether_stat_undersized_pkt"] = "ether-stat-undersized-pkt"

                                                self.out_octets = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutOctets()
                                                self.out_octets.parent = self
                                                self._children_name_map["out_octets"] = "out-octets"

                                                self.in_pause_frame = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPauseFrame()
                                                self.in_pause_frame.parent = self
                                                self._children_name_map["in_pause_frame"] = "in-pause-frame"

                                                self.in_good_bytes = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InGoodBytes()
                                                self.in_good_bytes.parent = self
                                                self._children_name_map["in_good_bytes"] = "in-good-bytes"

                                                self.in8021q_frames = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.In8021qFrames()
                                                self.in8021q_frames.parent = self
                                                self._children_name_map["in8021q_frames"] = "in8021q-frames"

                                                self.in_pkts1519_max_octets = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts1519MaxOctets()
                                                self.in_pkts1519_max_octets.parent = self
                                                self._children_name_map["in_pkts1519_max_octets"] = "in-pkts1519-max-octets"

                                                self.in_good_pkts = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InGoodPkts()
                                                self.in_good_pkts.parent = self
                                                self._children_name_map["in_good_pkts"] = "in-good-pkts"

                                                self.in_drop_overrun = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropOverrun()
                                                self.in_drop_overrun.parent = self
                                                self._children_name_map["in_drop_overrun"] = "in-drop-overrun"

                                                self.in_drop_abort = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropAbort()
                                                self.in_drop_abort.parent = self
                                                self._children_name_map["in_drop_abort"] = "in-drop-abort"

                                                self.in_drop_invalid_vlan = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropInvalidVlan()
                                                self.in_drop_invalid_vlan.parent = self
                                                self._children_name_map["in_drop_invalid_vlan"] = "in-drop-invalid-vlan"

                                                self.in_drop_invalid_dmac = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropInvalidDmac()
                                                self.in_drop_invalid_dmac.parent = self
                                                self._children_name_map["in_drop_invalid_dmac"] = "in-drop-invalid-dmac"

                                                self.in_drop_invalid_encap = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropInvalidEncap()
                                                self.in_drop_invalid_encap.parent = self
                                                self._children_name_map["in_drop_invalid_encap"] = "in-drop-invalid-encap"

                                                self.in_drop_other = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropOther()
                                                self.in_drop_other.parent = self
                                                self._children_name_map["in_drop_other"] = "in-drop-other"

                                                self.in_mib_giant = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InMibGiant()
                                                self.in_mib_giant.parent = self
                                                self._children_name_map["in_mib_giant"] = "in-mib-giant"

                                                self.in_mib_jabber = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InMibJabber()
                                                self.in_mib_jabber.parent = self
                                                self._children_name_map["in_mib_jabber"] = "in-mib-jabber"

                                                self.in_mibcrc = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InMibcrc()
                                                self.in_mibcrc.parent = self
                                                self._children_name_map["in_mibcrc"] = "in-mibcrc"

                                                self.in_error_collisions = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorCollisions()
                                                self.in_error_collisions.parent = self
                                                self._children_name_map["in_error_collisions"] = "in-error-collisions"

                                                self.in_error_symbol = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorSymbol()
                                                self.in_error_symbol.parent = self
                                                self._children_name_map["in_error_symbol"] = "in-error-symbol"

                                                self.out_good_bytes = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutGoodBytes()
                                                self.out_good_bytes.parent = self
                                                self._children_name_map["out_good_bytes"] = "out-good-bytes"

                                                self.out8021q_frames = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Out8021qFrames()
                                                self.out8021q_frames.parent = self
                                                self._children_name_map["out8021q_frames"] = "out8021q-frames"

                                                self.out_pause_frames = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPauseFrames()
                                                self.out_pause_frames.parent = self
                                                self._children_name_map["out_pause_frames"] = "out-pause-frames"

                                                self.out_pkts1519_max_octets = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts1519MaxOctets()
                                                self.out_pkts1519_max_octets.parent = self
                                                self._children_name_map["out_pkts1519_max_octets"] = "out-pkts1519-max-octets"

                                                self.out_good_pkts = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutGoodPkts()
                                                self.out_good_pkts.parent = self
                                                self._children_name_map["out_good_pkts"] = "out-good-pkts"

                                                self.out_drop_underrun = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutDropUnderrun()
                                                self.out_drop_underrun.parent = self
                                                self._children_name_map["out_drop_underrun"] = "out-drop-underrun"

                                                self.out_drop_abort = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutDropAbort()
                                                self.out_drop_abort.parent = self
                                                self._children_name_map["out_drop_abort"] = "out-drop-abort"

                                                self.out_drop_other = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutDropOther()
                                                self.out_drop_other.parent = self
                                                self._children_name_map["out_drop_other"] = "out-drop-other"

                                                self.out_error_other = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutErrorOther()
                                                self.out_error_other.parent = self
                                                self._children_name_map["out_error_other"] = "out-error-other"

                                                self.in_error_giant = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorGiant()
                                                self.in_error_giant.parent = self
                                                self._children_name_map["in_error_giant"] = "in-error-giant"

                                                self.in_error_runt = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorRunt()
                                                self.in_error_runt.parent = self
                                                self._children_name_map["in_error_runt"] = "in-error-runt"

                                                self.in_error_jabbers = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorJabbers()
                                                self.in_error_jabbers.parent = self
                                                self._children_name_map["in_error_jabbers"] = "in-error-jabbers"

                                                self.in_error_fragments = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorFragments()
                                                self.in_error_fragments.parent = self
                                                self._children_name_map["in_error_fragments"] = "in-error-fragments"

                                                self.in_error_other = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorOther()
                                                self.in_error_other.parent = self
                                                self._children_name_map["in_error_other"] = "in-error-other"

                                                self.in_pkt64_octet = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkt64Octet()
                                                self.in_pkt64_octet.parent = self
                                                self._children_name_map["in_pkt64_octet"] = "in-pkt64-octet"

                                                self.in_pkts65_to127_octets = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts65To127Octets()
                                                self.in_pkts65_to127_octets.parent = self
                                                self._children_name_map["in_pkts65_to127_octets"] = "in-pkts65-to127-octets"

                                                self.in_pkts128_to255_octets = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts128To255Octets()
                                                self.in_pkts128_to255_octets.parent = self
                                                self._children_name_map["in_pkts128_to255_octets"] = "in-pkts128-to255-octets"

                                                self.in_pkts256_to511_octets = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts256To511Octets()
                                                self.in_pkts256_to511_octets.parent = self
                                                self._children_name_map["in_pkts256_to511_octets"] = "in-pkts256-to511-octets"

                                                self.in_pkts512_to1023_octets = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts512To1023Octets()
                                                self.in_pkts512_to1023_octets.parent = self
                                                self._children_name_map["in_pkts512_to1023_octets"] = "in-pkts512-to1023-octets"

                                                self.in_pkts1024_to1518_octets = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts1024To1518Octets()
                                                self.in_pkts1024_to1518_octets.parent = self
                                                self._children_name_map["in_pkts1024_to1518_octets"] = "in-pkts1024-to1518-octets"

                                                self.outpkt64octet = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Outpkt64octet()
                                                self.outpkt64octet.parent = self
                                                self._children_name_map["outpkt64octet"] = "outpkt64octet"

                                                self.out_pkts65127_octets = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts65127Octets()
                                                self.out_pkts65127_octets.parent = self
                                                self._children_name_map["out_pkts65127_octets"] = "out-pkts65127-octets"

                                                self.out_pkts128255_octets = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts128255Octets()
                                                self.out_pkts128255_octets.parent = self
                                                self._children_name_map["out_pkts128255_octets"] = "out-pkts128255-octets"

                                                self.out_pkts256511_octets = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts256511Octets()
                                                self.out_pkts256511_octets.parent = self
                                                self._children_name_map["out_pkts256511_octets"] = "out-pkts256511-octets"

                                                self.out_pkts5121023_octets = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts5121023Octets()
                                                self.out_pkts5121023_octets.parent = self
                                                self._children_name_map["out_pkts5121023_octets"] = "out-pkts5121023-octets"

                                                self.out_pkts10241518_octets = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts10241518Octets()
                                                self.out_pkts10241518_octets.parent = self
                                                self._children_name_map["out_pkts10241518_octets"] = "out-pkts10241518-octets"

                                                self.rx_util = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.RxUtil()
                                                self.rx_util.parent = self
                                                self._children_name_map["rx_util"] = "rx-util"

                                                self.tx_util = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxUtil()
                                                self.tx_util.parent = self
                                                self._children_name_map["tx_util"] = "tx-util"

                                                self.tx_undersized_pkt = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxUndersizedPkt()
                                                self.tx_undersized_pkt.parent = self
                                                self._children_name_map["tx_undersized_pkt"] = "tx-undersized-pkt"

                                                self.tx_oversized_pkt = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxOversizedPkt()
                                                self.tx_oversized_pkt.parent = self
                                                self._children_name_map["tx_oversized_pkt"] = "tx-oversized-pkt"

                                                self.tx_fragments = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxFragments()
                                                self.tx_fragments.parent = self
                                                self._children_name_map["tx_fragments"] = "tx-fragments"

                                                self.tx_jabber = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxJabber()
                                                self.tx_jabber.parent = self
                                                self._children_name_map["tx_jabber"] = "tx-jabber"

                                                self.tx_bad_fcs = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxBadFcs()
                                                self.tx_bad_fcs.parent = self
                                                self._children_name_map["tx_bad_fcs"] = "tx-bad-fcs"
                                                self._segment_path = lambda: "second30-ether-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear30_sec_time', 'last_clear15_min_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                            class RxPkt(Entity):
                                                """
                                                RX PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.RxPkt, self).__init__()

                                                    self.yang_name = "rx-pkt"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "rx-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.RxPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class StatPkt(Entity):
                                                """
                                                STAT PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.StatPkt, self).__init__()

                                                    self.yang_name = "stat-pkt"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "stat-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.StatPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OctetStat(Entity):
                                                """
                                                OCTET STAT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OctetStat, self).__init__()

                                                    self.yang_name = "octet-stat"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "octet-stat"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OctetStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OversizePktStat(Entity):
                                                """
                                                OVERSIZE PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OversizePktStat, self).__init__()

                                                    self.yang_name = "oversize-pkt-stat"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "oversize-pkt-stat"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OversizePktStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class FcsErrorsStat(Entity):
                                                """
                                                FCS ERR
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.FcsErrorsStat, self).__init__()

                                                    self.yang_name = "fcs-errors-stat"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "fcs-errors-stat"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.FcsErrorsStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class LongFramesStat(Entity):
                                                """
                                                LONG FRAMES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.LongFramesStat, self).__init__()

                                                    self.yang_name = "long-frames-stat"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "long-frames-stat"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.LongFramesStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class JabberStat(Entity):
                                                """
                                                JABBER STATS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.JabberStat, self).__init__()

                                                    self.yang_name = "jabber-stat"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "jabber-stat"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.JabberStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class Ether64Octets(Entity):
                                                """
                                                SIXTY FOUR OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether64Octets, self).__init__()

                                                    self.yang_name = "ether64-octets"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ether64-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether64Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class Ether65127Octet(Entity):
                                                """
                                                OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether65127Octet, self).__init__()

                                                    self.yang_name = "ether65127-octet"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ether65127-octet"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether65127Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class Ether128255Octet(Entity):
                                                """
                                                TFF OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether128255Octet, self).__init__()

                                                    self.yang_name = "ether128255-octet"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ether128255-octet"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether128255Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class Ether256511Octet(Entity):
                                                """
                                                FOO OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether256511Octet, self).__init__()

                                                    self.yang_name = "ether256511-octet"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ether256511-octet"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether256511Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class Ether5121023Octet(Entity):
                                                """
                                                OZTT OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether5121023Octet, self).__init__()

                                                    self.yang_name = "ether5121023-octet"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ether5121023-octet"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether5121023Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class Ether10241518Octet(Entity):
                                                """
                                                OFO OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether10241518Octet, self).__init__()

                                                    self.yang_name = "ether10241518-octet"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ether10241518-octet"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether10241518Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InUcastPkt(Entity):
                                                """
                                                IN UCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InUcastPkt, self).__init__()

                                                    self.yang_name = "in-ucast-pkt"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-ucast-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InUcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InMcastPkt(Entity):
                                                """
                                                IN MCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InMcastPkt, self).__init__()

                                                    self.yang_name = "in-mcast-pkt"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-mcast-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InMcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InBcastPkt(Entity):
                                                """
                                                IN BCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InBcastPkt, self).__init__()

                                                    self.yang_name = "in-bcast-pkt"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-bcast-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InBcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutUcastPkt(Entity):
                                                """
                                                OUT UCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutUcastPkt, self).__init__()

                                                    self.yang_name = "out-ucast-pkt"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-ucast-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutUcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutBcastPkt(Entity):
                                                """
                                                OUT BCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutBcastPkt, self).__init__()

                                                    self.yang_name = "out-bcast-pkt"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-bcast-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutBcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutMcastPkt(Entity):
                                                """
                                                OUT MCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutMcastPkt, self).__init__()

                                                    self.yang_name = "out-mcast-pkt"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-mcast-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutMcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class TxPkt(Entity):
                                                """
                                                TX PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxPkt, self).__init__()

                                                    self.yang_name = "tx-pkt"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "tx-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class IfInErrors(Entity):
                                                """
                                                IFIN ERRORS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.IfInErrors, self).__init__()

                                                    self.yang_name = "if-in-errors"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "if-in-errors"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.IfInErrors, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class IfInOctets(Entity):
                                                """
                                                IFIN OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.IfInOctets, self).__init__()

                                                    self.yang_name = "if-in-octets"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "if-in-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.IfInOctets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class EtherStatMulticastPkt(Entity):
                                                """
                                                ETHER STAT MULTICAST PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.EtherStatMulticastPkt, self).__init__()

                                                    self.yang_name = "ether-stat-multicast-pkt"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ether-stat-multicast-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.EtherStatMulticastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class EtherStatBroadcastPkt(Entity):
                                                """
                                                ETHER STAT BROADCAST PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.EtherStatBroadcastPkt, self).__init__()

                                                    self.yang_name = "ether-stat-broadcast-pkt"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ether-stat-broadcast-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.EtherStatBroadcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class EtherStatUndersizedPkt(Entity):
                                                """
                                                ETHER STAT UNDERSIZED PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.EtherStatUndersizedPkt, self).__init__()

                                                    self.yang_name = "ether-stat-undersized-pkt"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ether-stat-undersized-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.EtherStatUndersizedPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutOctets(Entity):
                                                """
                                                OUT OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutOctets, self).__init__()

                                                    self.yang_name = "out-octets"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutOctets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPauseFrame(Entity):
                                                """
                                                INPUT PAUSE FRAME
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPauseFrame, self).__init__()

                                                    self.yang_name = "in-pause-frame"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pause-frame"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPauseFrame, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InGoodBytes(Entity):
                                                """
                                                INPUT GOOD BYTES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InGoodBytes, self).__init__()

                                                    self.yang_name = "in-good-bytes"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-good-bytes"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InGoodBytes, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class In8021qFrames(Entity):
                                                """
                                                INPUT 802 1Q FRAMES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.In8021qFrames, self).__init__()

                                                    self.yang_name = "in8021q-frames"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in8021q-frames"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.In8021qFrames, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPkts1519MaxOctets(Entity):
                                                """
                                                INPUT PKTS 1519MAX OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts1519MaxOctets, self).__init__()

                                                    self.yang_name = "in-pkts1519-max-octets"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts1519-max-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts1519MaxOctets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InGoodPkts(Entity):
                                                """
                                                INPUT GOOD PKTS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InGoodPkts, self).__init__()

                                                    self.yang_name = "in-good-pkts"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-good-pkts"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InGoodPkts, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InDropOverrun(Entity):
                                                """
                                                INPUT DROP OVERRUN
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropOverrun, self).__init__()

                                                    self.yang_name = "in-drop-overrun"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-drop-overrun"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropOverrun, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InDropAbort(Entity):
                                                """
                                                INPUT DROP ABORT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropAbort, self).__init__()

                                                    self.yang_name = "in-drop-abort"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-drop-abort"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropAbort, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InDropInvalidVlan(Entity):
                                                """
                                                INPUT DROP INVALID VLAN
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropInvalidVlan, self).__init__()

                                                    self.yang_name = "in-drop-invalid-vlan"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-drop-invalid-vlan"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropInvalidVlan, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InDropInvalidDmac(Entity):
                                                """
                                                INPUT DROP INVALID DMAC
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropInvalidDmac, self).__init__()

                                                    self.yang_name = "in-drop-invalid-dmac"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-drop-invalid-dmac"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropInvalidDmac, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InDropInvalidEncap(Entity):
                                                """
                                                INPUT DROP INVALID ENCAP
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropInvalidEncap, self).__init__()

                                                    self.yang_name = "in-drop-invalid-encap"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-drop-invalid-encap"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropInvalidEncap, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InDropOther(Entity):
                                                """
                                                INPUT DROP OTHER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropOther, self).__init__()

                                                    self.yang_name = "in-drop-other"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-drop-other"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropOther, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InMibGiant(Entity):
                                                """
                                                INPUT MIB GIANT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InMibGiant, self).__init__()

                                                    self.yang_name = "in-mib-giant"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-mib-giant"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InMibGiant, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InMibJabber(Entity):
                                                """
                                                INPUT MIB JABBER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InMibJabber, self).__init__()

                                                    self.yang_name = "in-mib-jabber"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-mib-jabber"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InMibJabber, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InMibcrc(Entity):
                                                """
                                                IN MIB CRC
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InMibcrc, self).__init__()

                                                    self.yang_name = "in-mibcrc"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-mibcrc"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InMibcrc, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InErrorCollisions(Entity):
                                                """
                                                IN ERROR COLLISIONS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorCollisions, self).__init__()

                                                    self.yang_name = "in-error-collisions"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-error-collisions"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorCollisions, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InErrorSymbol(Entity):
                                                """
                                                IN ERROR SYMBOL
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorSymbol, self).__init__()

                                                    self.yang_name = "in-error-symbol"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-error-symbol"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorSymbol, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutGoodBytes(Entity):
                                                """
                                                OUT GOOD BYTES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutGoodBytes, self).__init__()

                                                    self.yang_name = "out-good-bytes"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-good-bytes"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutGoodBytes, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class Out8021qFrames(Entity):
                                                """
                                                OUT 802 1Q FRAMES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Out8021qFrames, self).__init__()

                                                    self.yang_name = "out8021q-frames"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out8021q-frames"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Out8021qFrames, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutPauseFrames(Entity):
                                                """
                                                OUT PAUSE FRAMES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPauseFrames, self).__init__()

                                                    self.yang_name = "out-pause-frames"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-pause-frames"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPauseFrames, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutPkts1519MaxOctets(Entity):
                                                """
                                                OUT PKTS 1519 MAX OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts1519MaxOctets, self).__init__()

                                                    self.yang_name = "out-pkts1519-max-octets"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-pkts1519-max-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts1519MaxOctets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutGoodPkts(Entity):
                                                """
                                                OUT GOOD PKTS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutGoodPkts, self).__init__()

                                                    self.yang_name = "out-good-pkts"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-good-pkts"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutGoodPkts, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutDropUnderrun(Entity):
                                                """
                                                OUT DROP UNDERRUN
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutDropUnderrun, self).__init__()

                                                    self.yang_name = "out-drop-underrun"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-drop-underrun"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutDropUnderrun, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutDropAbort(Entity):
                                                """
                                                OUT DROP ABORT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutDropAbort, self).__init__()

                                                    self.yang_name = "out-drop-abort"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-drop-abort"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutDropAbort, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutDropOther(Entity):
                                                """
                                                OUT DROP OTHER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutDropOther, self).__init__()

                                                    self.yang_name = "out-drop-other"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-drop-other"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutDropOther, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutErrorOther(Entity):
                                                """
                                                OUT ERROR OTHER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutErrorOther, self).__init__()

                                                    self.yang_name = "out-error-other"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-error-other"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutErrorOther, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InErrorGiant(Entity):
                                                """
                                                IN ERROR GIANT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorGiant, self).__init__()

                                                    self.yang_name = "in-error-giant"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-error-giant"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorGiant, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InErrorRunt(Entity):
                                                """
                                                IN ERROR RUNT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorRunt, self).__init__()

                                                    self.yang_name = "in-error-runt"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-error-runt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorRunt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InErrorJabbers(Entity):
                                                """
                                                IN ERROR JABBERS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorJabbers, self).__init__()

                                                    self.yang_name = "in-error-jabbers"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-error-jabbers"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorJabbers, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InErrorFragments(Entity):
                                                """
                                                IN ERROR FRAGMENTS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorFragments, self).__init__()

                                                    self.yang_name = "in-error-fragments"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-error-fragments"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorFragments, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InErrorOther(Entity):
                                                """
                                                IN ERROR OTHER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorOther, self).__init__()

                                                    self.yang_name = "in-error-other"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-error-other"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorOther, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPkt64Octet(Entity):
                                                """
                                                IN PKT 64 OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkt64Octet, self).__init__()

                                                    self.yang_name = "in-pkt64-octet"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkt64-octet"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkt64Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPkts65To127Octets(Entity):
                                                """
                                                IN PKTS 65 127OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts65To127Octets, self).__init__()

                                                    self.yang_name = "in-pkts65-to127-octets"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts65-to127-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts65To127Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPkts128To255Octets(Entity):
                                                """
                                                IN PKTS 128 255 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts128To255Octets, self).__init__()

                                                    self.yang_name = "in-pkts128-to255-octets"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts128-to255-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts128To255Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPkts256To511Octets(Entity):
                                                """
                                                IN PKTS 256 511 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts256To511Octets, self).__init__()

                                                    self.yang_name = "in-pkts256-to511-octets"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts256-to511-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts256To511Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPkts512To1023Octets(Entity):
                                                """
                                                IN PKTS 512 1023 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts512To1023Octets, self).__init__()

                                                    self.yang_name = "in-pkts512-to1023-octets"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts512-to1023-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts512To1023Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPkts1024To1518Octets(Entity):
                                                """
                                                IN PKTS 1024 1518 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts1024To1518Octets, self).__init__()

                                                    self.yang_name = "in-pkts1024-to1518-octets"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts1024-to1518-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts1024To1518Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class Outpkt64octet(Entity):
                                                """
                                                OUT PKT 64 OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Outpkt64octet, self).__init__()

                                                    self.yang_name = "outpkt64octet"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "outpkt64octet"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Outpkt64octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutPkts65127Octets(Entity):
                                                """
                                                OUT PKTS 65 127OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts65127Octets, self).__init__()

                                                    self.yang_name = "out-pkts65127-octets"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-pkts65127-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts65127Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutPkts128255Octets(Entity):
                                                """
                                                OUT PKTS 128 255 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts128255Octets, self).__init__()

                                                    self.yang_name = "out-pkts128255-octets"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-pkts128255-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts128255Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutPkts256511Octets(Entity):
                                                """
                                                OUT PKTS 256 511 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts256511Octets, self).__init__()

                                                    self.yang_name = "out-pkts256511-octets"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-pkts256511-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts256511Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutPkts5121023Octets(Entity):
                                                """
                                                OUT PKTS 512 1023 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts5121023Octets, self).__init__()

                                                    self.yang_name = "out-pkts5121023-octets"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-pkts5121023-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts5121023Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutPkts10241518Octets(Entity):
                                                """
                                                OUT PKTS 1024 1518 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts10241518Octets, self).__init__()

                                                    self.yang_name = "out-pkts10241518-octets"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-pkts10241518-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts10241518Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class RxUtil(Entity):
                                                """
                                                Rx Utilization in Percent
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: str
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.RxUtil, self).__init__()

                                                    self.yang_name = "rx-util"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                        ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "rx-util"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.RxUtil, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class TxUtil(Entity):
                                                """
                                                Tx Utilization in Percent
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: str
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxUtil, self).__init__()

                                                    self.yang_name = "tx-util"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                        ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "tx-util"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxUtil, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class TxUndersizedPkt(Entity):
                                                """
                                                TX Undersized Pkt
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxUndersizedPkt, self).__init__()

                                                    self.yang_name = "tx-undersized-pkt"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "tx-undersized-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxUndersizedPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class TxOversizedPkt(Entity):
                                                """
                                                TX Oversized Pkt
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxOversizedPkt, self).__init__()

                                                    self.yang_name = "tx-oversized-pkt"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "tx-oversized-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxOversizedPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class TxFragments(Entity):
                                                """
                                                TX Fragments
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxFragments, self).__init__()

                                                    self.yang_name = "tx-fragments"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "tx-fragments"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxFragments, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class TxJabber(Entity):
                                                """
                                                TX Jabber
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxJabber, self).__init__()

                                                    self.yang_name = "tx-jabber"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "tx-jabber"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxJabber, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class TxBadFcs(Entity):
                                                """
                                                TX Bad Fcs
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxBadFcs, self).__init__()

                                                    self.yang_name = "tx-bad-fcs"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "tx-bad-fcs"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxBadFcs, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                            class Second30FecHistories(Entity):
                                """
                                ETHERNET port interval performance data
                                
                                .. attribute:: second30_fec_history
                                
                                	ETHERNET port 30 sec fec performance data
                                	**type**\: list of  		 :py:class:`Second30FecHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30FecHistories.Second30FecHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30FecHistories, self).__init__()

                                    self.yang_name = "second30-fec-histories"
                                    self.yang_parent_name = "ethernet-second30-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("second30-fec-history", ("second30_fec_history", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30FecHistories.Second30FecHistory))])
                                    self._leafs = OrderedDict()

                                    self.second30_fec_history = YList(self)
                                    self._segment_path = lambda: "second30-fec-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30FecHistories, [], name, value)


                                class Second30FecHistory(Entity):
                                    """
                                    ETHERNET port 30 sec fec performance data
                                    
                                    .. attribute:: slot_number  (key)
                                    
                                    	interval slot number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: second30_fec_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`Second30FecTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30FecHistories.Second30FecHistory.Second30FecTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30FecHistories.Second30FecHistory, self).__init__()

                                        self.yang_name = "second30-fec-history"
                                        self.yang_parent_name = "second30-fec-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['slot_number']
                                        self._child_classes = OrderedDict([("second30-fec-time-line-instances", ("second30_fec_time_line_instances", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30FecHistories.Second30FecHistory.Second30FecTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('slot_number', (YLeaf(YType.uint32, 'slot-number'), ['int'])),
                                        ])
                                        self.slot_number = None

                                        self.second30_fec_time_line_instances = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30FecHistories.Second30FecHistory.Second30FecTimeLineInstances()
                                        self.second30_fec_time_line_instances.parent = self
                                        self._children_name_map["second30_fec_time_line_instances"] = "second30-fec-time-line-instances"
                                        self._segment_path = lambda: "second30-fec-history" + "[slot-number='" + str(self.slot_number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30FecHistories.Second30FecHistory, ['slot_number'], name, value)


                                    class Second30FecTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: second30_fec_time_line_instance
                                        
                                        	port 30 sec fec performance data
                                        	**type**\: list of  		 :py:class:`Second30FecTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30FecHistories.Second30FecHistory.Second30FecTimeLineInstances.Second30FecTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30FecHistories.Second30FecHistory.Second30FecTimeLineInstances, self).__init__()

                                            self.yang_name = "second30-fec-time-line-instances"
                                            self.yang_parent_name = "second30-fec-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("second30-fec-time-line-instance", ("second30_fec_time_line_instance", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30FecHistories.Second30FecHistory.Second30FecTimeLineInstances.Second30FecTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.second30_fec_time_line_instance = YList(self)
                                            self._segment_path = lambda: "second30-fec-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30FecHistories.Second30FecHistory.Second30FecTimeLineInstances, [], name, value)


                                        class Second30FecTimeLineInstance(Entity):
                                            """
                                            port 30 sec fec performance data
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ec_bits
                                            
                                            	EC BITS
                                            	**type**\:  :py:class:`EcBits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30FecHistories.Second30FecHistory.Second30FecTimeLineInstances.Second30FecTimeLineInstance.EcBits>`
                                            
                                            .. attribute:: uc_words
                                            
                                            	UC WORDS
                                            	**type**\:  :py:class:`UcWords <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30FecHistories.Second30FecHistory.Second30FecTimeLineInstances.Second30FecTimeLineInstance.UcWords>`
                                            
                                            .. attribute:: pre_fec_ber
                                            
                                            	Pre FEC BER
                                            	**type**\:  :py:class:`PreFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30FecHistories.Second30FecHistory.Second30FecTimeLineInstances.Second30FecTimeLineInstance.PreFecBer>`
                                            
                                            .. attribute:: post_fec_ber
                                            
                                            	Post FEC BER
                                            	**type**\:  :py:class:`PostFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30FecHistories.Second30FecHistory.Second30FecTimeLineInstances.Second30FecTimeLineInstance.PostFecBer>`
                                            
                                            .. attribute:: q
                                            
                                            	Q
                                            	**type**\:  :py:class:`Q <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30FecHistories.Second30FecHistory.Second30FecTimeLineInstances.Second30FecTimeLineInstance.Q>`
                                            
                                            .. attribute:: qmargin
                                            
                                            	Q Margin
                                            	**type**\:  :py:class:`Qmargin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30FecHistories.Second30FecHistory.Second30FecTimeLineInstances.Second30FecTimeLineInstance.Qmargin>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30FecHistories.Second30FecHistory.Second30FecTimeLineInstances.Second30FecTimeLineInstance, self).__init__()

                                                self.yang_name = "second30-fec-time-line-instance"
                                                self.yang_parent_name = "second30-fec-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("ec-bits", ("ec_bits", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30FecHistories.Second30FecHistory.Second30FecTimeLineInstances.Second30FecTimeLineInstance.EcBits)), ("uc-words", ("uc_words", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30FecHistories.Second30FecHistory.Second30FecTimeLineInstances.Second30FecTimeLineInstance.UcWords)), ("pre-fec-ber", ("pre_fec_ber", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30FecHistories.Second30FecHistory.Second30FecTimeLineInstances.Second30FecTimeLineInstance.PreFecBer)), ("post-fec-ber", ("post_fec_ber", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30FecHistories.Second30FecHistory.Second30FecTimeLineInstances.Second30FecTimeLineInstance.PostFecBer)), ("q", ("q", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30FecHistories.Second30FecHistory.Second30FecTimeLineInstances.Second30FecTimeLineInstance.Q)), ("qmargin", ("qmargin", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30FecHistories.Second30FecHistory.Second30FecTimeLineInstances.Second30FecTimeLineInstance.Qmargin))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                    ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear24_hr_time = None
                                                self.sec30_support = None

                                                self.ec_bits = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30FecHistories.Second30FecHistory.Second30FecTimeLineInstances.Second30FecTimeLineInstance.EcBits()
                                                self.ec_bits.parent = self
                                                self._children_name_map["ec_bits"] = "ec-bits"

                                                self.uc_words = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30FecHistories.Second30FecHistory.Second30FecTimeLineInstances.Second30FecTimeLineInstance.UcWords()
                                                self.uc_words.parent = self
                                                self._children_name_map["uc_words"] = "uc-words"

                                                self.pre_fec_ber = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30FecHistories.Second30FecHistory.Second30FecTimeLineInstances.Second30FecTimeLineInstance.PreFecBer()
                                                self.pre_fec_ber.parent = self
                                                self._children_name_map["pre_fec_ber"] = "pre-fec-ber"

                                                self.post_fec_ber = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30FecHistories.Second30FecHistory.Second30FecTimeLineInstances.Second30FecTimeLineInstance.PostFecBer()
                                                self.post_fec_ber.parent = self
                                                self._children_name_map["post_fec_ber"] = "post-fec-ber"

                                                self.q = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30FecHistories.Second30FecHistory.Second30FecTimeLineInstances.Second30FecTimeLineInstance.Q()
                                                self.q.parent = self
                                                self._children_name_map["q"] = "q"

                                                self.qmargin = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30FecHistories.Second30FecHistory.Second30FecTimeLineInstances.Second30FecTimeLineInstance.Qmargin()
                                                self.qmargin.parent = self
                                                self._children_name_map["qmargin"] = "qmargin"
                                                self._segment_path = lambda: "second30-fec-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30FecHistories.Second30FecHistory.Second30FecTimeLineInstances.Second30FecTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                            class EcBits(Entity):
                                                """
                                                EC BITS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30FecHistories.Second30FecHistory.Second30FecTimeLineInstances.Second30FecTimeLineInstance.EcBits, self).__init__()

                                                    self.yang_name = "ec-bits"
                                                    self.yang_parent_name = "second30-fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ec-bits"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30FecHistories.Second30FecHistory.Second30FecTimeLineInstances.Second30FecTimeLineInstance.EcBits, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class UcWords(Entity):
                                                """
                                                UC WORDS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30FecHistories.Second30FecHistory.Second30FecTimeLineInstances.Second30FecTimeLineInstance.UcWords, self).__init__()

                                                    self.yang_name = "uc-words"
                                                    self.yang_parent_name = "second30-fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "uc-words"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30FecHistories.Second30FecHistory.Second30FecTimeLineInstances.Second30FecTimeLineInstance.UcWords, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class PreFecBer(Entity):
                                                """
                                                Pre FEC BER
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30FecHistories.Second30FecHistory.Second30FecTimeLineInstances.Second30FecTimeLineInstance.PreFecBer, self).__init__()

                                                    self.yang_name = "pre-fec-ber"
                                                    self.yang_parent_name = "second30-fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.maximum_tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "pre-fec-ber"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30FecHistories.Second30FecHistory.Second30FecTimeLineInstances.Second30FecTimeLineInstance.PreFecBer, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                            class PostFecBer(Entity):
                                                """
                                                Post FEC BER
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30FecHistories.Second30FecHistory.Second30FecTimeLineInstances.Second30FecTimeLineInstance.PostFecBer, self).__init__()

                                                    self.yang_name = "post-fec-ber"
                                                    self.yang_parent_name = "second30-fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.maximum_tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "post-fec-ber"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30FecHistories.Second30FecHistory.Second30FecTimeLineInstances.Second30FecTimeLineInstance.PostFecBer, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                            class Q(Entity):
                                                """
                                                Q
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30FecHistories.Second30FecHistory.Second30FecTimeLineInstances.Second30FecTimeLineInstance.Q, self).__init__()

                                                    self.yang_name = "q"
                                                    self.yang_parent_name = "second30-fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.maximum_tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "q"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30FecHistories.Second30FecHistory.Second30FecTimeLineInstances.Second30FecTimeLineInstance.Q, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                            class Qmargin(Entity):
                                                """
                                                Q Margin
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30FecHistories.Second30FecHistory.Second30FecTimeLineInstances.Second30FecTimeLineInstance.Qmargin, self).__init__()

                                                    self.yang_name = "qmargin"
                                                    self.yang_parent_name = "second30-fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.maximum_tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "qmargin"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30FecHistories.Second30FecHistory.Second30FecTimeLineInstances.Second30FecTimeLineInstance.Qmargin, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                        class EthernetHour24History(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: hour24pcs_histories
                            
                            	port current performance data
                            	**type**\:  :py:class:`Hour24pcsHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.Hour24pcsHistories>`
                            
                            .. attribute:: ethernet_hour24fec_histories
                            
                            	port current performance data
                            	**type**\:  :py:class:`EthernetHour24fecHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24fecHistories>`
                            
                            .. attribute:: ethernet_hour24_ether_histories
                            
                            	port current performance data
                            	**type**\:  :py:class:`EthernetHour24EtherHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History, self).__init__()

                                self.yang_name = "ethernet-hour24-history"
                                self.yang_parent_name = "ethernet-port-history"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("hour24pcs-histories", ("hour24pcs_histories", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.Hour24pcsHistories)), ("ethernet-hour24fec-histories", ("ethernet_hour24fec_histories", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24fecHistories)), ("ethernet-hour24-ether-histories", ("ethernet_hour24_ether_histories", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories))])
                                self._leafs = OrderedDict()

                                self.hour24pcs_histories = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.Hour24pcsHistories()
                                self.hour24pcs_histories.parent = self
                                self._children_name_map["hour24pcs_histories"] = "hour24pcs-histories"

                                self.ethernet_hour24fec_histories = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24fecHistories()
                                self.ethernet_hour24fec_histories.parent = self
                                self._children_name_map["ethernet_hour24fec_histories"] = "ethernet-hour24fec-histories"

                                self.ethernet_hour24_ether_histories = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories()
                                self.ethernet_hour24_ether_histories.parent = self
                                self._children_name_map["ethernet_hour24_ether_histories"] = "ethernet-hour24-ether-histories"
                                self._segment_path = lambda: "ethernet-hour24-history"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History, [], name, value)


                            class Hour24pcsHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: hour24pcs_history
                                
                                	port 24 hour ethernet performance data
                                	**type**\: list of  		 :py:class:`Hour24pcsHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.Hour24pcsHistories.Hour24pcsHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.Hour24pcsHistories, self).__init__()

                                    self.yang_name = "hour24pcs-histories"
                                    self.yang_parent_name = "ethernet-hour24-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("hour24pcs-history", ("hour24pcs_history", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.Hour24pcsHistories.Hour24pcsHistory))])
                                    self._leafs = OrderedDict()

                                    self.hour24pcs_history = YList(self)
                                    self._segment_path = lambda: "hour24pcs-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.Hour24pcsHistories, [], name, value)


                                class Hour24pcsHistory(Entity):
                                    """
                                    port 24 hour ethernet performance data
                                    
                                    .. attribute:: number  (key)
                                    
                                    	channel number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: hour24pcs_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`Hour24pcsTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.Hour24pcsHistories.Hour24pcsHistory.Hour24pcsTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.Hour24pcsHistories.Hour24pcsHistory, self).__init__()

                                        self.yang_name = "hour24pcs-history"
                                        self.yang_parent_name = "hour24pcs-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([("hour24pcs-time-line-instances", ("hour24pcs_time_line_instances", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.Hour24pcsHistories.Hour24pcsHistory.Hour24pcsTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ])
                                        self.number = None

                                        self.hour24pcs_time_line_instances = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.Hour24pcsHistories.Hour24pcsHistory.Hour24pcsTimeLineInstances()
                                        self.hour24pcs_time_line_instances.parent = self
                                        self._children_name_map["hour24pcs_time_line_instances"] = "hour24pcs-time-line-instances"
                                        self._segment_path = lambda: "hour24pcs-history" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.Hour24pcsHistories.Hour24pcsHistory, ['number'], name, value)


                                    class Hour24pcsTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: hour24pcs_time_line_instance
                                        
                                        	port 24\-hour ethernet performance data
                                        	**type**\: list of  		 :py:class:`Hour24pcsTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.Hour24pcsHistories.Hour24pcsHistory.Hour24pcsTimeLineInstances.Hour24pcsTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.Hour24pcsHistories.Hour24pcsHistory.Hour24pcsTimeLineInstances, self).__init__()

                                            self.yang_name = "hour24pcs-time-line-instances"
                                            self.yang_parent_name = "hour24pcs-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("hour24pcs-time-line-instance", ("hour24pcs_time_line_instance", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.Hour24pcsHistories.Hour24pcsHistory.Hour24pcsTimeLineInstances.Hour24pcsTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.hour24pcs_time_line_instance = YList(self)
                                            self._segment_path = lambda: "hour24pcs-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.Hour24pcsHistories.Hour24pcsHistory.Hour24pcsTimeLineInstances, [], name, value)


                                        class Hour24pcsTimeLineInstance(Entity):
                                            """
                                            port 24\-hour ethernet performance data
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: bip
                                            
                                            	Bip 
                                            	**type**\: list of  		 :py:class:`Bip <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.Hour24pcsHistories.Hour24pcsHistory.Hour24pcsTimeLineInstances.Hour24pcsTimeLineInstance.Bip>`
                                            
                                            .. attribute:: frm_err
                                            
                                            	Frm Err
                                            	**type**\: list of  		 :py:class:`FrmErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.Hour24pcsHistories.Hour24pcsHistory.Hour24pcsTimeLineInstances.Hour24pcsTimeLineInstance.FrmErr>`
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.Hour24pcsHistories.Hour24pcsHistory.Hour24pcsTimeLineInstances.Hour24pcsTimeLineInstance, self).__init__()

                                                self.yang_name = "hour24pcs-time-line-instance"
                                                self.yang_parent_name = "hour24pcs-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("bip", ("bip", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.Hour24pcsHistories.Hour24pcsHistory.Hour24pcsTimeLineInstances.Hour24pcsTimeLineInstance.Bip)), ("frm-err", ("frm_err", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.Hour24pcsHistories.Hour24pcsHistory.Hour24pcsTimeLineInstances.Hour24pcsTimeLineInstance.FrmErr))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear24_hr_time = None

                                                self.bip = YList(self)
                                                self.frm_err = YList(self)
                                                self._segment_path = lambda: "hour24pcs-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.Hour24pcsHistories.Hour24pcsHistory.Hour24pcsTimeLineInstances.Hour24pcsTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time'], name, value)


                                            class Bip(Entity):
                                                """
                                                Bip 
                                                
                                                .. attribute:: name
                                                
                                                	pcs param name
                                                	**type**\: str
                                                
                                                	**length:** 0..30
                                                
                                                .. attribute:: data
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.Hour24pcsHistories.Hour24pcsHistory.Hour24pcsTimeLineInstances.Hour24pcsTimeLineInstance.Bip, self).__init__()

                                                    self.yang_name = "bip"
                                                    self.yang_parent_name = "hour24pcs-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.name = None
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "bip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.Hour24pcsHistories.Hour24pcsHistory.Hour24pcsTimeLineInstances.Hour24pcsTimeLineInstance.Bip, ['name', 'data', 'threshold', 'tca_report'], name, value)


                                            class FrmErr(Entity):
                                                """
                                                Frm Err
                                                
                                                .. attribute:: name
                                                
                                                	pcs param name
                                                	**type**\: str
                                                
                                                	**length:** 0..30
                                                
                                                .. attribute:: data
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.Hour24pcsHistories.Hour24pcsHistory.Hour24pcsTimeLineInstances.Hour24pcsTimeLineInstance.FrmErr, self).__init__()

                                                    self.yang_name = "frm-err"
                                                    self.yang_parent_name = "hour24pcs-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.name = None
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "frm-err"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.Hour24pcsHistories.Hour24pcsHistory.Hour24pcsTimeLineInstances.Hour24pcsTimeLineInstance.FrmErr, ['name', 'data', 'threshold', 'tca_report'], name, value)


                            class EthernetHour24fecHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: ethernet_hour24fec_history
                                
                                	port 24 hour ethernet performance data
                                	**type**\: list of  		 :py:class:`EthernetHour24fecHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24fecHistories.EthernetHour24fecHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24fecHistories, self).__init__()

                                    self.yang_name = "ethernet-hour24fec-histories"
                                    self.yang_parent_name = "ethernet-hour24-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ethernet-hour24fec-history", ("ethernet_hour24fec_history", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24fecHistories.EthernetHour24fecHistory))])
                                    self._leafs = OrderedDict()

                                    self.ethernet_hour24fec_history = YList(self)
                                    self._segment_path = lambda: "ethernet-hour24fec-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24fecHistories, [], name, value)


                                class EthernetHour24fecHistory(Entity):
                                    """
                                    port 24 hour ethernet performance data
                                    
                                    .. attribute:: number  (key)
                                    
                                    	channel number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ethernet_hour24fec_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`EthernetHour24fecTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24fecHistories.EthernetHour24fecHistory.EthernetHour24fecTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24fecHistories.EthernetHour24fecHistory, self).__init__()

                                        self.yang_name = "ethernet-hour24fec-history"
                                        self.yang_parent_name = "ethernet-hour24fec-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([("ethernet-hour24fec-time-line-instances", ("ethernet_hour24fec_time_line_instances", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24fecHistories.EthernetHour24fecHistory.EthernetHour24fecTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ])
                                        self.number = None

                                        self.ethernet_hour24fec_time_line_instances = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24fecHistories.EthernetHour24fecHistory.EthernetHour24fecTimeLineInstances()
                                        self.ethernet_hour24fec_time_line_instances.parent = self
                                        self._children_name_map["ethernet_hour24fec_time_line_instances"] = "ethernet-hour24fec-time-line-instances"
                                        self._segment_path = lambda: "ethernet-hour24fec-history" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24fecHistories.EthernetHour24fecHistory, ['number'], name, value)


                                    class EthernetHour24fecTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: ethernet_hour24fec_time_line_instance
                                        
                                        	port 24\-hour ethernet performance data
                                        	**type**\: list of  		 :py:class:`EthernetHour24fecTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24fecHistories.EthernetHour24fecHistory.EthernetHour24fecTimeLineInstances.EthernetHour24fecTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24fecHistories.EthernetHour24fecHistory.EthernetHour24fecTimeLineInstances, self).__init__()

                                            self.yang_name = "ethernet-hour24fec-time-line-instances"
                                            self.yang_parent_name = "ethernet-hour24fec-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("ethernet-hour24fec-time-line-instance", ("ethernet_hour24fec_time_line_instance", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24fecHistories.EthernetHour24fecHistory.EthernetHour24fecTimeLineInstances.EthernetHour24fecTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.ethernet_hour24fec_time_line_instance = YList(self)
                                            self._segment_path = lambda: "ethernet-hour24fec-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24fecHistories.EthernetHour24fecHistory.EthernetHour24fecTimeLineInstances, [], name, value)


                                        class EthernetHour24fecTimeLineInstance(Entity):
                                            """
                                            port 24\-hour ethernet performance data
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ec_bits
                                            
                                            	EC BITS
                                            	**type**\:  :py:class:`EcBits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24fecHistories.EthernetHour24fecHistory.EthernetHour24fecTimeLineInstances.EthernetHour24fecTimeLineInstance.EcBits>`
                                            
                                            .. attribute:: uc_words
                                            
                                            	UC WORDS
                                            	**type**\:  :py:class:`UcWords <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24fecHistories.EthernetHour24fecHistory.EthernetHour24fecTimeLineInstances.EthernetHour24fecTimeLineInstance.UcWords>`
                                            
                                            .. attribute:: pre_fec_ber
                                            
                                            	Pre FEC BER
                                            	**type**\:  :py:class:`PreFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24fecHistories.EthernetHour24fecHistory.EthernetHour24fecTimeLineInstances.EthernetHour24fecTimeLineInstance.PreFecBer>`
                                            
                                            .. attribute:: post_fec_ber
                                            
                                            	Post FEC BER
                                            	**type**\:  :py:class:`PostFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24fecHistories.EthernetHour24fecHistory.EthernetHour24fecTimeLineInstances.EthernetHour24fecTimeLineInstance.PostFecBer>`
                                            
                                            .. attribute:: q
                                            
                                            	Q
                                            	**type**\:  :py:class:`Q <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24fecHistories.EthernetHour24fecHistory.EthernetHour24fecTimeLineInstances.EthernetHour24fecTimeLineInstance.Q>`
                                            
                                            .. attribute:: qmargin
                                            
                                            	Q Margin
                                            	**type**\:  :py:class:`Qmargin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24fecHistories.EthernetHour24fecHistory.EthernetHour24fecTimeLineInstances.EthernetHour24fecTimeLineInstance.Qmargin>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24fecHistories.EthernetHour24fecHistory.EthernetHour24fecTimeLineInstances.EthernetHour24fecTimeLineInstance, self).__init__()

                                                self.yang_name = "ethernet-hour24fec-time-line-instance"
                                                self.yang_parent_name = "ethernet-hour24fec-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("ec-bits", ("ec_bits", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24fecHistories.EthernetHour24fecHistory.EthernetHour24fecTimeLineInstances.EthernetHour24fecTimeLineInstance.EcBits)), ("uc-words", ("uc_words", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24fecHistories.EthernetHour24fecHistory.EthernetHour24fecTimeLineInstances.EthernetHour24fecTimeLineInstance.UcWords)), ("pre-fec-ber", ("pre_fec_ber", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24fecHistories.EthernetHour24fecHistory.EthernetHour24fecTimeLineInstances.EthernetHour24fecTimeLineInstance.PreFecBer)), ("post-fec-ber", ("post_fec_ber", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24fecHistories.EthernetHour24fecHistory.EthernetHour24fecTimeLineInstances.EthernetHour24fecTimeLineInstance.PostFecBer)), ("q", ("q", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24fecHistories.EthernetHour24fecHistory.EthernetHour24fecTimeLineInstances.EthernetHour24fecTimeLineInstance.Q)), ("qmargin", ("qmargin", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24fecHistories.EthernetHour24fecHistory.EthernetHour24fecTimeLineInstances.EthernetHour24fecTimeLineInstance.Qmargin))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                    ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear24_hr_time = None
                                                self.sec30_support = None

                                                self.ec_bits = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24fecHistories.EthernetHour24fecHistory.EthernetHour24fecTimeLineInstances.EthernetHour24fecTimeLineInstance.EcBits()
                                                self.ec_bits.parent = self
                                                self._children_name_map["ec_bits"] = "ec-bits"

                                                self.uc_words = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24fecHistories.EthernetHour24fecHistory.EthernetHour24fecTimeLineInstances.EthernetHour24fecTimeLineInstance.UcWords()
                                                self.uc_words.parent = self
                                                self._children_name_map["uc_words"] = "uc-words"

                                                self.pre_fec_ber = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24fecHistories.EthernetHour24fecHistory.EthernetHour24fecTimeLineInstances.EthernetHour24fecTimeLineInstance.PreFecBer()
                                                self.pre_fec_ber.parent = self
                                                self._children_name_map["pre_fec_ber"] = "pre-fec-ber"

                                                self.post_fec_ber = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24fecHistories.EthernetHour24fecHistory.EthernetHour24fecTimeLineInstances.EthernetHour24fecTimeLineInstance.PostFecBer()
                                                self.post_fec_ber.parent = self
                                                self._children_name_map["post_fec_ber"] = "post-fec-ber"

                                                self.q = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24fecHistories.EthernetHour24fecHistory.EthernetHour24fecTimeLineInstances.EthernetHour24fecTimeLineInstance.Q()
                                                self.q.parent = self
                                                self._children_name_map["q"] = "q"

                                                self.qmargin = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24fecHistories.EthernetHour24fecHistory.EthernetHour24fecTimeLineInstances.EthernetHour24fecTimeLineInstance.Qmargin()
                                                self.qmargin.parent = self
                                                self._children_name_map["qmargin"] = "qmargin"
                                                self._segment_path = lambda: "ethernet-hour24fec-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24fecHistories.EthernetHour24fecHistory.EthernetHour24fecTimeLineInstances.EthernetHour24fecTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                            class EcBits(Entity):
                                                """
                                                EC BITS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24fecHistories.EthernetHour24fecHistory.EthernetHour24fecTimeLineInstances.EthernetHour24fecTimeLineInstance.EcBits, self).__init__()

                                                    self.yang_name = "ec-bits"
                                                    self.yang_parent_name = "ethernet-hour24fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ec-bits"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24fecHistories.EthernetHour24fecHistory.EthernetHour24fecTimeLineInstances.EthernetHour24fecTimeLineInstance.EcBits, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class UcWords(Entity):
                                                """
                                                UC WORDS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24fecHistories.EthernetHour24fecHistory.EthernetHour24fecTimeLineInstances.EthernetHour24fecTimeLineInstance.UcWords, self).__init__()

                                                    self.yang_name = "uc-words"
                                                    self.yang_parent_name = "ethernet-hour24fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "uc-words"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24fecHistories.EthernetHour24fecHistory.EthernetHour24fecTimeLineInstances.EthernetHour24fecTimeLineInstance.UcWords, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class PreFecBer(Entity):
                                                """
                                                Pre FEC BER
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24fecHistories.EthernetHour24fecHistory.EthernetHour24fecTimeLineInstances.EthernetHour24fecTimeLineInstance.PreFecBer, self).__init__()

                                                    self.yang_name = "pre-fec-ber"
                                                    self.yang_parent_name = "ethernet-hour24fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.maximum_tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "pre-fec-ber"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24fecHistories.EthernetHour24fecHistory.EthernetHour24fecTimeLineInstances.EthernetHour24fecTimeLineInstance.PreFecBer, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                            class PostFecBer(Entity):
                                                """
                                                Post FEC BER
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24fecHistories.EthernetHour24fecHistory.EthernetHour24fecTimeLineInstances.EthernetHour24fecTimeLineInstance.PostFecBer, self).__init__()

                                                    self.yang_name = "post-fec-ber"
                                                    self.yang_parent_name = "ethernet-hour24fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.maximum_tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "post-fec-ber"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24fecHistories.EthernetHour24fecHistory.EthernetHour24fecTimeLineInstances.EthernetHour24fecTimeLineInstance.PostFecBer, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                            class Q(Entity):
                                                """
                                                Q
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24fecHistories.EthernetHour24fecHistory.EthernetHour24fecTimeLineInstances.EthernetHour24fecTimeLineInstance.Q, self).__init__()

                                                    self.yang_name = "q"
                                                    self.yang_parent_name = "ethernet-hour24fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.maximum_tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "q"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24fecHistories.EthernetHour24fecHistory.EthernetHour24fecTimeLineInstances.EthernetHour24fecTimeLineInstance.Q, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                            class Qmargin(Entity):
                                                """
                                                Q Margin
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24fecHistories.EthernetHour24fecHistory.EthernetHour24fecTimeLineInstances.EthernetHour24fecTimeLineInstance.Qmargin, self).__init__()

                                                    self.yang_name = "qmargin"
                                                    self.yang_parent_name = "ethernet-hour24fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.maximum_tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "qmargin"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24fecHistories.EthernetHour24fecHistory.EthernetHour24fecTimeLineInstances.EthernetHour24fecTimeLineInstance.Qmargin, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                            class EthernetHour24EtherHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: ethernet_hour24_ether_history
                                
                                	port 24 hour ethernet performance data
                                	**type**\: list of  		 :py:class:`EthernetHour24EtherHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories, self).__init__()

                                    self.yang_name = "ethernet-hour24-ether-histories"
                                    self.yang_parent_name = "ethernet-hour24-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ethernet-hour24-ether-history", ("ethernet_hour24_ether_history", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory))])
                                    self._leafs = OrderedDict()

                                    self.ethernet_hour24_ether_history = YList(self)
                                    self._segment_path = lambda: "ethernet-hour24-ether-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories, [], name, value)


                                class EthernetHour24EtherHistory(Entity):
                                    """
                                    port 24 hour ethernet performance data
                                    
                                    .. attribute:: number  (key)
                                    
                                    	channel number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ethernet_hour24_ether_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`EthernetHour24EtherTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory, self).__init__()

                                        self.yang_name = "ethernet-hour24-ether-history"
                                        self.yang_parent_name = "ethernet-hour24-ether-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([("ethernet-hour24-ether-time-line-instances", ("ethernet_hour24_ether_time_line_instances", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ])
                                        self.number = None

                                        self.ethernet_hour24_ether_time_line_instances = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances()
                                        self.ethernet_hour24_ether_time_line_instances.parent = self
                                        self._children_name_map["ethernet_hour24_ether_time_line_instances"] = "ethernet-hour24-ether-time-line-instances"
                                        self._segment_path = lambda: "ethernet-hour24-ether-history" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory, ['number'], name, value)


                                    class EthernetHour24EtherTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: ethernet_hour24_ether_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of  		 :py:class:`EthernetHour24EtherTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances, self).__init__()

                                            self.yang_name = "ethernet-hour24-ether-time-line-instances"
                                            self.yang_parent_name = "ethernet-hour24-ether-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("ethernet-hour24-ether-time-line-instance", ("ethernet_hour24_ether_time_line_instance", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.ethernet_hour24_ether_time_line_instance = YList(self)
                                            self._segment_path = lambda: "ethernet-hour24-ether-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances, [], name, value)


                                        class EthernetHour24EtherTimeLineInstance(Entity):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rx_pkt
                                            
                                            	RX PKT
                                            	**type**\:  :py:class:`RxPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.RxPkt>`
                                            
                                            .. attribute:: stat_pkt
                                            
                                            	STAT PKT
                                            	**type**\:  :py:class:`StatPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.StatPkt>`
                                            
                                            .. attribute:: octet_stat
                                            
                                            	OCTET STAT
                                            	**type**\:  :py:class:`OctetStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OctetStat>`
                                            
                                            .. attribute:: oversize_pkt_stat
                                            
                                            	OVERSIZE PKT
                                            	**type**\:  :py:class:`OversizePktStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OversizePktStat>`
                                            
                                            .. attribute:: fcs_errors_stat
                                            
                                            	FCS ERR
                                            	**type**\:  :py:class:`FcsErrorsStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.FcsErrorsStat>`
                                            
                                            .. attribute:: long_frames_stat
                                            
                                            	LONG FRAMES
                                            	**type**\:  :py:class:`LongFramesStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.LongFramesStat>`
                                            
                                            .. attribute:: jabber_stat
                                            
                                            	JABBER STATS
                                            	**type**\:  :py:class:`JabberStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.JabberStat>`
                                            
                                            .. attribute:: ether64_octets
                                            
                                            	SIXTY FOUR OCTET
                                            	**type**\:  :py:class:`Ether64Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether64Octets>`
                                            
                                            .. attribute:: ether65127_octet
                                            
                                            	OCTET
                                            	**type**\:  :py:class:`Ether65127Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether65127Octet>`
                                            
                                            .. attribute:: ether128255_octet
                                            
                                            	TFF OCTET
                                            	**type**\:  :py:class:`Ether128255Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether128255Octet>`
                                            
                                            .. attribute:: ether256511_octet
                                            
                                            	FOO OCTET
                                            	**type**\:  :py:class:`Ether256511Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether256511Octet>`
                                            
                                            .. attribute:: ether5121023_octet
                                            
                                            	OZTT OCTET
                                            	**type**\:  :py:class:`Ether5121023Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether5121023Octet>`
                                            
                                            .. attribute:: ether10241518_octet
                                            
                                            	OFO OCTET
                                            	**type**\:  :py:class:`Ether10241518Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether10241518Octet>`
                                            
                                            .. attribute:: in_ucast_pkt
                                            
                                            	IN UCAST
                                            	**type**\:  :py:class:`InUcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InUcastPkt>`
                                            
                                            .. attribute:: in_mcast_pkt
                                            
                                            	IN MCAST
                                            	**type**\:  :py:class:`InMcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InMcastPkt>`
                                            
                                            .. attribute:: in_bcast_pkt
                                            
                                            	IN BCAST
                                            	**type**\:  :py:class:`InBcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InBcastPkt>`
                                            
                                            .. attribute:: out_ucast_pkt
                                            
                                            	OUT UCAST
                                            	**type**\:  :py:class:`OutUcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutUcastPkt>`
                                            
                                            .. attribute:: out_bcast_pkt
                                            
                                            	OUT BCAST
                                            	**type**\:  :py:class:`OutBcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutBcastPkt>`
                                            
                                            .. attribute:: out_mcast_pkt
                                            
                                            	OUT MCAST
                                            	**type**\:  :py:class:`OutMcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutMcastPkt>`
                                            
                                            .. attribute:: tx_pkt
                                            
                                            	TX PKT
                                            	**type**\:  :py:class:`TxPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxPkt>`
                                            
                                            .. attribute:: if_in_errors
                                            
                                            	IFIN ERRORS
                                            	**type**\:  :py:class:`IfInErrors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.IfInErrors>`
                                            
                                            .. attribute:: if_in_octets
                                            
                                            	IFIN OCTETS
                                            	**type**\:  :py:class:`IfInOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.IfInOctets>`
                                            
                                            .. attribute:: ether_stat_multicast_pkt
                                            
                                            	ETHER STAT MULTICAST PKT
                                            	**type**\:  :py:class:`EtherStatMulticastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.EtherStatMulticastPkt>`
                                            
                                            .. attribute:: ether_stat_broadcast_pkt
                                            
                                            	ETHER STAT BROADCAST PKT
                                            	**type**\:  :py:class:`EtherStatBroadcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.EtherStatBroadcastPkt>`
                                            
                                            .. attribute:: ether_stat_undersized_pkt
                                            
                                            	ETHER STAT UNDERSIZED PKT
                                            	**type**\:  :py:class:`EtherStatUndersizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.EtherStatUndersizedPkt>`
                                            
                                            .. attribute:: out_octets
                                            
                                            	OUT OCTET
                                            	**type**\:  :py:class:`OutOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutOctets>`
                                            
                                            .. attribute:: in_pause_frame
                                            
                                            	INPUT PAUSE FRAME
                                            	**type**\:  :py:class:`InPauseFrame <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPauseFrame>`
                                            
                                            .. attribute:: in_good_bytes
                                            
                                            	INPUT GOOD BYTES
                                            	**type**\:  :py:class:`InGoodBytes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InGoodBytes>`
                                            
                                            .. attribute:: in8021q_frames
                                            
                                            	INPUT 802 1Q FRAMES
                                            	**type**\:  :py:class:`In8021qFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.In8021qFrames>`
                                            
                                            .. attribute:: in_pkts1519_max_octets
                                            
                                            	INPUT PKTS 1519MAX OCTETS
                                            	**type**\:  :py:class:`InPkts1519MaxOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts1519MaxOctets>`
                                            
                                            .. attribute:: in_good_pkts
                                            
                                            	INPUT GOOD PKTS
                                            	**type**\:  :py:class:`InGoodPkts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InGoodPkts>`
                                            
                                            .. attribute:: in_drop_overrun
                                            
                                            	INPUT DROP OVERRUN
                                            	**type**\:  :py:class:`InDropOverrun <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropOverrun>`
                                            
                                            .. attribute:: in_drop_abort
                                            
                                            	INPUT DROP ABORT
                                            	**type**\:  :py:class:`InDropAbort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropAbort>`
                                            
                                            .. attribute:: in_drop_invalid_vlan
                                            
                                            	INPUT DROP INVALID VLAN
                                            	**type**\:  :py:class:`InDropInvalidVlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropInvalidVlan>`
                                            
                                            .. attribute:: in_drop_invalid_dmac
                                            
                                            	INPUT DROP INVALID DMAC
                                            	**type**\:  :py:class:`InDropInvalidDmac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropInvalidDmac>`
                                            
                                            .. attribute:: in_drop_invalid_encap
                                            
                                            	INPUT DROP INVALID ENCAP
                                            	**type**\:  :py:class:`InDropInvalidEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropInvalidEncap>`
                                            
                                            .. attribute:: in_drop_other
                                            
                                            	INPUT DROP OTHER
                                            	**type**\:  :py:class:`InDropOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropOther>`
                                            
                                            .. attribute:: in_mib_giant
                                            
                                            	INPUT MIB GIANT
                                            	**type**\:  :py:class:`InMibGiant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InMibGiant>`
                                            
                                            .. attribute:: in_mib_jabber
                                            
                                            	INPUT MIB JABBER
                                            	**type**\:  :py:class:`InMibJabber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InMibJabber>`
                                            
                                            .. attribute:: in_mibcrc
                                            
                                            	IN MIB CRC
                                            	**type**\:  :py:class:`InMibcrc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InMibcrc>`
                                            
                                            .. attribute:: in_error_collisions
                                            
                                            	IN ERROR COLLISIONS
                                            	**type**\:  :py:class:`InErrorCollisions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorCollisions>`
                                            
                                            .. attribute:: in_error_symbol
                                            
                                            	IN ERROR SYMBOL
                                            	**type**\:  :py:class:`InErrorSymbol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorSymbol>`
                                            
                                            .. attribute:: out_good_bytes
                                            
                                            	OUT GOOD BYTES
                                            	**type**\:  :py:class:`OutGoodBytes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutGoodBytes>`
                                            
                                            .. attribute:: out8021q_frames
                                            
                                            	OUT 802 1Q FRAMES
                                            	**type**\:  :py:class:`Out8021qFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Out8021qFrames>`
                                            
                                            .. attribute:: out_pause_frames
                                            
                                            	OUT PAUSE FRAMES
                                            	**type**\:  :py:class:`OutPauseFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPauseFrames>`
                                            
                                            .. attribute:: out_pkts1519_max_octets
                                            
                                            	OUT PKTS 1519 MAX OCTETS
                                            	**type**\:  :py:class:`OutPkts1519MaxOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts1519MaxOctets>`
                                            
                                            .. attribute:: out_good_pkts
                                            
                                            	OUT GOOD PKTS
                                            	**type**\:  :py:class:`OutGoodPkts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutGoodPkts>`
                                            
                                            .. attribute:: out_drop_underrun
                                            
                                            	OUT DROP UNDERRUN
                                            	**type**\:  :py:class:`OutDropUnderrun <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutDropUnderrun>`
                                            
                                            .. attribute:: out_drop_abort
                                            
                                            	OUT DROP ABORT
                                            	**type**\:  :py:class:`OutDropAbort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutDropAbort>`
                                            
                                            .. attribute:: out_drop_other
                                            
                                            	OUT DROP OTHER
                                            	**type**\:  :py:class:`OutDropOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutDropOther>`
                                            
                                            .. attribute:: out_error_other
                                            
                                            	OUT ERROR OTHER
                                            	**type**\:  :py:class:`OutErrorOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutErrorOther>`
                                            
                                            .. attribute:: in_error_giant
                                            
                                            	IN ERROR GIANT
                                            	**type**\:  :py:class:`InErrorGiant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorGiant>`
                                            
                                            .. attribute:: in_error_runt
                                            
                                            	IN ERROR RUNT
                                            	**type**\:  :py:class:`InErrorRunt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorRunt>`
                                            
                                            .. attribute:: in_error_jabbers
                                            
                                            	IN ERROR JABBERS
                                            	**type**\:  :py:class:`InErrorJabbers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorJabbers>`
                                            
                                            .. attribute:: in_error_fragments
                                            
                                            	IN ERROR FRAGMENTS
                                            	**type**\:  :py:class:`InErrorFragments <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorFragments>`
                                            
                                            .. attribute:: in_error_other
                                            
                                            	IN ERROR OTHER
                                            	**type**\:  :py:class:`InErrorOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorOther>`
                                            
                                            .. attribute:: in_pkt64_octet
                                            
                                            	IN PKT 64 OCTET
                                            	**type**\:  :py:class:`InPkt64Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkt64Octet>`
                                            
                                            .. attribute:: in_pkts65_to127_octets
                                            
                                            	IN PKTS 65 127OCTETS
                                            	**type**\:  :py:class:`InPkts65To127Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts65To127Octets>`
                                            
                                            .. attribute:: in_pkts128_to255_octets
                                            
                                            	IN PKTS 128 255 OCTETS
                                            	**type**\:  :py:class:`InPkts128To255Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts128To255Octets>`
                                            
                                            .. attribute:: in_pkts256_to511_octets
                                            
                                            	IN PKTS 256 511 OCTETS
                                            	**type**\:  :py:class:`InPkts256To511Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts256To511Octets>`
                                            
                                            .. attribute:: in_pkts512_to1023_octets
                                            
                                            	IN PKTS 512 1023 OCTETS
                                            	**type**\:  :py:class:`InPkts512To1023Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts512To1023Octets>`
                                            
                                            .. attribute:: in_pkts1024_to1518_octets
                                            
                                            	IN PKTS 1024 1518 OCTETS
                                            	**type**\:  :py:class:`InPkts1024To1518Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts1024To1518Octets>`
                                            
                                            .. attribute:: outpkt64octet
                                            
                                            	OUT PKT 64 OCTET
                                            	**type**\:  :py:class:`Outpkt64octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Outpkt64octet>`
                                            
                                            .. attribute:: out_pkts65127_octets
                                            
                                            	OUT PKTS 65 127OCTETS
                                            	**type**\:  :py:class:`OutPkts65127Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts65127Octets>`
                                            
                                            .. attribute:: out_pkts128255_octets
                                            
                                            	OUT PKTS 128 255 OCTETS
                                            	**type**\:  :py:class:`OutPkts128255Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts128255Octets>`
                                            
                                            .. attribute:: out_pkts256511_octets
                                            
                                            	OUT PKTS 256 511 OCTETS
                                            	**type**\:  :py:class:`OutPkts256511Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts256511Octets>`
                                            
                                            .. attribute:: out_pkts5121023_octets
                                            
                                            	OUT PKTS 512 1023 OCTETS
                                            	**type**\:  :py:class:`OutPkts5121023Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts5121023Octets>`
                                            
                                            .. attribute:: out_pkts10241518_octets
                                            
                                            	OUT PKTS 1024 1518 OCTETS
                                            	**type**\:  :py:class:`OutPkts10241518Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts10241518Octets>`
                                            
                                            .. attribute:: rx_util
                                            
                                            	Rx Utilization in Percent
                                            	**type**\:  :py:class:`RxUtil <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.RxUtil>`
                                            
                                            .. attribute:: tx_util
                                            
                                            	Tx Utilization in Percent
                                            	**type**\:  :py:class:`TxUtil <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxUtil>`
                                            
                                            .. attribute:: tx_undersized_pkt
                                            
                                            	TX Undersized Pkt
                                            	**type**\:  :py:class:`TxUndersizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxUndersizedPkt>`
                                            
                                            .. attribute:: tx_oversized_pkt
                                            
                                            	TX Oversized Pkt
                                            	**type**\:  :py:class:`TxOversizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxOversizedPkt>`
                                            
                                            .. attribute:: tx_fragments
                                            
                                            	TX Fragments
                                            	**type**\:  :py:class:`TxFragments <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxFragments>`
                                            
                                            .. attribute:: tx_jabber
                                            
                                            	TX Jabber
                                            	**type**\:  :py:class:`TxJabber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxJabber>`
                                            
                                            .. attribute:: tx_bad_fcs
                                            
                                            	TX Bad Fcs
                                            	**type**\:  :py:class:`TxBadFcs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxBadFcs>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance, self).__init__()

                                                self.yang_name = "ethernet-hour24-ether-time-line-instance"
                                                self.yang_parent_name = "ethernet-hour24-ether-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("rx-pkt", ("rx_pkt", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.RxPkt)), ("stat-pkt", ("stat_pkt", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.StatPkt)), ("octet-stat", ("octet_stat", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OctetStat)), ("oversize-pkt-stat", ("oversize_pkt_stat", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OversizePktStat)), ("fcs-errors-stat", ("fcs_errors_stat", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.FcsErrorsStat)), ("long-frames-stat", ("long_frames_stat", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.LongFramesStat)), ("jabber-stat", ("jabber_stat", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.JabberStat)), ("ether64-octets", ("ether64_octets", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether64Octets)), ("ether65127-octet", ("ether65127_octet", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether65127Octet)), ("ether128255-octet", ("ether128255_octet", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether128255Octet)), ("ether256511-octet", ("ether256511_octet", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether256511Octet)), ("ether5121023-octet", ("ether5121023_octet", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether5121023Octet)), ("ether10241518-octet", ("ether10241518_octet", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether10241518Octet)), ("in-ucast-pkt", ("in_ucast_pkt", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InUcastPkt)), ("in-mcast-pkt", ("in_mcast_pkt", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InMcastPkt)), ("in-bcast-pkt", ("in_bcast_pkt", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InBcastPkt)), ("out-ucast-pkt", ("out_ucast_pkt", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutUcastPkt)), ("out-bcast-pkt", ("out_bcast_pkt", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutBcastPkt)), ("out-mcast-pkt", ("out_mcast_pkt", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutMcastPkt)), ("tx-pkt", ("tx_pkt", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxPkt)), ("if-in-errors", ("if_in_errors", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.IfInErrors)), ("if-in-octets", ("if_in_octets", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.IfInOctets)), ("ether-stat-multicast-pkt", ("ether_stat_multicast_pkt", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.EtherStatMulticastPkt)), ("ether-stat-broadcast-pkt", ("ether_stat_broadcast_pkt", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.EtherStatBroadcastPkt)), ("ether-stat-undersized-pkt", ("ether_stat_undersized_pkt", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.EtherStatUndersizedPkt)), ("out-octets", ("out_octets", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutOctets)), ("in-pause-frame", ("in_pause_frame", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPauseFrame)), ("in-good-bytes", ("in_good_bytes", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InGoodBytes)), ("in8021q-frames", ("in8021q_frames", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.In8021qFrames)), ("in-pkts1519-max-octets", ("in_pkts1519_max_octets", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts1519MaxOctets)), ("in-good-pkts", ("in_good_pkts", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InGoodPkts)), ("in-drop-overrun", ("in_drop_overrun", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropOverrun)), ("in-drop-abort", ("in_drop_abort", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropAbort)), ("in-drop-invalid-vlan", ("in_drop_invalid_vlan", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropInvalidVlan)), ("in-drop-invalid-dmac", ("in_drop_invalid_dmac", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropInvalidDmac)), ("in-drop-invalid-encap", ("in_drop_invalid_encap", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropInvalidEncap)), ("in-drop-other", ("in_drop_other", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropOther)), ("in-mib-giant", ("in_mib_giant", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InMibGiant)), ("in-mib-jabber", ("in_mib_jabber", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InMibJabber)), ("in-mibcrc", ("in_mibcrc", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InMibcrc)), ("in-error-collisions", ("in_error_collisions", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorCollisions)), ("in-error-symbol", ("in_error_symbol", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorSymbol)), ("out-good-bytes", ("out_good_bytes", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutGoodBytes)), ("out8021q-frames", ("out8021q_frames", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Out8021qFrames)), ("out-pause-frames", ("out_pause_frames", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPauseFrames)), ("out-pkts1519-max-octets", ("out_pkts1519_max_octets", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts1519MaxOctets)), ("out-good-pkts", ("out_good_pkts", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutGoodPkts)), ("out-drop-underrun", ("out_drop_underrun", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutDropUnderrun)), ("out-drop-abort", ("out_drop_abort", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutDropAbort)), ("out-drop-other", ("out_drop_other", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutDropOther)), ("out-error-other", ("out_error_other", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutErrorOther)), ("in-error-giant", ("in_error_giant", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorGiant)), ("in-error-runt", ("in_error_runt", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorRunt)), ("in-error-jabbers", ("in_error_jabbers", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorJabbers)), ("in-error-fragments", ("in_error_fragments", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorFragments)), ("in-error-other", ("in_error_other", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorOther)), ("in-pkt64-octet", ("in_pkt64_octet", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkt64Octet)), ("in-pkts65-to127-octets", ("in_pkts65_to127_octets", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts65To127Octets)), ("in-pkts128-to255-octets", ("in_pkts128_to255_octets", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts128To255Octets)), ("in-pkts256-to511-octets", ("in_pkts256_to511_octets", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts256To511Octets)), ("in-pkts512-to1023-octets", ("in_pkts512_to1023_octets", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts512To1023Octets)), ("in-pkts1024-to1518-octets", ("in_pkts1024_to1518_octets", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts1024To1518Octets)), ("outpkt64octet", ("outpkt64octet", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Outpkt64octet)), ("out-pkts65127-octets", ("out_pkts65127_octets", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts65127Octets)), ("out-pkts128255-octets", ("out_pkts128255_octets", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts128255Octets)), ("out-pkts256511-octets", ("out_pkts256511_octets", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts256511Octets)), ("out-pkts5121023-octets", ("out_pkts5121023_octets", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts5121023Octets)), ("out-pkts10241518-octets", ("out_pkts10241518_octets", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts10241518Octets)), ("rx-util", ("rx_util", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.RxUtil)), ("tx-util", ("tx_util", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxUtil)), ("tx-undersized-pkt", ("tx_undersized_pkt", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxUndersizedPkt)), ("tx-oversized-pkt", ("tx_oversized_pkt", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxOversizedPkt)), ("tx-fragments", ("tx_fragments", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxFragments)), ("tx-jabber", ("tx_jabber", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxJabber)), ("tx-bad-fcs", ("tx_bad_fcs", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxBadFcs))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                    ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None
                                                self.sec30_support = None

                                                self.rx_pkt = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.RxPkt()
                                                self.rx_pkt.parent = self
                                                self._children_name_map["rx_pkt"] = "rx-pkt"

                                                self.stat_pkt = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.StatPkt()
                                                self.stat_pkt.parent = self
                                                self._children_name_map["stat_pkt"] = "stat-pkt"

                                                self.octet_stat = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OctetStat()
                                                self.octet_stat.parent = self
                                                self._children_name_map["octet_stat"] = "octet-stat"

                                                self.oversize_pkt_stat = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OversizePktStat()
                                                self.oversize_pkt_stat.parent = self
                                                self._children_name_map["oversize_pkt_stat"] = "oversize-pkt-stat"

                                                self.fcs_errors_stat = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.FcsErrorsStat()
                                                self.fcs_errors_stat.parent = self
                                                self._children_name_map["fcs_errors_stat"] = "fcs-errors-stat"

                                                self.long_frames_stat = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.LongFramesStat()
                                                self.long_frames_stat.parent = self
                                                self._children_name_map["long_frames_stat"] = "long-frames-stat"

                                                self.jabber_stat = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.JabberStat()
                                                self.jabber_stat.parent = self
                                                self._children_name_map["jabber_stat"] = "jabber-stat"

                                                self.ether64_octets = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether64Octets()
                                                self.ether64_octets.parent = self
                                                self._children_name_map["ether64_octets"] = "ether64-octets"

                                                self.ether65127_octet = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether65127Octet()
                                                self.ether65127_octet.parent = self
                                                self._children_name_map["ether65127_octet"] = "ether65127-octet"

                                                self.ether128255_octet = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether128255Octet()
                                                self.ether128255_octet.parent = self
                                                self._children_name_map["ether128255_octet"] = "ether128255-octet"

                                                self.ether256511_octet = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether256511Octet()
                                                self.ether256511_octet.parent = self
                                                self._children_name_map["ether256511_octet"] = "ether256511-octet"

                                                self.ether5121023_octet = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether5121023Octet()
                                                self.ether5121023_octet.parent = self
                                                self._children_name_map["ether5121023_octet"] = "ether5121023-octet"

                                                self.ether10241518_octet = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether10241518Octet()
                                                self.ether10241518_octet.parent = self
                                                self._children_name_map["ether10241518_octet"] = "ether10241518-octet"

                                                self.in_ucast_pkt = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InUcastPkt()
                                                self.in_ucast_pkt.parent = self
                                                self._children_name_map["in_ucast_pkt"] = "in-ucast-pkt"

                                                self.in_mcast_pkt = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InMcastPkt()
                                                self.in_mcast_pkt.parent = self
                                                self._children_name_map["in_mcast_pkt"] = "in-mcast-pkt"

                                                self.in_bcast_pkt = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InBcastPkt()
                                                self.in_bcast_pkt.parent = self
                                                self._children_name_map["in_bcast_pkt"] = "in-bcast-pkt"

                                                self.out_ucast_pkt = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutUcastPkt()
                                                self.out_ucast_pkt.parent = self
                                                self._children_name_map["out_ucast_pkt"] = "out-ucast-pkt"

                                                self.out_bcast_pkt = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutBcastPkt()
                                                self.out_bcast_pkt.parent = self
                                                self._children_name_map["out_bcast_pkt"] = "out-bcast-pkt"

                                                self.out_mcast_pkt = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutMcastPkt()
                                                self.out_mcast_pkt.parent = self
                                                self._children_name_map["out_mcast_pkt"] = "out-mcast-pkt"

                                                self.tx_pkt = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxPkt()
                                                self.tx_pkt.parent = self
                                                self._children_name_map["tx_pkt"] = "tx-pkt"

                                                self.if_in_errors = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.IfInErrors()
                                                self.if_in_errors.parent = self
                                                self._children_name_map["if_in_errors"] = "if-in-errors"

                                                self.if_in_octets = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.IfInOctets()
                                                self.if_in_octets.parent = self
                                                self._children_name_map["if_in_octets"] = "if-in-octets"

                                                self.ether_stat_multicast_pkt = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.EtherStatMulticastPkt()
                                                self.ether_stat_multicast_pkt.parent = self
                                                self._children_name_map["ether_stat_multicast_pkt"] = "ether-stat-multicast-pkt"

                                                self.ether_stat_broadcast_pkt = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.EtherStatBroadcastPkt()
                                                self.ether_stat_broadcast_pkt.parent = self
                                                self._children_name_map["ether_stat_broadcast_pkt"] = "ether-stat-broadcast-pkt"

                                                self.ether_stat_undersized_pkt = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.EtherStatUndersizedPkt()
                                                self.ether_stat_undersized_pkt.parent = self
                                                self._children_name_map["ether_stat_undersized_pkt"] = "ether-stat-undersized-pkt"

                                                self.out_octets = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutOctets()
                                                self.out_octets.parent = self
                                                self._children_name_map["out_octets"] = "out-octets"

                                                self.in_pause_frame = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPauseFrame()
                                                self.in_pause_frame.parent = self
                                                self._children_name_map["in_pause_frame"] = "in-pause-frame"

                                                self.in_good_bytes = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InGoodBytes()
                                                self.in_good_bytes.parent = self
                                                self._children_name_map["in_good_bytes"] = "in-good-bytes"

                                                self.in8021q_frames = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.In8021qFrames()
                                                self.in8021q_frames.parent = self
                                                self._children_name_map["in8021q_frames"] = "in8021q-frames"

                                                self.in_pkts1519_max_octets = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts1519MaxOctets()
                                                self.in_pkts1519_max_octets.parent = self
                                                self._children_name_map["in_pkts1519_max_octets"] = "in-pkts1519-max-octets"

                                                self.in_good_pkts = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InGoodPkts()
                                                self.in_good_pkts.parent = self
                                                self._children_name_map["in_good_pkts"] = "in-good-pkts"

                                                self.in_drop_overrun = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropOverrun()
                                                self.in_drop_overrun.parent = self
                                                self._children_name_map["in_drop_overrun"] = "in-drop-overrun"

                                                self.in_drop_abort = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropAbort()
                                                self.in_drop_abort.parent = self
                                                self._children_name_map["in_drop_abort"] = "in-drop-abort"

                                                self.in_drop_invalid_vlan = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropInvalidVlan()
                                                self.in_drop_invalid_vlan.parent = self
                                                self._children_name_map["in_drop_invalid_vlan"] = "in-drop-invalid-vlan"

                                                self.in_drop_invalid_dmac = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropInvalidDmac()
                                                self.in_drop_invalid_dmac.parent = self
                                                self._children_name_map["in_drop_invalid_dmac"] = "in-drop-invalid-dmac"

                                                self.in_drop_invalid_encap = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropInvalidEncap()
                                                self.in_drop_invalid_encap.parent = self
                                                self._children_name_map["in_drop_invalid_encap"] = "in-drop-invalid-encap"

                                                self.in_drop_other = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropOther()
                                                self.in_drop_other.parent = self
                                                self._children_name_map["in_drop_other"] = "in-drop-other"

                                                self.in_mib_giant = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InMibGiant()
                                                self.in_mib_giant.parent = self
                                                self._children_name_map["in_mib_giant"] = "in-mib-giant"

                                                self.in_mib_jabber = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InMibJabber()
                                                self.in_mib_jabber.parent = self
                                                self._children_name_map["in_mib_jabber"] = "in-mib-jabber"

                                                self.in_mibcrc = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InMibcrc()
                                                self.in_mibcrc.parent = self
                                                self._children_name_map["in_mibcrc"] = "in-mibcrc"

                                                self.in_error_collisions = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorCollisions()
                                                self.in_error_collisions.parent = self
                                                self._children_name_map["in_error_collisions"] = "in-error-collisions"

                                                self.in_error_symbol = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorSymbol()
                                                self.in_error_symbol.parent = self
                                                self._children_name_map["in_error_symbol"] = "in-error-symbol"

                                                self.out_good_bytes = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutGoodBytes()
                                                self.out_good_bytes.parent = self
                                                self._children_name_map["out_good_bytes"] = "out-good-bytes"

                                                self.out8021q_frames = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Out8021qFrames()
                                                self.out8021q_frames.parent = self
                                                self._children_name_map["out8021q_frames"] = "out8021q-frames"

                                                self.out_pause_frames = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPauseFrames()
                                                self.out_pause_frames.parent = self
                                                self._children_name_map["out_pause_frames"] = "out-pause-frames"

                                                self.out_pkts1519_max_octets = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts1519MaxOctets()
                                                self.out_pkts1519_max_octets.parent = self
                                                self._children_name_map["out_pkts1519_max_octets"] = "out-pkts1519-max-octets"

                                                self.out_good_pkts = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutGoodPkts()
                                                self.out_good_pkts.parent = self
                                                self._children_name_map["out_good_pkts"] = "out-good-pkts"

                                                self.out_drop_underrun = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutDropUnderrun()
                                                self.out_drop_underrun.parent = self
                                                self._children_name_map["out_drop_underrun"] = "out-drop-underrun"

                                                self.out_drop_abort = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutDropAbort()
                                                self.out_drop_abort.parent = self
                                                self._children_name_map["out_drop_abort"] = "out-drop-abort"

                                                self.out_drop_other = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutDropOther()
                                                self.out_drop_other.parent = self
                                                self._children_name_map["out_drop_other"] = "out-drop-other"

                                                self.out_error_other = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutErrorOther()
                                                self.out_error_other.parent = self
                                                self._children_name_map["out_error_other"] = "out-error-other"

                                                self.in_error_giant = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorGiant()
                                                self.in_error_giant.parent = self
                                                self._children_name_map["in_error_giant"] = "in-error-giant"

                                                self.in_error_runt = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorRunt()
                                                self.in_error_runt.parent = self
                                                self._children_name_map["in_error_runt"] = "in-error-runt"

                                                self.in_error_jabbers = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorJabbers()
                                                self.in_error_jabbers.parent = self
                                                self._children_name_map["in_error_jabbers"] = "in-error-jabbers"

                                                self.in_error_fragments = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorFragments()
                                                self.in_error_fragments.parent = self
                                                self._children_name_map["in_error_fragments"] = "in-error-fragments"

                                                self.in_error_other = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorOther()
                                                self.in_error_other.parent = self
                                                self._children_name_map["in_error_other"] = "in-error-other"

                                                self.in_pkt64_octet = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkt64Octet()
                                                self.in_pkt64_octet.parent = self
                                                self._children_name_map["in_pkt64_octet"] = "in-pkt64-octet"

                                                self.in_pkts65_to127_octets = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts65To127Octets()
                                                self.in_pkts65_to127_octets.parent = self
                                                self._children_name_map["in_pkts65_to127_octets"] = "in-pkts65-to127-octets"

                                                self.in_pkts128_to255_octets = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts128To255Octets()
                                                self.in_pkts128_to255_octets.parent = self
                                                self._children_name_map["in_pkts128_to255_octets"] = "in-pkts128-to255-octets"

                                                self.in_pkts256_to511_octets = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts256To511Octets()
                                                self.in_pkts256_to511_octets.parent = self
                                                self._children_name_map["in_pkts256_to511_octets"] = "in-pkts256-to511-octets"

                                                self.in_pkts512_to1023_octets = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts512To1023Octets()
                                                self.in_pkts512_to1023_octets.parent = self
                                                self._children_name_map["in_pkts512_to1023_octets"] = "in-pkts512-to1023-octets"

                                                self.in_pkts1024_to1518_octets = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts1024To1518Octets()
                                                self.in_pkts1024_to1518_octets.parent = self
                                                self._children_name_map["in_pkts1024_to1518_octets"] = "in-pkts1024-to1518-octets"

                                                self.outpkt64octet = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Outpkt64octet()
                                                self.outpkt64octet.parent = self
                                                self._children_name_map["outpkt64octet"] = "outpkt64octet"

                                                self.out_pkts65127_octets = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts65127Octets()
                                                self.out_pkts65127_octets.parent = self
                                                self._children_name_map["out_pkts65127_octets"] = "out-pkts65127-octets"

                                                self.out_pkts128255_octets = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts128255Octets()
                                                self.out_pkts128255_octets.parent = self
                                                self._children_name_map["out_pkts128255_octets"] = "out-pkts128255-octets"

                                                self.out_pkts256511_octets = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts256511Octets()
                                                self.out_pkts256511_octets.parent = self
                                                self._children_name_map["out_pkts256511_octets"] = "out-pkts256511-octets"

                                                self.out_pkts5121023_octets = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts5121023Octets()
                                                self.out_pkts5121023_octets.parent = self
                                                self._children_name_map["out_pkts5121023_octets"] = "out-pkts5121023-octets"

                                                self.out_pkts10241518_octets = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts10241518Octets()
                                                self.out_pkts10241518_octets.parent = self
                                                self._children_name_map["out_pkts10241518_octets"] = "out-pkts10241518-octets"

                                                self.rx_util = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.RxUtil()
                                                self.rx_util.parent = self
                                                self._children_name_map["rx_util"] = "rx-util"

                                                self.tx_util = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxUtil()
                                                self.tx_util.parent = self
                                                self._children_name_map["tx_util"] = "tx-util"

                                                self.tx_undersized_pkt = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxUndersizedPkt()
                                                self.tx_undersized_pkt.parent = self
                                                self._children_name_map["tx_undersized_pkt"] = "tx-undersized-pkt"

                                                self.tx_oversized_pkt = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxOversizedPkt()
                                                self.tx_oversized_pkt.parent = self
                                                self._children_name_map["tx_oversized_pkt"] = "tx-oversized-pkt"

                                                self.tx_fragments = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxFragments()
                                                self.tx_fragments.parent = self
                                                self._children_name_map["tx_fragments"] = "tx-fragments"

                                                self.tx_jabber = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxJabber()
                                                self.tx_jabber.parent = self
                                                self._children_name_map["tx_jabber"] = "tx-jabber"

                                                self.tx_bad_fcs = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxBadFcs()
                                                self.tx_bad_fcs.parent = self
                                                self._children_name_map["tx_bad_fcs"] = "tx-bad-fcs"
                                                self._segment_path = lambda: "ethernet-hour24-ether-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear30_sec_time', 'last_clear15_min_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                            class RxPkt(Entity):
                                                """
                                                RX PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.RxPkt, self).__init__()

                                                    self.yang_name = "rx-pkt"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "rx-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.RxPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class StatPkt(Entity):
                                                """
                                                STAT PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.StatPkt, self).__init__()

                                                    self.yang_name = "stat-pkt"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "stat-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.StatPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OctetStat(Entity):
                                                """
                                                OCTET STAT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OctetStat, self).__init__()

                                                    self.yang_name = "octet-stat"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "octet-stat"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OctetStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OversizePktStat(Entity):
                                                """
                                                OVERSIZE PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OversizePktStat, self).__init__()

                                                    self.yang_name = "oversize-pkt-stat"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "oversize-pkt-stat"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OversizePktStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class FcsErrorsStat(Entity):
                                                """
                                                FCS ERR
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.FcsErrorsStat, self).__init__()

                                                    self.yang_name = "fcs-errors-stat"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "fcs-errors-stat"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.FcsErrorsStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class LongFramesStat(Entity):
                                                """
                                                LONG FRAMES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.LongFramesStat, self).__init__()

                                                    self.yang_name = "long-frames-stat"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "long-frames-stat"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.LongFramesStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class JabberStat(Entity):
                                                """
                                                JABBER STATS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.JabberStat, self).__init__()

                                                    self.yang_name = "jabber-stat"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "jabber-stat"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.JabberStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class Ether64Octets(Entity):
                                                """
                                                SIXTY FOUR OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether64Octets, self).__init__()

                                                    self.yang_name = "ether64-octets"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ether64-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether64Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class Ether65127Octet(Entity):
                                                """
                                                OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether65127Octet, self).__init__()

                                                    self.yang_name = "ether65127-octet"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ether65127-octet"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether65127Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class Ether128255Octet(Entity):
                                                """
                                                TFF OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether128255Octet, self).__init__()

                                                    self.yang_name = "ether128255-octet"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ether128255-octet"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether128255Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class Ether256511Octet(Entity):
                                                """
                                                FOO OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether256511Octet, self).__init__()

                                                    self.yang_name = "ether256511-octet"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ether256511-octet"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether256511Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class Ether5121023Octet(Entity):
                                                """
                                                OZTT OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether5121023Octet, self).__init__()

                                                    self.yang_name = "ether5121023-octet"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ether5121023-octet"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether5121023Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class Ether10241518Octet(Entity):
                                                """
                                                OFO OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether10241518Octet, self).__init__()

                                                    self.yang_name = "ether10241518-octet"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ether10241518-octet"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether10241518Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InUcastPkt(Entity):
                                                """
                                                IN UCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InUcastPkt, self).__init__()

                                                    self.yang_name = "in-ucast-pkt"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-ucast-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InUcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InMcastPkt(Entity):
                                                """
                                                IN MCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InMcastPkt, self).__init__()

                                                    self.yang_name = "in-mcast-pkt"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-mcast-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InMcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InBcastPkt(Entity):
                                                """
                                                IN BCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InBcastPkt, self).__init__()

                                                    self.yang_name = "in-bcast-pkt"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-bcast-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InBcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutUcastPkt(Entity):
                                                """
                                                OUT UCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutUcastPkt, self).__init__()

                                                    self.yang_name = "out-ucast-pkt"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-ucast-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutUcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutBcastPkt(Entity):
                                                """
                                                OUT BCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutBcastPkt, self).__init__()

                                                    self.yang_name = "out-bcast-pkt"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-bcast-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutBcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutMcastPkt(Entity):
                                                """
                                                OUT MCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutMcastPkt, self).__init__()

                                                    self.yang_name = "out-mcast-pkt"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-mcast-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutMcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class TxPkt(Entity):
                                                """
                                                TX PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxPkt, self).__init__()

                                                    self.yang_name = "tx-pkt"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "tx-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class IfInErrors(Entity):
                                                """
                                                IFIN ERRORS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.IfInErrors, self).__init__()

                                                    self.yang_name = "if-in-errors"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "if-in-errors"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.IfInErrors, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class IfInOctets(Entity):
                                                """
                                                IFIN OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.IfInOctets, self).__init__()

                                                    self.yang_name = "if-in-octets"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "if-in-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.IfInOctets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class EtherStatMulticastPkt(Entity):
                                                """
                                                ETHER STAT MULTICAST PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.EtherStatMulticastPkt, self).__init__()

                                                    self.yang_name = "ether-stat-multicast-pkt"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ether-stat-multicast-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.EtherStatMulticastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class EtherStatBroadcastPkt(Entity):
                                                """
                                                ETHER STAT BROADCAST PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.EtherStatBroadcastPkt, self).__init__()

                                                    self.yang_name = "ether-stat-broadcast-pkt"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ether-stat-broadcast-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.EtherStatBroadcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class EtherStatUndersizedPkt(Entity):
                                                """
                                                ETHER STAT UNDERSIZED PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.EtherStatUndersizedPkt, self).__init__()

                                                    self.yang_name = "ether-stat-undersized-pkt"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ether-stat-undersized-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.EtherStatUndersizedPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutOctets(Entity):
                                                """
                                                OUT OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutOctets, self).__init__()

                                                    self.yang_name = "out-octets"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutOctets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPauseFrame(Entity):
                                                """
                                                INPUT PAUSE FRAME
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPauseFrame, self).__init__()

                                                    self.yang_name = "in-pause-frame"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pause-frame"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPauseFrame, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InGoodBytes(Entity):
                                                """
                                                INPUT GOOD BYTES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InGoodBytes, self).__init__()

                                                    self.yang_name = "in-good-bytes"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-good-bytes"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InGoodBytes, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class In8021qFrames(Entity):
                                                """
                                                INPUT 802 1Q FRAMES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.In8021qFrames, self).__init__()

                                                    self.yang_name = "in8021q-frames"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in8021q-frames"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.In8021qFrames, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPkts1519MaxOctets(Entity):
                                                """
                                                INPUT PKTS 1519MAX OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts1519MaxOctets, self).__init__()

                                                    self.yang_name = "in-pkts1519-max-octets"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts1519-max-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts1519MaxOctets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InGoodPkts(Entity):
                                                """
                                                INPUT GOOD PKTS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InGoodPkts, self).__init__()

                                                    self.yang_name = "in-good-pkts"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-good-pkts"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InGoodPkts, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InDropOverrun(Entity):
                                                """
                                                INPUT DROP OVERRUN
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropOverrun, self).__init__()

                                                    self.yang_name = "in-drop-overrun"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-drop-overrun"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropOverrun, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InDropAbort(Entity):
                                                """
                                                INPUT DROP ABORT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropAbort, self).__init__()

                                                    self.yang_name = "in-drop-abort"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-drop-abort"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropAbort, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InDropInvalidVlan(Entity):
                                                """
                                                INPUT DROP INVALID VLAN
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropInvalidVlan, self).__init__()

                                                    self.yang_name = "in-drop-invalid-vlan"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-drop-invalid-vlan"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropInvalidVlan, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InDropInvalidDmac(Entity):
                                                """
                                                INPUT DROP INVALID DMAC
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropInvalidDmac, self).__init__()

                                                    self.yang_name = "in-drop-invalid-dmac"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-drop-invalid-dmac"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropInvalidDmac, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InDropInvalidEncap(Entity):
                                                """
                                                INPUT DROP INVALID ENCAP
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropInvalidEncap, self).__init__()

                                                    self.yang_name = "in-drop-invalid-encap"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-drop-invalid-encap"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropInvalidEncap, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InDropOther(Entity):
                                                """
                                                INPUT DROP OTHER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropOther, self).__init__()

                                                    self.yang_name = "in-drop-other"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-drop-other"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropOther, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InMibGiant(Entity):
                                                """
                                                INPUT MIB GIANT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InMibGiant, self).__init__()

                                                    self.yang_name = "in-mib-giant"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-mib-giant"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InMibGiant, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InMibJabber(Entity):
                                                """
                                                INPUT MIB JABBER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InMibJabber, self).__init__()

                                                    self.yang_name = "in-mib-jabber"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-mib-jabber"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InMibJabber, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InMibcrc(Entity):
                                                """
                                                IN MIB CRC
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InMibcrc, self).__init__()

                                                    self.yang_name = "in-mibcrc"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-mibcrc"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InMibcrc, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InErrorCollisions(Entity):
                                                """
                                                IN ERROR COLLISIONS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorCollisions, self).__init__()

                                                    self.yang_name = "in-error-collisions"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-error-collisions"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorCollisions, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InErrorSymbol(Entity):
                                                """
                                                IN ERROR SYMBOL
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorSymbol, self).__init__()

                                                    self.yang_name = "in-error-symbol"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-error-symbol"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorSymbol, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutGoodBytes(Entity):
                                                """
                                                OUT GOOD BYTES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutGoodBytes, self).__init__()

                                                    self.yang_name = "out-good-bytes"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-good-bytes"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutGoodBytes, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class Out8021qFrames(Entity):
                                                """
                                                OUT 802 1Q FRAMES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Out8021qFrames, self).__init__()

                                                    self.yang_name = "out8021q-frames"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out8021q-frames"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Out8021qFrames, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutPauseFrames(Entity):
                                                """
                                                OUT PAUSE FRAMES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPauseFrames, self).__init__()

                                                    self.yang_name = "out-pause-frames"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-pause-frames"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPauseFrames, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutPkts1519MaxOctets(Entity):
                                                """
                                                OUT PKTS 1519 MAX OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts1519MaxOctets, self).__init__()

                                                    self.yang_name = "out-pkts1519-max-octets"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-pkts1519-max-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts1519MaxOctets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutGoodPkts(Entity):
                                                """
                                                OUT GOOD PKTS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutGoodPkts, self).__init__()

                                                    self.yang_name = "out-good-pkts"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-good-pkts"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutGoodPkts, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutDropUnderrun(Entity):
                                                """
                                                OUT DROP UNDERRUN
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutDropUnderrun, self).__init__()

                                                    self.yang_name = "out-drop-underrun"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-drop-underrun"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutDropUnderrun, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutDropAbort(Entity):
                                                """
                                                OUT DROP ABORT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutDropAbort, self).__init__()

                                                    self.yang_name = "out-drop-abort"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-drop-abort"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutDropAbort, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutDropOther(Entity):
                                                """
                                                OUT DROP OTHER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutDropOther, self).__init__()

                                                    self.yang_name = "out-drop-other"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-drop-other"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutDropOther, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutErrorOther(Entity):
                                                """
                                                OUT ERROR OTHER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutErrorOther, self).__init__()

                                                    self.yang_name = "out-error-other"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-error-other"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutErrorOther, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InErrorGiant(Entity):
                                                """
                                                IN ERROR GIANT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorGiant, self).__init__()

                                                    self.yang_name = "in-error-giant"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-error-giant"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorGiant, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InErrorRunt(Entity):
                                                """
                                                IN ERROR RUNT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorRunt, self).__init__()

                                                    self.yang_name = "in-error-runt"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-error-runt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorRunt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InErrorJabbers(Entity):
                                                """
                                                IN ERROR JABBERS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorJabbers, self).__init__()

                                                    self.yang_name = "in-error-jabbers"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-error-jabbers"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorJabbers, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InErrorFragments(Entity):
                                                """
                                                IN ERROR FRAGMENTS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorFragments, self).__init__()

                                                    self.yang_name = "in-error-fragments"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-error-fragments"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorFragments, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InErrorOther(Entity):
                                                """
                                                IN ERROR OTHER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorOther, self).__init__()

                                                    self.yang_name = "in-error-other"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-error-other"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorOther, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPkt64Octet(Entity):
                                                """
                                                IN PKT 64 OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkt64Octet, self).__init__()

                                                    self.yang_name = "in-pkt64-octet"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkt64-octet"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkt64Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPkts65To127Octets(Entity):
                                                """
                                                IN PKTS 65 127OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts65To127Octets, self).__init__()

                                                    self.yang_name = "in-pkts65-to127-octets"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts65-to127-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts65To127Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPkts128To255Octets(Entity):
                                                """
                                                IN PKTS 128 255 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts128To255Octets, self).__init__()

                                                    self.yang_name = "in-pkts128-to255-octets"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts128-to255-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts128To255Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPkts256To511Octets(Entity):
                                                """
                                                IN PKTS 256 511 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts256To511Octets, self).__init__()

                                                    self.yang_name = "in-pkts256-to511-octets"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts256-to511-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts256To511Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPkts512To1023Octets(Entity):
                                                """
                                                IN PKTS 512 1023 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts512To1023Octets, self).__init__()

                                                    self.yang_name = "in-pkts512-to1023-octets"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts512-to1023-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts512To1023Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPkts1024To1518Octets(Entity):
                                                """
                                                IN PKTS 1024 1518 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts1024To1518Octets, self).__init__()

                                                    self.yang_name = "in-pkts1024-to1518-octets"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts1024-to1518-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts1024To1518Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class Outpkt64octet(Entity):
                                                """
                                                OUT PKT 64 OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Outpkt64octet, self).__init__()

                                                    self.yang_name = "outpkt64octet"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "outpkt64octet"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Outpkt64octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutPkts65127Octets(Entity):
                                                """
                                                OUT PKTS 65 127OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts65127Octets, self).__init__()

                                                    self.yang_name = "out-pkts65127-octets"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-pkts65127-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts65127Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutPkts128255Octets(Entity):
                                                """
                                                OUT PKTS 128 255 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts128255Octets, self).__init__()

                                                    self.yang_name = "out-pkts128255-octets"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-pkts128255-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts128255Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutPkts256511Octets(Entity):
                                                """
                                                OUT PKTS 256 511 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts256511Octets, self).__init__()

                                                    self.yang_name = "out-pkts256511-octets"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-pkts256511-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts256511Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutPkts5121023Octets(Entity):
                                                """
                                                OUT PKTS 512 1023 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts5121023Octets, self).__init__()

                                                    self.yang_name = "out-pkts5121023-octets"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-pkts5121023-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts5121023Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutPkts10241518Octets(Entity):
                                                """
                                                OUT PKTS 1024 1518 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts10241518Octets, self).__init__()

                                                    self.yang_name = "out-pkts10241518-octets"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-pkts10241518-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts10241518Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class RxUtil(Entity):
                                                """
                                                Rx Utilization in Percent
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: str
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.RxUtil, self).__init__()

                                                    self.yang_name = "rx-util"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                        ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "rx-util"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.RxUtil, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class TxUtil(Entity):
                                                """
                                                Tx Utilization in Percent
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: str
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxUtil, self).__init__()

                                                    self.yang_name = "tx-util"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                        ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "tx-util"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxUtil, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class TxUndersizedPkt(Entity):
                                                """
                                                TX Undersized Pkt
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxUndersizedPkt, self).__init__()

                                                    self.yang_name = "tx-undersized-pkt"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "tx-undersized-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxUndersizedPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class TxOversizedPkt(Entity):
                                                """
                                                TX Oversized Pkt
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxOversizedPkt, self).__init__()

                                                    self.yang_name = "tx-oversized-pkt"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "tx-oversized-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxOversizedPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class TxFragments(Entity):
                                                """
                                                TX Fragments
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxFragments, self).__init__()

                                                    self.yang_name = "tx-fragments"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "tx-fragments"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxFragments, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class TxJabber(Entity):
                                                """
                                                TX Jabber
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxJabber, self).__init__()

                                                    self.yang_name = "tx-jabber"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "tx-jabber"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxJabber, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class TxBadFcs(Entity):
                                                """
                                                TX Bad Fcs
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxBadFcs, self).__init__()

                                                    self.yang_name = "tx-bad-fcs"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "tx-bad-fcs"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxBadFcs, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                        class EthernetMinute15History(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: minute15pcs_histories
                            
                            	ETHERNET port interval performance data
                            	**type**\:  :py:class:`Minute15pcsHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15pcsHistories>`
                            
                            .. attribute:: minute15_ether_histories
                            
                            	ETHERNET port interval performance data
                            	**type**\:  :py:class:`Minute15EtherHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories>`
                            
                            .. attribute:: minute15_fec_histories
                            
                            	ETHERNET port interval performance data
                            	**type**\:  :py:class:`Minute15FecHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15FecHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History, self).__init__()

                                self.yang_name = "ethernet-minute15-history"
                                self.yang_parent_name = "ethernet-port-history"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("minute15pcs-histories", ("minute15pcs_histories", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15pcsHistories)), ("minute15-ether-histories", ("minute15_ether_histories", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories)), ("minute15-fec-histories", ("minute15_fec_histories", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15FecHistories))])
                                self._leafs = OrderedDict()

                                self.minute15pcs_histories = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15pcsHistories()
                                self.minute15pcs_histories.parent = self
                                self._children_name_map["minute15pcs_histories"] = "minute15pcs-histories"

                                self.minute15_ether_histories = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories()
                                self.minute15_ether_histories.parent = self
                                self._children_name_map["minute15_ether_histories"] = "minute15-ether-histories"

                                self.minute15_fec_histories = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15FecHistories()
                                self.minute15_fec_histories.parent = self
                                self._children_name_map["minute15_fec_histories"] = "minute15-fec-histories"
                                self._segment_path = lambda: "ethernet-minute15-history"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History, [], name, value)


                            class Minute15pcsHistories(Entity):
                                """
                                ETHERNET port interval performance data
                                
                                .. attribute:: minute15pcs_history
                                
                                	ETHERNET port 15\-minute pcs performance data
                                	**type**\: list of  		 :py:class:`Minute15pcsHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15pcsHistories.Minute15pcsHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15pcsHistories, self).__init__()

                                    self.yang_name = "minute15pcs-histories"
                                    self.yang_parent_name = "ethernet-minute15-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("minute15pcs-history", ("minute15pcs_history", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15pcsHistories.Minute15pcsHistory))])
                                    self._leafs = OrderedDict()

                                    self.minute15pcs_history = YList(self)
                                    self._segment_path = lambda: "minute15pcs-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15pcsHistories, [], name, value)


                                class Minute15pcsHistory(Entity):
                                    """
                                    ETHERNET port 15\-minute pcs performance
                                    data
                                    
                                    .. attribute:: slot_number  (key)
                                    
                                    	interval slot number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: minute15pcs_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`Minute15pcsTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15pcsHistories.Minute15pcsHistory.Minute15pcsTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15pcsHistories.Minute15pcsHistory, self).__init__()

                                        self.yang_name = "minute15pcs-history"
                                        self.yang_parent_name = "minute15pcs-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['slot_number']
                                        self._child_classes = OrderedDict([("minute15pcs-time-line-instances", ("minute15pcs_time_line_instances", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15pcsHistories.Minute15pcsHistory.Minute15pcsTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('slot_number', (YLeaf(YType.uint32, 'slot-number'), ['int'])),
                                        ])
                                        self.slot_number = None

                                        self.minute15pcs_time_line_instances = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15pcsHistories.Minute15pcsHistory.Minute15pcsTimeLineInstances()
                                        self.minute15pcs_time_line_instances.parent = self
                                        self._children_name_map["minute15pcs_time_line_instances"] = "minute15pcs-time-line-instances"
                                        self._segment_path = lambda: "minute15pcs-history" + "[slot-number='" + str(self.slot_number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15pcsHistories.Minute15pcsHistory, ['slot_number'], name, value)


                                    class Minute15pcsTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: minute15pcs_time_line_instance
                                        
                                        	port 15\-minute pcs performance data
                                        	**type**\: list of  		 :py:class:`Minute15pcsTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15pcsHistories.Minute15pcsHistory.Minute15pcsTimeLineInstances.Minute15pcsTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15pcsHistories.Minute15pcsHistory.Minute15pcsTimeLineInstances, self).__init__()

                                            self.yang_name = "minute15pcs-time-line-instances"
                                            self.yang_parent_name = "minute15pcs-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("minute15pcs-time-line-instance", ("minute15pcs_time_line_instance", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15pcsHistories.Minute15pcsHistory.Minute15pcsTimeLineInstances.Minute15pcsTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.minute15pcs_time_line_instance = YList(self)
                                            self._segment_path = lambda: "minute15pcs-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15pcsHistories.Minute15pcsHistory.Minute15pcsTimeLineInstances, [], name, value)


                                        class Minute15pcsTimeLineInstance(Entity):
                                            """
                                            port 15\-minute pcs performance data
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: bip
                                            
                                            	Bip 
                                            	**type**\: list of  		 :py:class:`Bip <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15pcsHistories.Minute15pcsHistory.Minute15pcsTimeLineInstances.Minute15pcsTimeLineInstance.Bip>`
                                            
                                            .. attribute:: frm_err
                                            
                                            	Frm Err
                                            	**type**\: list of  		 :py:class:`FrmErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15pcsHistories.Minute15pcsHistory.Minute15pcsTimeLineInstances.Minute15pcsTimeLineInstance.FrmErr>`
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15pcsHistories.Minute15pcsHistory.Minute15pcsTimeLineInstances.Minute15pcsTimeLineInstance, self).__init__()

                                                self.yang_name = "minute15pcs-time-line-instance"
                                                self.yang_parent_name = "minute15pcs-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("bip", ("bip", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15pcsHistories.Minute15pcsHistory.Minute15pcsTimeLineInstances.Minute15pcsTimeLineInstance.Bip)), ("frm-err", ("frm_err", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15pcsHistories.Minute15pcsHistory.Minute15pcsTimeLineInstances.Minute15pcsTimeLineInstance.FrmErr))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear24_hr_time = None

                                                self.bip = YList(self)
                                                self.frm_err = YList(self)
                                                self._segment_path = lambda: "minute15pcs-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15pcsHistories.Minute15pcsHistory.Minute15pcsTimeLineInstances.Minute15pcsTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time'], name, value)


                                            class Bip(Entity):
                                                """
                                                Bip 
                                                
                                                .. attribute:: name
                                                
                                                	pcs param name
                                                	**type**\: str
                                                
                                                	**length:** 0..30
                                                
                                                .. attribute:: data
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15pcsHistories.Minute15pcsHistory.Minute15pcsTimeLineInstances.Minute15pcsTimeLineInstance.Bip, self).__init__()

                                                    self.yang_name = "bip"
                                                    self.yang_parent_name = "minute15pcs-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.name = None
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "bip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15pcsHistories.Minute15pcsHistory.Minute15pcsTimeLineInstances.Minute15pcsTimeLineInstance.Bip, ['name', 'data', 'threshold', 'tca_report'], name, value)


                                            class FrmErr(Entity):
                                                """
                                                Frm Err
                                                
                                                .. attribute:: name
                                                
                                                	pcs param name
                                                	**type**\: str
                                                
                                                	**length:** 0..30
                                                
                                                .. attribute:: data
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15pcsHistories.Minute15pcsHistory.Minute15pcsTimeLineInstances.Minute15pcsTimeLineInstance.FrmErr, self).__init__()

                                                    self.yang_name = "frm-err"
                                                    self.yang_parent_name = "minute15pcs-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.name = None
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "frm-err"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15pcsHistories.Minute15pcsHistory.Minute15pcsTimeLineInstances.Minute15pcsTimeLineInstance.FrmErr, ['name', 'data', 'threshold', 'tca_report'], name, value)


                            class Minute15EtherHistories(Entity):
                                """
                                ETHERNET port interval performance data
                                
                                .. attribute:: minute15_ether_history
                                
                                	ETHERNET port 15\-minute ether performance data
                                	**type**\: list of  		 :py:class:`Minute15EtherHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories, self).__init__()

                                    self.yang_name = "minute15-ether-histories"
                                    self.yang_parent_name = "ethernet-minute15-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("minute15-ether-history", ("minute15_ether_history", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory))])
                                    self._leafs = OrderedDict()

                                    self.minute15_ether_history = YList(self)
                                    self._segment_path = lambda: "minute15-ether-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories, [], name, value)


                                class Minute15EtherHistory(Entity):
                                    """
                                    ETHERNET port 15\-minute ether performance
                                    data
                                    
                                    .. attribute:: slot_number  (key)
                                    
                                    	interval slot number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: minute15_ether_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`Minute15EtherTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory, self).__init__()

                                        self.yang_name = "minute15-ether-history"
                                        self.yang_parent_name = "minute15-ether-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['slot_number']
                                        self._child_classes = OrderedDict([("minute15-ether-time-line-instances", ("minute15_ether_time_line_instances", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('slot_number', (YLeaf(YType.uint32, 'slot-number'), ['int'])),
                                        ])
                                        self.slot_number = None

                                        self.minute15_ether_time_line_instances = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances()
                                        self.minute15_ether_time_line_instances.parent = self
                                        self._children_name_map["minute15_ether_time_line_instances"] = "minute15-ether-time-line-instances"
                                        self._segment_path = lambda: "minute15-ether-history" + "[slot-number='" + str(self.slot_number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory, ['slot_number'], name, value)


                                    class Minute15EtherTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: minute15_ether_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of  		 :py:class:`Minute15EtherTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances, self).__init__()

                                            self.yang_name = "minute15-ether-time-line-instances"
                                            self.yang_parent_name = "minute15-ether-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("minute15-ether-time-line-instance", ("minute15_ether_time_line_instance", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.minute15_ether_time_line_instance = YList(self)
                                            self._segment_path = lambda: "minute15-ether-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances, [], name, value)


                                        class Minute15EtherTimeLineInstance(Entity):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rx_pkt
                                            
                                            	RX PKT
                                            	**type**\:  :py:class:`RxPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.RxPkt>`
                                            
                                            .. attribute:: stat_pkt
                                            
                                            	STAT PKT
                                            	**type**\:  :py:class:`StatPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.StatPkt>`
                                            
                                            .. attribute:: octet_stat
                                            
                                            	OCTET STAT
                                            	**type**\:  :py:class:`OctetStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OctetStat>`
                                            
                                            .. attribute:: oversize_pkt_stat
                                            
                                            	OVERSIZE PKT
                                            	**type**\:  :py:class:`OversizePktStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OversizePktStat>`
                                            
                                            .. attribute:: fcs_errors_stat
                                            
                                            	FCS ERR
                                            	**type**\:  :py:class:`FcsErrorsStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.FcsErrorsStat>`
                                            
                                            .. attribute:: long_frames_stat
                                            
                                            	LONG FRAMES
                                            	**type**\:  :py:class:`LongFramesStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.LongFramesStat>`
                                            
                                            .. attribute:: jabber_stat
                                            
                                            	JABBER STATS
                                            	**type**\:  :py:class:`JabberStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.JabberStat>`
                                            
                                            .. attribute:: ether64_octets
                                            
                                            	SIXTY FOUR OCTET
                                            	**type**\:  :py:class:`Ether64Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether64Octets>`
                                            
                                            .. attribute:: ether65127_octet
                                            
                                            	OCTET
                                            	**type**\:  :py:class:`Ether65127Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether65127Octet>`
                                            
                                            .. attribute:: ether128255_octet
                                            
                                            	TFF OCTET
                                            	**type**\:  :py:class:`Ether128255Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether128255Octet>`
                                            
                                            .. attribute:: ether256511_octet
                                            
                                            	FOO OCTET
                                            	**type**\:  :py:class:`Ether256511Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether256511Octet>`
                                            
                                            .. attribute:: ether5121023_octet
                                            
                                            	OZTT OCTET
                                            	**type**\:  :py:class:`Ether5121023Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether5121023Octet>`
                                            
                                            .. attribute:: ether10241518_octet
                                            
                                            	OFO OCTET
                                            	**type**\:  :py:class:`Ether10241518Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether10241518Octet>`
                                            
                                            .. attribute:: in_ucast_pkt
                                            
                                            	IN UCAST
                                            	**type**\:  :py:class:`InUcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InUcastPkt>`
                                            
                                            .. attribute:: in_mcast_pkt
                                            
                                            	IN MCAST
                                            	**type**\:  :py:class:`InMcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InMcastPkt>`
                                            
                                            .. attribute:: in_bcast_pkt
                                            
                                            	IN BCAST
                                            	**type**\:  :py:class:`InBcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InBcastPkt>`
                                            
                                            .. attribute:: out_ucast_pkt
                                            
                                            	OUT UCAST
                                            	**type**\:  :py:class:`OutUcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutUcastPkt>`
                                            
                                            .. attribute:: out_bcast_pkt
                                            
                                            	OUT BCAST
                                            	**type**\:  :py:class:`OutBcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutBcastPkt>`
                                            
                                            .. attribute:: out_mcast_pkt
                                            
                                            	OUT MCAST
                                            	**type**\:  :py:class:`OutMcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutMcastPkt>`
                                            
                                            .. attribute:: tx_pkt
                                            
                                            	TX PKT
                                            	**type**\:  :py:class:`TxPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxPkt>`
                                            
                                            .. attribute:: if_in_errors
                                            
                                            	IFIN ERRORS
                                            	**type**\:  :py:class:`IfInErrors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.IfInErrors>`
                                            
                                            .. attribute:: if_in_octets
                                            
                                            	IFIN OCTETS
                                            	**type**\:  :py:class:`IfInOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.IfInOctets>`
                                            
                                            .. attribute:: ether_stat_multicast_pkt
                                            
                                            	ETHER STAT MULTICAST PKT
                                            	**type**\:  :py:class:`EtherStatMulticastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.EtherStatMulticastPkt>`
                                            
                                            .. attribute:: ether_stat_broadcast_pkt
                                            
                                            	ETHER STAT BROADCAST PKT
                                            	**type**\:  :py:class:`EtherStatBroadcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.EtherStatBroadcastPkt>`
                                            
                                            .. attribute:: ether_stat_undersized_pkt
                                            
                                            	ETHER STAT UNDERSIZED PKT
                                            	**type**\:  :py:class:`EtherStatUndersizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.EtherStatUndersizedPkt>`
                                            
                                            .. attribute:: out_octets
                                            
                                            	OUT OCTET
                                            	**type**\:  :py:class:`OutOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutOctets>`
                                            
                                            .. attribute:: in_pause_frame
                                            
                                            	INPUT PAUSE FRAME
                                            	**type**\:  :py:class:`InPauseFrame <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPauseFrame>`
                                            
                                            .. attribute:: in_good_bytes
                                            
                                            	INPUT GOOD BYTES
                                            	**type**\:  :py:class:`InGoodBytes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InGoodBytes>`
                                            
                                            .. attribute:: in8021q_frames
                                            
                                            	INPUT 802 1Q FRAMES
                                            	**type**\:  :py:class:`In8021qFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.In8021qFrames>`
                                            
                                            .. attribute:: in_pkts1519_max_octets
                                            
                                            	INPUT PKTS 1519MAX OCTETS
                                            	**type**\:  :py:class:`InPkts1519MaxOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts1519MaxOctets>`
                                            
                                            .. attribute:: in_good_pkts
                                            
                                            	INPUT GOOD PKTS
                                            	**type**\:  :py:class:`InGoodPkts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InGoodPkts>`
                                            
                                            .. attribute:: in_drop_overrun
                                            
                                            	INPUT DROP OVERRUN
                                            	**type**\:  :py:class:`InDropOverrun <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropOverrun>`
                                            
                                            .. attribute:: in_drop_abort
                                            
                                            	INPUT DROP ABORT
                                            	**type**\:  :py:class:`InDropAbort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropAbort>`
                                            
                                            .. attribute:: in_drop_invalid_vlan
                                            
                                            	INPUT DROP INVALID VLAN
                                            	**type**\:  :py:class:`InDropInvalidVlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropInvalidVlan>`
                                            
                                            .. attribute:: in_drop_invalid_dmac
                                            
                                            	INPUT DROP INVALID DMAC
                                            	**type**\:  :py:class:`InDropInvalidDmac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropInvalidDmac>`
                                            
                                            .. attribute:: in_drop_invalid_encap
                                            
                                            	INPUT DROP INVALID ENCAP
                                            	**type**\:  :py:class:`InDropInvalidEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropInvalidEncap>`
                                            
                                            .. attribute:: in_drop_other
                                            
                                            	INPUT DROP OTHER
                                            	**type**\:  :py:class:`InDropOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropOther>`
                                            
                                            .. attribute:: in_mib_giant
                                            
                                            	INPUT MIB GIANT
                                            	**type**\:  :py:class:`InMibGiant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InMibGiant>`
                                            
                                            .. attribute:: in_mib_jabber
                                            
                                            	INPUT MIB JABBER
                                            	**type**\:  :py:class:`InMibJabber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InMibJabber>`
                                            
                                            .. attribute:: in_mibcrc
                                            
                                            	IN MIB CRC
                                            	**type**\:  :py:class:`InMibcrc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InMibcrc>`
                                            
                                            .. attribute:: in_error_collisions
                                            
                                            	IN ERROR COLLISIONS
                                            	**type**\:  :py:class:`InErrorCollisions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorCollisions>`
                                            
                                            .. attribute:: in_error_symbol
                                            
                                            	IN ERROR SYMBOL
                                            	**type**\:  :py:class:`InErrorSymbol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorSymbol>`
                                            
                                            .. attribute:: out_good_bytes
                                            
                                            	OUT GOOD BYTES
                                            	**type**\:  :py:class:`OutGoodBytes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutGoodBytes>`
                                            
                                            .. attribute:: out8021q_frames
                                            
                                            	OUT 802 1Q FRAMES
                                            	**type**\:  :py:class:`Out8021qFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Out8021qFrames>`
                                            
                                            .. attribute:: out_pause_frames
                                            
                                            	OUT PAUSE FRAMES
                                            	**type**\:  :py:class:`OutPauseFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPauseFrames>`
                                            
                                            .. attribute:: out_pkts1519_max_octets
                                            
                                            	OUT PKTS 1519 MAX OCTETS
                                            	**type**\:  :py:class:`OutPkts1519MaxOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts1519MaxOctets>`
                                            
                                            .. attribute:: out_good_pkts
                                            
                                            	OUT GOOD PKTS
                                            	**type**\:  :py:class:`OutGoodPkts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutGoodPkts>`
                                            
                                            .. attribute:: out_drop_underrun
                                            
                                            	OUT DROP UNDERRUN
                                            	**type**\:  :py:class:`OutDropUnderrun <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutDropUnderrun>`
                                            
                                            .. attribute:: out_drop_abort
                                            
                                            	OUT DROP ABORT
                                            	**type**\:  :py:class:`OutDropAbort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutDropAbort>`
                                            
                                            .. attribute:: out_drop_other
                                            
                                            	OUT DROP OTHER
                                            	**type**\:  :py:class:`OutDropOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutDropOther>`
                                            
                                            .. attribute:: out_error_other
                                            
                                            	OUT ERROR OTHER
                                            	**type**\:  :py:class:`OutErrorOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutErrorOther>`
                                            
                                            .. attribute:: in_error_giant
                                            
                                            	IN ERROR GIANT
                                            	**type**\:  :py:class:`InErrorGiant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorGiant>`
                                            
                                            .. attribute:: in_error_runt
                                            
                                            	IN ERROR RUNT
                                            	**type**\:  :py:class:`InErrorRunt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorRunt>`
                                            
                                            .. attribute:: in_error_jabbers
                                            
                                            	IN ERROR JABBERS
                                            	**type**\:  :py:class:`InErrorJabbers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorJabbers>`
                                            
                                            .. attribute:: in_error_fragments
                                            
                                            	IN ERROR FRAGMENTS
                                            	**type**\:  :py:class:`InErrorFragments <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorFragments>`
                                            
                                            .. attribute:: in_error_other
                                            
                                            	IN ERROR OTHER
                                            	**type**\:  :py:class:`InErrorOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorOther>`
                                            
                                            .. attribute:: in_pkt64_octet
                                            
                                            	IN PKT 64 OCTET
                                            	**type**\:  :py:class:`InPkt64Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkt64Octet>`
                                            
                                            .. attribute:: in_pkts65_to127_octets
                                            
                                            	IN PKTS 65 127OCTETS
                                            	**type**\:  :py:class:`InPkts65To127Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts65To127Octets>`
                                            
                                            .. attribute:: in_pkts128_to255_octets
                                            
                                            	IN PKTS 128 255 OCTETS
                                            	**type**\:  :py:class:`InPkts128To255Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts128To255Octets>`
                                            
                                            .. attribute:: in_pkts256_to511_octets
                                            
                                            	IN PKTS 256 511 OCTETS
                                            	**type**\:  :py:class:`InPkts256To511Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts256To511Octets>`
                                            
                                            .. attribute:: in_pkts512_to1023_octets
                                            
                                            	IN PKTS 512 1023 OCTETS
                                            	**type**\:  :py:class:`InPkts512To1023Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts512To1023Octets>`
                                            
                                            .. attribute:: in_pkts1024_to1518_octets
                                            
                                            	IN PKTS 1024 1518 OCTETS
                                            	**type**\:  :py:class:`InPkts1024To1518Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts1024To1518Octets>`
                                            
                                            .. attribute:: outpkt64octet
                                            
                                            	OUT PKT 64 OCTET
                                            	**type**\:  :py:class:`Outpkt64octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Outpkt64octet>`
                                            
                                            .. attribute:: out_pkts65127_octets
                                            
                                            	OUT PKTS 65 127OCTETS
                                            	**type**\:  :py:class:`OutPkts65127Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts65127Octets>`
                                            
                                            .. attribute:: out_pkts128255_octets
                                            
                                            	OUT PKTS 128 255 OCTETS
                                            	**type**\:  :py:class:`OutPkts128255Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts128255Octets>`
                                            
                                            .. attribute:: out_pkts256511_octets
                                            
                                            	OUT PKTS 256 511 OCTETS
                                            	**type**\:  :py:class:`OutPkts256511Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts256511Octets>`
                                            
                                            .. attribute:: out_pkts5121023_octets
                                            
                                            	OUT PKTS 512 1023 OCTETS
                                            	**type**\:  :py:class:`OutPkts5121023Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts5121023Octets>`
                                            
                                            .. attribute:: out_pkts10241518_octets
                                            
                                            	OUT PKTS 1024 1518 OCTETS
                                            	**type**\:  :py:class:`OutPkts10241518Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts10241518Octets>`
                                            
                                            .. attribute:: rx_util
                                            
                                            	Rx Utilization in Percent
                                            	**type**\:  :py:class:`RxUtil <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.RxUtil>`
                                            
                                            .. attribute:: tx_util
                                            
                                            	Tx Utilization in Percent
                                            	**type**\:  :py:class:`TxUtil <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxUtil>`
                                            
                                            .. attribute:: tx_undersized_pkt
                                            
                                            	TX Undersized Pkt
                                            	**type**\:  :py:class:`TxUndersizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxUndersizedPkt>`
                                            
                                            .. attribute:: tx_oversized_pkt
                                            
                                            	TX Oversized Pkt
                                            	**type**\:  :py:class:`TxOversizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxOversizedPkt>`
                                            
                                            .. attribute:: tx_fragments
                                            
                                            	TX Fragments
                                            	**type**\:  :py:class:`TxFragments <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxFragments>`
                                            
                                            .. attribute:: tx_jabber
                                            
                                            	TX Jabber
                                            	**type**\:  :py:class:`TxJabber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxJabber>`
                                            
                                            .. attribute:: tx_bad_fcs
                                            
                                            	TX Bad Fcs
                                            	**type**\:  :py:class:`TxBadFcs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxBadFcs>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance, self).__init__()

                                                self.yang_name = "minute15-ether-time-line-instance"
                                                self.yang_parent_name = "minute15-ether-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("rx-pkt", ("rx_pkt", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.RxPkt)), ("stat-pkt", ("stat_pkt", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.StatPkt)), ("octet-stat", ("octet_stat", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OctetStat)), ("oversize-pkt-stat", ("oversize_pkt_stat", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OversizePktStat)), ("fcs-errors-stat", ("fcs_errors_stat", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.FcsErrorsStat)), ("long-frames-stat", ("long_frames_stat", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.LongFramesStat)), ("jabber-stat", ("jabber_stat", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.JabberStat)), ("ether64-octets", ("ether64_octets", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether64Octets)), ("ether65127-octet", ("ether65127_octet", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether65127Octet)), ("ether128255-octet", ("ether128255_octet", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether128255Octet)), ("ether256511-octet", ("ether256511_octet", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether256511Octet)), ("ether5121023-octet", ("ether5121023_octet", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether5121023Octet)), ("ether10241518-octet", ("ether10241518_octet", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether10241518Octet)), ("in-ucast-pkt", ("in_ucast_pkt", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InUcastPkt)), ("in-mcast-pkt", ("in_mcast_pkt", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InMcastPkt)), ("in-bcast-pkt", ("in_bcast_pkt", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InBcastPkt)), ("out-ucast-pkt", ("out_ucast_pkt", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutUcastPkt)), ("out-bcast-pkt", ("out_bcast_pkt", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutBcastPkt)), ("out-mcast-pkt", ("out_mcast_pkt", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutMcastPkt)), ("tx-pkt", ("tx_pkt", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxPkt)), ("if-in-errors", ("if_in_errors", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.IfInErrors)), ("if-in-octets", ("if_in_octets", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.IfInOctets)), ("ether-stat-multicast-pkt", ("ether_stat_multicast_pkt", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.EtherStatMulticastPkt)), ("ether-stat-broadcast-pkt", ("ether_stat_broadcast_pkt", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.EtherStatBroadcastPkt)), ("ether-stat-undersized-pkt", ("ether_stat_undersized_pkt", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.EtherStatUndersizedPkt)), ("out-octets", ("out_octets", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutOctets)), ("in-pause-frame", ("in_pause_frame", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPauseFrame)), ("in-good-bytes", ("in_good_bytes", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InGoodBytes)), ("in8021q-frames", ("in8021q_frames", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.In8021qFrames)), ("in-pkts1519-max-octets", ("in_pkts1519_max_octets", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts1519MaxOctets)), ("in-good-pkts", ("in_good_pkts", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InGoodPkts)), ("in-drop-overrun", ("in_drop_overrun", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropOverrun)), ("in-drop-abort", ("in_drop_abort", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropAbort)), ("in-drop-invalid-vlan", ("in_drop_invalid_vlan", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropInvalidVlan)), ("in-drop-invalid-dmac", ("in_drop_invalid_dmac", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropInvalidDmac)), ("in-drop-invalid-encap", ("in_drop_invalid_encap", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropInvalidEncap)), ("in-drop-other", ("in_drop_other", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropOther)), ("in-mib-giant", ("in_mib_giant", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InMibGiant)), ("in-mib-jabber", ("in_mib_jabber", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InMibJabber)), ("in-mibcrc", ("in_mibcrc", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InMibcrc)), ("in-error-collisions", ("in_error_collisions", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorCollisions)), ("in-error-symbol", ("in_error_symbol", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorSymbol)), ("out-good-bytes", ("out_good_bytes", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutGoodBytes)), ("out8021q-frames", ("out8021q_frames", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Out8021qFrames)), ("out-pause-frames", ("out_pause_frames", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPauseFrames)), ("out-pkts1519-max-octets", ("out_pkts1519_max_octets", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts1519MaxOctets)), ("out-good-pkts", ("out_good_pkts", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutGoodPkts)), ("out-drop-underrun", ("out_drop_underrun", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutDropUnderrun)), ("out-drop-abort", ("out_drop_abort", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutDropAbort)), ("out-drop-other", ("out_drop_other", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutDropOther)), ("out-error-other", ("out_error_other", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutErrorOther)), ("in-error-giant", ("in_error_giant", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorGiant)), ("in-error-runt", ("in_error_runt", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorRunt)), ("in-error-jabbers", ("in_error_jabbers", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorJabbers)), ("in-error-fragments", ("in_error_fragments", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorFragments)), ("in-error-other", ("in_error_other", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorOther)), ("in-pkt64-octet", ("in_pkt64_octet", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkt64Octet)), ("in-pkts65-to127-octets", ("in_pkts65_to127_octets", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts65To127Octets)), ("in-pkts128-to255-octets", ("in_pkts128_to255_octets", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts128To255Octets)), ("in-pkts256-to511-octets", ("in_pkts256_to511_octets", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts256To511Octets)), ("in-pkts512-to1023-octets", ("in_pkts512_to1023_octets", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts512To1023Octets)), ("in-pkts1024-to1518-octets", ("in_pkts1024_to1518_octets", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts1024To1518Octets)), ("outpkt64octet", ("outpkt64octet", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Outpkt64octet)), ("out-pkts65127-octets", ("out_pkts65127_octets", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts65127Octets)), ("out-pkts128255-octets", ("out_pkts128255_octets", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts128255Octets)), ("out-pkts256511-octets", ("out_pkts256511_octets", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts256511Octets)), ("out-pkts5121023-octets", ("out_pkts5121023_octets", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts5121023Octets)), ("out-pkts10241518-octets", ("out_pkts10241518_octets", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts10241518Octets)), ("rx-util", ("rx_util", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.RxUtil)), ("tx-util", ("tx_util", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxUtil)), ("tx-undersized-pkt", ("tx_undersized_pkt", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxUndersizedPkt)), ("tx-oversized-pkt", ("tx_oversized_pkt", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxOversizedPkt)), ("tx-fragments", ("tx_fragments", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxFragments)), ("tx-jabber", ("tx_jabber", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxJabber)), ("tx-bad-fcs", ("tx_bad_fcs", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxBadFcs))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                    ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None
                                                self.sec30_support = None

                                                self.rx_pkt = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.RxPkt()
                                                self.rx_pkt.parent = self
                                                self._children_name_map["rx_pkt"] = "rx-pkt"

                                                self.stat_pkt = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.StatPkt()
                                                self.stat_pkt.parent = self
                                                self._children_name_map["stat_pkt"] = "stat-pkt"

                                                self.octet_stat = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OctetStat()
                                                self.octet_stat.parent = self
                                                self._children_name_map["octet_stat"] = "octet-stat"

                                                self.oversize_pkt_stat = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OversizePktStat()
                                                self.oversize_pkt_stat.parent = self
                                                self._children_name_map["oversize_pkt_stat"] = "oversize-pkt-stat"

                                                self.fcs_errors_stat = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.FcsErrorsStat()
                                                self.fcs_errors_stat.parent = self
                                                self._children_name_map["fcs_errors_stat"] = "fcs-errors-stat"

                                                self.long_frames_stat = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.LongFramesStat()
                                                self.long_frames_stat.parent = self
                                                self._children_name_map["long_frames_stat"] = "long-frames-stat"

                                                self.jabber_stat = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.JabberStat()
                                                self.jabber_stat.parent = self
                                                self._children_name_map["jabber_stat"] = "jabber-stat"

                                                self.ether64_octets = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether64Octets()
                                                self.ether64_octets.parent = self
                                                self._children_name_map["ether64_octets"] = "ether64-octets"

                                                self.ether65127_octet = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether65127Octet()
                                                self.ether65127_octet.parent = self
                                                self._children_name_map["ether65127_octet"] = "ether65127-octet"

                                                self.ether128255_octet = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether128255Octet()
                                                self.ether128255_octet.parent = self
                                                self._children_name_map["ether128255_octet"] = "ether128255-octet"

                                                self.ether256511_octet = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether256511Octet()
                                                self.ether256511_octet.parent = self
                                                self._children_name_map["ether256511_octet"] = "ether256511-octet"

                                                self.ether5121023_octet = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether5121023Octet()
                                                self.ether5121023_octet.parent = self
                                                self._children_name_map["ether5121023_octet"] = "ether5121023-octet"

                                                self.ether10241518_octet = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether10241518Octet()
                                                self.ether10241518_octet.parent = self
                                                self._children_name_map["ether10241518_octet"] = "ether10241518-octet"

                                                self.in_ucast_pkt = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InUcastPkt()
                                                self.in_ucast_pkt.parent = self
                                                self._children_name_map["in_ucast_pkt"] = "in-ucast-pkt"

                                                self.in_mcast_pkt = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InMcastPkt()
                                                self.in_mcast_pkt.parent = self
                                                self._children_name_map["in_mcast_pkt"] = "in-mcast-pkt"

                                                self.in_bcast_pkt = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InBcastPkt()
                                                self.in_bcast_pkt.parent = self
                                                self._children_name_map["in_bcast_pkt"] = "in-bcast-pkt"

                                                self.out_ucast_pkt = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutUcastPkt()
                                                self.out_ucast_pkt.parent = self
                                                self._children_name_map["out_ucast_pkt"] = "out-ucast-pkt"

                                                self.out_bcast_pkt = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutBcastPkt()
                                                self.out_bcast_pkt.parent = self
                                                self._children_name_map["out_bcast_pkt"] = "out-bcast-pkt"

                                                self.out_mcast_pkt = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutMcastPkt()
                                                self.out_mcast_pkt.parent = self
                                                self._children_name_map["out_mcast_pkt"] = "out-mcast-pkt"

                                                self.tx_pkt = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxPkt()
                                                self.tx_pkt.parent = self
                                                self._children_name_map["tx_pkt"] = "tx-pkt"

                                                self.if_in_errors = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.IfInErrors()
                                                self.if_in_errors.parent = self
                                                self._children_name_map["if_in_errors"] = "if-in-errors"

                                                self.if_in_octets = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.IfInOctets()
                                                self.if_in_octets.parent = self
                                                self._children_name_map["if_in_octets"] = "if-in-octets"

                                                self.ether_stat_multicast_pkt = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.EtherStatMulticastPkt()
                                                self.ether_stat_multicast_pkt.parent = self
                                                self._children_name_map["ether_stat_multicast_pkt"] = "ether-stat-multicast-pkt"

                                                self.ether_stat_broadcast_pkt = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.EtherStatBroadcastPkt()
                                                self.ether_stat_broadcast_pkt.parent = self
                                                self._children_name_map["ether_stat_broadcast_pkt"] = "ether-stat-broadcast-pkt"

                                                self.ether_stat_undersized_pkt = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.EtherStatUndersizedPkt()
                                                self.ether_stat_undersized_pkt.parent = self
                                                self._children_name_map["ether_stat_undersized_pkt"] = "ether-stat-undersized-pkt"

                                                self.out_octets = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutOctets()
                                                self.out_octets.parent = self
                                                self._children_name_map["out_octets"] = "out-octets"

                                                self.in_pause_frame = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPauseFrame()
                                                self.in_pause_frame.parent = self
                                                self._children_name_map["in_pause_frame"] = "in-pause-frame"

                                                self.in_good_bytes = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InGoodBytes()
                                                self.in_good_bytes.parent = self
                                                self._children_name_map["in_good_bytes"] = "in-good-bytes"

                                                self.in8021q_frames = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.In8021qFrames()
                                                self.in8021q_frames.parent = self
                                                self._children_name_map["in8021q_frames"] = "in8021q-frames"

                                                self.in_pkts1519_max_octets = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts1519MaxOctets()
                                                self.in_pkts1519_max_octets.parent = self
                                                self._children_name_map["in_pkts1519_max_octets"] = "in-pkts1519-max-octets"

                                                self.in_good_pkts = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InGoodPkts()
                                                self.in_good_pkts.parent = self
                                                self._children_name_map["in_good_pkts"] = "in-good-pkts"

                                                self.in_drop_overrun = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropOverrun()
                                                self.in_drop_overrun.parent = self
                                                self._children_name_map["in_drop_overrun"] = "in-drop-overrun"

                                                self.in_drop_abort = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropAbort()
                                                self.in_drop_abort.parent = self
                                                self._children_name_map["in_drop_abort"] = "in-drop-abort"

                                                self.in_drop_invalid_vlan = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropInvalidVlan()
                                                self.in_drop_invalid_vlan.parent = self
                                                self._children_name_map["in_drop_invalid_vlan"] = "in-drop-invalid-vlan"

                                                self.in_drop_invalid_dmac = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropInvalidDmac()
                                                self.in_drop_invalid_dmac.parent = self
                                                self._children_name_map["in_drop_invalid_dmac"] = "in-drop-invalid-dmac"

                                                self.in_drop_invalid_encap = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropInvalidEncap()
                                                self.in_drop_invalid_encap.parent = self
                                                self._children_name_map["in_drop_invalid_encap"] = "in-drop-invalid-encap"

                                                self.in_drop_other = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropOther()
                                                self.in_drop_other.parent = self
                                                self._children_name_map["in_drop_other"] = "in-drop-other"

                                                self.in_mib_giant = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InMibGiant()
                                                self.in_mib_giant.parent = self
                                                self._children_name_map["in_mib_giant"] = "in-mib-giant"

                                                self.in_mib_jabber = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InMibJabber()
                                                self.in_mib_jabber.parent = self
                                                self._children_name_map["in_mib_jabber"] = "in-mib-jabber"

                                                self.in_mibcrc = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InMibcrc()
                                                self.in_mibcrc.parent = self
                                                self._children_name_map["in_mibcrc"] = "in-mibcrc"

                                                self.in_error_collisions = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorCollisions()
                                                self.in_error_collisions.parent = self
                                                self._children_name_map["in_error_collisions"] = "in-error-collisions"

                                                self.in_error_symbol = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorSymbol()
                                                self.in_error_symbol.parent = self
                                                self._children_name_map["in_error_symbol"] = "in-error-symbol"

                                                self.out_good_bytes = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutGoodBytes()
                                                self.out_good_bytes.parent = self
                                                self._children_name_map["out_good_bytes"] = "out-good-bytes"

                                                self.out8021q_frames = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Out8021qFrames()
                                                self.out8021q_frames.parent = self
                                                self._children_name_map["out8021q_frames"] = "out8021q-frames"

                                                self.out_pause_frames = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPauseFrames()
                                                self.out_pause_frames.parent = self
                                                self._children_name_map["out_pause_frames"] = "out-pause-frames"

                                                self.out_pkts1519_max_octets = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts1519MaxOctets()
                                                self.out_pkts1519_max_octets.parent = self
                                                self._children_name_map["out_pkts1519_max_octets"] = "out-pkts1519-max-octets"

                                                self.out_good_pkts = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutGoodPkts()
                                                self.out_good_pkts.parent = self
                                                self._children_name_map["out_good_pkts"] = "out-good-pkts"

                                                self.out_drop_underrun = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutDropUnderrun()
                                                self.out_drop_underrun.parent = self
                                                self._children_name_map["out_drop_underrun"] = "out-drop-underrun"

                                                self.out_drop_abort = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutDropAbort()
                                                self.out_drop_abort.parent = self
                                                self._children_name_map["out_drop_abort"] = "out-drop-abort"

                                                self.out_drop_other = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutDropOther()
                                                self.out_drop_other.parent = self
                                                self._children_name_map["out_drop_other"] = "out-drop-other"

                                                self.out_error_other = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutErrorOther()
                                                self.out_error_other.parent = self
                                                self._children_name_map["out_error_other"] = "out-error-other"

                                                self.in_error_giant = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorGiant()
                                                self.in_error_giant.parent = self
                                                self._children_name_map["in_error_giant"] = "in-error-giant"

                                                self.in_error_runt = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorRunt()
                                                self.in_error_runt.parent = self
                                                self._children_name_map["in_error_runt"] = "in-error-runt"

                                                self.in_error_jabbers = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorJabbers()
                                                self.in_error_jabbers.parent = self
                                                self._children_name_map["in_error_jabbers"] = "in-error-jabbers"

                                                self.in_error_fragments = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorFragments()
                                                self.in_error_fragments.parent = self
                                                self._children_name_map["in_error_fragments"] = "in-error-fragments"

                                                self.in_error_other = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorOther()
                                                self.in_error_other.parent = self
                                                self._children_name_map["in_error_other"] = "in-error-other"

                                                self.in_pkt64_octet = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkt64Octet()
                                                self.in_pkt64_octet.parent = self
                                                self._children_name_map["in_pkt64_octet"] = "in-pkt64-octet"

                                                self.in_pkts65_to127_octets = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts65To127Octets()
                                                self.in_pkts65_to127_octets.parent = self
                                                self._children_name_map["in_pkts65_to127_octets"] = "in-pkts65-to127-octets"

                                                self.in_pkts128_to255_octets = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts128To255Octets()
                                                self.in_pkts128_to255_octets.parent = self
                                                self._children_name_map["in_pkts128_to255_octets"] = "in-pkts128-to255-octets"

                                                self.in_pkts256_to511_octets = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts256To511Octets()
                                                self.in_pkts256_to511_octets.parent = self
                                                self._children_name_map["in_pkts256_to511_octets"] = "in-pkts256-to511-octets"

                                                self.in_pkts512_to1023_octets = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts512To1023Octets()
                                                self.in_pkts512_to1023_octets.parent = self
                                                self._children_name_map["in_pkts512_to1023_octets"] = "in-pkts512-to1023-octets"

                                                self.in_pkts1024_to1518_octets = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts1024To1518Octets()
                                                self.in_pkts1024_to1518_octets.parent = self
                                                self._children_name_map["in_pkts1024_to1518_octets"] = "in-pkts1024-to1518-octets"

                                                self.outpkt64octet = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Outpkt64octet()
                                                self.outpkt64octet.parent = self
                                                self._children_name_map["outpkt64octet"] = "outpkt64octet"

                                                self.out_pkts65127_octets = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts65127Octets()
                                                self.out_pkts65127_octets.parent = self
                                                self._children_name_map["out_pkts65127_octets"] = "out-pkts65127-octets"

                                                self.out_pkts128255_octets = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts128255Octets()
                                                self.out_pkts128255_octets.parent = self
                                                self._children_name_map["out_pkts128255_octets"] = "out-pkts128255-octets"

                                                self.out_pkts256511_octets = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts256511Octets()
                                                self.out_pkts256511_octets.parent = self
                                                self._children_name_map["out_pkts256511_octets"] = "out-pkts256511-octets"

                                                self.out_pkts5121023_octets = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts5121023Octets()
                                                self.out_pkts5121023_octets.parent = self
                                                self._children_name_map["out_pkts5121023_octets"] = "out-pkts5121023-octets"

                                                self.out_pkts10241518_octets = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts10241518Octets()
                                                self.out_pkts10241518_octets.parent = self
                                                self._children_name_map["out_pkts10241518_octets"] = "out-pkts10241518-octets"

                                                self.rx_util = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.RxUtil()
                                                self.rx_util.parent = self
                                                self._children_name_map["rx_util"] = "rx-util"

                                                self.tx_util = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxUtil()
                                                self.tx_util.parent = self
                                                self._children_name_map["tx_util"] = "tx-util"

                                                self.tx_undersized_pkt = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxUndersizedPkt()
                                                self.tx_undersized_pkt.parent = self
                                                self._children_name_map["tx_undersized_pkt"] = "tx-undersized-pkt"

                                                self.tx_oversized_pkt = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxOversizedPkt()
                                                self.tx_oversized_pkt.parent = self
                                                self._children_name_map["tx_oversized_pkt"] = "tx-oversized-pkt"

                                                self.tx_fragments = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxFragments()
                                                self.tx_fragments.parent = self
                                                self._children_name_map["tx_fragments"] = "tx-fragments"

                                                self.tx_jabber = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxJabber()
                                                self.tx_jabber.parent = self
                                                self._children_name_map["tx_jabber"] = "tx-jabber"

                                                self.tx_bad_fcs = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxBadFcs()
                                                self.tx_bad_fcs.parent = self
                                                self._children_name_map["tx_bad_fcs"] = "tx-bad-fcs"
                                                self._segment_path = lambda: "minute15-ether-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear30_sec_time', 'last_clear15_min_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                            class RxPkt(Entity):
                                                """
                                                RX PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.RxPkt, self).__init__()

                                                    self.yang_name = "rx-pkt"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "rx-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.RxPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class StatPkt(Entity):
                                                """
                                                STAT PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.StatPkt, self).__init__()

                                                    self.yang_name = "stat-pkt"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "stat-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.StatPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OctetStat(Entity):
                                                """
                                                OCTET STAT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OctetStat, self).__init__()

                                                    self.yang_name = "octet-stat"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "octet-stat"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OctetStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OversizePktStat(Entity):
                                                """
                                                OVERSIZE PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OversizePktStat, self).__init__()

                                                    self.yang_name = "oversize-pkt-stat"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "oversize-pkt-stat"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OversizePktStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class FcsErrorsStat(Entity):
                                                """
                                                FCS ERR
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.FcsErrorsStat, self).__init__()

                                                    self.yang_name = "fcs-errors-stat"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "fcs-errors-stat"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.FcsErrorsStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class LongFramesStat(Entity):
                                                """
                                                LONG FRAMES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.LongFramesStat, self).__init__()

                                                    self.yang_name = "long-frames-stat"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "long-frames-stat"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.LongFramesStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class JabberStat(Entity):
                                                """
                                                JABBER STATS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.JabberStat, self).__init__()

                                                    self.yang_name = "jabber-stat"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "jabber-stat"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.JabberStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class Ether64Octets(Entity):
                                                """
                                                SIXTY FOUR OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether64Octets, self).__init__()

                                                    self.yang_name = "ether64-octets"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ether64-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether64Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class Ether65127Octet(Entity):
                                                """
                                                OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether65127Octet, self).__init__()

                                                    self.yang_name = "ether65127-octet"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ether65127-octet"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether65127Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class Ether128255Octet(Entity):
                                                """
                                                TFF OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether128255Octet, self).__init__()

                                                    self.yang_name = "ether128255-octet"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ether128255-octet"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether128255Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class Ether256511Octet(Entity):
                                                """
                                                FOO OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether256511Octet, self).__init__()

                                                    self.yang_name = "ether256511-octet"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ether256511-octet"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether256511Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class Ether5121023Octet(Entity):
                                                """
                                                OZTT OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether5121023Octet, self).__init__()

                                                    self.yang_name = "ether5121023-octet"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ether5121023-octet"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether5121023Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class Ether10241518Octet(Entity):
                                                """
                                                OFO OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether10241518Octet, self).__init__()

                                                    self.yang_name = "ether10241518-octet"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ether10241518-octet"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether10241518Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InUcastPkt(Entity):
                                                """
                                                IN UCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InUcastPkt, self).__init__()

                                                    self.yang_name = "in-ucast-pkt"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-ucast-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InUcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InMcastPkt(Entity):
                                                """
                                                IN MCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InMcastPkt, self).__init__()

                                                    self.yang_name = "in-mcast-pkt"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-mcast-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InMcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InBcastPkt(Entity):
                                                """
                                                IN BCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InBcastPkt, self).__init__()

                                                    self.yang_name = "in-bcast-pkt"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-bcast-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InBcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutUcastPkt(Entity):
                                                """
                                                OUT UCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutUcastPkt, self).__init__()

                                                    self.yang_name = "out-ucast-pkt"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-ucast-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutUcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutBcastPkt(Entity):
                                                """
                                                OUT BCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutBcastPkt, self).__init__()

                                                    self.yang_name = "out-bcast-pkt"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-bcast-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutBcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutMcastPkt(Entity):
                                                """
                                                OUT MCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutMcastPkt, self).__init__()

                                                    self.yang_name = "out-mcast-pkt"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-mcast-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutMcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class TxPkt(Entity):
                                                """
                                                TX PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxPkt, self).__init__()

                                                    self.yang_name = "tx-pkt"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "tx-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class IfInErrors(Entity):
                                                """
                                                IFIN ERRORS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.IfInErrors, self).__init__()

                                                    self.yang_name = "if-in-errors"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "if-in-errors"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.IfInErrors, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class IfInOctets(Entity):
                                                """
                                                IFIN OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.IfInOctets, self).__init__()

                                                    self.yang_name = "if-in-octets"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "if-in-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.IfInOctets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class EtherStatMulticastPkt(Entity):
                                                """
                                                ETHER STAT MULTICAST PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.EtherStatMulticastPkt, self).__init__()

                                                    self.yang_name = "ether-stat-multicast-pkt"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ether-stat-multicast-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.EtherStatMulticastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class EtherStatBroadcastPkt(Entity):
                                                """
                                                ETHER STAT BROADCAST PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.EtherStatBroadcastPkt, self).__init__()

                                                    self.yang_name = "ether-stat-broadcast-pkt"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ether-stat-broadcast-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.EtherStatBroadcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class EtherStatUndersizedPkt(Entity):
                                                """
                                                ETHER STAT UNDERSIZED PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.EtherStatUndersizedPkt, self).__init__()

                                                    self.yang_name = "ether-stat-undersized-pkt"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ether-stat-undersized-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.EtherStatUndersizedPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutOctets(Entity):
                                                """
                                                OUT OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutOctets, self).__init__()

                                                    self.yang_name = "out-octets"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutOctets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPauseFrame(Entity):
                                                """
                                                INPUT PAUSE FRAME
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPauseFrame, self).__init__()

                                                    self.yang_name = "in-pause-frame"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pause-frame"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPauseFrame, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InGoodBytes(Entity):
                                                """
                                                INPUT GOOD BYTES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InGoodBytes, self).__init__()

                                                    self.yang_name = "in-good-bytes"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-good-bytes"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InGoodBytes, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class In8021qFrames(Entity):
                                                """
                                                INPUT 802 1Q FRAMES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.In8021qFrames, self).__init__()

                                                    self.yang_name = "in8021q-frames"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in8021q-frames"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.In8021qFrames, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPkts1519MaxOctets(Entity):
                                                """
                                                INPUT PKTS 1519MAX OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts1519MaxOctets, self).__init__()

                                                    self.yang_name = "in-pkts1519-max-octets"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts1519-max-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts1519MaxOctets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InGoodPkts(Entity):
                                                """
                                                INPUT GOOD PKTS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InGoodPkts, self).__init__()

                                                    self.yang_name = "in-good-pkts"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-good-pkts"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InGoodPkts, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InDropOverrun(Entity):
                                                """
                                                INPUT DROP OVERRUN
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropOverrun, self).__init__()

                                                    self.yang_name = "in-drop-overrun"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-drop-overrun"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropOverrun, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InDropAbort(Entity):
                                                """
                                                INPUT DROP ABORT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropAbort, self).__init__()

                                                    self.yang_name = "in-drop-abort"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-drop-abort"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropAbort, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InDropInvalidVlan(Entity):
                                                """
                                                INPUT DROP INVALID VLAN
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropInvalidVlan, self).__init__()

                                                    self.yang_name = "in-drop-invalid-vlan"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-drop-invalid-vlan"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropInvalidVlan, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InDropInvalidDmac(Entity):
                                                """
                                                INPUT DROP INVALID DMAC
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropInvalidDmac, self).__init__()

                                                    self.yang_name = "in-drop-invalid-dmac"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-drop-invalid-dmac"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropInvalidDmac, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InDropInvalidEncap(Entity):
                                                """
                                                INPUT DROP INVALID ENCAP
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropInvalidEncap, self).__init__()

                                                    self.yang_name = "in-drop-invalid-encap"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-drop-invalid-encap"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropInvalidEncap, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InDropOther(Entity):
                                                """
                                                INPUT DROP OTHER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropOther, self).__init__()

                                                    self.yang_name = "in-drop-other"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-drop-other"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropOther, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InMibGiant(Entity):
                                                """
                                                INPUT MIB GIANT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InMibGiant, self).__init__()

                                                    self.yang_name = "in-mib-giant"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-mib-giant"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InMibGiant, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InMibJabber(Entity):
                                                """
                                                INPUT MIB JABBER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InMibJabber, self).__init__()

                                                    self.yang_name = "in-mib-jabber"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-mib-jabber"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InMibJabber, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InMibcrc(Entity):
                                                """
                                                IN MIB CRC
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InMibcrc, self).__init__()

                                                    self.yang_name = "in-mibcrc"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-mibcrc"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InMibcrc, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InErrorCollisions(Entity):
                                                """
                                                IN ERROR COLLISIONS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorCollisions, self).__init__()

                                                    self.yang_name = "in-error-collisions"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-error-collisions"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorCollisions, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InErrorSymbol(Entity):
                                                """
                                                IN ERROR SYMBOL
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorSymbol, self).__init__()

                                                    self.yang_name = "in-error-symbol"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-error-symbol"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorSymbol, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutGoodBytes(Entity):
                                                """
                                                OUT GOOD BYTES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutGoodBytes, self).__init__()

                                                    self.yang_name = "out-good-bytes"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-good-bytes"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutGoodBytes, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class Out8021qFrames(Entity):
                                                """
                                                OUT 802 1Q FRAMES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Out8021qFrames, self).__init__()

                                                    self.yang_name = "out8021q-frames"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out8021q-frames"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Out8021qFrames, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutPauseFrames(Entity):
                                                """
                                                OUT PAUSE FRAMES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPauseFrames, self).__init__()

                                                    self.yang_name = "out-pause-frames"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-pause-frames"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPauseFrames, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutPkts1519MaxOctets(Entity):
                                                """
                                                OUT PKTS 1519 MAX OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts1519MaxOctets, self).__init__()

                                                    self.yang_name = "out-pkts1519-max-octets"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-pkts1519-max-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts1519MaxOctets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutGoodPkts(Entity):
                                                """
                                                OUT GOOD PKTS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutGoodPkts, self).__init__()

                                                    self.yang_name = "out-good-pkts"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-good-pkts"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutGoodPkts, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutDropUnderrun(Entity):
                                                """
                                                OUT DROP UNDERRUN
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutDropUnderrun, self).__init__()

                                                    self.yang_name = "out-drop-underrun"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-drop-underrun"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutDropUnderrun, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutDropAbort(Entity):
                                                """
                                                OUT DROP ABORT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutDropAbort, self).__init__()

                                                    self.yang_name = "out-drop-abort"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-drop-abort"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutDropAbort, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutDropOther(Entity):
                                                """
                                                OUT DROP OTHER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutDropOther, self).__init__()

                                                    self.yang_name = "out-drop-other"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-drop-other"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutDropOther, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutErrorOther(Entity):
                                                """
                                                OUT ERROR OTHER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutErrorOther, self).__init__()

                                                    self.yang_name = "out-error-other"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-error-other"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutErrorOther, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InErrorGiant(Entity):
                                                """
                                                IN ERROR GIANT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorGiant, self).__init__()

                                                    self.yang_name = "in-error-giant"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-error-giant"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorGiant, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InErrorRunt(Entity):
                                                """
                                                IN ERROR RUNT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorRunt, self).__init__()

                                                    self.yang_name = "in-error-runt"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-error-runt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorRunt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InErrorJabbers(Entity):
                                                """
                                                IN ERROR JABBERS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorJabbers, self).__init__()

                                                    self.yang_name = "in-error-jabbers"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-error-jabbers"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorJabbers, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InErrorFragments(Entity):
                                                """
                                                IN ERROR FRAGMENTS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorFragments, self).__init__()

                                                    self.yang_name = "in-error-fragments"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-error-fragments"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorFragments, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InErrorOther(Entity):
                                                """
                                                IN ERROR OTHER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorOther, self).__init__()

                                                    self.yang_name = "in-error-other"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-error-other"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorOther, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPkt64Octet(Entity):
                                                """
                                                IN PKT 64 OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkt64Octet, self).__init__()

                                                    self.yang_name = "in-pkt64-octet"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkt64-octet"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkt64Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPkts65To127Octets(Entity):
                                                """
                                                IN PKTS 65 127OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts65To127Octets, self).__init__()

                                                    self.yang_name = "in-pkts65-to127-octets"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts65-to127-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts65To127Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPkts128To255Octets(Entity):
                                                """
                                                IN PKTS 128 255 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts128To255Octets, self).__init__()

                                                    self.yang_name = "in-pkts128-to255-octets"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts128-to255-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts128To255Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPkts256To511Octets(Entity):
                                                """
                                                IN PKTS 256 511 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts256To511Octets, self).__init__()

                                                    self.yang_name = "in-pkts256-to511-octets"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts256-to511-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts256To511Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPkts512To1023Octets(Entity):
                                                """
                                                IN PKTS 512 1023 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts512To1023Octets, self).__init__()

                                                    self.yang_name = "in-pkts512-to1023-octets"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts512-to1023-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts512To1023Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPkts1024To1518Octets(Entity):
                                                """
                                                IN PKTS 1024 1518 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts1024To1518Octets, self).__init__()

                                                    self.yang_name = "in-pkts1024-to1518-octets"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts1024-to1518-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts1024To1518Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class Outpkt64octet(Entity):
                                                """
                                                OUT PKT 64 OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Outpkt64octet, self).__init__()

                                                    self.yang_name = "outpkt64octet"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "outpkt64octet"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Outpkt64octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutPkts65127Octets(Entity):
                                                """
                                                OUT PKTS 65 127OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts65127Octets, self).__init__()

                                                    self.yang_name = "out-pkts65127-octets"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-pkts65127-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts65127Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutPkts128255Octets(Entity):
                                                """
                                                OUT PKTS 128 255 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts128255Octets, self).__init__()

                                                    self.yang_name = "out-pkts128255-octets"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-pkts128255-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts128255Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutPkts256511Octets(Entity):
                                                """
                                                OUT PKTS 256 511 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts256511Octets, self).__init__()

                                                    self.yang_name = "out-pkts256511-octets"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-pkts256511-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts256511Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutPkts5121023Octets(Entity):
                                                """
                                                OUT PKTS 512 1023 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts5121023Octets, self).__init__()

                                                    self.yang_name = "out-pkts5121023-octets"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-pkts5121023-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts5121023Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutPkts10241518Octets(Entity):
                                                """
                                                OUT PKTS 1024 1518 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts10241518Octets, self).__init__()

                                                    self.yang_name = "out-pkts10241518-octets"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-pkts10241518-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts10241518Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class RxUtil(Entity):
                                                """
                                                Rx Utilization in Percent
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: str
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.RxUtil, self).__init__()

                                                    self.yang_name = "rx-util"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                        ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "rx-util"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.RxUtil, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class TxUtil(Entity):
                                                """
                                                Tx Utilization in Percent
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: str
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxUtil, self).__init__()

                                                    self.yang_name = "tx-util"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                        ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "tx-util"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxUtil, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class TxUndersizedPkt(Entity):
                                                """
                                                TX Undersized Pkt
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxUndersizedPkt, self).__init__()

                                                    self.yang_name = "tx-undersized-pkt"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "tx-undersized-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxUndersizedPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class TxOversizedPkt(Entity):
                                                """
                                                TX Oversized Pkt
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxOversizedPkt, self).__init__()

                                                    self.yang_name = "tx-oversized-pkt"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "tx-oversized-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxOversizedPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class TxFragments(Entity):
                                                """
                                                TX Fragments
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxFragments, self).__init__()

                                                    self.yang_name = "tx-fragments"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "tx-fragments"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxFragments, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class TxJabber(Entity):
                                                """
                                                TX Jabber
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxJabber, self).__init__()

                                                    self.yang_name = "tx-jabber"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "tx-jabber"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxJabber, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class TxBadFcs(Entity):
                                                """
                                                TX Bad Fcs
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxBadFcs, self).__init__()

                                                    self.yang_name = "tx-bad-fcs"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "tx-bad-fcs"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxBadFcs, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                            class Minute15FecHistories(Entity):
                                """
                                ETHERNET port interval performance data
                                
                                .. attribute:: minute15_fec_history
                                
                                	ETHERNET port 15\-minute fec performance data
                                	**type**\: list of  		 :py:class:`Minute15FecHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15FecHistories.Minute15FecHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15FecHistories, self).__init__()

                                    self.yang_name = "minute15-fec-histories"
                                    self.yang_parent_name = "ethernet-minute15-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("minute15-fec-history", ("minute15_fec_history", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15FecHistories.Minute15FecHistory))])
                                    self._leafs = OrderedDict()

                                    self.minute15_fec_history = YList(self)
                                    self._segment_path = lambda: "minute15-fec-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15FecHistories, [], name, value)


                                class Minute15FecHistory(Entity):
                                    """
                                    ETHERNET port 15\-minute fec performance
                                    data
                                    
                                    .. attribute:: slot_number  (key)
                                    
                                    	interval slot number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: minute15_fec_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`Minute15FecTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15FecHistories.Minute15FecHistory.Minute15FecTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15FecHistories.Minute15FecHistory, self).__init__()

                                        self.yang_name = "minute15-fec-history"
                                        self.yang_parent_name = "minute15-fec-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['slot_number']
                                        self._child_classes = OrderedDict([("minute15-fec-time-line-instances", ("minute15_fec_time_line_instances", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15FecHistories.Minute15FecHistory.Minute15FecTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('slot_number', (YLeaf(YType.uint32, 'slot-number'), ['int'])),
                                        ])
                                        self.slot_number = None

                                        self.minute15_fec_time_line_instances = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15FecHistories.Minute15FecHistory.Minute15FecTimeLineInstances()
                                        self.minute15_fec_time_line_instances.parent = self
                                        self._children_name_map["minute15_fec_time_line_instances"] = "minute15-fec-time-line-instances"
                                        self._segment_path = lambda: "minute15-fec-history" + "[slot-number='" + str(self.slot_number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15FecHistories.Minute15FecHistory, ['slot_number'], name, value)


                                    class Minute15FecTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: minute15_fec_time_line_instance
                                        
                                        	port 15\-minute fec performance data
                                        	**type**\: list of  		 :py:class:`Minute15FecTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15FecHistories.Minute15FecHistory.Minute15FecTimeLineInstances.Minute15FecTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15FecHistories.Minute15FecHistory.Minute15FecTimeLineInstances, self).__init__()

                                            self.yang_name = "minute15-fec-time-line-instances"
                                            self.yang_parent_name = "minute15-fec-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("minute15-fec-time-line-instance", ("minute15_fec_time_line_instance", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15FecHistories.Minute15FecHistory.Minute15FecTimeLineInstances.Minute15FecTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.minute15_fec_time_line_instance = YList(self)
                                            self._segment_path = lambda: "minute15-fec-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15FecHistories.Minute15FecHistory.Minute15FecTimeLineInstances, [], name, value)


                                        class Minute15FecTimeLineInstance(Entity):
                                            """
                                            port 15\-minute fec performance data
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ec_bits
                                            
                                            	EC BITS
                                            	**type**\:  :py:class:`EcBits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15FecHistories.Minute15FecHistory.Minute15FecTimeLineInstances.Minute15FecTimeLineInstance.EcBits>`
                                            
                                            .. attribute:: uc_words
                                            
                                            	UC WORDS
                                            	**type**\:  :py:class:`UcWords <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15FecHistories.Minute15FecHistory.Minute15FecTimeLineInstances.Minute15FecTimeLineInstance.UcWords>`
                                            
                                            .. attribute:: pre_fec_ber
                                            
                                            	Pre FEC BER
                                            	**type**\:  :py:class:`PreFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15FecHistories.Minute15FecHistory.Minute15FecTimeLineInstances.Minute15FecTimeLineInstance.PreFecBer>`
                                            
                                            .. attribute:: post_fec_ber
                                            
                                            	Post FEC BER
                                            	**type**\:  :py:class:`PostFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15FecHistories.Minute15FecHistory.Minute15FecTimeLineInstances.Minute15FecTimeLineInstance.PostFecBer>`
                                            
                                            .. attribute:: q
                                            
                                            	Q
                                            	**type**\:  :py:class:`Q <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15FecHistories.Minute15FecHistory.Minute15FecTimeLineInstances.Minute15FecTimeLineInstance.Q>`
                                            
                                            .. attribute:: qmargin
                                            
                                            	Q Margin
                                            	**type**\:  :py:class:`Qmargin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15FecHistories.Minute15FecHistory.Minute15FecTimeLineInstances.Minute15FecTimeLineInstance.Qmargin>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15FecHistories.Minute15FecHistory.Minute15FecTimeLineInstances.Minute15FecTimeLineInstance, self).__init__()

                                                self.yang_name = "minute15-fec-time-line-instance"
                                                self.yang_parent_name = "minute15-fec-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("ec-bits", ("ec_bits", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15FecHistories.Minute15FecHistory.Minute15FecTimeLineInstances.Minute15FecTimeLineInstance.EcBits)), ("uc-words", ("uc_words", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15FecHistories.Minute15FecHistory.Minute15FecTimeLineInstances.Minute15FecTimeLineInstance.UcWords)), ("pre-fec-ber", ("pre_fec_ber", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15FecHistories.Minute15FecHistory.Minute15FecTimeLineInstances.Minute15FecTimeLineInstance.PreFecBer)), ("post-fec-ber", ("post_fec_ber", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15FecHistories.Minute15FecHistory.Minute15FecTimeLineInstances.Minute15FecTimeLineInstance.PostFecBer)), ("q", ("q", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15FecHistories.Minute15FecHistory.Minute15FecTimeLineInstances.Minute15FecTimeLineInstance.Q)), ("qmargin", ("qmargin", PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15FecHistories.Minute15FecHistory.Minute15FecTimeLineInstances.Minute15FecTimeLineInstance.Qmargin))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                    ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear24_hr_time = None
                                                self.sec30_support = None

                                                self.ec_bits = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15FecHistories.Minute15FecHistory.Minute15FecTimeLineInstances.Minute15FecTimeLineInstance.EcBits()
                                                self.ec_bits.parent = self
                                                self._children_name_map["ec_bits"] = "ec-bits"

                                                self.uc_words = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15FecHistories.Minute15FecHistory.Minute15FecTimeLineInstances.Minute15FecTimeLineInstance.UcWords()
                                                self.uc_words.parent = self
                                                self._children_name_map["uc_words"] = "uc-words"

                                                self.pre_fec_ber = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15FecHistories.Minute15FecHistory.Minute15FecTimeLineInstances.Minute15FecTimeLineInstance.PreFecBer()
                                                self.pre_fec_ber.parent = self
                                                self._children_name_map["pre_fec_ber"] = "pre-fec-ber"

                                                self.post_fec_ber = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15FecHistories.Minute15FecHistory.Minute15FecTimeLineInstances.Minute15FecTimeLineInstance.PostFecBer()
                                                self.post_fec_ber.parent = self
                                                self._children_name_map["post_fec_ber"] = "post-fec-ber"

                                                self.q = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15FecHistories.Minute15FecHistory.Minute15FecTimeLineInstances.Minute15FecTimeLineInstance.Q()
                                                self.q.parent = self
                                                self._children_name_map["q"] = "q"

                                                self.qmargin = PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15FecHistories.Minute15FecHistory.Minute15FecTimeLineInstances.Minute15FecTimeLineInstance.Qmargin()
                                                self.qmargin.parent = self
                                                self._children_name_map["qmargin"] = "qmargin"
                                                self._segment_path = lambda: "minute15-fec-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15FecHistories.Minute15FecHistory.Minute15FecTimeLineInstances.Minute15FecTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                            class EcBits(Entity):
                                                """
                                                EC BITS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15FecHistories.Minute15FecHistory.Minute15FecTimeLineInstances.Minute15FecTimeLineInstance.EcBits, self).__init__()

                                                    self.yang_name = "ec-bits"
                                                    self.yang_parent_name = "minute15-fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ec-bits"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15FecHistories.Minute15FecHistory.Minute15FecTimeLineInstances.Minute15FecTimeLineInstance.EcBits, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class UcWords(Entity):
                                                """
                                                UC WORDS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15FecHistories.Minute15FecHistory.Minute15FecTimeLineInstances.Minute15FecTimeLineInstance.UcWords, self).__init__()

                                                    self.yang_name = "uc-words"
                                                    self.yang_parent_name = "minute15-fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "uc-words"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15FecHistories.Minute15FecHistory.Minute15FecTimeLineInstances.Minute15FecTimeLineInstance.UcWords, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class PreFecBer(Entity):
                                                """
                                                Pre FEC BER
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15FecHistories.Minute15FecHistory.Minute15FecTimeLineInstances.Minute15FecTimeLineInstance.PreFecBer, self).__init__()

                                                    self.yang_name = "pre-fec-ber"
                                                    self.yang_parent_name = "minute15-fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.maximum_tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "pre-fec-ber"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15FecHistories.Minute15FecHistory.Minute15FecTimeLineInstances.Minute15FecTimeLineInstance.PreFecBer, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                            class PostFecBer(Entity):
                                                """
                                                Post FEC BER
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15FecHistories.Minute15FecHistory.Minute15FecTimeLineInstances.Minute15FecTimeLineInstance.PostFecBer, self).__init__()

                                                    self.yang_name = "post-fec-ber"
                                                    self.yang_parent_name = "minute15-fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.maximum_tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "post-fec-ber"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15FecHistories.Minute15FecHistory.Minute15FecTimeLineInstances.Minute15FecTimeLineInstance.PostFecBer, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                            class Q(Entity):
                                                """
                                                Q
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15FecHistories.Minute15FecHistory.Minute15FecTimeLineInstances.Minute15FecTimeLineInstance.Q, self).__init__()

                                                    self.yang_name = "q"
                                                    self.yang_parent_name = "minute15-fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.maximum_tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "q"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15FecHistories.Minute15FecHistory.Minute15FecTimeLineInstances.Minute15FecTimeLineInstance.Q, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                            class Qmargin(Entity):
                                                """
                                                Q Margin
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15FecHistories.Minute15FecHistory.Minute15FecTimeLineInstances.Minute15FecTimeLineInstance.Qmargin, self).__init__()

                                                    self.yang_name = "qmargin"
                                                    self.yang_parent_name = "minute15-fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.maximum_tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "qmargin"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15FecHistories.Minute15FecHistory.Minute15FecTimeLineInstances.Minute15FecTimeLineInstance.Qmargin, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


            class DwdmHistory(Entity):
                """
                DWDM controller History performance data
                
                .. attribute:: dwdm_port_histories
                
                	Port performance data
                	**type**\:  :py:class:`DwdmPortHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory, self).__init__()

                    self.yang_name = "dwdm-history"
                    self.yang_parent_name = "periodic"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("dwdm-port-histories", ("dwdm_port_histories", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories))])
                    self._leafs = OrderedDict()

                    self.dwdm_port_histories = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories()
                    self.dwdm_port_histories.parent = self
                    self._children_name_map["dwdm_port_histories"] = "dwdm-port-histories"
                    self._segment_path = lambda: "dwdm-history"
                    self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory, [], name, value)


                class DwdmPortHistories(Entity):
                    """
                    Port performance data
                    
                    .. attribute:: dwdm_port_history
                    
                    	Port performance data
                    	**type**\: list of  		 :py:class:`DwdmPortHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories, self).__init__()

                        self.yang_name = "dwdm-port-histories"
                        self.yang_parent_name = "dwdm-history"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("dwdm-port-history", ("dwdm_port_history", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory))])
                        self._leafs = OrderedDict()

                        self.dwdm_port_history = YList(self)
                        self._segment_path = lambda: "dwdm-port-histories"
                        self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/dwdm-history/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories, [], name, value)


                    class DwdmPortHistory(Entity):
                        """
                        Port performance data
                        
                        .. attribute:: name  (key)
                        
                        	Port name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: dwdm_minute15_history
                        
                        	port current performance data
                        	**type**\:  :py:class:`DwdmMinute15History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History>`
                        
                        .. attribute:: dwdm_hour24_history
                        
                        	port current performance data
                        	**type**\:  :py:class:`DwdmHour24History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory, self).__init__()

                            self.yang_name = "dwdm-port-history"
                            self.yang_parent_name = "dwdm-port-histories"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("dwdm-minute15-history", ("dwdm_minute15_history", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History)), ("dwdm-hour24-history", ("dwdm_hour24_history", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None

                            self.dwdm_minute15_history = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History()
                            self.dwdm_minute15_history.parent = self
                            self._children_name_map["dwdm_minute15_history"] = "dwdm-minute15-history"

                            self.dwdm_hour24_history = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History()
                            self.dwdm_hour24_history.parent = self
                            self._children_name_map["dwdm_hour24_history"] = "dwdm-hour24-history"
                            self._segment_path = lambda: "dwdm-port-history" + "[name='" + str(self.name) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/dwdm-history/dwdm-port-histories/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory, ['name'], name, value)


                        class DwdmMinute15History(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: dwdm_minute15otn_histories
                            
                            	port current performance data
                            	**type**\:  :py:class:`DwdmMinute15otnHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories>`
                            
                            .. attribute:: dwdm_minute15fec_histories
                            
                            	port current performance data
                            	**type**\:  :py:class:`DwdmMinute15fecHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15fecHistories>`
                            
                            .. attribute:: dwdm_minute15_optics_histories
                            
                            	port current performance data
                            	**type**\:  :py:class:`DwdmMinute15OpticsHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History, self).__init__()

                                self.yang_name = "dwdm-minute15-history"
                                self.yang_parent_name = "dwdm-port-history"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dwdm-minute15otn-histories", ("dwdm_minute15otn_histories", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories)), ("dwdm-minute15fec-histories", ("dwdm_minute15fec_histories", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15fecHistories)), ("dwdm-minute15-optics-histories", ("dwdm_minute15_optics_histories", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories))])
                                self._leafs = OrderedDict()

                                self.dwdm_minute15otn_histories = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories()
                                self.dwdm_minute15otn_histories.parent = self
                                self._children_name_map["dwdm_minute15otn_histories"] = "dwdm-minute15otn-histories"

                                self.dwdm_minute15fec_histories = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15fecHistories()
                                self.dwdm_minute15fec_histories.parent = self
                                self._children_name_map["dwdm_minute15fec_histories"] = "dwdm-minute15fec-histories"

                                self.dwdm_minute15_optics_histories = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories()
                                self.dwdm_minute15_optics_histories.parent = self
                                self._children_name_map["dwdm_minute15_optics_histories"] = "dwdm-minute15-optics-histories"
                                self._segment_path = lambda: "dwdm-minute15-history"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History, [], name, value)


                            class DwdmMinute15otnHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: dwdm_minute15otn_history
                                
                                	port 15\-minute otn performance data
                                	**type**\: list of  		 :py:class:`DwdmMinute15otnHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories, self).__init__()

                                    self.yang_name = "dwdm-minute15otn-histories"
                                    self.yang_parent_name = "dwdm-minute15-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("dwdm-minute15otn-history", ("dwdm_minute15otn_history", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory))])
                                    self._leafs = OrderedDict()

                                    self.dwdm_minute15otn_history = YList(self)
                                    self._segment_path = lambda: "dwdm-minute15otn-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories, [], name, value)


                                class DwdmMinute15otnHistory(Entity):
                                    """
                                    port 15\-minute otn performance data
                                    
                                    .. attribute:: number  (key)
                                    
                                    	channel number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: dwdm_minute15otn_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`DwdmMinute15otnTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory, self).__init__()

                                        self.yang_name = "dwdm-minute15otn-history"
                                        self.yang_parent_name = "dwdm-minute15otn-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([("dwdm-minute15otn-time-line-instances", ("dwdm_minute15otn_time_line_instances", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ])
                                        self.number = None

                                        self.dwdm_minute15otn_time_line_instances = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances()
                                        self.dwdm_minute15otn_time_line_instances.parent = self
                                        self._children_name_map["dwdm_minute15otn_time_line_instances"] = "dwdm-minute15otn-time-line-instances"
                                        self._segment_path = lambda: "dwdm-minute15otn-history" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory, ['number'], name, value)


                                    class DwdmMinute15otnTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: dwdm_minute15otn_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of  		 :py:class:`DwdmMinute15otnTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances, self).__init__()

                                            self.yang_name = "dwdm-minute15otn-time-line-instances"
                                            self.yang_parent_name = "dwdm-minute15otn-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dwdm-minute15otn-time-line-instance", ("dwdm_minute15otn_time_line_instance", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.dwdm_minute15otn_time_line_instance = YList(self)
                                            self._segment_path = lambda: "dwdm-minute15otn-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances, [], name, value)


                                        class DwdmMinute15otnTimeLineInstance(Entity):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lbc
                                            
                                            	LBC
                                            	**type**\:  :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.Lbc>`
                                            
                                            .. attribute:: es_ne
                                            
                                            	ES SM NE
                                            	**type**\:  :py:class:`EsNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.EsNe>`
                                            
                                            .. attribute:: esr_ne
                                            
                                            	ESR PM NE
                                            	**type**\:  :py:class:`EsrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.EsrNe>`
                                            
                                            .. attribute:: ses_ne
                                            
                                            	SES SM NE
                                            	**type**\:  :py:class:`SesNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.SesNe>`
                                            
                                            .. attribute:: sesr_ne
                                            
                                            	SESR SM NE
                                            	**type**\:  :py:class:`SesrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.SesrNe>`
                                            
                                            .. attribute:: uas_ne
                                            
                                            	UAS SM NE
                                            	**type**\:  :py:class:`UasNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.UasNe>`
                                            
                                            .. attribute:: bbe_ne
                                            
                                            	BBE SM NE
                                            	**type**\:  :py:class:`BbeNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.BbeNe>`
                                            
                                            .. attribute:: bber_ne
                                            
                                            	BBER SM NE
                                            	**type**\:  :py:class:`BberNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.BberNe>`
                                            
                                            .. attribute:: fc_ne
                                            
                                            	FC SM NE
                                            	**type**\:  :py:class:`FcNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.FcNe>`
                                            
                                            .. attribute:: es_fe
                                            
                                            	ES SM FE
                                            	**type**\:  :py:class:`EsFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.EsFe>`
                                            
                                            .. attribute:: esr_fe
                                            
                                            	ESR PM FE
                                            	**type**\:  :py:class:`EsrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.EsrFe>`
                                            
                                            .. attribute:: ses_fe
                                            
                                            	SES SM FE
                                            	**type**\:  :py:class:`SesFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.SesFe>`
                                            
                                            .. attribute:: sesr_fe
                                            
                                            	SESR SM FE
                                            	**type**\:  :py:class:`SesrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.SesrFe>`
                                            
                                            .. attribute:: uas_fe
                                            
                                            	UAS SM FE
                                            	**type**\:  :py:class:`UasFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.UasFe>`
                                            
                                            .. attribute:: bbe_fe
                                            
                                            	BBE SM FE
                                            	**type**\:  :py:class:`BbeFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.BbeFe>`
                                            
                                            .. attribute:: bber_fe
                                            
                                            	BBER SM FE
                                            	**type**\:  :py:class:`BberFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.BberFe>`
                                            
                                            .. attribute:: fc_fe
                                            
                                            	FC SM FE
                                            	**type**\:  :py:class:`FcFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.FcFe>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance, self).__init__()

                                                self.yang_name = "dwdm-minute15otn-time-line-instance"
                                                self.yang_parent_name = "dwdm-minute15otn-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("lbc", ("lbc", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.Lbc)), ("es-ne", ("es_ne", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.EsNe)), ("esr-ne", ("esr_ne", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.EsrNe)), ("ses-ne", ("ses_ne", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.SesNe)), ("sesr-ne", ("sesr_ne", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.SesrNe)), ("uas-ne", ("uas_ne", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.UasNe)), ("bbe-ne", ("bbe_ne", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.BbeNe)), ("bber-ne", ("bber_ne", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.BberNe)), ("fc-ne", ("fc_ne", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.FcNe)), ("es-fe", ("es_fe", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.EsFe)), ("esr-fe", ("esr_fe", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.EsrFe)), ("ses-fe", ("ses_fe", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.SesFe)), ("sesr-fe", ("sesr_fe", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.SesrFe)), ("uas-fe", ("uas_fe", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.UasFe)), ("bbe-fe", ("bbe_fe", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.BbeFe)), ("bber-fe", ("bber_fe", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.BberFe)), ("fc-fe", ("fc_fe", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.FcFe))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                    ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear24_hr_time = None
                                                self.sec30_support = None

                                                self.lbc = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.Lbc()
                                                self.lbc.parent = self
                                                self._children_name_map["lbc"] = "lbc"

                                                self.es_ne = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.EsNe()
                                                self.es_ne.parent = self
                                                self._children_name_map["es_ne"] = "es-ne"

                                                self.esr_ne = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.EsrNe()
                                                self.esr_ne.parent = self
                                                self._children_name_map["esr_ne"] = "esr-ne"

                                                self.ses_ne = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.SesNe()
                                                self.ses_ne.parent = self
                                                self._children_name_map["ses_ne"] = "ses-ne"

                                                self.sesr_ne = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.SesrNe()
                                                self.sesr_ne.parent = self
                                                self._children_name_map["sesr_ne"] = "sesr-ne"

                                                self.uas_ne = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.UasNe()
                                                self.uas_ne.parent = self
                                                self._children_name_map["uas_ne"] = "uas-ne"

                                                self.bbe_ne = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.BbeNe()
                                                self.bbe_ne.parent = self
                                                self._children_name_map["bbe_ne"] = "bbe-ne"

                                                self.bber_ne = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.BberNe()
                                                self.bber_ne.parent = self
                                                self._children_name_map["bber_ne"] = "bber-ne"

                                                self.fc_ne = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.FcNe()
                                                self.fc_ne.parent = self
                                                self._children_name_map["fc_ne"] = "fc-ne"

                                                self.es_fe = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.EsFe()
                                                self.es_fe.parent = self
                                                self._children_name_map["es_fe"] = "es-fe"

                                                self.esr_fe = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.EsrFe()
                                                self.esr_fe.parent = self
                                                self._children_name_map["esr_fe"] = "esr-fe"

                                                self.ses_fe = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.SesFe()
                                                self.ses_fe.parent = self
                                                self._children_name_map["ses_fe"] = "ses-fe"

                                                self.sesr_fe = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.SesrFe()
                                                self.sesr_fe.parent = self
                                                self._children_name_map["sesr_fe"] = "sesr-fe"

                                                self.uas_fe = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.UasFe()
                                                self.uas_fe.parent = self
                                                self._children_name_map["uas_fe"] = "uas-fe"

                                                self.bbe_fe = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.BbeFe()
                                                self.bbe_fe.parent = self
                                                self._children_name_map["bbe_fe"] = "bbe-fe"

                                                self.bber_fe = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.BberFe()
                                                self.bber_fe.parent = self
                                                self._children_name_map["bber_fe"] = "bber-fe"

                                                self.fc_fe = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.FcFe()
                                                self.fc_fe.parent = self
                                                self._children_name_map["fc_fe"] = "fc-fe"
                                                self._segment_path = lambda: "dwdm-minute15otn-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                            class Lbc(Entity):
                                                """
                                                LBC
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.Lbc, self).__init__()

                                                    self.yang_name = "lbc"
                                                    self.yang_parent_name = "dwdm-minute15otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "lbc"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.Lbc, ['data', 'threshold', 'tca_report'], name, value)


                                            class EsNe(Entity):
                                                """
                                                ES SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.EsNe, self).__init__()

                                                    self.yang_name = "es-ne"
                                                    self.yang_parent_name = "dwdm-minute15otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "es-ne"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.EsNe, ['data', 'threshold', 'tca_report'], name, value)


                                            class EsrNe(Entity):
                                                """
                                                ESR PM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: str
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.EsrNe, self).__init__()

                                                    self.yang_name = "esr-ne"
                                                    self.yang_parent_name = "dwdm-minute15otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                        ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "esr-ne"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.EsrNe, ['data', 'threshold', 'tca_report'], name, value)


                                            class SesNe(Entity):
                                                """
                                                SES SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.SesNe, self).__init__()

                                                    self.yang_name = "ses-ne"
                                                    self.yang_parent_name = "dwdm-minute15otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "ses-ne"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.SesNe, ['data', 'threshold', 'tca_report'], name, value)


                                            class SesrNe(Entity):
                                                """
                                                SESR SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: str
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.SesrNe, self).__init__()

                                                    self.yang_name = "sesr-ne"
                                                    self.yang_parent_name = "dwdm-minute15otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                        ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "sesr-ne"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.SesrNe, ['data', 'threshold', 'tca_report'], name, value)


                                            class UasNe(Entity):
                                                """
                                                UAS SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.UasNe, self).__init__()

                                                    self.yang_name = "uas-ne"
                                                    self.yang_parent_name = "dwdm-minute15otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "uas-ne"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.UasNe, ['data', 'threshold', 'tca_report'], name, value)


                                            class BbeNe(Entity):
                                                """
                                                BBE SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.BbeNe, self).__init__()

                                                    self.yang_name = "bbe-ne"
                                                    self.yang_parent_name = "dwdm-minute15otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "bbe-ne"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.BbeNe, ['data', 'threshold', 'tca_report'], name, value)


                                            class BberNe(Entity):
                                                """
                                                BBER SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: str
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.BberNe, self).__init__()

                                                    self.yang_name = "bber-ne"
                                                    self.yang_parent_name = "dwdm-minute15otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                        ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "bber-ne"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.BberNe, ['data', 'threshold', 'tca_report'], name, value)


                                            class FcNe(Entity):
                                                """
                                                FC SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.FcNe, self).__init__()

                                                    self.yang_name = "fc-ne"
                                                    self.yang_parent_name = "dwdm-minute15otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "fc-ne"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.FcNe, ['data', 'threshold', 'tca_report'], name, value)


                                            class EsFe(Entity):
                                                """
                                                ES SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.EsFe, self).__init__()

                                                    self.yang_name = "es-fe"
                                                    self.yang_parent_name = "dwdm-minute15otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "es-fe"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.EsFe, ['data', 'threshold', 'tca_report'], name, value)


                                            class EsrFe(Entity):
                                                """
                                                ESR PM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: str
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.EsrFe, self).__init__()

                                                    self.yang_name = "esr-fe"
                                                    self.yang_parent_name = "dwdm-minute15otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                        ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "esr-fe"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.EsrFe, ['data', 'threshold', 'tca_report'], name, value)


                                            class SesFe(Entity):
                                                """
                                                SES SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.SesFe, self).__init__()

                                                    self.yang_name = "ses-fe"
                                                    self.yang_parent_name = "dwdm-minute15otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "ses-fe"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.SesFe, ['data', 'threshold', 'tca_report'], name, value)


                                            class SesrFe(Entity):
                                                """
                                                SESR SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: str
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.SesrFe, self).__init__()

                                                    self.yang_name = "sesr-fe"
                                                    self.yang_parent_name = "dwdm-minute15otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                        ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "sesr-fe"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.SesrFe, ['data', 'threshold', 'tca_report'], name, value)


                                            class UasFe(Entity):
                                                """
                                                UAS SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.UasFe, self).__init__()

                                                    self.yang_name = "uas-fe"
                                                    self.yang_parent_name = "dwdm-minute15otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "uas-fe"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.UasFe, ['data', 'threshold', 'tca_report'], name, value)


                                            class BbeFe(Entity):
                                                """
                                                BBE SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.BbeFe, self).__init__()

                                                    self.yang_name = "bbe-fe"
                                                    self.yang_parent_name = "dwdm-minute15otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "bbe-fe"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.BbeFe, ['data', 'threshold', 'tca_report'], name, value)


                                            class BberFe(Entity):
                                                """
                                                BBER SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: str
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.BberFe, self).__init__()

                                                    self.yang_name = "bber-fe"
                                                    self.yang_parent_name = "dwdm-minute15otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                        ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "bber-fe"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.BberFe, ['data', 'threshold', 'tca_report'], name, value)


                                            class FcFe(Entity):
                                                """
                                                FC SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.FcFe, self).__init__()

                                                    self.yang_name = "fc-fe"
                                                    self.yang_parent_name = "dwdm-minute15otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "fc-fe"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15otnHistories.DwdmMinute15otnHistory.DwdmMinute15otnTimeLineInstances.DwdmMinute15otnTimeLineInstance.FcFe, ['data', 'threshold', 'tca_report'], name, value)


                            class DwdmMinute15fecHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: dwdm_minute15fec_history
                                
                                	port 15\-minute fec performance data
                                	**type**\: list of  		 :py:class:`DwdmMinute15fecHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15fecHistories.DwdmMinute15fecHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15fecHistories, self).__init__()

                                    self.yang_name = "dwdm-minute15fec-histories"
                                    self.yang_parent_name = "dwdm-minute15-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("dwdm-minute15fec-history", ("dwdm_minute15fec_history", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15fecHistories.DwdmMinute15fecHistory))])
                                    self._leafs = OrderedDict()

                                    self.dwdm_minute15fec_history = YList(self)
                                    self._segment_path = lambda: "dwdm-minute15fec-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15fecHistories, [], name, value)


                                class DwdmMinute15fecHistory(Entity):
                                    """
                                    port 15\-minute fec performance data
                                    
                                    .. attribute:: number  (key)
                                    
                                    	channel number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: dwdm_minute15fec_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`DwdmMinute15fecTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15fecHistories.DwdmMinute15fecHistory.DwdmMinute15fecTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15fecHistories.DwdmMinute15fecHistory, self).__init__()

                                        self.yang_name = "dwdm-minute15fec-history"
                                        self.yang_parent_name = "dwdm-minute15fec-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([("dwdm-minute15fec-time-line-instances", ("dwdm_minute15fec_time_line_instances", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15fecHistories.DwdmMinute15fecHistory.DwdmMinute15fecTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ])
                                        self.number = None

                                        self.dwdm_minute15fec_time_line_instances = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15fecHistories.DwdmMinute15fecHistory.DwdmMinute15fecTimeLineInstances()
                                        self.dwdm_minute15fec_time_line_instances.parent = self
                                        self._children_name_map["dwdm_minute15fec_time_line_instances"] = "dwdm-minute15fec-time-line-instances"
                                        self._segment_path = lambda: "dwdm-minute15fec-history" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15fecHistories.DwdmMinute15fecHistory, ['number'], name, value)


                                    class DwdmMinute15fecTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: dwdm_minute15fec_time_line_instance
                                        
                                        	port 15\-minute fec performance data by index
                                        	**type**\: list of  		 :py:class:`DwdmMinute15fecTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15fecHistories.DwdmMinute15fecHistory.DwdmMinute15fecTimeLineInstances.DwdmMinute15fecTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15fecHistories.DwdmMinute15fecHistory.DwdmMinute15fecTimeLineInstances, self).__init__()

                                            self.yang_name = "dwdm-minute15fec-time-line-instances"
                                            self.yang_parent_name = "dwdm-minute15fec-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dwdm-minute15fec-time-line-instance", ("dwdm_minute15fec_time_line_instance", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15fecHistories.DwdmMinute15fecHistory.DwdmMinute15fecTimeLineInstances.DwdmMinute15fecTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.dwdm_minute15fec_time_line_instance = YList(self)
                                            self._segment_path = lambda: "dwdm-minute15fec-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15fecHistories.DwdmMinute15fecHistory.DwdmMinute15fecTimeLineInstances, [], name, value)


                                        class DwdmMinute15fecTimeLineInstance(Entity):
                                            """
                                            port 15\-minute fec performance data by
                                            index
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ec_bits
                                            
                                            	EC BITS
                                            	**type**\:  :py:class:`EcBits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15fecHistories.DwdmMinute15fecHistory.DwdmMinute15fecTimeLineInstances.DwdmMinute15fecTimeLineInstance.EcBits>`
                                            
                                            .. attribute:: uc_words
                                            
                                            	UC WORDS
                                            	**type**\:  :py:class:`UcWords <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15fecHistories.DwdmMinute15fecHistory.DwdmMinute15fecTimeLineInstances.DwdmMinute15fecTimeLineInstance.UcWords>`
                                            
                                            .. attribute:: pre_fec_ber
                                            
                                            	Pre FEC BER
                                            	**type**\:  :py:class:`PreFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15fecHistories.DwdmMinute15fecHistory.DwdmMinute15fecTimeLineInstances.DwdmMinute15fecTimeLineInstance.PreFecBer>`
                                            
                                            .. attribute:: post_fec_ber
                                            
                                            	Post FEC BER
                                            	**type**\:  :py:class:`PostFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15fecHistories.DwdmMinute15fecHistory.DwdmMinute15fecTimeLineInstances.DwdmMinute15fecTimeLineInstance.PostFecBer>`
                                            
                                            .. attribute:: q
                                            
                                            	Q
                                            	**type**\:  :py:class:`Q <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15fecHistories.DwdmMinute15fecHistory.DwdmMinute15fecTimeLineInstances.DwdmMinute15fecTimeLineInstance.Q>`
                                            
                                            .. attribute:: qmargin
                                            
                                            	Q Margin
                                            	**type**\:  :py:class:`Qmargin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15fecHistories.DwdmMinute15fecHistory.DwdmMinute15fecTimeLineInstances.DwdmMinute15fecTimeLineInstance.Qmargin>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15fecHistories.DwdmMinute15fecHistory.DwdmMinute15fecTimeLineInstances.DwdmMinute15fecTimeLineInstance, self).__init__()

                                                self.yang_name = "dwdm-minute15fec-time-line-instance"
                                                self.yang_parent_name = "dwdm-minute15fec-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("ec-bits", ("ec_bits", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15fecHistories.DwdmMinute15fecHistory.DwdmMinute15fecTimeLineInstances.DwdmMinute15fecTimeLineInstance.EcBits)), ("uc-words", ("uc_words", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15fecHistories.DwdmMinute15fecHistory.DwdmMinute15fecTimeLineInstances.DwdmMinute15fecTimeLineInstance.UcWords)), ("pre-fec-ber", ("pre_fec_ber", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15fecHistories.DwdmMinute15fecHistory.DwdmMinute15fecTimeLineInstances.DwdmMinute15fecTimeLineInstance.PreFecBer)), ("post-fec-ber", ("post_fec_ber", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15fecHistories.DwdmMinute15fecHistory.DwdmMinute15fecTimeLineInstances.DwdmMinute15fecTimeLineInstance.PostFecBer)), ("q", ("q", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15fecHistories.DwdmMinute15fecHistory.DwdmMinute15fecTimeLineInstances.DwdmMinute15fecTimeLineInstance.Q)), ("qmargin", ("qmargin", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15fecHistories.DwdmMinute15fecHistory.DwdmMinute15fecTimeLineInstances.DwdmMinute15fecTimeLineInstance.Qmargin))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                    ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear24_hr_time = None
                                                self.sec30_support = None

                                                self.ec_bits = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15fecHistories.DwdmMinute15fecHistory.DwdmMinute15fecTimeLineInstances.DwdmMinute15fecTimeLineInstance.EcBits()
                                                self.ec_bits.parent = self
                                                self._children_name_map["ec_bits"] = "ec-bits"

                                                self.uc_words = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15fecHistories.DwdmMinute15fecHistory.DwdmMinute15fecTimeLineInstances.DwdmMinute15fecTimeLineInstance.UcWords()
                                                self.uc_words.parent = self
                                                self._children_name_map["uc_words"] = "uc-words"

                                                self.pre_fec_ber = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15fecHistories.DwdmMinute15fecHistory.DwdmMinute15fecTimeLineInstances.DwdmMinute15fecTimeLineInstance.PreFecBer()
                                                self.pre_fec_ber.parent = self
                                                self._children_name_map["pre_fec_ber"] = "pre-fec-ber"

                                                self.post_fec_ber = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15fecHistories.DwdmMinute15fecHistory.DwdmMinute15fecTimeLineInstances.DwdmMinute15fecTimeLineInstance.PostFecBer()
                                                self.post_fec_ber.parent = self
                                                self._children_name_map["post_fec_ber"] = "post-fec-ber"

                                                self.q = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15fecHistories.DwdmMinute15fecHistory.DwdmMinute15fecTimeLineInstances.DwdmMinute15fecTimeLineInstance.Q()
                                                self.q.parent = self
                                                self._children_name_map["q"] = "q"

                                                self.qmargin = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15fecHistories.DwdmMinute15fecHistory.DwdmMinute15fecTimeLineInstances.DwdmMinute15fecTimeLineInstance.Qmargin()
                                                self.qmargin.parent = self
                                                self._children_name_map["qmargin"] = "qmargin"
                                                self._segment_path = lambda: "dwdm-minute15fec-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15fecHistories.DwdmMinute15fecHistory.DwdmMinute15fecTimeLineInstances.DwdmMinute15fecTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                            class EcBits(Entity):
                                                """
                                                EC BITS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15fecHistories.DwdmMinute15fecHistory.DwdmMinute15fecTimeLineInstances.DwdmMinute15fecTimeLineInstance.EcBits, self).__init__()

                                                    self.yang_name = "ec-bits"
                                                    self.yang_parent_name = "dwdm-minute15fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ec-bits"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15fecHistories.DwdmMinute15fecHistory.DwdmMinute15fecTimeLineInstances.DwdmMinute15fecTimeLineInstance.EcBits, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class UcWords(Entity):
                                                """
                                                UC WORDS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15fecHistories.DwdmMinute15fecHistory.DwdmMinute15fecTimeLineInstances.DwdmMinute15fecTimeLineInstance.UcWords, self).__init__()

                                                    self.yang_name = "uc-words"
                                                    self.yang_parent_name = "dwdm-minute15fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "uc-words"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15fecHistories.DwdmMinute15fecHistory.DwdmMinute15fecTimeLineInstances.DwdmMinute15fecTimeLineInstance.UcWords, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class PreFecBer(Entity):
                                                """
                                                Pre FEC BER
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15fecHistories.DwdmMinute15fecHistory.DwdmMinute15fecTimeLineInstances.DwdmMinute15fecTimeLineInstance.PreFecBer, self).__init__()

                                                    self.yang_name = "pre-fec-ber"
                                                    self.yang_parent_name = "dwdm-minute15fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.maximum_tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "pre-fec-ber"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15fecHistories.DwdmMinute15fecHistory.DwdmMinute15fecTimeLineInstances.DwdmMinute15fecTimeLineInstance.PreFecBer, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                            class PostFecBer(Entity):
                                                """
                                                Post FEC BER
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15fecHistories.DwdmMinute15fecHistory.DwdmMinute15fecTimeLineInstances.DwdmMinute15fecTimeLineInstance.PostFecBer, self).__init__()

                                                    self.yang_name = "post-fec-ber"
                                                    self.yang_parent_name = "dwdm-minute15fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.maximum_tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "post-fec-ber"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15fecHistories.DwdmMinute15fecHistory.DwdmMinute15fecTimeLineInstances.DwdmMinute15fecTimeLineInstance.PostFecBer, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                            class Q(Entity):
                                                """
                                                Q
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15fecHistories.DwdmMinute15fecHistory.DwdmMinute15fecTimeLineInstances.DwdmMinute15fecTimeLineInstance.Q, self).__init__()

                                                    self.yang_name = "q"
                                                    self.yang_parent_name = "dwdm-minute15fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.maximum_tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "q"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15fecHistories.DwdmMinute15fecHistory.DwdmMinute15fecTimeLineInstances.DwdmMinute15fecTimeLineInstance.Q, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                            class Qmargin(Entity):
                                                """
                                                Q Margin
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15fecHistories.DwdmMinute15fecHistory.DwdmMinute15fecTimeLineInstances.DwdmMinute15fecTimeLineInstance.Qmargin, self).__init__()

                                                    self.yang_name = "qmargin"
                                                    self.yang_parent_name = "dwdm-minute15fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.maximum_tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "qmargin"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15fecHistories.DwdmMinute15fecHistory.DwdmMinute15fecTimeLineInstances.DwdmMinute15fecTimeLineInstance.Qmargin, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                            class DwdmMinute15OpticsHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: dwdm_minute15_optics_history
                                
                                	port 15\-minute optics performance data
                                	**type**\: list of  		 :py:class:`DwdmMinute15OpticsHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories, self).__init__()

                                    self.yang_name = "dwdm-minute15-optics-histories"
                                    self.yang_parent_name = "dwdm-minute15-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("dwdm-minute15-optics-history", ("dwdm_minute15_optics_history", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory))])
                                    self._leafs = OrderedDict()

                                    self.dwdm_minute15_optics_history = YList(self)
                                    self._segment_path = lambda: "dwdm-minute15-optics-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories, [], name, value)


                                class DwdmMinute15OpticsHistory(Entity):
                                    """
                                    port 15\-minute optics performance data
                                    
                                    .. attribute:: number  (key)
                                    
                                    	channel number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: dwdm_minute15_optics_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`DwdmMinute15OpticsTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory, self).__init__()

                                        self.yang_name = "dwdm-minute15-optics-history"
                                        self.yang_parent_name = "dwdm-minute15-optics-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([("dwdm-minute15-optics-time-line-instances", ("dwdm_minute15_optics_time_line_instances", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ])
                                        self.number = None

                                        self.dwdm_minute15_optics_time_line_instances = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances()
                                        self.dwdm_minute15_optics_time_line_instances.parent = self
                                        self._children_name_map["dwdm_minute15_optics_time_line_instances"] = "dwdm-minute15-optics-time-line-instances"
                                        self._segment_path = lambda: "dwdm-minute15-optics-history" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory, ['number'], name, value)


                                    class DwdmMinute15OpticsTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: dwdm_minute15_optics_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of  		 :py:class:`DwdmMinute15OpticsTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances, self).__init__()

                                            self.yang_name = "dwdm-minute15-optics-time-line-instances"
                                            self.yang_parent_name = "dwdm-minute15-optics-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dwdm-minute15-optics-time-line-instance", ("dwdm_minute15_optics_time_line_instance", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.dwdm_minute15_optics_time_line_instance = YList(self)
                                            self._segment_path = lambda: "dwdm-minute15-optics-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances, [], name, value)


                                        class DwdmMinute15OpticsTimeLineInstance(Entity):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lbc
                                            
                                            	LBC
                                            	**type**\:  :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Lbc>`
                                            
                                            .. attribute:: lbc_pc
                                            
                                            	LBC in percentage
                                            	**type**\:  :py:class:`LbcPc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.LbcPc>`
                                            
                                            .. attribute:: opt
                                            
                                            	OPT
                                            	**type**\:  :py:class:`Opt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Opt>`
                                            
                                            .. attribute:: opr
                                            
                                            	OPR
                                            	**type**\:  :py:class:`Opr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Opr>`
                                            
                                            .. attribute:: cd
                                            
                                            	Chromatic Dispersion
                                            	**type**\:  :py:class:`Cd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Cd>`
                                            
                                            .. attribute:: dgd
                                            
                                            	Differential group Delay
                                            	**type**\:  :py:class:`Dgd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Dgd>`
                                            
                                            .. attribute:: pmd
                                            
                                            	Polarization Mode Dispersion
                                            	**type**\:  :py:class:`Pmd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Pmd>`
                                            
                                            .. attribute:: osnr
                                            
                                            	Optical Signal to Noise Ratio
                                            	**type**\:  :py:class:`Osnr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Osnr>`
                                            
                                            .. attribute:: center_wavelength
                                            
                                            	Center Wavelength/Frequency
                                            	**type**\:  :py:class:`CenterWavelength <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.CenterWavelength>`
                                            
                                            .. attribute:: pdl
                                            
                                            	Polarization Dependent Loss
                                            	**type**\:  :py:class:`Pdl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Pdl>`
                                            
                                            .. attribute:: pcr
                                            
                                            	Polarization Change Rate
                                            	**type**\:  :py:class:`Pcr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Pcr>`
                                            
                                            .. attribute:: pn
                                            
                                            	Phase Noise
                                            	**type**\:  :py:class:`Pn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Pn>`
                                            
                                            .. attribute:: rx_sig_pow
                                            
                                            	Rx signal power
                                            	**type**\:  :py:class:`RxSigPow <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.RxSigPow>`
                                            
                                            .. attribute:: low_sig_freq_off
                                            
                                            	low freq sig off
                                            	**type**\:  :py:class:`LowSigFreqOff <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.LowSigFreqOff>`
                                            
                                            .. attribute:: ampli_gain
                                            
                                            	Ampli Gain
                                            	**type**\:  :py:class:`AmpliGain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.AmpliGain>`
                                            
                                            .. attribute:: ampli_gain_tilt
                                            
                                            	Ampli Gain Tilt
                                            	**type**\:  :py:class:`AmpliGainTilt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.AmpliGainTilt>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance, self).__init__()

                                                self.yang_name = "dwdm-minute15-optics-time-line-instance"
                                                self.yang_parent_name = "dwdm-minute15-optics-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("lbc", ("lbc", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Lbc)), ("lbc-pc", ("lbc_pc", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.LbcPc)), ("opt", ("opt", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Opt)), ("opr", ("opr", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Opr)), ("cd", ("cd", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Cd)), ("dgd", ("dgd", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Dgd)), ("pmd", ("pmd", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Pmd)), ("osnr", ("osnr", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Osnr)), ("center-wavelength", ("center_wavelength", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.CenterWavelength)), ("pdl", ("pdl", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Pdl)), ("pcr", ("pcr", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Pcr)), ("pn", ("pn", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Pn)), ("rx-sig-pow", ("rx_sig_pow", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.RxSigPow)), ("low-sig-freq-off", ("low_sig_freq_off", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.LowSigFreqOff)), ("ampli-gain", ("ampli_gain", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.AmpliGain)), ("ampli-gain-tilt", ("ampli_gain_tilt", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.AmpliGainTilt))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                    ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear24_hr_time = None
                                                self.sec30_support = None

                                                self.lbc = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Lbc()
                                                self.lbc.parent = self
                                                self._children_name_map["lbc"] = "lbc"

                                                self.lbc_pc = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.LbcPc()
                                                self.lbc_pc.parent = self
                                                self._children_name_map["lbc_pc"] = "lbc-pc"

                                                self.opt = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Opt()
                                                self.opt.parent = self
                                                self._children_name_map["opt"] = "opt"

                                                self.opr = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Opr()
                                                self.opr.parent = self
                                                self._children_name_map["opr"] = "opr"

                                                self.cd = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Cd()
                                                self.cd.parent = self
                                                self._children_name_map["cd"] = "cd"

                                                self.dgd = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Dgd()
                                                self.dgd.parent = self
                                                self._children_name_map["dgd"] = "dgd"

                                                self.pmd = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Pmd()
                                                self.pmd.parent = self
                                                self._children_name_map["pmd"] = "pmd"

                                                self.osnr = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Osnr()
                                                self.osnr.parent = self
                                                self._children_name_map["osnr"] = "osnr"

                                                self.center_wavelength = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.CenterWavelength()
                                                self.center_wavelength.parent = self
                                                self._children_name_map["center_wavelength"] = "center-wavelength"

                                                self.pdl = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Pdl()
                                                self.pdl.parent = self
                                                self._children_name_map["pdl"] = "pdl"

                                                self.pcr = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Pcr()
                                                self.pcr.parent = self
                                                self._children_name_map["pcr"] = "pcr"

                                                self.pn = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Pn()
                                                self.pn.parent = self
                                                self._children_name_map["pn"] = "pn"

                                                self.rx_sig_pow = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.RxSigPow()
                                                self.rx_sig_pow.parent = self
                                                self._children_name_map["rx_sig_pow"] = "rx-sig-pow"

                                                self.low_sig_freq_off = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.LowSigFreqOff()
                                                self.low_sig_freq_off.parent = self
                                                self._children_name_map["low_sig_freq_off"] = "low-sig-freq-off"

                                                self.ampli_gain = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.AmpliGain()
                                                self.ampli_gain.parent = self
                                                self._children_name_map["ampli_gain"] = "ampli-gain"

                                                self.ampli_gain_tilt = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.AmpliGainTilt()
                                                self.ampli_gain_tilt.parent = self
                                                self._children_name_map["ampli_gain_tilt"] = "ampli-gain-tilt"
                                                self._segment_path = lambda: "dwdm-minute15-optics-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                            class Lbc(Entity):
                                                """
                                                LBC
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Lbc, self).__init__()

                                                    self.yang_name = "lbc"
                                                    self.yang_parent_name = "dwdm-minute15-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.int32, 'minimum'), ['int'])),
                                                        ('average', (YLeaf(YType.int32, 'average'), ['int'])),
                                                        ('maximum', (YLeaf(YType.int32, 'maximum'), ['int'])),
                                                        ('minimum_threshold', (YLeaf(YType.int32, 'minimum-threshold'), ['int'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.int32, 'maximum-threshold'), ['int'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "lbc"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Lbc, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class LbcPc(Entity):
                                                """
                                                LBC in percentage
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.LbcPc, self).__init__()

                                                    self.yang_name = "lbc-pc"
                                                    self.yang_parent_name = "dwdm-minute15-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "lbc-pc"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.LbcPc, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class Opt(Entity):
                                                """
                                                OPT
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Opt, self).__init__()

                                                    self.yang_name = "opt"
                                                    self.yang_parent_name = "dwdm-minute15-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "opt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Opt, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class Opr(Entity):
                                                """
                                                OPR
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Opr, self).__init__()

                                                    self.yang_name = "opr"
                                                    self.yang_parent_name = "dwdm-minute15-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "opr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Opr, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class Cd(Entity):
                                                """
                                                Chromatic Dispersion
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Cd, self).__init__()

                                                    self.yang_name = "cd"
                                                    self.yang_parent_name = "dwdm-minute15-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.int32, 'minimum'), ['int'])),
                                                        ('average', (YLeaf(YType.int32, 'average'), ['int'])),
                                                        ('maximum', (YLeaf(YType.int32, 'maximum'), ['int'])),
                                                        ('minimum_threshold', (YLeaf(YType.int32, 'minimum-threshold'), ['int'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.int32, 'maximum-threshold'), ['int'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "cd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Cd, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class Dgd(Entity):
                                                """
                                                Differential group Delay
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Dgd, self).__init__()

                                                    self.yang_name = "dgd"
                                                    self.yang_parent_name = "dwdm-minute15-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "dgd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Dgd, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class Pmd(Entity):
                                                """
                                                Polarization Mode Dispersion
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Pmd, self).__init__()

                                                    self.yang_name = "pmd"
                                                    self.yang_parent_name = "dwdm-minute15-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "pmd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Pmd, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class Osnr(Entity):
                                                """
                                                Optical Signal to Noise Ratio
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Osnr, self).__init__()

                                                    self.yang_name = "osnr"
                                                    self.yang_parent_name = "dwdm-minute15-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "osnr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Osnr, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class CenterWavelength(Entity):
                                                """
                                                Center Wavelength/Frequency
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.CenterWavelength, self).__init__()

                                                    self.yang_name = "center-wavelength"
                                                    self.yang_parent_name = "dwdm-minute15-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "center-wavelength"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.CenterWavelength, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class Pdl(Entity):
                                                """
                                                Polarization Dependent Loss
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Pdl, self).__init__()

                                                    self.yang_name = "pdl"
                                                    self.yang_parent_name = "dwdm-minute15-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "pdl"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Pdl, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class Pcr(Entity):
                                                """
                                                Polarization Change Rate
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Pcr, self).__init__()

                                                    self.yang_name = "pcr"
                                                    self.yang_parent_name = "dwdm-minute15-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "pcr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Pcr, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class Pn(Entity):
                                                """
                                                Phase Noise
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Pn, self).__init__()

                                                    self.yang_name = "pn"
                                                    self.yang_parent_name = "dwdm-minute15-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "pn"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Pn, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class RxSigPow(Entity):
                                                """
                                                Rx signal power
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.RxSigPow, self).__init__()

                                                    self.yang_name = "rx-sig-pow"
                                                    self.yang_parent_name = "dwdm-minute15-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "rx-sig-pow"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.RxSigPow, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class LowSigFreqOff(Entity):
                                                """
                                                low freq sig off
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.LowSigFreqOff, self).__init__()

                                                    self.yang_name = "low-sig-freq-off"
                                                    self.yang_parent_name = "dwdm-minute15-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.int32, 'minimum'), ['int'])),
                                                        ('average', (YLeaf(YType.int32, 'average'), ['int'])),
                                                        ('maximum', (YLeaf(YType.int32, 'maximum'), ['int'])),
                                                        ('minimum_threshold', (YLeaf(YType.int32, 'minimum-threshold'), ['int'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.int32, 'maximum-threshold'), ['int'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "low-sig-freq-off"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.LowSigFreqOff, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class AmpliGain(Entity):
                                                """
                                                Ampli Gain
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.AmpliGain, self).__init__()

                                                    self.yang_name = "ampli-gain"
                                                    self.yang_parent_name = "dwdm-minute15-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "ampli-gain"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.AmpliGain, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class AmpliGainTilt(Entity):
                                                """
                                                Ampli Gain Tilt
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.AmpliGainTilt, self).__init__()

                                                    self.yang_name = "ampli-gain-tilt"
                                                    self.yang_parent_name = "dwdm-minute15-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "ampli-gain-tilt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.AmpliGainTilt, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                        class DwdmHour24History(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: dwdm_hour24otn_histories
                            
                            	port 24 hour performance data
                            	**type**\:  :py:class:`DwdmHour24otnHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories>`
                            
                            .. attribute:: dwdm_hour24fec_histories
                            
                            	port current performance data
                            	**type**\:  :py:class:`DwdmHour24fecHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24fecHistories>`
                            
                            .. attribute:: dwdm_hour24_optics_histories
                            
                            	port 24 hour performance data
                            	**type**\:  :py:class:`DwdmHour24OpticsHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History, self).__init__()

                                self.yang_name = "dwdm-hour24-history"
                                self.yang_parent_name = "dwdm-port-history"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dwdm-hour24otn-histories", ("dwdm_hour24otn_histories", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories)), ("dwdm-hour24fec-histories", ("dwdm_hour24fec_histories", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24fecHistories)), ("dwdm-hour24-optics-histories", ("dwdm_hour24_optics_histories", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories))])
                                self._leafs = OrderedDict()

                                self.dwdm_hour24otn_histories = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories()
                                self.dwdm_hour24otn_histories.parent = self
                                self._children_name_map["dwdm_hour24otn_histories"] = "dwdm-hour24otn-histories"

                                self.dwdm_hour24fec_histories = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24fecHistories()
                                self.dwdm_hour24fec_histories.parent = self
                                self._children_name_map["dwdm_hour24fec_histories"] = "dwdm-hour24fec-histories"

                                self.dwdm_hour24_optics_histories = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories()
                                self.dwdm_hour24_optics_histories.parent = self
                                self._children_name_map["dwdm_hour24_optics_histories"] = "dwdm-hour24-optics-histories"
                                self._segment_path = lambda: "dwdm-hour24-history"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History, [], name, value)


                            class DwdmHour24otnHistories(Entity):
                                """
                                port 24 hour performance data
                                
                                .. attribute:: dwdm_hour24otn_history
                                
                                	port 24 hour otn performance data
                                	**type**\: list of  		 :py:class:`DwdmHour24otnHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories, self).__init__()

                                    self.yang_name = "dwdm-hour24otn-histories"
                                    self.yang_parent_name = "dwdm-hour24-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("dwdm-hour24otn-history", ("dwdm_hour24otn_history", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory))])
                                    self._leafs = OrderedDict()

                                    self.dwdm_hour24otn_history = YList(self)
                                    self._segment_path = lambda: "dwdm-hour24otn-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories, [], name, value)


                                class DwdmHour24otnHistory(Entity):
                                    """
                                    port 24 hour otn performance data
                                    
                                    .. attribute:: number  (key)
                                    
                                    	channel number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: dwdm_hour24otn_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`DwdmHour24otnTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory, self).__init__()

                                        self.yang_name = "dwdm-hour24otn-history"
                                        self.yang_parent_name = "dwdm-hour24otn-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([("dwdm-hour24otn-time-line-instances", ("dwdm_hour24otn_time_line_instances", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ])
                                        self.number = None

                                        self.dwdm_hour24otn_time_line_instances = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances()
                                        self.dwdm_hour24otn_time_line_instances.parent = self
                                        self._children_name_map["dwdm_hour24otn_time_line_instances"] = "dwdm-hour24otn-time-line-instances"
                                        self._segment_path = lambda: "dwdm-hour24otn-history" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory, ['number'], name, value)


                                    class DwdmHour24otnTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: dwdm_hour24otn_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of  		 :py:class:`DwdmHour24otnTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances, self).__init__()

                                            self.yang_name = "dwdm-hour24otn-time-line-instances"
                                            self.yang_parent_name = "dwdm-hour24otn-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dwdm-hour24otn-time-line-instance", ("dwdm_hour24otn_time_line_instance", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.dwdm_hour24otn_time_line_instance = YList(self)
                                            self._segment_path = lambda: "dwdm-hour24otn-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances, [], name, value)


                                        class DwdmHour24otnTimeLineInstance(Entity):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lbc
                                            
                                            	LBC
                                            	**type**\:  :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.Lbc>`
                                            
                                            .. attribute:: es_ne
                                            
                                            	ES SM NE
                                            	**type**\:  :py:class:`EsNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.EsNe>`
                                            
                                            .. attribute:: esr_ne
                                            
                                            	ESR PM NE
                                            	**type**\:  :py:class:`EsrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.EsrNe>`
                                            
                                            .. attribute:: ses_ne
                                            
                                            	SES SM NE
                                            	**type**\:  :py:class:`SesNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.SesNe>`
                                            
                                            .. attribute:: sesr_ne
                                            
                                            	SESR SM NE
                                            	**type**\:  :py:class:`SesrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.SesrNe>`
                                            
                                            .. attribute:: uas_ne
                                            
                                            	UAS SM NE
                                            	**type**\:  :py:class:`UasNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.UasNe>`
                                            
                                            .. attribute:: bbe_ne
                                            
                                            	BBE SM NE
                                            	**type**\:  :py:class:`BbeNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.BbeNe>`
                                            
                                            .. attribute:: bber_ne
                                            
                                            	BBER SM NE
                                            	**type**\:  :py:class:`BberNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.BberNe>`
                                            
                                            .. attribute:: fc_ne
                                            
                                            	FC SM NE
                                            	**type**\:  :py:class:`FcNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.FcNe>`
                                            
                                            .. attribute:: es_fe
                                            
                                            	ES SM FE
                                            	**type**\:  :py:class:`EsFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.EsFe>`
                                            
                                            .. attribute:: esr_fe
                                            
                                            	ESR PM FE
                                            	**type**\:  :py:class:`EsrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.EsrFe>`
                                            
                                            .. attribute:: ses_fe
                                            
                                            	SES SM FE
                                            	**type**\:  :py:class:`SesFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.SesFe>`
                                            
                                            .. attribute:: sesr_fe
                                            
                                            	SESR SM FE
                                            	**type**\:  :py:class:`SesrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.SesrFe>`
                                            
                                            .. attribute:: uas_fe
                                            
                                            	UAS SM FE
                                            	**type**\:  :py:class:`UasFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.UasFe>`
                                            
                                            .. attribute:: bbe_fe
                                            
                                            	BBE SM FE
                                            	**type**\:  :py:class:`BbeFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.BbeFe>`
                                            
                                            .. attribute:: bber_fe
                                            
                                            	BBER SM FE
                                            	**type**\:  :py:class:`BberFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.BberFe>`
                                            
                                            .. attribute:: fc_fe
                                            
                                            	FC SM FE
                                            	**type**\:  :py:class:`FcFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.FcFe>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance, self).__init__()

                                                self.yang_name = "dwdm-hour24otn-time-line-instance"
                                                self.yang_parent_name = "dwdm-hour24otn-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("lbc", ("lbc", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.Lbc)), ("es-ne", ("es_ne", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.EsNe)), ("esr-ne", ("esr_ne", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.EsrNe)), ("ses-ne", ("ses_ne", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.SesNe)), ("sesr-ne", ("sesr_ne", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.SesrNe)), ("uas-ne", ("uas_ne", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.UasNe)), ("bbe-ne", ("bbe_ne", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.BbeNe)), ("bber-ne", ("bber_ne", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.BberNe)), ("fc-ne", ("fc_ne", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.FcNe)), ("es-fe", ("es_fe", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.EsFe)), ("esr-fe", ("esr_fe", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.EsrFe)), ("ses-fe", ("ses_fe", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.SesFe)), ("sesr-fe", ("sesr_fe", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.SesrFe)), ("uas-fe", ("uas_fe", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.UasFe)), ("bbe-fe", ("bbe_fe", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.BbeFe)), ("bber-fe", ("bber_fe", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.BberFe)), ("fc-fe", ("fc_fe", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.FcFe))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                    ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear24_hr_time = None
                                                self.sec30_support = None

                                                self.lbc = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.Lbc()
                                                self.lbc.parent = self
                                                self._children_name_map["lbc"] = "lbc"

                                                self.es_ne = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.EsNe()
                                                self.es_ne.parent = self
                                                self._children_name_map["es_ne"] = "es-ne"

                                                self.esr_ne = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.EsrNe()
                                                self.esr_ne.parent = self
                                                self._children_name_map["esr_ne"] = "esr-ne"

                                                self.ses_ne = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.SesNe()
                                                self.ses_ne.parent = self
                                                self._children_name_map["ses_ne"] = "ses-ne"

                                                self.sesr_ne = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.SesrNe()
                                                self.sesr_ne.parent = self
                                                self._children_name_map["sesr_ne"] = "sesr-ne"

                                                self.uas_ne = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.UasNe()
                                                self.uas_ne.parent = self
                                                self._children_name_map["uas_ne"] = "uas-ne"

                                                self.bbe_ne = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.BbeNe()
                                                self.bbe_ne.parent = self
                                                self._children_name_map["bbe_ne"] = "bbe-ne"

                                                self.bber_ne = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.BberNe()
                                                self.bber_ne.parent = self
                                                self._children_name_map["bber_ne"] = "bber-ne"

                                                self.fc_ne = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.FcNe()
                                                self.fc_ne.parent = self
                                                self._children_name_map["fc_ne"] = "fc-ne"

                                                self.es_fe = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.EsFe()
                                                self.es_fe.parent = self
                                                self._children_name_map["es_fe"] = "es-fe"

                                                self.esr_fe = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.EsrFe()
                                                self.esr_fe.parent = self
                                                self._children_name_map["esr_fe"] = "esr-fe"

                                                self.ses_fe = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.SesFe()
                                                self.ses_fe.parent = self
                                                self._children_name_map["ses_fe"] = "ses-fe"

                                                self.sesr_fe = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.SesrFe()
                                                self.sesr_fe.parent = self
                                                self._children_name_map["sesr_fe"] = "sesr-fe"

                                                self.uas_fe = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.UasFe()
                                                self.uas_fe.parent = self
                                                self._children_name_map["uas_fe"] = "uas-fe"

                                                self.bbe_fe = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.BbeFe()
                                                self.bbe_fe.parent = self
                                                self._children_name_map["bbe_fe"] = "bbe-fe"

                                                self.bber_fe = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.BberFe()
                                                self.bber_fe.parent = self
                                                self._children_name_map["bber_fe"] = "bber-fe"

                                                self.fc_fe = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.FcFe()
                                                self.fc_fe.parent = self
                                                self._children_name_map["fc_fe"] = "fc-fe"
                                                self._segment_path = lambda: "dwdm-hour24otn-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                            class Lbc(Entity):
                                                """
                                                LBC
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.Lbc, self).__init__()

                                                    self.yang_name = "lbc"
                                                    self.yang_parent_name = "dwdm-hour24otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "lbc"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.Lbc, ['data', 'threshold', 'tca_report'], name, value)


                                            class EsNe(Entity):
                                                """
                                                ES SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.EsNe, self).__init__()

                                                    self.yang_name = "es-ne"
                                                    self.yang_parent_name = "dwdm-hour24otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "es-ne"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.EsNe, ['data', 'threshold', 'tca_report'], name, value)


                                            class EsrNe(Entity):
                                                """
                                                ESR PM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: str
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.EsrNe, self).__init__()

                                                    self.yang_name = "esr-ne"
                                                    self.yang_parent_name = "dwdm-hour24otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                        ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "esr-ne"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.EsrNe, ['data', 'threshold', 'tca_report'], name, value)


                                            class SesNe(Entity):
                                                """
                                                SES SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.SesNe, self).__init__()

                                                    self.yang_name = "ses-ne"
                                                    self.yang_parent_name = "dwdm-hour24otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "ses-ne"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.SesNe, ['data', 'threshold', 'tca_report'], name, value)


                                            class SesrNe(Entity):
                                                """
                                                SESR SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: str
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.SesrNe, self).__init__()

                                                    self.yang_name = "sesr-ne"
                                                    self.yang_parent_name = "dwdm-hour24otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                        ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "sesr-ne"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.SesrNe, ['data', 'threshold', 'tca_report'], name, value)


                                            class UasNe(Entity):
                                                """
                                                UAS SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.UasNe, self).__init__()

                                                    self.yang_name = "uas-ne"
                                                    self.yang_parent_name = "dwdm-hour24otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "uas-ne"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.UasNe, ['data', 'threshold', 'tca_report'], name, value)


                                            class BbeNe(Entity):
                                                """
                                                BBE SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.BbeNe, self).__init__()

                                                    self.yang_name = "bbe-ne"
                                                    self.yang_parent_name = "dwdm-hour24otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "bbe-ne"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.BbeNe, ['data', 'threshold', 'tca_report'], name, value)


                                            class BberNe(Entity):
                                                """
                                                BBER SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: str
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.BberNe, self).__init__()

                                                    self.yang_name = "bber-ne"
                                                    self.yang_parent_name = "dwdm-hour24otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                        ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "bber-ne"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.BberNe, ['data', 'threshold', 'tca_report'], name, value)


                                            class FcNe(Entity):
                                                """
                                                FC SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.FcNe, self).__init__()

                                                    self.yang_name = "fc-ne"
                                                    self.yang_parent_name = "dwdm-hour24otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "fc-ne"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.FcNe, ['data', 'threshold', 'tca_report'], name, value)


                                            class EsFe(Entity):
                                                """
                                                ES SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.EsFe, self).__init__()

                                                    self.yang_name = "es-fe"
                                                    self.yang_parent_name = "dwdm-hour24otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "es-fe"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.EsFe, ['data', 'threshold', 'tca_report'], name, value)


                                            class EsrFe(Entity):
                                                """
                                                ESR PM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: str
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.EsrFe, self).__init__()

                                                    self.yang_name = "esr-fe"
                                                    self.yang_parent_name = "dwdm-hour24otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                        ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "esr-fe"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.EsrFe, ['data', 'threshold', 'tca_report'], name, value)


                                            class SesFe(Entity):
                                                """
                                                SES SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.SesFe, self).__init__()

                                                    self.yang_name = "ses-fe"
                                                    self.yang_parent_name = "dwdm-hour24otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "ses-fe"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.SesFe, ['data', 'threshold', 'tca_report'], name, value)


                                            class SesrFe(Entity):
                                                """
                                                SESR SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: str
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.SesrFe, self).__init__()

                                                    self.yang_name = "sesr-fe"
                                                    self.yang_parent_name = "dwdm-hour24otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                        ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "sesr-fe"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.SesrFe, ['data', 'threshold', 'tca_report'], name, value)


                                            class UasFe(Entity):
                                                """
                                                UAS SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.UasFe, self).__init__()

                                                    self.yang_name = "uas-fe"
                                                    self.yang_parent_name = "dwdm-hour24otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "uas-fe"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.UasFe, ['data', 'threshold', 'tca_report'], name, value)


                                            class BbeFe(Entity):
                                                """
                                                BBE SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.BbeFe, self).__init__()

                                                    self.yang_name = "bbe-fe"
                                                    self.yang_parent_name = "dwdm-hour24otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "bbe-fe"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.BbeFe, ['data', 'threshold', 'tca_report'], name, value)


                                            class BberFe(Entity):
                                                """
                                                BBER SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: str
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.BberFe, self).__init__()

                                                    self.yang_name = "bber-fe"
                                                    self.yang_parent_name = "dwdm-hour24otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                        ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "bber-fe"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.BberFe, ['data', 'threshold', 'tca_report'], name, value)


                                            class FcFe(Entity):
                                                """
                                                FC SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.FcFe, self).__init__()

                                                    self.yang_name = "fc-fe"
                                                    self.yang_parent_name = "dwdm-hour24otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "fc-fe"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24otnHistories.DwdmHour24otnHistory.DwdmHour24otnTimeLineInstances.DwdmHour24otnTimeLineInstance.FcFe, ['data', 'threshold', 'tca_report'], name, value)


                            class DwdmHour24fecHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: dwdm_hour24fec_history
                                
                                	port 24 hour fec performance data
                                	**type**\: list of  		 :py:class:`DwdmHour24fecHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24fecHistories.DwdmHour24fecHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24fecHistories, self).__init__()

                                    self.yang_name = "dwdm-hour24fec-histories"
                                    self.yang_parent_name = "dwdm-hour24-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("dwdm-hour24fec-history", ("dwdm_hour24fec_history", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24fecHistories.DwdmHour24fecHistory))])
                                    self._leafs = OrderedDict()

                                    self.dwdm_hour24fec_history = YList(self)
                                    self._segment_path = lambda: "dwdm-hour24fec-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24fecHistories, [], name, value)


                                class DwdmHour24fecHistory(Entity):
                                    """
                                    port 24 hour fec performance data
                                    
                                    .. attribute:: number  (key)
                                    
                                    	channel number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: dwdm_hour24fec_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`DwdmHour24fecTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24fecHistories.DwdmHour24fecHistory.DwdmHour24fecTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24fecHistories.DwdmHour24fecHistory, self).__init__()

                                        self.yang_name = "dwdm-hour24fec-history"
                                        self.yang_parent_name = "dwdm-hour24fec-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([("dwdm-hour24fec-time-line-instances", ("dwdm_hour24fec_time_line_instances", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24fecHistories.DwdmHour24fecHistory.DwdmHour24fecTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ])
                                        self.number = None

                                        self.dwdm_hour24fec_time_line_instances = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24fecHistories.DwdmHour24fecHistory.DwdmHour24fecTimeLineInstances()
                                        self.dwdm_hour24fec_time_line_instances.parent = self
                                        self._children_name_map["dwdm_hour24fec_time_line_instances"] = "dwdm-hour24fec-time-line-instances"
                                        self._segment_path = lambda: "dwdm-hour24fec-history" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24fecHistories.DwdmHour24fecHistory, ['number'], name, value)


                                    class DwdmHour24fecTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: dwdm_hour24fec_time_line_instance
                                        
                                        	port 15\-minute fec performance data by index
                                        	**type**\: list of  		 :py:class:`DwdmHour24fecTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24fecHistories.DwdmHour24fecHistory.DwdmHour24fecTimeLineInstances.DwdmHour24fecTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24fecHistories.DwdmHour24fecHistory.DwdmHour24fecTimeLineInstances, self).__init__()

                                            self.yang_name = "dwdm-hour24fec-time-line-instances"
                                            self.yang_parent_name = "dwdm-hour24fec-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dwdm-hour24fec-time-line-instance", ("dwdm_hour24fec_time_line_instance", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24fecHistories.DwdmHour24fecHistory.DwdmHour24fecTimeLineInstances.DwdmHour24fecTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.dwdm_hour24fec_time_line_instance = YList(self)
                                            self._segment_path = lambda: "dwdm-hour24fec-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24fecHistories.DwdmHour24fecHistory.DwdmHour24fecTimeLineInstances, [], name, value)


                                        class DwdmHour24fecTimeLineInstance(Entity):
                                            """
                                            port 15\-minute fec performance data by
                                            index
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ec_bits
                                            
                                            	EC BITS
                                            	**type**\:  :py:class:`EcBits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24fecHistories.DwdmHour24fecHistory.DwdmHour24fecTimeLineInstances.DwdmHour24fecTimeLineInstance.EcBits>`
                                            
                                            .. attribute:: uc_words
                                            
                                            	UC WORDS
                                            	**type**\:  :py:class:`UcWords <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24fecHistories.DwdmHour24fecHistory.DwdmHour24fecTimeLineInstances.DwdmHour24fecTimeLineInstance.UcWords>`
                                            
                                            .. attribute:: pre_fec_ber
                                            
                                            	Pre FEC BER
                                            	**type**\:  :py:class:`PreFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24fecHistories.DwdmHour24fecHistory.DwdmHour24fecTimeLineInstances.DwdmHour24fecTimeLineInstance.PreFecBer>`
                                            
                                            .. attribute:: post_fec_ber
                                            
                                            	Post FEC BER
                                            	**type**\:  :py:class:`PostFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24fecHistories.DwdmHour24fecHistory.DwdmHour24fecTimeLineInstances.DwdmHour24fecTimeLineInstance.PostFecBer>`
                                            
                                            .. attribute:: q
                                            
                                            	Q
                                            	**type**\:  :py:class:`Q <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24fecHistories.DwdmHour24fecHistory.DwdmHour24fecTimeLineInstances.DwdmHour24fecTimeLineInstance.Q>`
                                            
                                            .. attribute:: qmargin
                                            
                                            	Q Margin
                                            	**type**\:  :py:class:`Qmargin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24fecHistories.DwdmHour24fecHistory.DwdmHour24fecTimeLineInstances.DwdmHour24fecTimeLineInstance.Qmargin>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24fecHistories.DwdmHour24fecHistory.DwdmHour24fecTimeLineInstances.DwdmHour24fecTimeLineInstance, self).__init__()

                                                self.yang_name = "dwdm-hour24fec-time-line-instance"
                                                self.yang_parent_name = "dwdm-hour24fec-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("ec-bits", ("ec_bits", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24fecHistories.DwdmHour24fecHistory.DwdmHour24fecTimeLineInstances.DwdmHour24fecTimeLineInstance.EcBits)), ("uc-words", ("uc_words", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24fecHistories.DwdmHour24fecHistory.DwdmHour24fecTimeLineInstances.DwdmHour24fecTimeLineInstance.UcWords)), ("pre-fec-ber", ("pre_fec_ber", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24fecHistories.DwdmHour24fecHistory.DwdmHour24fecTimeLineInstances.DwdmHour24fecTimeLineInstance.PreFecBer)), ("post-fec-ber", ("post_fec_ber", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24fecHistories.DwdmHour24fecHistory.DwdmHour24fecTimeLineInstances.DwdmHour24fecTimeLineInstance.PostFecBer)), ("q", ("q", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24fecHistories.DwdmHour24fecHistory.DwdmHour24fecTimeLineInstances.DwdmHour24fecTimeLineInstance.Q)), ("qmargin", ("qmargin", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24fecHistories.DwdmHour24fecHistory.DwdmHour24fecTimeLineInstances.DwdmHour24fecTimeLineInstance.Qmargin))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                    ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear24_hr_time = None
                                                self.sec30_support = None

                                                self.ec_bits = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24fecHistories.DwdmHour24fecHistory.DwdmHour24fecTimeLineInstances.DwdmHour24fecTimeLineInstance.EcBits()
                                                self.ec_bits.parent = self
                                                self._children_name_map["ec_bits"] = "ec-bits"

                                                self.uc_words = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24fecHistories.DwdmHour24fecHistory.DwdmHour24fecTimeLineInstances.DwdmHour24fecTimeLineInstance.UcWords()
                                                self.uc_words.parent = self
                                                self._children_name_map["uc_words"] = "uc-words"

                                                self.pre_fec_ber = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24fecHistories.DwdmHour24fecHistory.DwdmHour24fecTimeLineInstances.DwdmHour24fecTimeLineInstance.PreFecBer()
                                                self.pre_fec_ber.parent = self
                                                self._children_name_map["pre_fec_ber"] = "pre-fec-ber"

                                                self.post_fec_ber = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24fecHistories.DwdmHour24fecHistory.DwdmHour24fecTimeLineInstances.DwdmHour24fecTimeLineInstance.PostFecBer()
                                                self.post_fec_ber.parent = self
                                                self._children_name_map["post_fec_ber"] = "post-fec-ber"

                                                self.q = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24fecHistories.DwdmHour24fecHistory.DwdmHour24fecTimeLineInstances.DwdmHour24fecTimeLineInstance.Q()
                                                self.q.parent = self
                                                self._children_name_map["q"] = "q"

                                                self.qmargin = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24fecHistories.DwdmHour24fecHistory.DwdmHour24fecTimeLineInstances.DwdmHour24fecTimeLineInstance.Qmargin()
                                                self.qmargin.parent = self
                                                self._children_name_map["qmargin"] = "qmargin"
                                                self._segment_path = lambda: "dwdm-hour24fec-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24fecHistories.DwdmHour24fecHistory.DwdmHour24fecTimeLineInstances.DwdmHour24fecTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                            class EcBits(Entity):
                                                """
                                                EC BITS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24fecHistories.DwdmHour24fecHistory.DwdmHour24fecTimeLineInstances.DwdmHour24fecTimeLineInstance.EcBits, self).__init__()

                                                    self.yang_name = "ec-bits"
                                                    self.yang_parent_name = "dwdm-hour24fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ec-bits"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24fecHistories.DwdmHour24fecHistory.DwdmHour24fecTimeLineInstances.DwdmHour24fecTimeLineInstance.EcBits, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class UcWords(Entity):
                                                """
                                                UC WORDS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24fecHistories.DwdmHour24fecHistory.DwdmHour24fecTimeLineInstances.DwdmHour24fecTimeLineInstance.UcWords, self).__init__()

                                                    self.yang_name = "uc-words"
                                                    self.yang_parent_name = "dwdm-hour24fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "uc-words"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24fecHistories.DwdmHour24fecHistory.DwdmHour24fecTimeLineInstances.DwdmHour24fecTimeLineInstance.UcWords, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class PreFecBer(Entity):
                                                """
                                                Pre FEC BER
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24fecHistories.DwdmHour24fecHistory.DwdmHour24fecTimeLineInstances.DwdmHour24fecTimeLineInstance.PreFecBer, self).__init__()

                                                    self.yang_name = "pre-fec-ber"
                                                    self.yang_parent_name = "dwdm-hour24fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.maximum_tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "pre-fec-ber"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24fecHistories.DwdmHour24fecHistory.DwdmHour24fecTimeLineInstances.DwdmHour24fecTimeLineInstance.PreFecBer, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                            class PostFecBer(Entity):
                                                """
                                                Post FEC BER
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24fecHistories.DwdmHour24fecHistory.DwdmHour24fecTimeLineInstances.DwdmHour24fecTimeLineInstance.PostFecBer, self).__init__()

                                                    self.yang_name = "post-fec-ber"
                                                    self.yang_parent_name = "dwdm-hour24fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.maximum_tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "post-fec-ber"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24fecHistories.DwdmHour24fecHistory.DwdmHour24fecTimeLineInstances.DwdmHour24fecTimeLineInstance.PostFecBer, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                            class Q(Entity):
                                                """
                                                Q
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24fecHistories.DwdmHour24fecHistory.DwdmHour24fecTimeLineInstances.DwdmHour24fecTimeLineInstance.Q, self).__init__()

                                                    self.yang_name = "q"
                                                    self.yang_parent_name = "dwdm-hour24fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.maximum_tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "q"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24fecHistories.DwdmHour24fecHistory.DwdmHour24fecTimeLineInstances.DwdmHour24fecTimeLineInstance.Q, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                            class Qmargin(Entity):
                                                """
                                                Q Margin
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24fecHistories.DwdmHour24fecHistory.DwdmHour24fecTimeLineInstances.DwdmHour24fecTimeLineInstance.Qmargin, self).__init__()

                                                    self.yang_name = "qmargin"
                                                    self.yang_parent_name = "dwdm-hour24fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.maximum_tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "qmargin"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24fecHistories.DwdmHour24fecHistory.DwdmHour24fecTimeLineInstances.DwdmHour24fecTimeLineInstance.Qmargin, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                            class DwdmHour24OpticsHistories(Entity):
                                """
                                port 24 hour performance data
                                
                                .. attribute:: dwdm_hour24_optics_history
                                
                                	port 24 hour optics performance data
                                	**type**\: list of  		 :py:class:`DwdmHour24OpticsHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories, self).__init__()

                                    self.yang_name = "dwdm-hour24-optics-histories"
                                    self.yang_parent_name = "dwdm-hour24-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("dwdm-hour24-optics-history", ("dwdm_hour24_optics_history", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory))])
                                    self._leafs = OrderedDict()

                                    self.dwdm_hour24_optics_history = YList(self)
                                    self._segment_path = lambda: "dwdm-hour24-optics-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories, [], name, value)


                                class DwdmHour24OpticsHistory(Entity):
                                    """
                                    port 24 hour optics performance data
                                    
                                    .. attribute:: number  (key)
                                    
                                    	channel number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: dwdm_hour24_optics_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`DwdmHour24OpticsTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory, self).__init__()

                                        self.yang_name = "dwdm-hour24-optics-history"
                                        self.yang_parent_name = "dwdm-hour24-optics-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([("dwdm-hour24-optics-time-line-instances", ("dwdm_hour24_optics_time_line_instances", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ])
                                        self.number = None

                                        self.dwdm_hour24_optics_time_line_instances = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances()
                                        self.dwdm_hour24_optics_time_line_instances.parent = self
                                        self._children_name_map["dwdm_hour24_optics_time_line_instances"] = "dwdm-hour24-optics-time-line-instances"
                                        self._segment_path = lambda: "dwdm-hour24-optics-history" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory, ['number'], name, value)


                                    class DwdmHour24OpticsTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: dwdm_hour24_optics_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of  		 :py:class:`DwdmHour24OpticsTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances, self).__init__()

                                            self.yang_name = "dwdm-hour24-optics-time-line-instances"
                                            self.yang_parent_name = "dwdm-hour24-optics-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dwdm-hour24-optics-time-line-instance", ("dwdm_hour24_optics_time_line_instance", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.dwdm_hour24_optics_time_line_instance = YList(self)
                                            self._segment_path = lambda: "dwdm-hour24-optics-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances, [], name, value)


                                        class DwdmHour24OpticsTimeLineInstance(Entity):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lbc
                                            
                                            	LBC
                                            	**type**\:  :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Lbc>`
                                            
                                            .. attribute:: lbc_pc
                                            
                                            	LBC in percentage
                                            	**type**\:  :py:class:`LbcPc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.LbcPc>`
                                            
                                            .. attribute:: opt
                                            
                                            	OPT
                                            	**type**\:  :py:class:`Opt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Opt>`
                                            
                                            .. attribute:: opr
                                            
                                            	OPR
                                            	**type**\:  :py:class:`Opr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Opr>`
                                            
                                            .. attribute:: cd
                                            
                                            	Chromatic Dispersion
                                            	**type**\:  :py:class:`Cd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Cd>`
                                            
                                            .. attribute:: dgd
                                            
                                            	Differential group Delay
                                            	**type**\:  :py:class:`Dgd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Dgd>`
                                            
                                            .. attribute:: pmd
                                            
                                            	Polarization Mode Dispersion
                                            	**type**\:  :py:class:`Pmd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Pmd>`
                                            
                                            .. attribute:: osnr
                                            
                                            	Optical Signal to Noise Ratio
                                            	**type**\:  :py:class:`Osnr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Osnr>`
                                            
                                            .. attribute:: center_wavelength
                                            
                                            	Center Wavelength/Frequency
                                            	**type**\:  :py:class:`CenterWavelength <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.CenterWavelength>`
                                            
                                            .. attribute:: pdl
                                            
                                            	Polarization Dependent Loss
                                            	**type**\:  :py:class:`Pdl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Pdl>`
                                            
                                            .. attribute:: pcr
                                            
                                            	Polarization Change Rate
                                            	**type**\:  :py:class:`Pcr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Pcr>`
                                            
                                            .. attribute:: pn
                                            
                                            	Phase Noise
                                            	**type**\:  :py:class:`Pn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Pn>`
                                            
                                            .. attribute:: rx_sig_pow
                                            
                                            	Rx signal power
                                            	**type**\:  :py:class:`RxSigPow <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.RxSigPow>`
                                            
                                            .. attribute:: low_sig_freq_off
                                            
                                            	low freq sig off
                                            	**type**\:  :py:class:`LowSigFreqOff <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.LowSigFreqOff>`
                                            
                                            .. attribute:: ampli_gain
                                            
                                            	Ampli Gain
                                            	**type**\:  :py:class:`AmpliGain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.AmpliGain>`
                                            
                                            .. attribute:: ampli_gain_tilt
                                            
                                            	Ampli Gain Tilt
                                            	**type**\:  :py:class:`AmpliGainTilt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.AmpliGainTilt>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance, self).__init__()

                                                self.yang_name = "dwdm-hour24-optics-time-line-instance"
                                                self.yang_parent_name = "dwdm-hour24-optics-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("lbc", ("lbc", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Lbc)), ("lbc-pc", ("lbc_pc", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.LbcPc)), ("opt", ("opt", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Opt)), ("opr", ("opr", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Opr)), ("cd", ("cd", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Cd)), ("dgd", ("dgd", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Dgd)), ("pmd", ("pmd", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Pmd)), ("osnr", ("osnr", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Osnr)), ("center-wavelength", ("center_wavelength", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.CenterWavelength)), ("pdl", ("pdl", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Pdl)), ("pcr", ("pcr", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Pcr)), ("pn", ("pn", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Pn)), ("rx-sig-pow", ("rx_sig_pow", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.RxSigPow)), ("low-sig-freq-off", ("low_sig_freq_off", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.LowSigFreqOff)), ("ampli-gain", ("ampli_gain", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.AmpliGain)), ("ampli-gain-tilt", ("ampli_gain_tilt", PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.AmpliGainTilt))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                    ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear24_hr_time = None
                                                self.sec30_support = None

                                                self.lbc = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Lbc()
                                                self.lbc.parent = self
                                                self._children_name_map["lbc"] = "lbc"

                                                self.lbc_pc = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.LbcPc()
                                                self.lbc_pc.parent = self
                                                self._children_name_map["lbc_pc"] = "lbc-pc"

                                                self.opt = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Opt()
                                                self.opt.parent = self
                                                self._children_name_map["opt"] = "opt"

                                                self.opr = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Opr()
                                                self.opr.parent = self
                                                self._children_name_map["opr"] = "opr"

                                                self.cd = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Cd()
                                                self.cd.parent = self
                                                self._children_name_map["cd"] = "cd"

                                                self.dgd = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Dgd()
                                                self.dgd.parent = self
                                                self._children_name_map["dgd"] = "dgd"

                                                self.pmd = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Pmd()
                                                self.pmd.parent = self
                                                self._children_name_map["pmd"] = "pmd"

                                                self.osnr = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Osnr()
                                                self.osnr.parent = self
                                                self._children_name_map["osnr"] = "osnr"

                                                self.center_wavelength = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.CenterWavelength()
                                                self.center_wavelength.parent = self
                                                self._children_name_map["center_wavelength"] = "center-wavelength"

                                                self.pdl = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Pdl()
                                                self.pdl.parent = self
                                                self._children_name_map["pdl"] = "pdl"

                                                self.pcr = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Pcr()
                                                self.pcr.parent = self
                                                self._children_name_map["pcr"] = "pcr"

                                                self.pn = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Pn()
                                                self.pn.parent = self
                                                self._children_name_map["pn"] = "pn"

                                                self.rx_sig_pow = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.RxSigPow()
                                                self.rx_sig_pow.parent = self
                                                self._children_name_map["rx_sig_pow"] = "rx-sig-pow"

                                                self.low_sig_freq_off = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.LowSigFreqOff()
                                                self.low_sig_freq_off.parent = self
                                                self._children_name_map["low_sig_freq_off"] = "low-sig-freq-off"

                                                self.ampli_gain = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.AmpliGain()
                                                self.ampli_gain.parent = self
                                                self._children_name_map["ampli_gain"] = "ampli-gain"

                                                self.ampli_gain_tilt = PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.AmpliGainTilt()
                                                self.ampli_gain_tilt.parent = self
                                                self._children_name_map["ampli_gain_tilt"] = "ampli-gain-tilt"
                                                self._segment_path = lambda: "dwdm-hour24-optics-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                            class Lbc(Entity):
                                                """
                                                LBC
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Lbc, self).__init__()

                                                    self.yang_name = "lbc"
                                                    self.yang_parent_name = "dwdm-hour24-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.int32, 'minimum'), ['int'])),
                                                        ('average', (YLeaf(YType.int32, 'average'), ['int'])),
                                                        ('maximum', (YLeaf(YType.int32, 'maximum'), ['int'])),
                                                        ('minimum_threshold', (YLeaf(YType.int32, 'minimum-threshold'), ['int'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.int32, 'maximum-threshold'), ['int'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "lbc"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Lbc, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class LbcPc(Entity):
                                                """
                                                LBC in percentage
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.LbcPc, self).__init__()

                                                    self.yang_name = "lbc-pc"
                                                    self.yang_parent_name = "dwdm-hour24-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "lbc-pc"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.LbcPc, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class Opt(Entity):
                                                """
                                                OPT
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Opt, self).__init__()

                                                    self.yang_name = "opt"
                                                    self.yang_parent_name = "dwdm-hour24-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "opt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Opt, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class Opr(Entity):
                                                """
                                                OPR
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Opr, self).__init__()

                                                    self.yang_name = "opr"
                                                    self.yang_parent_name = "dwdm-hour24-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "opr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Opr, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class Cd(Entity):
                                                """
                                                Chromatic Dispersion
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Cd, self).__init__()

                                                    self.yang_name = "cd"
                                                    self.yang_parent_name = "dwdm-hour24-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.int32, 'minimum'), ['int'])),
                                                        ('average', (YLeaf(YType.int32, 'average'), ['int'])),
                                                        ('maximum', (YLeaf(YType.int32, 'maximum'), ['int'])),
                                                        ('minimum_threshold', (YLeaf(YType.int32, 'minimum-threshold'), ['int'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.int32, 'maximum-threshold'), ['int'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "cd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Cd, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class Dgd(Entity):
                                                """
                                                Differential group Delay
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Dgd, self).__init__()

                                                    self.yang_name = "dgd"
                                                    self.yang_parent_name = "dwdm-hour24-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "dgd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Dgd, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class Pmd(Entity):
                                                """
                                                Polarization Mode Dispersion
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Pmd, self).__init__()

                                                    self.yang_name = "pmd"
                                                    self.yang_parent_name = "dwdm-hour24-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "pmd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Pmd, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class Osnr(Entity):
                                                """
                                                Optical Signal to Noise Ratio
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Osnr, self).__init__()

                                                    self.yang_name = "osnr"
                                                    self.yang_parent_name = "dwdm-hour24-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "osnr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Osnr, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class CenterWavelength(Entity):
                                                """
                                                Center Wavelength/Frequency
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.CenterWavelength, self).__init__()

                                                    self.yang_name = "center-wavelength"
                                                    self.yang_parent_name = "dwdm-hour24-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "center-wavelength"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.CenterWavelength, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class Pdl(Entity):
                                                """
                                                Polarization Dependent Loss
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Pdl, self).__init__()

                                                    self.yang_name = "pdl"
                                                    self.yang_parent_name = "dwdm-hour24-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "pdl"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Pdl, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class Pcr(Entity):
                                                """
                                                Polarization Change Rate
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Pcr, self).__init__()

                                                    self.yang_name = "pcr"
                                                    self.yang_parent_name = "dwdm-hour24-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "pcr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Pcr, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class Pn(Entity):
                                                """
                                                Phase Noise
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Pn, self).__init__()

                                                    self.yang_name = "pn"
                                                    self.yang_parent_name = "dwdm-hour24-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "pn"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Pn, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class RxSigPow(Entity):
                                                """
                                                Rx signal power
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.RxSigPow, self).__init__()

                                                    self.yang_name = "rx-sig-pow"
                                                    self.yang_parent_name = "dwdm-hour24-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "rx-sig-pow"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.RxSigPow, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class LowSigFreqOff(Entity):
                                                """
                                                low freq sig off
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.LowSigFreqOff, self).__init__()

                                                    self.yang_name = "low-sig-freq-off"
                                                    self.yang_parent_name = "dwdm-hour24-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.int32, 'minimum'), ['int'])),
                                                        ('average', (YLeaf(YType.int32, 'average'), ['int'])),
                                                        ('maximum', (YLeaf(YType.int32, 'maximum'), ['int'])),
                                                        ('minimum_threshold', (YLeaf(YType.int32, 'minimum-threshold'), ['int'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.int32, 'maximum-threshold'), ['int'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "low-sig-freq-off"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.LowSigFreqOff, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class AmpliGain(Entity):
                                                """
                                                Ampli Gain
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.AmpliGain, self).__init__()

                                                    self.yang_name = "ampli-gain"
                                                    self.yang_parent_name = "dwdm-hour24-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "ampli-gain"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.AmpliGain, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class AmpliGainTilt(Entity):
                                                """
                                                Ampli Gain Tilt
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.AmpliGainTilt, self).__init__()

                                                    self.yang_name = "ampli-gain-tilt"
                                                    self.yang_parent_name = "dwdm-hour24-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "ampli-gain-tilt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.AmpliGainTilt, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


            class StmHistory(Entity):
                """
                STM controller History performance data
                
                .. attribute:: stm_port_histories
                
                	Port performance data
                	**type**\:  :py:class:`StmPortHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(PerformanceManagementHistory.Global.Periodic.StmHistory, self).__init__()

                    self.yang_name = "stm-history"
                    self.yang_parent_name = "periodic"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("stm-port-histories", ("stm_port_histories", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories))])
                    self._leafs = OrderedDict()

                    self.stm_port_histories = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories()
                    self.stm_port_histories.parent = self
                    self._children_name_map["stm_port_histories"] = "stm-port-histories"
                    self._segment_path = lambda: "stm-history"
                    self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory, [], name, value)


                class StmPortHistories(Entity):
                    """
                    Port performance data
                    
                    .. attribute:: stm_port_history
                    
                    	Port performance data
                    	**type**\: list of  		 :py:class:`StmPortHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories, self).__init__()

                        self.yang_name = "stm-port-histories"
                        self.yang_parent_name = "stm-history"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("stm-port-history", ("stm_port_history", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory))])
                        self._leafs = OrderedDict()

                        self.stm_port_history = YList(self)
                        self._segment_path = lambda: "stm-port-histories"
                        self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/stm-history/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories, [], name, value)


                    class StmPortHistory(Entity):
                        """
                        Port performance data
                        
                        .. attribute:: name  (key)
                        
                        	Port name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: stm_hour24_history
                        
                        	port current performance data
                        	**type**\:  :py:class:`StmHour24History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History>`
                        
                        .. attribute:: stm_minute15_history
                        
                        	port current performance data
                        	**type**\:  :py:class:`StmMinute15History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory, self).__init__()

                            self.yang_name = "stm-port-history"
                            self.yang_parent_name = "stm-port-histories"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("stm-hour24-history", ("stm_hour24_history", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History)), ("stm-minute15-history", ("stm_minute15_history", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None

                            self.stm_hour24_history = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History()
                            self.stm_hour24_history.parent = self
                            self._children_name_map["stm_hour24_history"] = "stm-hour24-history"

                            self.stm_minute15_history = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History()
                            self.stm_minute15_history.parent = self
                            self._children_name_map["stm_minute15_history"] = "stm-minute15-history"
                            self._segment_path = lambda: "stm-port-history" + "[name='" + str(self.name) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/stm-history/stm-port-histories/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory, ['name'], name, value)


                        class StmHour24History(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: stm_hour24stm_histories
                            
                            	port current performance data
                            	**type**\:  :py:class:`StmHour24stmHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History, self).__init__()

                                self.yang_name = "stm-hour24-history"
                                self.yang_parent_name = "stm-port-history"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("stm-hour24stm-histories", ("stm_hour24stm_histories", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories))])
                                self._leafs = OrderedDict()

                                self.stm_hour24stm_histories = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories()
                                self.stm_hour24stm_histories.parent = self
                                self._children_name_map["stm_hour24stm_histories"] = "stm-hour24stm-histories"
                                self._segment_path = lambda: "stm-hour24-history"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History, [], name, value)


                            class StmHour24stmHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: stm_hour24stm_history
                                
                                	port 24 hour stm performance data
                                	**type**\: list of  		 :py:class:`StmHour24stmHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories, self).__init__()

                                    self.yang_name = "stm-hour24stm-histories"
                                    self.yang_parent_name = "stm-hour24-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("stm-hour24stm-history", ("stm_hour24stm_history", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory))])
                                    self._leafs = OrderedDict()

                                    self.stm_hour24stm_history = YList(self)
                                    self._segment_path = lambda: "stm-hour24stm-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories, [], name, value)


                                class StmHour24stmHistory(Entity):
                                    """
                                    port 24 hour stm performance data
                                    
                                    .. attribute:: number  (key)
                                    
                                    	channel number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: stm_hour24stm_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`StmHour24stmTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory, self).__init__()

                                        self.yang_name = "stm-hour24stm-history"
                                        self.yang_parent_name = "stm-hour24stm-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([("stm-hour24stm-time-line-instances", ("stm_hour24stm_time_line_instances", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ])
                                        self.number = None

                                        self.stm_hour24stm_time_line_instances = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances()
                                        self.stm_hour24stm_time_line_instances.parent = self
                                        self._children_name_map["stm_hour24stm_time_line_instances"] = "stm-hour24stm-time-line-instances"
                                        self._segment_path = lambda: "stm-hour24stm-history" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory, ['number'], name, value)


                                    class StmHour24stmTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: stm_hour24stm_time_line_instance
                                        
                                        	port 15\-minute stm performance data
                                        	**type**\: list of  		 :py:class:`StmHour24stmTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances, self).__init__()

                                            self.yang_name = "stm-hour24stm-time-line-instances"
                                            self.yang_parent_name = "stm-hour24stm-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("stm-hour24stm-time-line-instance", ("stm_hour24stm_time_line_instance", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.stm_hour24stm_time_line_instance = YList(self)
                                            self._segment_path = lambda: "stm-hour24stm-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances, [], name, value)


                                        class StmHour24stmTimeLineInstance(Entity):
                                            """
                                            port 15\-minute stm performance data
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: section
                                            
                                            	SECTION
                                            	**type**\:  :py:class:`Section <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Section>`
                                            
                                            .. attribute:: line
                                            
                                            	LINE
                                            	**type**\:  :py:class:`Line <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Line>`
                                            
                                            .. attribute:: fe_line
                                            
                                            	FarEnd LINE
                                            	**type**\:  :py:class:`FeLine <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.FeLine>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance, self).__init__()

                                                self.yang_name = "stm-hour24stm-time-line-instance"
                                                self.yang_parent_name = "stm-hour24stm-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("section", ("section", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Section)), ("line", ("line", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Line)), ("fe-line", ("fe_line", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.FeLine))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None

                                                self.section = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Section()
                                                self.section.parent = self
                                                self._children_name_map["section"] = "section"

                                                self.line = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Line()
                                                self.line.parent = self
                                                self._children_name_map["line"] = "line"

                                                self.fe_line = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.FeLine()
                                                self.fe_line.parent = self
                                                self._children_name_map["fe_line"] = "fe-line"
                                                self._segment_path = lambda: "stm-hour24stm-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear24_hr_time'], name, value)


                                            class Section(Entity):
                                                """
                                                SECTION
                                                
                                                .. attribute:: section_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:  :py:class:`SectionESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Section.SectionESs>`
                                                
                                                .. attribute:: section_es_rs
                                                
                                                	The number of Errored Seconds Ratio
                                                	**type**\:  :py:class:`SectionEsRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Section.SectionEsRs>`
                                                
                                                .. attribute:: section_bb_es
                                                
                                                	The number of Background Block Errors
                                                	**type**\:  :py:class:`SectionBbEs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Section.SectionBbEs>`
                                                
                                                .. attribute:: section_bbe_rs
                                                
                                                	The number of Background Block Errors
                                                	**type**\:  :py:class:`SectionBbeRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Section.SectionBbeRs>`
                                                
                                                .. attribute:: section_se_ss
                                                
                                                	The number of Severely Errored Second
                                                	**type**\:  :py:class:`SectionSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Section.SectionSeSs>`
                                                
                                                .. attribute:: section_ses_rs
                                                
                                                	The number of Severely Errored Second Ratio
                                                	**type**\:  :py:class:`SectionSesRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Section.SectionSesRs>`
                                                
                                                .. attribute:: section_ua_ss
                                                
                                                	The number of Unavailable Second
                                                	**type**\:  :py:class:`SectionUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Section.SectionUaSs>`
                                                
                                                .. attribute:: section_e_bs
                                                
                                                	The number of Errored Block Second
                                                	**type**\:  :py:class:`SectionEBs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Section.SectionEBs>`
                                                
                                                .. attribute:: section_status
                                                
                                                	 status of the interface
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Section, self).__init__()

                                                    self.yang_name = "section"
                                                    self.yang_parent_name = "stm-hour24stm-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("section-e-ss", ("section_e_ss", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Section.SectionESs)), ("section-es-rs", ("section_es_rs", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Section.SectionEsRs)), ("section-bb-es", ("section_bb_es", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Section.SectionBbEs)), ("section-bbe-rs", ("section_bbe_rs", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Section.SectionBbeRs)), ("section-se-ss", ("section_se_ss", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Section.SectionSeSs)), ("section-ses-rs", ("section_ses_rs", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Section.SectionSesRs)), ("section-ua-ss", ("section_ua_ss", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Section.SectionUaSs)), ("section-e-bs", ("section_e_bs", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Section.SectionEBs))])
                                                    self._leafs = OrderedDict([
                                                        ('section_status', (YLeaf(YType.int32, 'section-status'), ['int'])),
                                                    ])
                                                    self.section_status = None

                                                    self.section_e_ss = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Section.SectionESs()
                                                    self.section_e_ss.parent = self
                                                    self._children_name_map["section_e_ss"] = "section-e-ss"

                                                    self.section_es_rs = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Section.SectionEsRs()
                                                    self.section_es_rs.parent = self
                                                    self._children_name_map["section_es_rs"] = "section-es-rs"

                                                    self.section_bb_es = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Section.SectionBbEs()
                                                    self.section_bb_es.parent = self
                                                    self._children_name_map["section_bb_es"] = "section-bb-es"

                                                    self.section_bbe_rs = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Section.SectionBbeRs()
                                                    self.section_bbe_rs.parent = self
                                                    self._children_name_map["section_bbe_rs"] = "section-bbe-rs"

                                                    self.section_se_ss = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Section.SectionSeSs()
                                                    self.section_se_ss.parent = self
                                                    self._children_name_map["section_se_ss"] = "section-se-ss"

                                                    self.section_ses_rs = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Section.SectionSesRs()
                                                    self.section_ses_rs.parent = self
                                                    self._children_name_map["section_ses_rs"] = "section-ses-rs"

                                                    self.section_ua_ss = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Section.SectionUaSs()
                                                    self.section_ua_ss.parent = self
                                                    self._children_name_map["section_ua_ss"] = "section-ua-ss"

                                                    self.section_e_bs = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Section.SectionEBs()
                                                    self.section_e_bs.parent = self
                                                    self._children_name_map["section_e_bs"] = "section-e-bs"
                                                    self._segment_path = lambda: "section"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Section, ['section_status'], name, value)


                                                class SectionESs(Entity):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Section.SectionESs, self).__init__()

                                                        self.yang_name = "section-e-ss"
                                                        self.yang_parent_name = "section"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "section-e-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Section.SectionESs, ['data', 'threshold', 'tca_report'], name, value)


                                                class SectionEsRs(Entity):
                                                    """
                                                    The number of Errored Seconds Ratio
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Section.SectionEsRs, self).__init__()

                                                        self.yang_name = "section-es-rs"
                                                        self.yang_parent_name = "section"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "section-es-rs"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Section.SectionEsRs, ['data', 'threshold', 'tca_report'], name, value)


                                                class SectionBbEs(Entity):
                                                    """
                                                    The number of Background Block Errors
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Section.SectionBbEs, self).__init__()

                                                        self.yang_name = "section-bb-es"
                                                        self.yang_parent_name = "section"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "section-bb-es"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Section.SectionBbEs, ['data', 'threshold', 'tca_report'], name, value)


                                                class SectionBbeRs(Entity):
                                                    """
                                                    The number of Background Block Errors
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Section.SectionBbeRs, self).__init__()

                                                        self.yang_name = "section-bbe-rs"
                                                        self.yang_parent_name = "section"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "section-bbe-rs"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Section.SectionBbeRs, ['data', 'threshold', 'tca_report'], name, value)


                                                class SectionSeSs(Entity):
                                                    """
                                                    The number of Severely Errored Second
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Section.SectionSeSs, self).__init__()

                                                        self.yang_name = "section-se-ss"
                                                        self.yang_parent_name = "section"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "section-se-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Section.SectionSeSs, ['data', 'threshold', 'tca_report'], name, value)


                                                class SectionSesRs(Entity):
                                                    """
                                                    The number of Severely Errored Second Ratio
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Section.SectionSesRs, self).__init__()

                                                        self.yang_name = "section-ses-rs"
                                                        self.yang_parent_name = "section"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "section-ses-rs"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Section.SectionSesRs, ['data', 'threshold', 'tca_report'], name, value)


                                                class SectionUaSs(Entity):
                                                    """
                                                    The number of Unavailable Second
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Section.SectionUaSs, self).__init__()

                                                        self.yang_name = "section-ua-ss"
                                                        self.yang_parent_name = "section"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "section-ua-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Section.SectionUaSs, ['data', 'threshold', 'tca_report'], name, value)


                                                class SectionEBs(Entity):
                                                    """
                                                    The number of Errored Block Second
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Section.SectionEBs, self).__init__()

                                                        self.yang_name = "section-e-bs"
                                                        self.yang_parent_name = "section"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "section-e-bs"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Section.SectionEBs, ['data', 'threshold', 'tca_report'], name, value)


                                            class Line(Entity):
                                                """
                                                LINE
                                                
                                                .. attribute:: line_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:  :py:class:`LineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Line.LineESs>`
                                                
                                                .. attribute:: line_es_rs
                                                
                                                	The number of Errored Seconds Ratio
                                                	**type**\:  :py:class:`LineEsRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Line.LineEsRs>`
                                                
                                                .. attribute:: line_bb_es
                                                
                                                	The number of Background Block Errors
                                                	**type**\:  :py:class:`LineBbEs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Line.LineBbEs>`
                                                
                                                .. attribute:: line_bbe_rs
                                                
                                                	The number of Background Block Errors
                                                	**type**\:  :py:class:`LineBbeRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Line.LineBbeRs>`
                                                
                                                .. attribute:: line_se_ss
                                                
                                                	The number of Severely Errored Second
                                                	**type**\:  :py:class:`LineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Line.LineSeSs>`
                                                
                                                .. attribute:: line_ses_rs
                                                
                                                	The number of Severely Errored Second Ratio
                                                	**type**\:  :py:class:`LineSesRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Line.LineSesRs>`
                                                
                                                .. attribute:: line_ua_ss
                                                
                                                	The number of Unavailable Second
                                                	**type**\:  :py:class:`LineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Line.LineUaSs>`
                                                
                                                .. attribute:: line_e_bs
                                                
                                                	The number of Errored Block Second
                                                	**type**\:  :py:class:`LineEBs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Line.LineEBs>`
                                                
                                                .. attribute:: line_status
                                                
                                                	 status of the interface
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Line, self).__init__()

                                                    self.yang_name = "line"
                                                    self.yang_parent_name = "stm-hour24stm-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("line-e-ss", ("line_e_ss", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Line.LineESs)), ("line-es-rs", ("line_es_rs", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Line.LineEsRs)), ("line-bb-es", ("line_bb_es", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Line.LineBbEs)), ("line-bbe-rs", ("line_bbe_rs", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Line.LineBbeRs)), ("line-se-ss", ("line_se_ss", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Line.LineSeSs)), ("line-ses-rs", ("line_ses_rs", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Line.LineSesRs)), ("line-ua-ss", ("line_ua_ss", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Line.LineUaSs)), ("line-e-bs", ("line_e_bs", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Line.LineEBs))])
                                                    self._leafs = OrderedDict([
                                                        ('line_status', (YLeaf(YType.int32, 'line-status'), ['int'])),
                                                    ])
                                                    self.line_status = None

                                                    self.line_e_ss = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Line.LineESs()
                                                    self.line_e_ss.parent = self
                                                    self._children_name_map["line_e_ss"] = "line-e-ss"

                                                    self.line_es_rs = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Line.LineEsRs()
                                                    self.line_es_rs.parent = self
                                                    self._children_name_map["line_es_rs"] = "line-es-rs"

                                                    self.line_bb_es = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Line.LineBbEs()
                                                    self.line_bb_es.parent = self
                                                    self._children_name_map["line_bb_es"] = "line-bb-es"

                                                    self.line_bbe_rs = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Line.LineBbeRs()
                                                    self.line_bbe_rs.parent = self
                                                    self._children_name_map["line_bbe_rs"] = "line-bbe-rs"

                                                    self.line_se_ss = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Line.LineSeSs()
                                                    self.line_se_ss.parent = self
                                                    self._children_name_map["line_se_ss"] = "line-se-ss"

                                                    self.line_ses_rs = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Line.LineSesRs()
                                                    self.line_ses_rs.parent = self
                                                    self._children_name_map["line_ses_rs"] = "line-ses-rs"

                                                    self.line_ua_ss = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Line.LineUaSs()
                                                    self.line_ua_ss.parent = self
                                                    self._children_name_map["line_ua_ss"] = "line-ua-ss"

                                                    self.line_e_bs = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Line.LineEBs()
                                                    self.line_e_bs.parent = self
                                                    self._children_name_map["line_e_bs"] = "line-e-bs"
                                                    self._segment_path = lambda: "line"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Line, ['line_status'], name, value)


                                                class LineESs(Entity):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Line.LineESs, self).__init__()

                                                        self.yang_name = "line-e-ss"
                                                        self.yang_parent_name = "line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "line-e-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Line.LineESs, ['data', 'threshold', 'tca_report'], name, value)


                                                class LineEsRs(Entity):
                                                    """
                                                    The number of Errored Seconds Ratio
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Line.LineEsRs, self).__init__()

                                                        self.yang_name = "line-es-rs"
                                                        self.yang_parent_name = "line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "line-es-rs"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Line.LineEsRs, ['data', 'threshold', 'tca_report'], name, value)


                                                class LineBbEs(Entity):
                                                    """
                                                    The number of Background Block Errors
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Line.LineBbEs, self).__init__()

                                                        self.yang_name = "line-bb-es"
                                                        self.yang_parent_name = "line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "line-bb-es"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Line.LineBbEs, ['data', 'threshold', 'tca_report'], name, value)


                                                class LineBbeRs(Entity):
                                                    """
                                                    The number of Background Block Errors
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Line.LineBbeRs, self).__init__()

                                                        self.yang_name = "line-bbe-rs"
                                                        self.yang_parent_name = "line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "line-bbe-rs"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Line.LineBbeRs, ['data', 'threshold', 'tca_report'], name, value)


                                                class LineSeSs(Entity):
                                                    """
                                                    The number of Severely Errored Second
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Line.LineSeSs, self).__init__()

                                                        self.yang_name = "line-se-ss"
                                                        self.yang_parent_name = "line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "line-se-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Line.LineSeSs, ['data', 'threshold', 'tca_report'], name, value)


                                                class LineSesRs(Entity):
                                                    """
                                                    The number of Severely Errored Second Ratio
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Line.LineSesRs, self).__init__()

                                                        self.yang_name = "line-ses-rs"
                                                        self.yang_parent_name = "line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "line-ses-rs"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Line.LineSesRs, ['data', 'threshold', 'tca_report'], name, value)


                                                class LineUaSs(Entity):
                                                    """
                                                    The number of Unavailable Second
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Line.LineUaSs, self).__init__()

                                                        self.yang_name = "line-ua-ss"
                                                        self.yang_parent_name = "line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "line-ua-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Line.LineUaSs, ['data', 'threshold', 'tca_report'], name, value)


                                                class LineEBs(Entity):
                                                    """
                                                    The number of Errored Block Second
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Line.LineEBs, self).__init__()

                                                        self.yang_name = "line-e-bs"
                                                        self.yang_parent_name = "line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "line-e-bs"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.Line.LineEBs, ['data', 'threshold', 'tca_report'], name, value)


                                            class FeLine(Entity):
                                                """
                                                FarEnd LINE
                                                
                                                .. attribute:: far_end_line_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:  :py:class:`FarEndLineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.FeLine.FarEndLineESs>`
                                                
                                                .. attribute:: far_end_line_es_rs
                                                
                                                	The number of Errored Seconds Ratio
                                                	**type**\:  :py:class:`FarEndLineEsRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.FeLine.FarEndLineEsRs>`
                                                
                                                .. attribute:: far_end_line_ebb_es
                                                
                                                	The number of Background Block Errors
                                                	**type**\:  :py:class:`FarEndLineEbbEs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.FeLine.FarEndLineEbbEs>`
                                                
                                                .. attribute:: far_end_line_bbe_rs
                                                
                                                	The number of Background Block Errors
                                                	**type**\:  :py:class:`FarEndLineBbeRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.FeLine.FarEndLineBbeRs>`
                                                
                                                .. attribute:: far_end_line_se_ss
                                                
                                                	The number of Severely Errored Second
                                                	**type**\:  :py:class:`FarEndLineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.FeLine.FarEndLineSeSs>`
                                                
                                                .. attribute:: far_end_line_ses_rs
                                                
                                                	The number of Severely Errored Second Ratio
                                                	**type**\:  :py:class:`FarEndLineSesRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.FeLine.FarEndLineSesRs>`
                                                
                                                .. attribute:: far_end_line_ua_ss
                                                
                                                	The number of Unavailable Second
                                                	**type**\:  :py:class:`FarEndLineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.FeLine.FarEndLineUaSs>`
                                                
                                                .. attribute:: far_end_line_e_bs
                                                
                                                	The number of Errored Block Second
                                                	**type**\:  :py:class:`FarEndLineEBs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.FeLine.FarEndLineEBs>`
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.FeLine, self).__init__()

                                                    self.yang_name = "fe-line"
                                                    self.yang_parent_name = "stm-hour24stm-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("far-end-line-e-ss", ("far_end_line_e_ss", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.FeLine.FarEndLineESs)), ("far-end-line-es-rs", ("far_end_line_es_rs", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.FeLine.FarEndLineEsRs)), ("far-end-line-ebb-es", ("far_end_line_ebb_es", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.FeLine.FarEndLineEbbEs)), ("far-end-line-bbe-rs", ("far_end_line_bbe_rs", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.FeLine.FarEndLineBbeRs)), ("far-end-line-se-ss", ("far_end_line_se_ss", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.FeLine.FarEndLineSeSs)), ("far-end-line-ses-rs", ("far_end_line_ses_rs", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.FeLine.FarEndLineSesRs)), ("far-end-line-ua-ss", ("far_end_line_ua_ss", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.FeLine.FarEndLineUaSs)), ("far-end-line-e-bs", ("far_end_line_e_bs", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.FeLine.FarEndLineEBs))])
                                                    self._leafs = OrderedDict()

                                                    self.far_end_line_e_ss = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.FeLine.FarEndLineESs()
                                                    self.far_end_line_e_ss.parent = self
                                                    self._children_name_map["far_end_line_e_ss"] = "far-end-line-e-ss"

                                                    self.far_end_line_es_rs = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.FeLine.FarEndLineEsRs()
                                                    self.far_end_line_es_rs.parent = self
                                                    self._children_name_map["far_end_line_es_rs"] = "far-end-line-es-rs"

                                                    self.far_end_line_ebb_es = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.FeLine.FarEndLineEbbEs()
                                                    self.far_end_line_ebb_es.parent = self
                                                    self._children_name_map["far_end_line_ebb_es"] = "far-end-line-ebb-es"

                                                    self.far_end_line_bbe_rs = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.FeLine.FarEndLineBbeRs()
                                                    self.far_end_line_bbe_rs.parent = self
                                                    self._children_name_map["far_end_line_bbe_rs"] = "far-end-line-bbe-rs"

                                                    self.far_end_line_se_ss = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.FeLine.FarEndLineSeSs()
                                                    self.far_end_line_se_ss.parent = self
                                                    self._children_name_map["far_end_line_se_ss"] = "far-end-line-se-ss"

                                                    self.far_end_line_ses_rs = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.FeLine.FarEndLineSesRs()
                                                    self.far_end_line_ses_rs.parent = self
                                                    self._children_name_map["far_end_line_ses_rs"] = "far-end-line-ses-rs"

                                                    self.far_end_line_ua_ss = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.FeLine.FarEndLineUaSs()
                                                    self.far_end_line_ua_ss.parent = self
                                                    self._children_name_map["far_end_line_ua_ss"] = "far-end-line-ua-ss"

                                                    self.far_end_line_e_bs = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.FeLine.FarEndLineEBs()
                                                    self.far_end_line_e_bs.parent = self
                                                    self._children_name_map["far_end_line_e_bs"] = "far-end-line-e-bs"
                                                    self._segment_path = lambda: "fe-line"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.FeLine, [], name, value)


                                                class FarEndLineESs(Entity):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.FeLine.FarEndLineESs, self).__init__()

                                                        self.yang_name = "far-end-line-e-ss"
                                                        self.yang_parent_name = "fe-line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "far-end-line-e-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.FeLine.FarEndLineESs, ['data', 'threshold', 'tca_report'], name, value)


                                                class FarEndLineEsRs(Entity):
                                                    """
                                                    The number of Errored Seconds Ratio
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.FeLine.FarEndLineEsRs, self).__init__()

                                                        self.yang_name = "far-end-line-es-rs"
                                                        self.yang_parent_name = "fe-line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "far-end-line-es-rs"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.FeLine.FarEndLineEsRs, ['data', 'threshold', 'tca_report'], name, value)


                                                class FarEndLineEbbEs(Entity):
                                                    """
                                                    The number of Background Block Errors
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.FeLine.FarEndLineEbbEs, self).__init__()

                                                        self.yang_name = "far-end-line-ebb-es"
                                                        self.yang_parent_name = "fe-line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "far-end-line-ebb-es"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.FeLine.FarEndLineEbbEs, ['data', 'threshold', 'tca_report'], name, value)


                                                class FarEndLineBbeRs(Entity):
                                                    """
                                                    The number of Background Block Errors
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.FeLine.FarEndLineBbeRs, self).__init__()

                                                        self.yang_name = "far-end-line-bbe-rs"
                                                        self.yang_parent_name = "fe-line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "far-end-line-bbe-rs"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.FeLine.FarEndLineBbeRs, ['data', 'threshold', 'tca_report'], name, value)


                                                class FarEndLineSeSs(Entity):
                                                    """
                                                    The number of Severely Errored Second
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.FeLine.FarEndLineSeSs, self).__init__()

                                                        self.yang_name = "far-end-line-se-ss"
                                                        self.yang_parent_name = "fe-line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "far-end-line-se-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.FeLine.FarEndLineSeSs, ['data', 'threshold', 'tca_report'], name, value)


                                                class FarEndLineSesRs(Entity):
                                                    """
                                                    The number of Severely Errored Second Ratio
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.FeLine.FarEndLineSesRs, self).__init__()

                                                        self.yang_name = "far-end-line-ses-rs"
                                                        self.yang_parent_name = "fe-line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "far-end-line-ses-rs"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.FeLine.FarEndLineSesRs, ['data', 'threshold', 'tca_report'], name, value)


                                                class FarEndLineUaSs(Entity):
                                                    """
                                                    The number of Unavailable Second
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.FeLine.FarEndLineUaSs, self).__init__()

                                                        self.yang_name = "far-end-line-ua-ss"
                                                        self.yang_parent_name = "fe-line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "far-end-line-ua-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.FeLine.FarEndLineUaSs, ['data', 'threshold', 'tca_report'], name, value)


                                                class FarEndLineEBs(Entity):
                                                    """
                                                    The number of Errored Block Second
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.FeLine.FarEndLineEBs, self).__init__()

                                                        self.yang_name = "far-end-line-e-bs"
                                                        self.yang_parent_name = "fe-line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "far-end-line-e-bs"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24stmHistories.StmHour24stmHistory.StmHour24stmTimeLineInstances.StmHour24stmTimeLineInstance.FeLine.FarEndLineEBs, ['data', 'threshold', 'tca_report'], name, value)


                        class StmMinute15History(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: stm_minute15stm_histories
                            
                            	port current performance data
                            	**type**\:  :py:class:`StmMinute15stmHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History, self).__init__()

                                self.yang_name = "stm-minute15-history"
                                self.yang_parent_name = "stm-port-history"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("stm-minute15stm-histories", ("stm_minute15stm_histories", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories))])
                                self._leafs = OrderedDict()

                                self.stm_minute15stm_histories = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories()
                                self.stm_minute15stm_histories.parent = self
                                self._children_name_map["stm_minute15stm_histories"] = "stm-minute15stm-histories"
                                self._segment_path = lambda: "stm-minute15-history"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History, [], name, value)


                            class StmMinute15stmHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: stm_minute15stm_history
                                
                                	port 15\-minute stm performance data
                                	**type**\: list of  		 :py:class:`StmMinute15stmHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories, self).__init__()

                                    self.yang_name = "stm-minute15stm-histories"
                                    self.yang_parent_name = "stm-minute15-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("stm-minute15stm-history", ("stm_minute15stm_history", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory))])
                                    self._leafs = OrderedDict()

                                    self.stm_minute15stm_history = YList(self)
                                    self._segment_path = lambda: "stm-minute15stm-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories, [], name, value)


                                class StmMinute15stmHistory(Entity):
                                    """
                                    port 15\-minute stm performance data
                                    
                                    .. attribute:: number  (key)
                                    
                                    	channel number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: stm_minute15stm_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`StmMinute15stmTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory, self).__init__()

                                        self.yang_name = "stm-minute15stm-history"
                                        self.yang_parent_name = "stm-minute15stm-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([("stm-minute15stm-time-line-instances", ("stm_minute15stm_time_line_instances", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ])
                                        self.number = None

                                        self.stm_minute15stm_time_line_instances = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances()
                                        self.stm_minute15stm_time_line_instances.parent = self
                                        self._children_name_map["stm_minute15stm_time_line_instances"] = "stm-minute15stm-time-line-instances"
                                        self._segment_path = lambda: "stm-minute15stm-history" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory, ['number'], name, value)


                                    class StmMinute15stmTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: stm_minute15stm_time_line_instance
                                        
                                        	port 15\-minute stm performance data
                                        	**type**\: list of  		 :py:class:`StmMinute15stmTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances, self).__init__()

                                            self.yang_name = "stm-minute15stm-time-line-instances"
                                            self.yang_parent_name = "stm-minute15stm-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("stm-minute15stm-time-line-instance", ("stm_minute15stm_time_line_instance", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.stm_minute15stm_time_line_instance = YList(self)
                                            self._segment_path = lambda: "stm-minute15stm-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances, [], name, value)


                                        class StmMinute15stmTimeLineInstance(Entity):
                                            """
                                            port 15\-minute stm performance data
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: section
                                            
                                            	SECTION
                                            	**type**\:  :py:class:`Section <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Section>`
                                            
                                            .. attribute:: line
                                            
                                            	LINE
                                            	**type**\:  :py:class:`Line <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Line>`
                                            
                                            .. attribute:: fe_line
                                            
                                            	FarEnd LINE
                                            	**type**\:  :py:class:`FeLine <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.FeLine>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance, self).__init__()

                                                self.yang_name = "stm-minute15stm-time-line-instance"
                                                self.yang_parent_name = "stm-minute15stm-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("section", ("section", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Section)), ("line", ("line", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Line)), ("fe-line", ("fe_line", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.FeLine))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None

                                                self.section = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Section()
                                                self.section.parent = self
                                                self._children_name_map["section"] = "section"

                                                self.line = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Line()
                                                self.line.parent = self
                                                self._children_name_map["line"] = "line"

                                                self.fe_line = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.FeLine()
                                                self.fe_line.parent = self
                                                self._children_name_map["fe_line"] = "fe-line"
                                                self._segment_path = lambda: "stm-minute15stm-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear24_hr_time'], name, value)


                                            class Section(Entity):
                                                """
                                                SECTION
                                                
                                                .. attribute:: section_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:  :py:class:`SectionESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Section.SectionESs>`
                                                
                                                .. attribute:: section_es_rs
                                                
                                                	The number of Errored Seconds Ratio
                                                	**type**\:  :py:class:`SectionEsRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Section.SectionEsRs>`
                                                
                                                .. attribute:: section_bb_es
                                                
                                                	The number of Background Block Errors
                                                	**type**\:  :py:class:`SectionBbEs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Section.SectionBbEs>`
                                                
                                                .. attribute:: section_bbe_rs
                                                
                                                	The number of Background Block Errors
                                                	**type**\:  :py:class:`SectionBbeRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Section.SectionBbeRs>`
                                                
                                                .. attribute:: section_se_ss
                                                
                                                	The number of Severely Errored Second
                                                	**type**\:  :py:class:`SectionSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Section.SectionSeSs>`
                                                
                                                .. attribute:: section_ses_rs
                                                
                                                	The number of Severely Errored Second Ratio
                                                	**type**\:  :py:class:`SectionSesRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Section.SectionSesRs>`
                                                
                                                .. attribute:: section_ua_ss
                                                
                                                	The number of Unavailable Second
                                                	**type**\:  :py:class:`SectionUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Section.SectionUaSs>`
                                                
                                                .. attribute:: section_e_bs
                                                
                                                	The number of Errored Block Second
                                                	**type**\:  :py:class:`SectionEBs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Section.SectionEBs>`
                                                
                                                .. attribute:: section_status
                                                
                                                	 status of the interface
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Section, self).__init__()

                                                    self.yang_name = "section"
                                                    self.yang_parent_name = "stm-minute15stm-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("section-e-ss", ("section_e_ss", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Section.SectionESs)), ("section-es-rs", ("section_es_rs", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Section.SectionEsRs)), ("section-bb-es", ("section_bb_es", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Section.SectionBbEs)), ("section-bbe-rs", ("section_bbe_rs", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Section.SectionBbeRs)), ("section-se-ss", ("section_se_ss", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Section.SectionSeSs)), ("section-ses-rs", ("section_ses_rs", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Section.SectionSesRs)), ("section-ua-ss", ("section_ua_ss", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Section.SectionUaSs)), ("section-e-bs", ("section_e_bs", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Section.SectionEBs))])
                                                    self._leafs = OrderedDict([
                                                        ('section_status', (YLeaf(YType.int32, 'section-status'), ['int'])),
                                                    ])
                                                    self.section_status = None

                                                    self.section_e_ss = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Section.SectionESs()
                                                    self.section_e_ss.parent = self
                                                    self._children_name_map["section_e_ss"] = "section-e-ss"

                                                    self.section_es_rs = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Section.SectionEsRs()
                                                    self.section_es_rs.parent = self
                                                    self._children_name_map["section_es_rs"] = "section-es-rs"

                                                    self.section_bb_es = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Section.SectionBbEs()
                                                    self.section_bb_es.parent = self
                                                    self._children_name_map["section_bb_es"] = "section-bb-es"

                                                    self.section_bbe_rs = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Section.SectionBbeRs()
                                                    self.section_bbe_rs.parent = self
                                                    self._children_name_map["section_bbe_rs"] = "section-bbe-rs"

                                                    self.section_se_ss = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Section.SectionSeSs()
                                                    self.section_se_ss.parent = self
                                                    self._children_name_map["section_se_ss"] = "section-se-ss"

                                                    self.section_ses_rs = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Section.SectionSesRs()
                                                    self.section_ses_rs.parent = self
                                                    self._children_name_map["section_ses_rs"] = "section-ses-rs"

                                                    self.section_ua_ss = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Section.SectionUaSs()
                                                    self.section_ua_ss.parent = self
                                                    self._children_name_map["section_ua_ss"] = "section-ua-ss"

                                                    self.section_e_bs = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Section.SectionEBs()
                                                    self.section_e_bs.parent = self
                                                    self._children_name_map["section_e_bs"] = "section-e-bs"
                                                    self._segment_path = lambda: "section"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Section, ['section_status'], name, value)


                                                class SectionESs(Entity):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Section.SectionESs, self).__init__()

                                                        self.yang_name = "section-e-ss"
                                                        self.yang_parent_name = "section"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "section-e-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Section.SectionESs, ['data', 'threshold', 'tca_report'], name, value)


                                                class SectionEsRs(Entity):
                                                    """
                                                    The number of Errored Seconds Ratio
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Section.SectionEsRs, self).__init__()

                                                        self.yang_name = "section-es-rs"
                                                        self.yang_parent_name = "section"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "section-es-rs"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Section.SectionEsRs, ['data', 'threshold', 'tca_report'], name, value)


                                                class SectionBbEs(Entity):
                                                    """
                                                    The number of Background Block Errors
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Section.SectionBbEs, self).__init__()

                                                        self.yang_name = "section-bb-es"
                                                        self.yang_parent_name = "section"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "section-bb-es"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Section.SectionBbEs, ['data', 'threshold', 'tca_report'], name, value)


                                                class SectionBbeRs(Entity):
                                                    """
                                                    The number of Background Block Errors
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Section.SectionBbeRs, self).__init__()

                                                        self.yang_name = "section-bbe-rs"
                                                        self.yang_parent_name = "section"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "section-bbe-rs"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Section.SectionBbeRs, ['data', 'threshold', 'tca_report'], name, value)


                                                class SectionSeSs(Entity):
                                                    """
                                                    The number of Severely Errored Second
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Section.SectionSeSs, self).__init__()

                                                        self.yang_name = "section-se-ss"
                                                        self.yang_parent_name = "section"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "section-se-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Section.SectionSeSs, ['data', 'threshold', 'tca_report'], name, value)


                                                class SectionSesRs(Entity):
                                                    """
                                                    The number of Severely Errored Second Ratio
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Section.SectionSesRs, self).__init__()

                                                        self.yang_name = "section-ses-rs"
                                                        self.yang_parent_name = "section"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "section-ses-rs"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Section.SectionSesRs, ['data', 'threshold', 'tca_report'], name, value)


                                                class SectionUaSs(Entity):
                                                    """
                                                    The number of Unavailable Second
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Section.SectionUaSs, self).__init__()

                                                        self.yang_name = "section-ua-ss"
                                                        self.yang_parent_name = "section"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "section-ua-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Section.SectionUaSs, ['data', 'threshold', 'tca_report'], name, value)


                                                class SectionEBs(Entity):
                                                    """
                                                    The number of Errored Block Second
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Section.SectionEBs, self).__init__()

                                                        self.yang_name = "section-e-bs"
                                                        self.yang_parent_name = "section"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "section-e-bs"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Section.SectionEBs, ['data', 'threshold', 'tca_report'], name, value)


                                            class Line(Entity):
                                                """
                                                LINE
                                                
                                                .. attribute:: line_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:  :py:class:`LineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Line.LineESs>`
                                                
                                                .. attribute:: line_es_rs
                                                
                                                	The number of Errored Seconds Ratio
                                                	**type**\:  :py:class:`LineEsRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Line.LineEsRs>`
                                                
                                                .. attribute:: line_bb_es
                                                
                                                	The number of Background Block Errors
                                                	**type**\:  :py:class:`LineBbEs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Line.LineBbEs>`
                                                
                                                .. attribute:: line_bbe_rs
                                                
                                                	The number of Background Block Errors
                                                	**type**\:  :py:class:`LineBbeRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Line.LineBbeRs>`
                                                
                                                .. attribute:: line_se_ss
                                                
                                                	The number of Severely Errored Second
                                                	**type**\:  :py:class:`LineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Line.LineSeSs>`
                                                
                                                .. attribute:: line_ses_rs
                                                
                                                	The number of Severely Errored Second Ratio
                                                	**type**\:  :py:class:`LineSesRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Line.LineSesRs>`
                                                
                                                .. attribute:: line_ua_ss
                                                
                                                	The number of Unavailable Second
                                                	**type**\:  :py:class:`LineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Line.LineUaSs>`
                                                
                                                .. attribute:: line_e_bs
                                                
                                                	The number of Errored Block Second
                                                	**type**\:  :py:class:`LineEBs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Line.LineEBs>`
                                                
                                                .. attribute:: line_status
                                                
                                                	 status of the interface
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Line, self).__init__()

                                                    self.yang_name = "line"
                                                    self.yang_parent_name = "stm-minute15stm-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("line-e-ss", ("line_e_ss", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Line.LineESs)), ("line-es-rs", ("line_es_rs", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Line.LineEsRs)), ("line-bb-es", ("line_bb_es", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Line.LineBbEs)), ("line-bbe-rs", ("line_bbe_rs", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Line.LineBbeRs)), ("line-se-ss", ("line_se_ss", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Line.LineSeSs)), ("line-ses-rs", ("line_ses_rs", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Line.LineSesRs)), ("line-ua-ss", ("line_ua_ss", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Line.LineUaSs)), ("line-e-bs", ("line_e_bs", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Line.LineEBs))])
                                                    self._leafs = OrderedDict([
                                                        ('line_status', (YLeaf(YType.int32, 'line-status'), ['int'])),
                                                    ])
                                                    self.line_status = None

                                                    self.line_e_ss = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Line.LineESs()
                                                    self.line_e_ss.parent = self
                                                    self._children_name_map["line_e_ss"] = "line-e-ss"

                                                    self.line_es_rs = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Line.LineEsRs()
                                                    self.line_es_rs.parent = self
                                                    self._children_name_map["line_es_rs"] = "line-es-rs"

                                                    self.line_bb_es = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Line.LineBbEs()
                                                    self.line_bb_es.parent = self
                                                    self._children_name_map["line_bb_es"] = "line-bb-es"

                                                    self.line_bbe_rs = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Line.LineBbeRs()
                                                    self.line_bbe_rs.parent = self
                                                    self._children_name_map["line_bbe_rs"] = "line-bbe-rs"

                                                    self.line_se_ss = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Line.LineSeSs()
                                                    self.line_se_ss.parent = self
                                                    self._children_name_map["line_se_ss"] = "line-se-ss"

                                                    self.line_ses_rs = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Line.LineSesRs()
                                                    self.line_ses_rs.parent = self
                                                    self._children_name_map["line_ses_rs"] = "line-ses-rs"

                                                    self.line_ua_ss = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Line.LineUaSs()
                                                    self.line_ua_ss.parent = self
                                                    self._children_name_map["line_ua_ss"] = "line-ua-ss"

                                                    self.line_e_bs = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Line.LineEBs()
                                                    self.line_e_bs.parent = self
                                                    self._children_name_map["line_e_bs"] = "line-e-bs"
                                                    self._segment_path = lambda: "line"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Line, ['line_status'], name, value)


                                                class LineESs(Entity):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Line.LineESs, self).__init__()

                                                        self.yang_name = "line-e-ss"
                                                        self.yang_parent_name = "line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "line-e-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Line.LineESs, ['data', 'threshold', 'tca_report'], name, value)


                                                class LineEsRs(Entity):
                                                    """
                                                    The number of Errored Seconds Ratio
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Line.LineEsRs, self).__init__()

                                                        self.yang_name = "line-es-rs"
                                                        self.yang_parent_name = "line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "line-es-rs"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Line.LineEsRs, ['data', 'threshold', 'tca_report'], name, value)


                                                class LineBbEs(Entity):
                                                    """
                                                    The number of Background Block Errors
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Line.LineBbEs, self).__init__()

                                                        self.yang_name = "line-bb-es"
                                                        self.yang_parent_name = "line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "line-bb-es"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Line.LineBbEs, ['data', 'threshold', 'tca_report'], name, value)


                                                class LineBbeRs(Entity):
                                                    """
                                                    The number of Background Block Errors
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Line.LineBbeRs, self).__init__()

                                                        self.yang_name = "line-bbe-rs"
                                                        self.yang_parent_name = "line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "line-bbe-rs"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Line.LineBbeRs, ['data', 'threshold', 'tca_report'], name, value)


                                                class LineSeSs(Entity):
                                                    """
                                                    The number of Severely Errored Second
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Line.LineSeSs, self).__init__()

                                                        self.yang_name = "line-se-ss"
                                                        self.yang_parent_name = "line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "line-se-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Line.LineSeSs, ['data', 'threshold', 'tca_report'], name, value)


                                                class LineSesRs(Entity):
                                                    """
                                                    The number of Severely Errored Second Ratio
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Line.LineSesRs, self).__init__()

                                                        self.yang_name = "line-ses-rs"
                                                        self.yang_parent_name = "line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "line-ses-rs"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Line.LineSesRs, ['data', 'threshold', 'tca_report'], name, value)


                                                class LineUaSs(Entity):
                                                    """
                                                    The number of Unavailable Second
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Line.LineUaSs, self).__init__()

                                                        self.yang_name = "line-ua-ss"
                                                        self.yang_parent_name = "line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "line-ua-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Line.LineUaSs, ['data', 'threshold', 'tca_report'], name, value)


                                                class LineEBs(Entity):
                                                    """
                                                    The number of Errored Block Second
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Line.LineEBs, self).__init__()

                                                        self.yang_name = "line-e-bs"
                                                        self.yang_parent_name = "line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "line-e-bs"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.Line.LineEBs, ['data', 'threshold', 'tca_report'], name, value)


                                            class FeLine(Entity):
                                                """
                                                FarEnd LINE
                                                
                                                .. attribute:: far_end_line_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:  :py:class:`FarEndLineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.FeLine.FarEndLineESs>`
                                                
                                                .. attribute:: far_end_line_es_rs
                                                
                                                	The number of Errored Seconds Ratio
                                                	**type**\:  :py:class:`FarEndLineEsRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.FeLine.FarEndLineEsRs>`
                                                
                                                .. attribute:: far_end_line_ebb_es
                                                
                                                	The number of Background Block Errors
                                                	**type**\:  :py:class:`FarEndLineEbbEs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.FeLine.FarEndLineEbbEs>`
                                                
                                                .. attribute:: far_end_line_bbe_rs
                                                
                                                	The number of Background Block Errors
                                                	**type**\:  :py:class:`FarEndLineBbeRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.FeLine.FarEndLineBbeRs>`
                                                
                                                .. attribute:: far_end_line_se_ss
                                                
                                                	The number of Severely Errored Second
                                                	**type**\:  :py:class:`FarEndLineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.FeLine.FarEndLineSeSs>`
                                                
                                                .. attribute:: far_end_line_ses_rs
                                                
                                                	The number of Severely Errored Second Ratio
                                                	**type**\:  :py:class:`FarEndLineSesRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.FeLine.FarEndLineSesRs>`
                                                
                                                .. attribute:: far_end_line_ua_ss
                                                
                                                	The number of Unavailable Second
                                                	**type**\:  :py:class:`FarEndLineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.FeLine.FarEndLineUaSs>`
                                                
                                                .. attribute:: far_end_line_e_bs
                                                
                                                	The number of Errored Block Second
                                                	**type**\:  :py:class:`FarEndLineEBs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.FeLine.FarEndLineEBs>`
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.FeLine, self).__init__()

                                                    self.yang_name = "fe-line"
                                                    self.yang_parent_name = "stm-minute15stm-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("far-end-line-e-ss", ("far_end_line_e_ss", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.FeLine.FarEndLineESs)), ("far-end-line-es-rs", ("far_end_line_es_rs", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.FeLine.FarEndLineEsRs)), ("far-end-line-ebb-es", ("far_end_line_ebb_es", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.FeLine.FarEndLineEbbEs)), ("far-end-line-bbe-rs", ("far_end_line_bbe_rs", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.FeLine.FarEndLineBbeRs)), ("far-end-line-se-ss", ("far_end_line_se_ss", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.FeLine.FarEndLineSeSs)), ("far-end-line-ses-rs", ("far_end_line_ses_rs", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.FeLine.FarEndLineSesRs)), ("far-end-line-ua-ss", ("far_end_line_ua_ss", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.FeLine.FarEndLineUaSs)), ("far-end-line-e-bs", ("far_end_line_e_bs", PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.FeLine.FarEndLineEBs))])
                                                    self._leafs = OrderedDict()

                                                    self.far_end_line_e_ss = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.FeLine.FarEndLineESs()
                                                    self.far_end_line_e_ss.parent = self
                                                    self._children_name_map["far_end_line_e_ss"] = "far-end-line-e-ss"

                                                    self.far_end_line_es_rs = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.FeLine.FarEndLineEsRs()
                                                    self.far_end_line_es_rs.parent = self
                                                    self._children_name_map["far_end_line_es_rs"] = "far-end-line-es-rs"

                                                    self.far_end_line_ebb_es = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.FeLine.FarEndLineEbbEs()
                                                    self.far_end_line_ebb_es.parent = self
                                                    self._children_name_map["far_end_line_ebb_es"] = "far-end-line-ebb-es"

                                                    self.far_end_line_bbe_rs = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.FeLine.FarEndLineBbeRs()
                                                    self.far_end_line_bbe_rs.parent = self
                                                    self._children_name_map["far_end_line_bbe_rs"] = "far-end-line-bbe-rs"

                                                    self.far_end_line_se_ss = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.FeLine.FarEndLineSeSs()
                                                    self.far_end_line_se_ss.parent = self
                                                    self._children_name_map["far_end_line_se_ss"] = "far-end-line-se-ss"

                                                    self.far_end_line_ses_rs = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.FeLine.FarEndLineSesRs()
                                                    self.far_end_line_ses_rs.parent = self
                                                    self._children_name_map["far_end_line_ses_rs"] = "far-end-line-ses-rs"

                                                    self.far_end_line_ua_ss = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.FeLine.FarEndLineUaSs()
                                                    self.far_end_line_ua_ss.parent = self
                                                    self._children_name_map["far_end_line_ua_ss"] = "far-end-line-ua-ss"

                                                    self.far_end_line_e_bs = PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.FeLine.FarEndLineEBs()
                                                    self.far_end_line_e_bs.parent = self
                                                    self._children_name_map["far_end_line_e_bs"] = "far-end-line-e-bs"
                                                    self._segment_path = lambda: "fe-line"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.FeLine, [], name, value)


                                                class FarEndLineESs(Entity):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.FeLine.FarEndLineESs, self).__init__()

                                                        self.yang_name = "far-end-line-e-ss"
                                                        self.yang_parent_name = "fe-line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "far-end-line-e-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.FeLine.FarEndLineESs, ['data', 'threshold', 'tca_report'], name, value)


                                                class FarEndLineEsRs(Entity):
                                                    """
                                                    The number of Errored Seconds Ratio
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.FeLine.FarEndLineEsRs, self).__init__()

                                                        self.yang_name = "far-end-line-es-rs"
                                                        self.yang_parent_name = "fe-line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "far-end-line-es-rs"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.FeLine.FarEndLineEsRs, ['data', 'threshold', 'tca_report'], name, value)


                                                class FarEndLineEbbEs(Entity):
                                                    """
                                                    The number of Background Block Errors
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.FeLine.FarEndLineEbbEs, self).__init__()

                                                        self.yang_name = "far-end-line-ebb-es"
                                                        self.yang_parent_name = "fe-line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "far-end-line-ebb-es"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.FeLine.FarEndLineEbbEs, ['data', 'threshold', 'tca_report'], name, value)


                                                class FarEndLineBbeRs(Entity):
                                                    """
                                                    The number of Background Block Errors
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.FeLine.FarEndLineBbeRs, self).__init__()

                                                        self.yang_name = "far-end-line-bbe-rs"
                                                        self.yang_parent_name = "fe-line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "far-end-line-bbe-rs"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.FeLine.FarEndLineBbeRs, ['data', 'threshold', 'tca_report'], name, value)


                                                class FarEndLineSeSs(Entity):
                                                    """
                                                    The number of Severely Errored Second
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.FeLine.FarEndLineSeSs, self).__init__()

                                                        self.yang_name = "far-end-line-se-ss"
                                                        self.yang_parent_name = "fe-line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "far-end-line-se-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.FeLine.FarEndLineSeSs, ['data', 'threshold', 'tca_report'], name, value)


                                                class FarEndLineSesRs(Entity):
                                                    """
                                                    The number of Severely Errored Second Ratio
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.FeLine.FarEndLineSesRs, self).__init__()

                                                        self.yang_name = "far-end-line-ses-rs"
                                                        self.yang_parent_name = "fe-line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "far-end-line-ses-rs"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.FeLine.FarEndLineSesRs, ['data', 'threshold', 'tca_report'], name, value)


                                                class FarEndLineUaSs(Entity):
                                                    """
                                                    The number of Unavailable Second
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.FeLine.FarEndLineUaSs, self).__init__()

                                                        self.yang_name = "far-end-line-ua-ss"
                                                        self.yang_parent_name = "fe-line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "far-end-line-ua-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.FeLine.FarEndLineUaSs, ['data', 'threshold', 'tca_report'], name, value)


                                                class FarEndLineEBs(Entity):
                                                    """
                                                    The number of Errored Block Second
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.FeLine.FarEndLineEBs, self).__init__()

                                                        self.yang_name = "far-end-line-e-bs"
                                                        self.yang_parent_name = "fe-line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "far-end-line-e-bs"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15stmHistories.StmMinute15stmHistory.StmMinute15stmTimeLineInstances.StmMinute15stmTimeLineInstance.FeLine.FarEndLineEBs, ['data', 'threshold', 'tca_report'], name, value)


            class MacsecHistory(Entity):
                """
                MACSEC controller History performance data
                
                .. attribute:: macsec_port_histories
                
                	Port performance data
                	**type**\:  :py:class:`MacsecPortHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory, self).__init__()

                    self.yang_name = "macsec-history"
                    self.yang_parent_name = "periodic"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("macsec-port-histories", ("macsec_port_histories", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories))])
                    self._leafs = OrderedDict()

                    self.macsec_port_histories = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories()
                    self.macsec_port_histories.parent = self
                    self._children_name_map["macsec_port_histories"] = "macsec-port-histories"
                    self._segment_path = lambda: "macsec-history"
                    self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory, [], name, value)


                class MacsecPortHistories(Entity):
                    """
                    Port performance data
                    
                    .. attribute:: macsec_port_history
                    
                    	Port performance data
                    	**type**\: list of  		 :py:class:`MacsecPortHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories, self).__init__()

                        self.yang_name = "macsec-port-histories"
                        self.yang_parent_name = "macsec-history"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("macsec-port-history", ("macsec_port_history", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory))])
                        self._leafs = OrderedDict()

                        self.macsec_port_history = YList(self)
                        self._segment_path = lambda: "macsec-port-histories"
                        self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/macsec-history/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories, [], name, value)


                    class MacsecPortHistory(Entity):
                        """
                        Port performance data
                        
                        .. attribute:: name  (key)
                        
                        	Port name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: macsec_minute15_history
                        
                        	port current performance data
                        	**type**\:  :py:class:`MacsecMinute15History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History>`
                        
                        .. attribute:: macsec_hour24_history
                        
                        	port current performance data
                        	**type**\:  :py:class:`MacsecHour24History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History>`
                        
                        .. attribute:: macsec_second30_history
                        
                        	port current performance data
                        	**type**\:  :py:class:`MacsecSecond30History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory, self).__init__()

                            self.yang_name = "macsec-port-history"
                            self.yang_parent_name = "macsec-port-histories"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("macsec-minute15-history", ("macsec_minute15_history", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History)), ("macsec-hour24-history", ("macsec_hour24_history", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History)), ("macsec-second30-history", ("macsec_second30_history", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None

                            self.macsec_minute15_history = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History()
                            self.macsec_minute15_history.parent = self
                            self._children_name_map["macsec_minute15_history"] = "macsec-minute15-history"

                            self.macsec_hour24_history = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History()
                            self.macsec_hour24_history.parent = self
                            self._children_name_map["macsec_hour24_history"] = "macsec-hour24-history"

                            self.macsec_second30_history = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History()
                            self.macsec_second30_history.parent = self
                            self._children_name_map["macsec_second30_history"] = "macsec-second30-history"
                            self._segment_path = lambda: "macsec-port-history" + "[name='" + str(self.name) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/macsec-history/macsec-port-histories/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory, ['name'], name, value)


                        class MacsecMinute15History(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: macsec_minute15secyrx_histories
                            
                            	port current performance data
                            	**type**\:  :py:class:`MacsecMinute15secyrxHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories>`
                            
                            .. attribute:: macsec_minute15_ether_histories
                            
                            	port current performance data
                            	**type**\:  :py:class:`MacsecMinute15EtherHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories>`
                            
                            .. attribute:: macsec_minute15secytx_histories
                            
                            	port current performance data
                            	**type**\:  :py:class:`MacsecMinute15secytxHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secytxHistories>`
                            
                            .. attribute:: macsec_minute15secyif_histories
                            
                            	port current performance data
                            	**type**\:  :py:class:`MacsecMinute15secyifHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History, self).__init__()

                                self.yang_name = "macsec-minute15-history"
                                self.yang_parent_name = "macsec-port-history"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("macsec-minute15secyrx-histories", ("macsec_minute15secyrx_histories", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories)), ("macsec-minute15-ether-histories", ("macsec_minute15_ether_histories", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories)), ("macsec-minute15secytx-histories", ("macsec_minute15secytx_histories", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secytxHistories)), ("macsec-minute15secyif-histories", ("macsec_minute15secyif_histories", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories))])
                                self._leafs = OrderedDict()

                                self.macsec_minute15secyrx_histories = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories()
                                self.macsec_minute15secyrx_histories.parent = self
                                self._children_name_map["macsec_minute15secyrx_histories"] = "macsec-minute15secyrx-histories"

                                self.macsec_minute15_ether_histories = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories()
                                self.macsec_minute15_ether_histories.parent = self
                                self._children_name_map["macsec_minute15_ether_histories"] = "macsec-minute15-ether-histories"

                                self.macsec_minute15secytx_histories = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secytxHistories()
                                self.macsec_minute15secytx_histories.parent = self
                                self._children_name_map["macsec_minute15secytx_histories"] = "macsec-minute15secytx-histories"

                                self.macsec_minute15secyif_histories = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories()
                                self.macsec_minute15secyif_histories.parent = self
                                self._children_name_map["macsec_minute15secyif_histories"] = "macsec-minute15secyif-histories"
                                self._segment_path = lambda: "macsec-minute15-history"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History, [], name, value)


                            class MacsecMinute15secyrxHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: macsec_minute15secyrx_history
                                
                                	port 15\-minute secy\_rx performance data
                                	**type**\: list of  		 :py:class:`MacsecMinute15secyrxHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories, self).__init__()

                                    self.yang_name = "macsec-minute15secyrx-histories"
                                    self.yang_parent_name = "macsec-minute15-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("macsec-minute15secyrx-history", ("macsec_minute15secyrx_history", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory))])
                                    self._leafs = OrderedDict()

                                    self.macsec_minute15secyrx_history = YList(self)
                                    self._segment_path = lambda: "macsec-minute15secyrx-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories, [], name, value)


                                class MacsecMinute15secyrxHistory(Entity):
                                    """
                                    port 15\-minute secy\_rx performance data
                                    
                                    .. attribute:: number  (key)
                                    
                                    	channel number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: macsec_minute15secyrx_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`MacsecMinute15secyrxTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory, self).__init__()

                                        self.yang_name = "macsec-minute15secyrx-history"
                                        self.yang_parent_name = "macsec-minute15secyrx-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([("macsec-minute15secyrx-time-line-instances", ("macsec_minute15secyrx_time_line_instances", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ])
                                        self.number = None

                                        self.macsec_minute15secyrx_time_line_instances = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances()
                                        self.macsec_minute15secyrx_time_line_instances.parent = self
                                        self._children_name_map["macsec_minute15secyrx_time_line_instances"] = "macsec-minute15secyrx-time-line-instances"
                                        self._segment_path = lambda: "macsec-minute15secyrx-history" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory, ['number'], name, value)


                                    class MacsecMinute15secyrxTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: macsec_minute15secyrx_time_line_instance
                                        
                                        	port 15\-minute secy\_rx performance data by index
                                        	**type**\: list of  		 :py:class:`MacsecMinute15secyrxTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances, self).__init__()

                                            self.yang_name = "macsec-minute15secyrx-time-line-instances"
                                            self.yang_parent_name = "macsec-minute15secyrx-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("macsec-minute15secyrx-time-line-instance", ("macsec_minute15secyrx_time_line_instance", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.macsec_minute15secyrx_time_line_instance = YList(self)
                                            self._segment_path = lambda: "macsec-minute15secyrx-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances, [], name, value)


                                        class MacsecMinute15secyrxTimeLineInstance(Entity):
                                            """
                                            port 15\-minute secy\_rx performance data
                                            by index
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: in_pkts_unchecked
                                            
                                            	In Packet Unchecked
                                            	**type**\:  :py:class:`InPktsUnchecked <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance.InPktsUnchecked>`
                                            
                                            .. attribute:: in_pkts_delayed
                                            
                                            	In Packet Delay
                                            	**type**\:  :py:class:`InPktsDelayed <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance.InPktsDelayed>`
                                            
                                            .. attribute:: in_pkts_late
                                            
                                            	In Packet Late
                                            	**type**\:  :py:class:`InPktsLate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance.InPktsLate>`
                                            
                                            .. attribute:: in_pkts_ok
                                            
                                            	In Packet Ok
                                            	**type**\:  :py:class:`InPktsOk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance.InPktsOk>`
                                            
                                            .. attribute:: in_pkts_invalid
                                            
                                            	In Packet Invalid
                                            	**type**\:  :py:class:`InPktsInvalid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance.InPktsInvalid>`
                                            
                                            .. attribute:: in_pkts_not_valid
                                            
                                            	In Packet Not Valid
                                            	**type**\:  :py:class:`InPktsNotValid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance.InPktsNotValid>`
                                            
                                            .. attribute:: in_pkts_not_using_sa
                                            
                                            	In Packet Not Using SA
                                            	**type**\:  :py:class:`InPktsNotUsingSa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance.InPktsNotUsingSa>`
                                            
                                            .. attribute:: in_pkts_unused_sa
                                            
                                            	In Packet Unused SA
                                            	**type**\:  :py:class:`InPktsUnusedSa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance.InPktsUnusedSa>`
                                            
                                            .. attribute:: in_pkts_untagged_hit
                                            
                                            	In Packet Untagged Hit
                                            	**type**\:  :py:class:`InPktsUntaggedHit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance.InPktsUntaggedHit>`
                                            
                                            .. attribute:: in_octets_validated
                                            
                                            	In Octet Validated
                                            	**type**\:  :py:class:`InOctetsValidated <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance.InOctetsValidated>`
                                            
                                            .. attribute:: in_octets_decrypted
                                            
                                            	In Octet Decrypted
                                            	**type**\:  :py:class:`InOctetsDecrypted <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance.InOctetsDecrypted>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\: bool
                                            
                                            .. attribute:: sample_count
                                            
                                            	Running Sample Count
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance, self).__init__()

                                                self.yang_name = "macsec-minute15secyrx-time-line-instance"
                                                self.yang_parent_name = "macsec-minute15secyrx-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("in-pkts-unchecked", ("in_pkts_unchecked", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance.InPktsUnchecked)), ("in-pkts-delayed", ("in_pkts_delayed", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance.InPktsDelayed)), ("in-pkts-late", ("in_pkts_late", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance.InPktsLate)), ("in-pkts-ok", ("in_pkts_ok", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance.InPktsOk)), ("in-pkts-invalid", ("in_pkts_invalid", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance.InPktsInvalid)), ("in-pkts-not-valid", ("in_pkts_not_valid", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance.InPktsNotValid)), ("in-pkts-not-using-sa", ("in_pkts_not_using_sa", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance.InPktsNotUsingSa)), ("in-pkts-unused-sa", ("in_pkts_unused_sa", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance.InPktsUnusedSa)), ("in-pkts-untagged-hit", ("in_pkts_untagged_hit", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance.InPktsUntaggedHit)), ("in-octets-validated", ("in_octets_validated", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance.InOctetsValidated)), ("in-octets-decrypted", ("in_octets_decrypted", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance.InOctetsDecrypted))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                    ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                                    ('sample_count', (YLeaf(YType.uint64, 'sample-count'), ['int'])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear24_hr_time = None
                                                self.sec30_support = None
                                                self.sample_count = None

                                                self.in_pkts_unchecked = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance.InPktsUnchecked()
                                                self.in_pkts_unchecked.parent = self
                                                self._children_name_map["in_pkts_unchecked"] = "in-pkts-unchecked"

                                                self.in_pkts_delayed = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance.InPktsDelayed()
                                                self.in_pkts_delayed.parent = self
                                                self._children_name_map["in_pkts_delayed"] = "in-pkts-delayed"

                                                self.in_pkts_late = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance.InPktsLate()
                                                self.in_pkts_late.parent = self
                                                self._children_name_map["in_pkts_late"] = "in-pkts-late"

                                                self.in_pkts_ok = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance.InPktsOk()
                                                self.in_pkts_ok.parent = self
                                                self._children_name_map["in_pkts_ok"] = "in-pkts-ok"

                                                self.in_pkts_invalid = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance.InPktsInvalid()
                                                self.in_pkts_invalid.parent = self
                                                self._children_name_map["in_pkts_invalid"] = "in-pkts-invalid"

                                                self.in_pkts_not_valid = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance.InPktsNotValid()
                                                self.in_pkts_not_valid.parent = self
                                                self._children_name_map["in_pkts_not_valid"] = "in-pkts-not-valid"

                                                self.in_pkts_not_using_sa = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance.InPktsNotUsingSa()
                                                self.in_pkts_not_using_sa.parent = self
                                                self._children_name_map["in_pkts_not_using_sa"] = "in-pkts-not-using-sa"

                                                self.in_pkts_unused_sa = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance.InPktsUnusedSa()
                                                self.in_pkts_unused_sa.parent = self
                                                self._children_name_map["in_pkts_unused_sa"] = "in-pkts-unused-sa"

                                                self.in_pkts_untagged_hit = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance.InPktsUntaggedHit()
                                                self.in_pkts_untagged_hit.parent = self
                                                self._children_name_map["in_pkts_untagged_hit"] = "in-pkts-untagged-hit"

                                                self.in_octets_validated = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance.InOctetsValidated()
                                                self.in_octets_validated.parent = self
                                                self._children_name_map["in_octets_validated"] = "in-octets-validated"

                                                self.in_octets_decrypted = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance.InOctetsDecrypted()
                                                self.in_octets_decrypted.parent = self
                                                self._children_name_map["in_octets_decrypted"] = "in-octets-decrypted"
                                                self._segment_path = lambda: "macsec-minute15secyrx-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support', 'sample_count'], name, value)


                                            class InPktsUnchecked(Entity):
                                                """
                                                In Packet Unchecked
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance.InPktsUnchecked, self).__init__()

                                                    self.yang_name = "in-pkts-unchecked"
                                                    self.yang_parent_name = "macsec-minute15secyrx-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts-unchecked"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance.InPktsUnchecked, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPktsDelayed(Entity):
                                                """
                                                In Packet Delay
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance.InPktsDelayed, self).__init__()

                                                    self.yang_name = "in-pkts-delayed"
                                                    self.yang_parent_name = "macsec-minute15secyrx-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts-delayed"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance.InPktsDelayed, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPktsLate(Entity):
                                                """
                                                In Packet Late
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance.InPktsLate, self).__init__()

                                                    self.yang_name = "in-pkts-late"
                                                    self.yang_parent_name = "macsec-minute15secyrx-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts-late"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance.InPktsLate, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPktsOk(Entity):
                                                """
                                                In Packet Ok
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance.InPktsOk, self).__init__()

                                                    self.yang_name = "in-pkts-ok"
                                                    self.yang_parent_name = "macsec-minute15secyrx-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts-ok"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance.InPktsOk, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPktsInvalid(Entity):
                                                """
                                                In Packet Invalid
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance.InPktsInvalid, self).__init__()

                                                    self.yang_name = "in-pkts-invalid"
                                                    self.yang_parent_name = "macsec-minute15secyrx-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts-invalid"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance.InPktsInvalid, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPktsNotValid(Entity):
                                                """
                                                In Packet Not Valid
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance.InPktsNotValid, self).__init__()

                                                    self.yang_name = "in-pkts-not-valid"
                                                    self.yang_parent_name = "macsec-minute15secyrx-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts-not-valid"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance.InPktsNotValid, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPktsNotUsingSa(Entity):
                                                """
                                                In Packet Not Using SA
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance.InPktsNotUsingSa, self).__init__()

                                                    self.yang_name = "in-pkts-not-using-sa"
                                                    self.yang_parent_name = "macsec-minute15secyrx-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts-not-using-sa"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance.InPktsNotUsingSa, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPktsUnusedSa(Entity):
                                                """
                                                In Packet Unused SA
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance.InPktsUnusedSa, self).__init__()

                                                    self.yang_name = "in-pkts-unused-sa"
                                                    self.yang_parent_name = "macsec-minute15secyrx-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts-unused-sa"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance.InPktsUnusedSa, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPktsUntaggedHit(Entity):
                                                """
                                                In Packet Untagged Hit
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance.InPktsUntaggedHit, self).__init__()

                                                    self.yang_name = "in-pkts-untagged-hit"
                                                    self.yang_parent_name = "macsec-minute15secyrx-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts-untagged-hit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance.InPktsUntaggedHit, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InOctetsValidated(Entity):
                                                """
                                                In Octet Validated
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance.InOctetsValidated, self).__init__()

                                                    self.yang_name = "in-octets-validated"
                                                    self.yang_parent_name = "macsec-minute15secyrx-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-octets-validated"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance.InOctetsValidated, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InOctetsDecrypted(Entity):
                                                """
                                                In Octet Decrypted
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance.InOctetsDecrypted, self).__init__()

                                                    self.yang_name = "in-octets-decrypted"
                                                    self.yang_parent_name = "macsec-minute15secyrx-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-octets-decrypted"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyrxHistories.MacsecMinute15secyrxHistory.MacsecMinute15secyrxTimeLineInstances.MacsecMinute15secyrxTimeLineInstance.InOctetsDecrypted, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                            class MacsecMinute15EtherHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: macsec_minute15_ether_history
                                
                                	port 15\-minute ether performance data
                                	**type**\: list of  		 :py:class:`MacsecMinute15EtherHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories, self).__init__()

                                    self.yang_name = "macsec-minute15-ether-histories"
                                    self.yang_parent_name = "macsec-minute15-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("macsec-minute15-ether-history", ("macsec_minute15_ether_history", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory))])
                                    self._leafs = OrderedDict()

                                    self.macsec_minute15_ether_history = YList(self)
                                    self._segment_path = lambda: "macsec-minute15-ether-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories, [], name, value)


                                class MacsecMinute15EtherHistory(Entity):
                                    """
                                    port 15\-minute ether performance data
                                    
                                    .. attribute:: number  (key)
                                    
                                    	channel number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: macsec_minute15_ether_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`MacsecMinute15EtherTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory, self).__init__()

                                        self.yang_name = "macsec-minute15-ether-history"
                                        self.yang_parent_name = "macsec-minute15-ether-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([("macsec-minute15-ether-time-line-instances", ("macsec_minute15_ether_time_line_instances", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ])
                                        self.number = None

                                        self.macsec_minute15_ether_time_line_instances = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances()
                                        self.macsec_minute15_ether_time_line_instances.parent = self
                                        self._children_name_map["macsec_minute15_ether_time_line_instances"] = "macsec-minute15-ether-time-line-instances"
                                        self._segment_path = lambda: "macsec-minute15-ether-history" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory, ['number'], name, value)


                                    class MacsecMinute15EtherTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: macsec_minute15_ether_time_line_instance
                                        
                                        	port 15\-minute ether performance data by index
                                        	**type**\: list of  		 :py:class:`MacsecMinute15EtherTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances, self).__init__()

                                            self.yang_name = "macsec-minute15-ether-time-line-instances"
                                            self.yang_parent_name = "macsec-minute15-ether-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("macsec-minute15-ether-time-line-instance", ("macsec_minute15_ether_time_line_instance", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.macsec_minute15_ether_time_line_instance = YList(self)
                                            self._segment_path = lambda: "macsec-minute15-ether-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances, [], name, value)


                                        class MacsecMinute15EtherTimeLineInstance(Entity):
                                            """
                                            port 15\-minute ether performance data
                                            by index
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rx_pkt
                                            
                                            	RX PKT
                                            	**type**\:  :py:class:`RxPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.RxPkt>`
                                            
                                            .. attribute:: stat_pkt
                                            
                                            	STAT PKT
                                            	**type**\:  :py:class:`StatPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.StatPkt>`
                                            
                                            .. attribute:: octet_stat
                                            
                                            	OCTET STAT
                                            	**type**\:  :py:class:`OctetStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OctetStat>`
                                            
                                            .. attribute:: oversize_pkt_stat
                                            
                                            	OVERSIZE PKT
                                            	**type**\:  :py:class:`OversizePktStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OversizePktStat>`
                                            
                                            .. attribute:: fcs_errors_stat
                                            
                                            	FCS ERR
                                            	**type**\:  :py:class:`FcsErrorsStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.FcsErrorsStat>`
                                            
                                            .. attribute:: long_frames_stat
                                            
                                            	LONG FRAMES
                                            	**type**\:  :py:class:`LongFramesStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.LongFramesStat>`
                                            
                                            .. attribute:: jabber_stat
                                            
                                            	JABBER STATS
                                            	**type**\:  :py:class:`JabberStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.JabberStat>`
                                            
                                            .. attribute:: ether64_octets
                                            
                                            	SIXTY FOUR OCTET
                                            	**type**\:  :py:class:`Ether64Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.Ether64Octets>`
                                            
                                            .. attribute:: ether65127_octet
                                            
                                            	OCTET
                                            	**type**\:  :py:class:`Ether65127Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.Ether65127Octet>`
                                            
                                            .. attribute:: ether128255_octet
                                            
                                            	TFF OCTET
                                            	**type**\:  :py:class:`Ether128255Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.Ether128255Octet>`
                                            
                                            .. attribute:: ether256511_octet
                                            
                                            	FOO OCTET
                                            	**type**\:  :py:class:`Ether256511Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.Ether256511Octet>`
                                            
                                            .. attribute:: ether5121023_octet
                                            
                                            	OZTT OCTET
                                            	**type**\:  :py:class:`Ether5121023Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.Ether5121023Octet>`
                                            
                                            .. attribute:: ether10241518_octet
                                            
                                            	OFO OCTET
                                            	**type**\:  :py:class:`Ether10241518Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.Ether10241518Octet>`
                                            
                                            .. attribute:: in_ucast_pkt
                                            
                                            	IN UCAST
                                            	**type**\:  :py:class:`InUcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InUcastPkt>`
                                            
                                            .. attribute:: in_mcast_pkt
                                            
                                            	IN MCAST
                                            	**type**\:  :py:class:`InMcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InMcastPkt>`
                                            
                                            .. attribute:: in_bcast_pkt
                                            
                                            	IN BCAST
                                            	**type**\:  :py:class:`InBcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InBcastPkt>`
                                            
                                            .. attribute:: out_ucast_pkt
                                            
                                            	OUT UCAST
                                            	**type**\:  :py:class:`OutUcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutUcastPkt>`
                                            
                                            .. attribute:: out_bcast_pkt
                                            
                                            	OUT BCAST
                                            	**type**\:  :py:class:`OutBcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutBcastPkt>`
                                            
                                            .. attribute:: out_mcast_pkt
                                            
                                            	OUT MCAST
                                            	**type**\:  :py:class:`OutMcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutMcastPkt>`
                                            
                                            .. attribute:: tx_pkt
                                            
                                            	TX PKT
                                            	**type**\:  :py:class:`TxPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.TxPkt>`
                                            
                                            .. attribute:: if_in_errors
                                            
                                            	IFIN ERRORS
                                            	**type**\:  :py:class:`IfInErrors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.IfInErrors>`
                                            
                                            .. attribute:: if_in_octets
                                            
                                            	IFIN OCTETS
                                            	**type**\:  :py:class:`IfInOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.IfInOctets>`
                                            
                                            .. attribute:: ether_stat_multicast_pkt
                                            
                                            	ETHER STAT MULTICAST PKT
                                            	**type**\:  :py:class:`EtherStatMulticastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.EtherStatMulticastPkt>`
                                            
                                            .. attribute:: ether_stat_broadcast_pkt
                                            
                                            	ETHER STAT BROADCAST PKT
                                            	**type**\:  :py:class:`EtherStatBroadcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.EtherStatBroadcastPkt>`
                                            
                                            .. attribute:: ether_stat_undersized_pkt
                                            
                                            	ETHER STAT UNDERSIZED PKT
                                            	**type**\:  :py:class:`EtherStatUndersizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.EtherStatUndersizedPkt>`
                                            
                                            .. attribute:: out_octets
                                            
                                            	OUT OCTET
                                            	**type**\:  :py:class:`OutOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutOctets>`
                                            
                                            .. attribute:: in_pause_frame
                                            
                                            	INPUT PAUSE FRAME
                                            	**type**\:  :py:class:`InPauseFrame <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InPauseFrame>`
                                            
                                            .. attribute:: in_good_bytes
                                            
                                            	INPUT GOOD BYTES
                                            	**type**\:  :py:class:`InGoodBytes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InGoodBytes>`
                                            
                                            .. attribute:: in8021q_frames
                                            
                                            	INPUT 802 1Q FRAMES
                                            	**type**\:  :py:class:`In8021qFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.In8021qFrames>`
                                            
                                            .. attribute:: in_pkts1519_max_octets
                                            
                                            	INPUT PKTS 1519MAX OCTETS
                                            	**type**\:  :py:class:`InPkts1519MaxOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InPkts1519MaxOctets>`
                                            
                                            .. attribute:: in_good_pkts
                                            
                                            	INPUT GOOD PKTS
                                            	**type**\:  :py:class:`InGoodPkts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InGoodPkts>`
                                            
                                            .. attribute:: in_drop_overrun
                                            
                                            	INPUT DROP OVERRUN
                                            	**type**\:  :py:class:`InDropOverrun <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InDropOverrun>`
                                            
                                            .. attribute:: in_drop_abort
                                            
                                            	INPUT DROP ABORT
                                            	**type**\:  :py:class:`InDropAbort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InDropAbort>`
                                            
                                            .. attribute:: in_drop_invalid_vlan
                                            
                                            	INPUT DROP INVALID VLAN
                                            	**type**\:  :py:class:`InDropInvalidVlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InDropInvalidVlan>`
                                            
                                            .. attribute:: in_drop_invalid_dmac
                                            
                                            	INPUT DROP INVALID DMAC
                                            	**type**\:  :py:class:`InDropInvalidDmac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InDropInvalidDmac>`
                                            
                                            .. attribute:: in_drop_invalid_encap
                                            
                                            	INPUT DROP INVALID ENCAP
                                            	**type**\:  :py:class:`InDropInvalidEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InDropInvalidEncap>`
                                            
                                            .. attribute:: in_drop_other
                                            
                                            	INPUT DROP OTHER
                                            	**type**\:  :py:class:`InDropOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InDropOther>`
                                            
                                            .. attribute:: in_mib_giant
                                            
                                            	INPUT MIB GIANT
                                            	**type**\:  :py:class:`InMibGiant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InMibGiant>`
                                            
                                            .. attribute:: in_mib_jabber
                                            
                                            	INPUT MIB JABBER
                                            	**type**\:  :py:class:`InMibJabber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InMibJabber>`
                                            
                                            .. attribute:: in_mibcrc
                                            
                                            	IN MIB CRC
                                            	**type**\:  :py:class:`InMibcrc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InMibcrc>`
                                            
                                            .. attribute:: in_error_collisions
                                            
                                            	IN ERROR COLLISIONS
                                            	**type**\:  :py:class:`InErrorCollisions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InErrorCollisions>`
                                            
                                            .. attribute:: in_error_symbol
                                            
                                            	IN ERROR SYMBOL
                                            	**type**\:  :py:class:`InErrorSymbol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InErrorSymbol>`
                                            
                                            .. attribute:: out_good_bytes
                                            
                                            	OUT GOOD BYTES
                                            	**type**\:  :py:class:`OutGoodBytes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutGoodBytes>`
                                            
                                            .. attribute:: out8021q_frames
                                            
                                            	OUT 802 1Q FRAMES
                                            	**type**\:  :py:class:`Out8021qFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.Out8021qFrames>`
                                            
                                            .. attribute:: out_pause_frames
                                            
                                            	OUT PAUSE FRAMES
                                            	**type**\:  :py:class:`OutPauseFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutPauseFrames>`
                                            
                                            .. attribute:: out_pkts1519_max_octets
                                            
                                            	OUT PKTS 1519 MAX OCTETS
                                            	**type**\:  :py:class:`OutPkts1519MaxOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutPkts1519MaxOctets>`
                                            
                                            .. attribute:: out_good_pkts
                                            
                                            	OUT GOOD PKTS
                                            	**type**\:  :py:class:`OutGoodPkts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutGoodPkts>`
                                            
                                            .. attribute:: out_drop_underrun
                                            
                                            	OUT DROP UNDERRUN
                                            	**type**\:  :py:class:`OutDropUnderrun <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutDropUnderrun>`
                                            
                                            .. attribute:: out_drop_abort
                                            
                                            	OUT DROP ABORT
                                            	**type**\:  :py:class:`OutDropAbort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutDropAbort>`
                                            
                                            .. attribute:: out_drop_other
                                            
                                            	OUT DROP OTHER
                                            	**type**\:  :py:class:`OutDropOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutDropOther>`
                                            
                                            .. attribute:: out_error_other
                                            
                                            	OUT ERROR OTHER
                                            	**type**\:  :py:class:`OutErrorOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutErrorOther>`
                                            
                                            .. attribute:: in_error_giant
                                            
                                            	IN ERROR GIANT
                                            	**type**\:  :py:class:`InErrorGiant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InErrorGiant>`
                                            
                                            .. attribute:: in_error_runt
                                            
                                            	IN ERROR RUNT
                                            	**type**\:  :py:class:`InErrorRunt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InErrorRunt>`
                                            
                                            .. attribute:: in_error_jabbers
                                            
                                            	IN ERROR JABBERS
                                            	**type**\:  :py:class:`InErrorJabbers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InErrorJabbers>`
                                            
                                            .. attribute:: in_error_fragments
                                            
                                            	IN ERROR FRAGMENTS
                                            	**type**\:  :py:class:`InErrorFragments <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InErrorFragments>`
                                            
                                            .. attribute:: in_error_other
                                            
                                            	IN ERROR OTHER
                                            	**type**\:  :py:class:`InErrorOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InErrorOther>`
                                            
                                            .. attribute:: in_pkt64_octet
                                            
                                            	IN PKT 64 OCTET
                                            	**type**\:  :py:class:`InPkt64Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InPkt64Octet>`
                                            
                                            .. attribute:: in_pkts65_to127_octets
                                            
                                            	IN PKTS 65 127OCTETS
                                            	**type**\:  :py:class:`InPkts65To127Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InPkts65To127Octets>`
                                            
                                            .. attribute:: in_pkts128_to255_octets
                                            
                                            	IN PKTS 128 255 OCTETS
                                            	**type**\:  :py:class:`InPkts128To255Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InPkts128To255Octets>`
                                            
                                            .. attribute:: in_pkts256_to511_octets
                                            
                                            	IN PKTS 256 511 OCTETS
                                            	**type**\:  :py:class:`InPkts256To511Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InPkts256To511Octets>`
                                            
                                            .. attribute:: in_pkts512_to1023_octets
                                            
                                            	IN PKTS 512 1023 OCTETS
                                            	**type**\:  :py:class:`InPkts512To1023Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InPkts512To1023Octets>`
                                            
                                            .. attribute:: in_pkts1024_to1518_octets
                                            
                                            	IN PKTS 1024 1518 OCTETS
                                            	**type**\:  :py:class:`InPkts1024To1518Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InPkts1024To1518Octets>`
                                            
                                            .. attribute:: outpkt64octet
                                            
                                            	OUT PKT 64 OCTET
                                            	**type**\:  :py:class:`Outpkt64octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.Outpkt64octet>`
                                            
                                            .. attribute:: out_pkts65127_octets
                                            
                                            	OUT PKTS 65 127OCTETS
                                            	**type**\:  :py:class:`OutPkts65127Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutPkts65127Octets>`
                                            
                                            .. attribute:: out_pkts128255_octets
                                            
                                            	OUT PKTS 128 255 OCTETS
                                            	**type**\:  :py:class:`OutPkts128255Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutPkts128255Octets>`
                                            
                                            .. attribute:: out_pkts256511_octets
                                            
                                            	OUT PKTS 256 511 OCTETS
                                            	**type**\:  :py:class:`OutPkts256511Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutPkts256511Octets>`
                                            
                                            .. attribute:: out_pkts5121023_octets
                                            
                                            	OUT PKTS 512 1023 OCTETS
                                            	**type**\:  :py:class:`OutPkts5121023Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutPkts5121023Octets>`
                                            
                                            .. attribute:: out_pkts10241518_octets
                                            
                                            	OUT PKTS 1024 1518 OCTETS
                                            	**type**\:  :py:class:`OutPkts10241518Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutPkts10241518Octets>`
                                            
                                            .. attribute:: rx_util
                                            
                                            	Rx Utilization in Percent
                                            	**type**\:  :py:class:`RxUtil <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.RxUtil>`
                                            
                                            .. attribute:: tx_util
                                            
                                            	Tx Utilization in Percent
                                            	**type**\:  :py:class:`TxUtil <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.TxUtil>`
                                            
                                            .. attribute:: tx_undersized_pkt
                                            
                                            	TX Undersized Pkt
                                            	**type**\:  :py:class:`TxUndersizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.TxUndersizedPkt>`
                                            
                                            .. attribute:: tx_oversized_pkt
                                            
                                            	TX Oversized Pkt
                                            	**type**\:  :py:class:`TxOversizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.TxOversizedPkt>`
                                            
                                            .. attribute:: tx_fragments
                                            
                                            	TX Fragments
                                            	**type**\:  :py:class:`TxFragments <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.TxFragments>`
                                            
                                            .. attribute:: tx_jabber
                                            
                                            	TX Jabber
                                            	**type**\:  :py:class:`TxJabber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.TxJabber>`
                                            
                                            .. attribute:: tx_bad_fcs
                                            
                                            	TX Bad Fcs
                                            	**type**\:  :py:class:`TxBadFcs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.TxBadFcs>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance, self).__init__()

                                                self.yang_name = "macsec-minute15-ether-time-line-instance"
                                                self.yang_parent_name = "macsec-minute15-ether-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("rx-pkt", ("rx_pkt", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.RxPkt)), ("stat-pkt", ("stat_pkt", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.StatPkt)), ("octet-stat", ("octet_stat", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OctetStat)), ("oversize-pkt-stat", ("oversize_pkt_stat", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OversizePktStat)), ("fcs-errors-stat", ("fcs_errors_stat", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.FcsErrorsStat)), ("long-frames-stat", ("long_frames_stat", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.LongFramesStat)), ("jabber-stat", ("jabber_stat", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.JabberStat)), ("ether64-octets", ("ether64_octets", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.Ether64Octets)), ("ether65127-octet", ("ether65127_octet", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.Ether65127Octet)), ("ether128255-octet", ("ether128255_octet", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.Ether128255Octet)), ("ether256511-octet", ("ether256511_octet", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.Ether256511Octet)), ("ether5121023-octet", ("ether5121023_octet", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.Ether5121023Octet)), ("ether10241518-octet", ("ether10241518_octet", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.Ether10241518Octet)), ("in-ucast-pkt", ("in_ucast_pkt", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InUcastPkt)), ("in-mcast-pkt", ("in_mcast_pkt", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InMcastPkt)), ("in-bcast-pkt", ("in_bcast_pkt", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InBcastPkt)), ("out-ucast-pkt", ("out_ucast_pkt", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutUcastPkt)), ("out-bcast-pkt", ("out_bcast_pkt", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutBcastPkt)), ("out-mcast-pkt", ("out_mcast_pkt", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutMcastPkt)), ("tx-pkt", ("tx_pkt", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.TxPkt)), ("if-in-errors", ("if_in_errors", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.IfInErrors)), ("if-in-octets", ("if_in_octets", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.IfInOctets)), ("ether-stat-multicast-pkt", ("ether_stat_multicast_pkt", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.EtherStatMulticastPkt)), ("ether-stat-broadcast-pkt", ("ether_stat_broadcast_pkt", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.EtherStatBroadcastPkt)), ("ether-stat-undersized-pkt", ("ether_stat_undersized_pkt", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.EtherStatUndersizedPkt)), ("out-octets", ("out_octets", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutOctets)), ("in-pause-frame", ("in_pause_frame", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InPauseFrame)), ("in-good-bytes", ("in_good_bytes", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InGoodBytes)), ("in8021q-frames", ("in8021q_frames", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.In8021qFrames)), ("in-pkts1519-max-octets", ("in_pkts1519_max_octets", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InPkts1519MaxOctets)), ("in-good-pkts", ("in_good_pkts", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InGoodPkts)), ("in-drop-overrun", ("in_drop_overrun", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InDropOverrun)), ("in-drop-abort", ("in_drop_abort", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InDropAbort)), ("in-drop-invalid-vlan", ("in_drop_invalid_vlan", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InDropInvalidVlan)), ("in-drop-invalid-dmac", ("in_drop_invalid_dmac", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InDropInvalidDmac)), ("in-drop-invalid-encap", ("in_drop_invalid_encap", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InDropInvalidEncap)), ("in-drop-other", ("in_drop_other", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InDropOther)), ("in-mib-giant", ("in_mib_giant", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InMibGiant)), ("in-mib-jabber", ("in_mib_jabber", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InMibJabber)), ("in-mibcrc", ("in_mibcrc", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InMibcrc)), ("in-error-collisions", ("in_error_collisions", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InErrorCollisions)), ("in-error-symbol", ("in_error_symbol", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InErrorSymbol)), ("out-good-bytes", ("out_good_bytes", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutGoodBytes)), ("out8021q-frames", ("out8021q_frames", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.Out8021qFrames)), ("out-pause-frames", ("out_pause_frames", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutPauseFrames)), ("out-pkts1519-max-octets", ("out_pkts1519_max_octets", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutPkts1519MaxOctets)), ("out-good-pkts", ("out_good_pkts", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutGoodPkts)), ("out-drop-underrun", ("out_drop_underrun", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutDropUnderrun)), ("out-drop-abort", ("out_drop_abort", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutDropAbort)), ("out-drop-other", ("out_drop_other", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutDropOther)), ("out-error-other", ("out_error_other", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutErrorOther)), ("in-error-giant", ("in_error_giant", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InErrorGiant)), ("in-error-runt", ("in_error_runt", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InErrorRunt)), ("in-error-jabbers", ("in_error_jabbers", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InErrorJabbers)), ("in-error-fragments", ("in_error_fragments", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InErrorFragments)), ("in-error-other", ("in_error_other", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InErrorOther)), ("in-pkt64-octet", ("in_pkt64_octet", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InPkt64Octet)), ("in-pkts65-to127-octets", ("in_pkts65_to127_octets", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InPkts65To127Octets)), ("in-pkts128-to255-octets", ("in_pkts128_to255_octets", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InPkts128To255Octets)), ("in-pkts256-to511-octets", ("in_pkts256_to511_octets", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InPkts256To511Octets)), ("in-pkts512-to1023-octets", ("in_pkts512_to1023_octets", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InPkts512To1023Octets)), ("in-pkts1024-to1518-octets", ("in_pkts1024_to1518_octets", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InPkts1024To1518Octets)), ("outpkt64octet", ("outpkt64octet", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.Outpkt64octet)), ("out-pkts65127-octets", ("out_pkts65127_octets", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutPkts65127Octets)), ("out-pkts128255-octets", ("out_pkts128255_octets", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutPkts128255Octets)), ("out-pkts256511-octets", ("out_pkts256511_octets", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutPkts256511Octets)), ("out-pkts5121023-octets", ("out_pkts5121023_octets", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutPkts5121023Octets)), ("out-pkts10241518-octets", ("out_pkts10241518_octets", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutPkts10241518Octets)), ("rx-util", ("rx_util", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.RxUtil)), ("tx-util", ("tx_util", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.TxUtil)), ("tx-undersized-pkt", ("tx_undersized_pkt", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.TxUndersizedPkt)), ("tx-oversized-pkt", ("tx_oversized_pkt", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.TxOversizedPkt)), ("tx-fragments", ("tx_fragments", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.TxFragments)), ("tx-jabber", ("tx_jabber", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.TxJabber)), ("tx-bad-fcs", ("tx_bad_fcs", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.TxBadFcs))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                    ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None
                                                self.sec30_support = None

                                                self.rx_pkt = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.RxPkt()
                                                self.rx_pkt.parent = self
                                                self._children_name_map["rx_pkt"] = "rx-pkt"

                                                self.stat_pkt = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.StatPkt()
                                                self.stat_pkt.parent = self
                                                self._children_name_map["stat_pkt"] = "stat-pkt"

                                                self.octet_stat = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OctetStat()
                                                self.octet_stat.parent = self
                                                self._children_name_map["octet_stat"] = "octet-stat"

                                                self.oversize_pkt_stat = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OversizePktStat()
                                                self.oversize_pkt_stat.parent = self
                                                self._children_name_map["oversize_pkt_stat"] = "oversize-pkt-stat"

                                                self.fcs_errors_stat = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.FcsErrorsStat()
                                                self.fcs_errors_stat.parent = self
                                                self._children_name_map["fcs_errors_stat"] = "fcs-errors-stat"

                                                self.long_frames_stat = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.LongFramesStat()
                                                self.long_frames_stat.parent = self
                                                self._children_name_map["long_frames_stat"] = "long-frames-stat"

                                                self.jabber_stat = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.JabberStat()
                                                self.jabber_stat.parent = self
                                                self._children_name_map["jabber_stat"] = "jabber-stat"

                                                self.ether64_octets = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.Ether64Octets()
                                                self.ether64_octets.parent = self
                                                self._children_name_map["ether64_octets"] = "ether64-octets"

                                                self.ether65127_octet = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.Ether65127Octet()
                                                self.ether65127_octet.parent = self
                                                self._children_name_map["ether65127_octet"] = "ether65127-octet"

                                                self.ether128255_octet = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.Ether128255Octet()
                                                self.ether128255_octet.parent = self
                                                self._children_name_map["ether128255_octet"] = "ether128255-octet"

                                                self.ether256511_octet = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.Ether256511Octet()
                                                self.ether256511_octet.parent = self
                                                self._children_name_map["ether256511_octet"] = "ether256511-octet"

                                                self.ether5121023_octet = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.Ether5121023Octet()
                                                self.ether5121023_octet.parent = self
                                                self._children_name_map["ether5121023_octet"] = "ether5121023-octet"

                                                self.ether10241518_octet = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.Ether10241518Octet()
                                                self.ether10241518_octet.parent = self
                                                self._children_name_map["ether10241518_octet"] = "ether10241518-octet"

                                                self.in_ucast_pkt = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InUcastPkt()
                                                self.in_ucast_pkt.parent = self
                                                self._children_name_map["in_ucast_pkt"] = "in-ucast-pkt"

                                                self.in_mcast_pkt = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InMcastPkt()
                                                self.in_mcast_pkt.parent = self
                                                self._children_name_map["in_mcast_pkt"] = "in-mcast-pkt"

                                                self.in_bcast_pkt = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InBcastPkt()
                                                self.in_bcast_pkt.parent = self
                                                self._children_name_map["in_bcast_pkt"] = "in-bcast-pkt"

                                                self.out_ucast_pkt = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutUcastPkt()
                                                self.out_ucast_pkt.parent = self
                                                self._children_name_map["out_ucast_pkt"] = "out-ucast-pkt"

                                                self.out_bcast_pkt = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutBcastPkt()
                                                self.out_bcast_pkt.parent = self
                                                self._children_name_map["out_bcast_pkt"] = "out-bcast-pkt"

                                                self.out_mcast_pkt = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutMcastPkt()
                                                self.out_mcast_pkt.parent = self
                                                self._children_name_map["out_mcast_pkt"] = "out-mcast-pkt"

                                                self.tx_pkt = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.TxPkt()
                                                self.tx_pkt.parent = self
                                                self._children_name_map["tx_pkt"] = "tx-pkt"

                                                self.if_in_errors = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.IfInErrors()
                                                self.if_in_errors.parent = self
                                                self._children_name_map["if_in_errors"] = "if-in-errors"

                                                self.if_in_octets = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.IfInOctets()
                                                self.if_in_octets.parent = self
                                                self._children_name_map["if_in_octets"] = "if-in-octets"

                                                self.ether_stat_multicast_pkt = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.EtherStatMulticastPkt()
                                                self.ether_stat_multicast_pkt.parent = self
                                                self._children_name_map["ether_stat_multicast_pkt"] = "ether-stat-multicast-pkt"

                                                self.ether_stat_broadcast_pkt = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.EtherStatBroadcastPkt()
                                                self.ether_stat_broadcast_pkt.parent = self
                                                self._children_name_map["ether_stat_broadcast_pkt"] = "ether-stat-broadcast-pkt"

                                                self.ether_stat_undersized_pkt = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.EtherStatUndersizedPkt()
                                                self.ether_stat_undersized_pkt.parent = self
                                                self._children_name_map["ether_stat_undersized_pkt"] = "ether-stat-undersized-pkt"

                                                self.out_octets = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutOctets()
                                                self.out_octets.parent = self
                                                self._children_name_map["out_octets"] = "out-octets"

                                                self.in_pause_frame = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InPauseFrame()
                                                self.in_pause_frame.parent = self
                                                self._children_name_map["in_pause_frame"] = "in-pause-frame"

                                                self.in_good_bytes = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InGoodBytes()
                                                self.in_good_bytes.parent = self
                                                self._children_name_map["in_good_bytes"] = "in-good-bytes"

                                                self.in8021q_frames = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.In8021qFrames()
                                                self.in8021q_frames.parent = self
                                                self._children_name_map["in8021q_frames"] = "in8021q-frames"

                                                self.in_pkts1519_max_octets = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InPkts1519MaxOctets()
                                                self.in_pkts1519_max_octets.parent = self
                                                self._children_name_map["in_pkts1519_max_octets"] = "in-pkts1519-max-octets"

                                                self.in_good_pkts = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InGoodPkts()
                                                self.in_good_pkts.parent = self
                                                self._children_name_map["in_good_pkts"] = "in-good-pkts"

                                                self.in_drop_overrun = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InDropOverrun()
                                                self.in_drop_overrun.parent = self
                                                self._children_name_map["in_drop_overrun"] = "in-drop-overrun"

                                                self.in_drop_abort = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InDropAbort()
                                                self.in_drop_abort.parent = self
                                                self._children_name_map["in_drop_abort"] = "in-drop-abort"

                                                self.in_drop_invalid_vlan = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InDropInvalidVlan()
                                                self.in_drop_invalid_vlan.parent = self
                                                self._children_name_map["in_drop_invalid_vlan"] = "in-drop-invalid-vlan"

                                                self.in_drop_invalid_dmac = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InDropInvalidDmac()
                                                self.in_drop_invalid_dmac.parent = self
                                                self._children_name_map["in_drop_invalid_dmac"] = "in-drop-invalid-dmac"

                                                self.in_drop_invalid_encap = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InDropInvalidEncap()
                                                self.in_drop_invalid_encap.parent = self
                                                self._children_name_map["in_drop_invalid_encap"] = "in-drop-invalid-encap"

                                                self.in_drop_other = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InDropOther()
                                                self.in_drop_other.parent = self
                                                self._children_name_map["in_drop_other"] = "in-drop-other"

                                                self.in_mib_giant = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InMibGiant()
                                                self.in_mib_giant.parent = self
                                                self._children_name_map["in_mib_giant"] = "in-mib-giant"

                                                self.in_mib_jabber = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InMibJabber()
                                                self.in_mib_jabber.parent = self
                                                self._children_name_map["in_mib_jabber"] = "in-mib-jabber"

                                                self.in_mibcrc = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InMibcrc()
                                                self.in_mibcrc.parent = self
                                                self._children_name_map["in_mibcrc"] = "in-mibcrc"

                                                self.in_error_collisions = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InErrorCollisions()
                                                self.in_error_collisions.parent = self
                                                self._children_name_map["in_error_collisions"] = "in-error-collisions"

                                                self.in_error_symbol = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InErrorSymbol()
                                                self.in_error_symbol.parent = self
                                                self._children_name_map["in_error_symbol"] = "in-error-symbol"

                                                self.out_good_bytes = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutGoodBytes()
                                                self.out_good_bytes.parent = self
                                                self._children_name_map["out_good_bytes"] = "out-good-bytes"

                                                self.out8021q_frames = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.Out8021qFrames()
                                                self.out8021q_frames.parent = self
                                                self._children_name_map["out8021q_frames"] = "out8021q-frames"

                                                self.out_pause_frames = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutPauseFrames()
                                                self.out_pause_frames.parent = self
                                                self._children_name_map["out_pause_frames"] = "out-pause-frames"

                                                self.out_pkts1519_max_octets = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutPkts1519MaxOctets()
                                                self.out_pkts1519_max_octets.parent = self
                                                self._children_name_map["out_pkts1519_max_octets"] = "out-pkts1519-max-octets"

                                                self.out_good_pkts = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutGoodPkts()
                                                self.out_good_pkts.parent = self
                                                self._children_name_map["out_good_pkts"] = "out-good-pkts"

                                                self.out_drop_underrun = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutDropUnderrun()
                                                self.out_drop_underrun.parent = self
                                                self._children_name_map["out_drop_underrun"] = "out-drop-underrun"

                                                self.out_drop_abort = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutDropAbort()
                                                self.out_drop_abort.parent = self
                                                self._children_name_map["out_drop_abort"] = "out-drop-abort"

                                                self.out_drop_other = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutDropOther()
                                                self.out_drop_other.parent = self
                                                self._children_name_map["out_drop_other"] = "out-drop-other"

                                                self.out_error_other = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutErrorOther()
                                                self.out_error_other.parent = self
                                                self._children_name_map["out_error_other"] = "out-error-other"

                                                self.in_error_giant = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InErrorGiant()
                                                self.in_error_giant.parent = self
                                                self._children_name_map["in_error_giant"] = "in-error-giant"

                                                self.in_error_runt = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InErrorRunt()
                                                self.in_error_runt.parent = self
                                                self._children_name_map["in_error_runt"] = "in-error-runt"

                                                self.in_error_jabbers = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InErrorJabbers()
                                                self.in_error_jabbers.parent = self
                                                self._children_name_map["in_error_jabbers"] = "in-error-jabbers"

                                                self.in_error_fragments = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InErrorFragments()
                                                self.in_error_fragments.parent = self
                                                self._children_name_map["in_error_fragments"] = "in-error-fragments"

                                                self.in_error_other = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InErrorOther()
                                                self.in_error_other.parent = self
                                                self._children_name_map["in_error_other"] = "in-error-other"

                                                self.in_pkt64_octet = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InPkt64Octet()
                                                self.in_pkt64_octet.parent = self
                                                self._children_name_map["in_pkt64_octet"] = "in-pkt64-octet"

                                                self.in_pkts65_to127_octets = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InPkts65To127Octets()
                                                self.in_pkts65_to127_octets.parent = self
                                                self._children_name_map["in_pkts65_to127_octets"] = "in-pkts65-to127-octets"

                                                self.in_pkts128_to255_octets = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InPkts128To255Octets()
                                                self.in_pkts128_to255_octets.parent = self
                                                self._children_name_map["in_pkts128_to255_octets"] = "in-pkts128-to255-octets"

                                                self.in_pkts256_to511_octets = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InPkts256To511Octets()
                                                self.in_pkts256_to511_octets.parent = self
                                                self._children_name_map["in_pkts256_to511_octets"] = "in-pkts256-to511-octets"

                                                self.in_pkts512_to1023_octets = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InPkts512To1023Octets()
                                                self.in_pkts512_to1023_octets.parent = self
                                                self._children_name_map["in_pkts512_to1023_octets"] = "in-pkts512-to1023-octets"

                                                self.in_pkts1024_to1518_octets = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InPkts1024To1518Octets()
                                                self.in_pkts1024_to1518_octets.parent = self
                                                self._children_name_map["in_pkts1024_to1518_octets"] = "in-pkts1024-to1518-octets"

                                                self.outpkt64octet = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.Outpkt64octet()
                                                self.outpkt64octet.parent = self
                                                self._children_name_map["outpkt64octet"] = "outpkt64octet"

                                                self.out_pkts65127_octets = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutPkts65127Octets()
                                                self.out_pkts65127_octets.parent = self
                                                self._children_name_map["out_pkts65127_octets"] = "out-pkts65127-octets"

                                                self.out_pkts128255_octets = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutPkts128255Octets()
                                                self.out_pkts128255_octets.parent = self
                                                self._children_name_map["out_pkts128255_octets"] = "out-pkts128255-octets"

                                                self.out_pkts256511_octets = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutPkts256511Octets()
                                                self.out_pkts256511_octets.parent = self
                                                self._children_name_map["out_pkts256511_octets"] = "out-pkts256511-octets"

                                                self.out_pkts5121023_octets = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutPkts5121023Octets()
                                                self.out_pkts5121023_octets.parent = self
                                                self._children_name_map["out_pkts5121023_octets"] = "out-pkts5121023-octets"

                                                self.out_pkts10241518_octets = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutPkts10241518Octets()
                                                self.out_pkts10241518_octets.parent = self
                                                self._children_name_map["out_pkts10241518_octets"] = "out-pkts10241518-octets"

                                                self.rx_util = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.RxUtil()
                                                self.rx_util.parent = self
                                                self._children_name_map["rx_util"] = "rx-util"

                                                self.tx_util = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.TxUtil()
                                                self.tx_util.parent = self
                                                self._children_name_map["tx_util"] = "tx-util"

                                                self.tx_undersized_pkt = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.TxUndersizedPkt()
                                                self.tx_undersized_pkt.parent = self
                                                self._children_name_map["tx_undersized_pkt"] = "tx-undersized-pkt"

                                                self.tx_oversized_pkt = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.TxOversizedPkt()
                                                self.tx_oversized_pkt.parent = self
                                                self._children_name_map["tx_oversized_pkt"] = "tx-oversized-pkt"

                                                self.tx_fragments = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.TxFragments()
                                                self.tx_fragments.parent = self
                                                self._children_name_map["tx_fragments"] = "tx-fragments"

                                                self.tx_jabber = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.TxJabber()
                                                self.tx_jabber.parent = self
                                                self._children_name_map["tx_jabber"] = "tx-jabber"

                                                self.tx_bad_fcs = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.TxBadFcs()
                                                self.tx_bad_fcs.parent = self
                                                self._children_name_map["tx_bad_fcs"] = "tx-bad-fcs"
                                                self._segment_path = lambda: "macsec-minute15-ether-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear30_sec_time', 'last_clear15_min_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                            class RxPkt(Entity):
                                                """
                                                RX PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.RxPkt, self).__init__()

                                                    self.yang_name = "rx-pkt"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "rx-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.RxPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class StatPkt(Entity):
                                                """
                                                STAT PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.StatPkt, self).__init__()

                                                    self.yang_name = "stat-pkt"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "stat-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.StatPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OctetStat(Entity):
                                                """
                                                OCTET STAT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OctetStat, self).__init__()

                                                    self.yang_name = "octet-stat"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "octet-stat"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OctetStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OversizePktStat(Entity):
                                                """
                                                OVERSIZE PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OversizePktStat, self).__init__()

                                                    self.yang_name = "oversize-pkt-stat"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "oversize-pkt-stat"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OversizePktStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class FcsErrorsStat(Entity):
                                                """
                                                FCS ERR
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.FcsErrorsStat, self).__init__()

                                                    self.yang_name = "fcs-errors-stat"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "fcs-errors-stat"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.FcsErrorsStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class LongFramesStat(Entity):
                                                """
                                                LONG FRAMES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.LongFramesStat, self).__init__()

                                                    self.yang_name = "long-frames-stat"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "long-frames-stat"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.LongFramesStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class JabberStat(Entity):
                                                """
                                                JABBER STATS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.JabberStat, self).__init__()

                                                    self.yang_name = "jabber-stat"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "jabber-stat"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.JabberStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class Ether64Octets(Entity):
                                                """
                                                SIXTY FOUR OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.Ether64Octets, self).__init__()

                                                    self.yang_name = "ether64-octets"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ether64-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.Ether64Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class Ether65127Octet(Entity):
                                                """
                                                OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.Ether65127Octet, self).__init__()

                                                    self.yang_name = "ether65127-octet"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ether65127-octet"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.Ether65127Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class Ether128255Octet(Entity):
                                                """
                                                TFF OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.Ether128255Octet, self).__init__()

                                                    self.yang_name = "ether128255-octet"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ether128255-octet"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.Ether128255Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class Ether256511Octet(Entity):
                                                """
                                                FOO OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.Ether256511Octet, self).__init__()

                                                    self.yang_name = "ether256511-octet"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ether256511-octet"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.Ether256511Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class Ether5121023Octet(Entity):
                                                """
                                                OZTT OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.Ether5121023Octet, self).__init__()

                                                    self.yang_name = "ether5121023-octet"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ether5121023-octet"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.Ether5121023Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class Ether10241518Octet(Entity):
                                                """
                                                OFO OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.Ether10241518Octet, self).__init__()

                                                    self.yang_name = "ether10241518-octet"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ether10241518-octet"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.Ether10241518Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InUcastPkt(Entity):
                                                """
                                                IN UCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InUcastPkt, self).__init__()

                                                    self.yang_name = "in-ucast-pkt"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-ucast-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InUcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InMcastPkt(Entity):
                                                """
                                                IN MCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InMcastPkt, self).__init__()

                                                    self.yang_name = "in-mcast-pkt"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-mcast-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InMcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InBcastPkt(Entity):
                                                """
                                                IN BCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InBcastPkt, self).__init__()

                                                    self.yang_name = "in-bcast-pkt"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-bcast-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InBcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutUcastPkt(Entity):
                                                """
                                                OUT UCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutUcastPkt, self).__init__()

                                                    self.yang_name = "out-ucast-pkt"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-ucast-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutUcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutBcastPkt(Entity):
                                                """
                                                OUT BCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutBcastPkt, self).__init__()

                                                    self.yang_name = "out-bcast-pkt"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-bcast-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutBcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutMcastPkt(Entity):
                                                """
                                                OUT MCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutMcastPkt, self).__init__()

                                                    self.yang_name = "out-mcast-pkt"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-mcast-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutMcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class TxPkt(Entity):
                                                """
                                                TX PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.TxPkt, self).__init__()

                                                    self.yang_name = "tx-pkt"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "tx-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.TxPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class IfInErrors(Entity):
                                                """
                                                IFIN ERRORS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.IfInErrors, self).__init__()

                                                    self.yang_name = "if-in-errors"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "if-in-errors"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.IfInErrors, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class IfInOctets(Entity):
                                                """
                                                IFIN OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.IfInOctets, self).__init__()

                                                    self.yang_name = "if-in-octets"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "if-in-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.IfInOctets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class EtherStatMulticastPkt(Entity):
                                                """
                                                ETHER STAT MULTICAST PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.EtherStatMulticastPkt, self).__init__()

                                                    self.yang_name = "ether-stat-multicast-pkt"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ether-stat-multicast-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.EtherStatMulticastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class EtherStatBroadcastPkt(Entity):
                                                """
                                                ETHER STAT BROADCAST PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.EtherStatBroadcastPkt, self).__init__()

                                                    self.yang_name = "ether-stat-broadcast-pkt"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ether-stat-broadcast-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.EtherStatBroadcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class EtherStatUndersizedPkt(Entity):
                                                """
                                                ETHER STAT UNDERSIZED PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.EtherStatUndersizedPkt, self).__init__()

                                                    self.yang_name = "ether-stat-undersized-pkt"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ether-stat-undersized-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.EtherStatUndersizedPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutOctets(Entity):
                                                """
                                                OUT OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutOctets, self).__init__()

                                                    self.yang_name = "out-octets"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutOctets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPauseFrame(Entity):
                                                """
                                                INPUT PAUSE FRAME
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InPauseFrame, self).__init__()

                                                    self.yang_name = "in-pause-frame"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pause-frame"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InPauseFrame, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InGoodBytes(Entity):
                                                """
                                                INPUT GOOD BYTES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InGoodBytes, self).__init__()

                                                    self.yang_name = "in-good-bytes"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-good-bytes"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InGoodBytes, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class In8021qFrames(Entity):
                                                """
                                                INPUT 802 1Q FRAMES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.In8021qFrames, self).__init__()

                                                    self.yang_name = "in8021q-frames"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in8021q-frames"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.In8021qFrames, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPkts1519MaxOctets(Entity):
                                                """
                                                INPUT PKTS 1519MAX OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InPkts1519MaxOctets, self).__init__()

                                                    self.yang_name = "in-pkts1519-max-octets"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts1519-max-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InPkts1519MaxOctets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InGoodPkts(Entity):
                                                """
                                                INPUT GOOD PKTS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InGoodPkts, self).__init__()

                                                    self.yang_name = "in-good-pkts"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-good-pkts"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InGoodPkts, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InDropOverrun(Entity):
                                                """
                                                INPUT DROP OVERRUN
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InDropOverrun, self).__init__()

                                                    self.yang_name = "in-drop-overrun"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-drop-overrun"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InDropOverrun, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InDropAbort(Entity):
                                                """
                                                INPUT DROP ABORT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InDropAbort, self).__init__()

                                                    self.yang_name = "in-drop-abort"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-drop-abort"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InDropAbort, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InDropInvalidVlan(Entity):
                                                """
                                                INPUT DROP INVALID VLAN
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InDropInvalidVlan, self).__init__()

                                                    self.yang_name = "in-drop-invalid-vlan"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-drop-invalid-vlan"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InDropInvalidVlan, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InDropInvalidDmac(Entity):
                                                """
                                                INPUT DROP INVALID DMAC
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InDropInvalidDmac, self).__init__()

                                                    self.yang_name = "in-drop-invalid-dmac"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-drop-invalid-dmac"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InDropInvalidDmac, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InDropInvalidEncap(Entity):
                                                """
                                                INPUT DROP INVALID ENCAP
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InDropInvalidEncap, self).__init__()

                                                    self.yang_name = "in-drop-invalid-encap"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-drop-invalid-encap"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InDropInvalidEncap, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InDropOther(Entity):
                                                """
                                                INPUT DROP OTHER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InDropOther, self).__init__()

                                                    self.yang_name = "in-drop-other"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-drop-other"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InDropOther, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InMibGiant(Entity):
                                                """
                                                INPUT MIB GIANT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InMibGiant, self).__init__()

                                                    self.yang_name = "in-mib-giant"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-mib-giant"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InMibGiant, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InMibJabber(Entity):
                                                """
                                                INPUT MIB JABBER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InMibJabber, self).__init__()

                                                    self.yang_name = "in-mib-jabber"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-mib-jabber"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InMibJabber, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InMibcrc(Entity):
                                                """
                                                IN MIB CRC
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InMibcrc, self).__init__()

                                                    self.yang_name = "in-mibcrc"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-mibcrc"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InMibcrc, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InErrorCollisions(Entity):
                                                """
                                                IN ERROR COLLISIONS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InErrorCollisions, self).__init__()

                                                    self.yang_name = "in-error-collisions"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-error-collisions"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InErrorCollisions, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InErrorSymbol(Entity):
                                                """
                                                IN ERROR SYMBOL
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InErrorSymbol, self).__init__()

                                                    self.yang_name = "in-error-symbol"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-error-symbol"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InErrorSymbol, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutGoodBytes(Entity):
                                                """
                                                OUT GOOD BYTES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutGoodBytes, self).__init__()

                                                    self.yang_name = "out-good-bytes"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-good-bytes"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutGoodBytes, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class Out8021qFrames(Entity):
                                                """
                                                OUT 802 1Q FRAMES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.Out8021qFrames, self).__init__()

                                                    self.yang_name = "out8021q-frames"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out8021q-frames"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.Out8021qFrames, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutPauseFrames(Entity):
                                                """
                                                OUT PAUSE FRAMES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutPauseFrames, self).__init__()

                                                    self.yang_name = "out-pause-frames"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-pause-frames"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutPauseFrames, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutPkts1519MaxOctets(Entity):
                                                """
                                                OUT PKTS 1519 MAX OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutPkts1519MaxOctets, self).__init__()

                                                    self.yang_name = "out-pkts1519-max-octets"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-pkts1519-max-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutPkts1519MaxOctets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutGoodPkts(Entity):
                                                """
                                                OUT GOOD PKTS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutGoodPkts, self).__init__()

                                                    self.yang_name = "out-good-pkts"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-good-pkts"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutGoodPkts, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutDropUnderrun(Entity):
                                                """
                                                OUT DROP UNDERRUN
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutDropUnderrun, self).__init__()

                                                    self.yang_name = "out-drop-underrun"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-drop-underrun"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutDropUnderrun, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutDropAbort(Entity):
                                                """
                                                OUT DROP ABORT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutDropAbort, self).__init__()

                                                    self.yang_name = "out-drop-abort"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-drop-abort"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutDropAbort, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutDropOther(Entity):
                                                """
                                                OUT DROP OTHER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutDropOther, self).__init__()

                                                    self.yang_name = "out-drop-other"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-drop-other"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutDropOther, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutErrorOther(Entity):
                                                """
                                                OUT ERROR OTHER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutErrorOther, self).__init__()

                                                    self.yang_name = "out-error-other"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-error-other"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutErrorOther, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InErrorGiant(Entity):
                                                """
                                                IN ERROR GIANT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InErrorGiant, self).__init__()

                                                    self.yang_name = "in-error-giant"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-error-giant"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InErrorGiant, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InErrorRunt(Entity):
                                                """
                                                IN ERROR RUNT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InErrorRunt, self).__init__()

                                                    self.yang_name = "in-error-runt"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-error-runt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InErrorRunt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InErrorJabbers(Entity):
                                                """
                                                IN ERROR JABBERS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InErrorJabbers, self).__init__()

                                                    self.yang_name = "in-error-jabbers"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-error-jabbers"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InErrorJabbers, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InErrorFragments(Entity):
                                                """
                                                IN ERROR FRAGMENTS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InErrorFragments, self).__init__()

                                                    self.yang_name = "in-error-fragments"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-error-fragments"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InErrorFragments, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InErrorOther(Entity):
                                                """
                                                IN ERROR OTHER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InErrorOther, self).__init__()

                                                    self.yang_name = "in-error-other"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-error-other"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InErrorOther, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPkt64Octet(Entity):
                                                """
                                                IN PKT 64 OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InPkt64Octet, self).__init__()

                                                    self.yang_name = "in-pkt64-octet"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkt64-octet"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InPkt64Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPkts65To127Octets(Entity):
                                                """
                                                IN PKTS 65 127OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InPkts65To127Octets, self).__init__()

                                                    self.yang_name = "in-pkts65-to127-octets"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts65-to127-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InPkts65To127Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPkts128To255Octets(Entity):
                                                """
                                                IN PKTS 128 255 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InPkts128To255Octets, self).__init__()

                                                    self.yang_name = "in-pkts128-to255-octets"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts128-to255-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InPkts128To255Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPkts256To511Octets(Entity):
                                                """
                                                IN PKTS 256 511 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InPkts256To511Octets, self).__init__()

                                                    self.yang_name = "in-pkts256-to511-octets"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts256-to511-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InPkts256To511Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPkts512To1023Octets(Entity):
                                                """
                                                IN PKTS 512 1023 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InPkts512To1023Octets, self).__init__()

                                                    self.yang_name = "in-pkts512-to1023-octets"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts512-to1023-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InPkts512To1023Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPkts1024To1518Octets(Entity):
                                                """
                                                IN PKTS 1024 1518 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InPkts1024To1518Octets, self).__init__()

                                                    self.yang_name = "in-pkts1024-to1518-octets"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts1024-to1518-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.InPkts1024To1518Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class Outpkt64octet(Entity):
                                                """
                                                OUT PKT 64 OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.Outpkt64octet, self).__init__()

                                                    self.yang_name = "outpkt64octet"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "outpkt64octet"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.Outpkt64octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutPkts65127Octets(Entity):
                                                """
                                                OUT PKTS 65 127OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutPkts65127Octets, self).__init__()

                                                    self.yang_name = "out-pkts65127-octets"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-pkts65127-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutPkts65127Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutPkts128255Octets(Entity):
                                                """
                                                OUT PKTS 128 255 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutPkts128255Octets, self).__init__()

                                                    self.yang_name = "out-pkts128255-octets"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-pkts128255-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutPkts128255Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutPkts256511Octets(Entity):
                                                """
                                                OUT PKTS 256 511 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutPkts256511Octets, self).__init__()

                                                    self.yang_name = "out-pkts256511-octets"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-pkts256511-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutPkts256511Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutPkts5121023Octets(Entity):
                                                """
                                                OUT PKTS 512 1023 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutPkts5121023Octets, self).__init__()

                                                    self.yang_name = "out-pkts5121023-octets"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-pkts5121023-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutPkts5121023Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutPkts10241518Octets(Entity):
                                                """
                                                OUT PKTS 1024 1518 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutPkts10241518Octets, self).__init__()

                                                    self.yang_name = "out-pkts10241518-octets"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-pkts10241518-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.OutPkts10241518Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class RxUtil(Entity):
                                                """
                                                Rx Utilization in Percent
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: str
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.RxUtil, self).__init__()

                                                    self.yang_name = "rx-util"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                        ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "rx-util"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.RxUtil, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class TxUtil(Entity):
                                                """
                                                Tx Utilization in Percent
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: str
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.TxUtil, self).__init__()

                                                    self.yang_name = "tx-util"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                        ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "tx-util"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.TxUtil, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class TxUndersizedPkt(Entity):
                                                """
                                                TX Undersized Pkt
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.TxUndersizedPkt, self).__init__()

                                                    self.yang_name = "tx-undersized-pkt"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "tx-undersized-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.TxUndersizedPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class TxOversizedPkt(Entity):
                                                """
                                                TX Oversized Pkt
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.TxOversizedPkt, self).__init__()

                                                    self.yang_name = "tx-oversized-pkt"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "tx-oversized-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.TxOversizedPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class TxFragments(Entity):
                                                """
                                                TX Fragments
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.TxFragments, self).__init__()

                                                    self.yang_name = "tx-fragments"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "tx-fragments"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.TxFragments, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class TxJabber(Entity):
                                                """
                                                TX Jabber
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.TxJabber, self).__init__()

                                                    self.yang_name = "tx-jabber"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "tx-jabber"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.TxJabber, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class TxBadFcs(Entity):
                                                """
                                                TX Bad Fcs
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.TxBadFcs, self).__init__()

                                                    self.yang_name = "tx-bad-fcs"
                                                    self.yang_parent_name = "macsec-minute15-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "tx-bad-fcs"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15EtherHistories.MacsecMinute15EtherHistory.MacsecMinute15EtherTimeLineInstances.MacsecMinute15EtherTimeLineInstance.TxBadFcs, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                            class MacsecMinute15secytxHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: macsec_minute15secytx_history
                                
                                	port 15\-minute secy\_tx performance data
                                	**type**\: list of  		 :py:class:`MacsecMinute15secytxHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secytxHistories.MacsecMinute15secytxHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secytxHistories, self).__init__()

                                    self.yang_name = "macsec-minute15secytx-histories"
                                    self.yang_parent_name = "macsec-minute15-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("macsec-minute15secytx-history", ("macsec_minute15secytx_history", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secytxHistories.MacsecMinute15secytxHistory))])
                                    self._leafs = OrderedDict()

                                    self.macsec_minute15secytx_history = YList(self)
                                    self._segment_path = lambda: "macsec-minute15secytx-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secytxHistories, [], name, value)


                                class MacsecMinute15secytxHistory(Entity):
                                    """
                                    port 15\-minute secy\_tx performance data
                                    
                                    .. attribute:: number  (key)
                                    
                                    	channel number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: macsec_minute15secytx_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`MacsecMinute15secytxTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secytxHistories.MacsecMinute15secytxHistory.MacsecMinute15secytxTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secytxHistories.MacsecMinute15secytxHistory, self).__init__()

                                        self.yang_name = "macsec-minute15secytx-history"
                                        self.yang_parent_name = "macsec-minute15secytx-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([("macsec-minute15secytx-time-line-instances", ("macsec_minute15secytx_time_line_instances", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secytxHistories.MacsecMinute15secytxHistory.MacsecMinute15secytxTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ])
                                        self.number = None

                                        self.macsec_minute15secytx_time_line_instances = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secytxHistories.MacsecMinute15secytxHistory.MacsecMinute15secytxTimeLineInstances()
                                        self.macsec_minute15secytx_time_line_instances.parent = self
                                        self._children_name_map["macsec_minute15secytx_time_line_instances"] = "macsec-minute15secytx-time-line-instances"
                                        self._segment_path = lambda: "macsec-minute15secytx-history" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secytxHistories.MacsecMinute15secytxHistory, ['number'], name, value)


                                    class MacsecMinute15secytxTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: macsec_minute15secytx_time_line_instance
                                        
                                        	port 15\-minute secy\_tx performance data by index
                                        	**type**\: list of  		 :py:class:`MacsecMinute15secytxTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secytxHistories.MacsecMinute15secytxHistory.MacsecMinute15secytxTimeLineInstances.MacsecMinute15secytxTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secytxHistories.MacsecMinute15secytxHistory.MacsecMinute15secytxTimeLineInstances, self).__init__()

                                            self.yang_name = "macsec-minute15secytx-time-line-instances"
                                            self.yang_parent_name = "macsec-minute15secytx-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("macsec-minute15secytx-time-line-instance", ("macsec_minute15secytx_time_line_instance", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secytxHistories.MacsecMinute15secytxHistory.MacsecMinute15secytxTimeLineInstances.MacsecMinute15secytxTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.macsec_minute15secytx_time_line_instance = YList(self)
                                            self._segment_path = lambda: "macsec-minute15secytx-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secytxHistories.MacsecMinute15secytxHistory.MacsecMinute15secytxTimeLineInstances, [], name, value)


                                        class MacsecMinute15secytxTimeLineInstance(Entity):
                                            """
                                            port 15\-minute secy\_tx performance data
                                            by index
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: out_pkts_protected
                                            
                                            	Out Packets Protected
                                            	**type**\:  :py:class:`OutPktsProtected <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secytxHistories.MacsecMinute15secytxHistory.MacsecMinute15secytxTimeLineInstances.MacsecMinute15secytxTimeLineInstance.OutPktsProtected>`
                                            
                                            .. attribute:: out_pkts_encrypted
                                            
                                            	Out Packets Encrypted
                                            	**type**\:  :py:class:`OutPktsEncrypted <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secytxHistories.MacsecMinute15secytxHistory.MacsecMinute15secytxTimeLineInstances.MacsecMinute15secytxTimeLineInstance.OutPktsEncrypted>`
                                            
                                            .. attribute:: out_octets_protected
                                            
                                            	Out Octets Protected 
                                            	**type**\:  :py:class:`OutOctetsProtected <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secytxHistories.MacsecMinute15secytxHistory.MacsecMinute15secytxTimeLineInstances.MacsecMinute15secytxTimeLineInstance.OutOctetsProtected>`
                                            
                                            .. attribute:: out_octets_encrypted
                                            
                                            	Out Octets Encrypted
                                            	**type**\:  :py:class:`OutOctetsEncrypted <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secytxHistories.MacsecMinute15secytxHistory.MacsecMinute15secytxTimeLineInstances.MacsecMinute15secytxTimeLineInstance.OutOctetsEncrypted>`
                                            
                                            .. attribute:: out_pkts_too_long
                                            
                                            	Out Packets Too Long
                                            	**type**\:  :py:class:`OutPktsTooLong <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secytxHistories.MacsecMinute15secytxHistory.MacsecMinute15secytxTimeLineInstances.MacsecMinute15secytxTimeLineInstance.OutPktsTooLong>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\: bool
                                            
                                            .. attribute:: sample_count
                                            
                                            	Running Sample Count
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secytxHistories.MacsecMinute15secytxHistory.MacsecMinute15secytxTimeLineInstances.MacsecMinute15secytxTimeLineInstance, self).__init__()

                                                self.yang_name = "macsec-minute15secytx-time-line-instance"
                                                self.yang_parent_name = "macsec-minute15secytx-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("out-pkts-protected", ("out_pkts_protected", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secytxHistories.MacsecMinute15secytxHistory.MacsecMinute15secytxTimeLineInstances.MacsecMinute15secytxTimeLineInstance.OutPktsProtected)), ("out-pkts-encrypted", ("out_pkts_encrypted", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secytxHistories.MacsecMinute15secytxHistory.MacsecMinute15secytxTimeLineInstances.MacsecMinute15secytxTimeLineInstance.OutPktsEncrypted)), ("out-octets-protected", ("out_octets_protected", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secytxHistories.MacsecMinute15secytxHistory.MacsecMinute15secytxTimeLineInstances.MacsecMinute15secytxTimeLineInstance.OutOctetsProtected)), ("out-octets-encrypted", ("out_octets_encrypted", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secytxHistories.MacsecMinute15secytxHistory.MacsecMinute15secytxTimeLineInstances.MacsecMinute15secytxTimeLineInstance.OutOctetsEncrypted)), ("out-pkts-too-long", ("out_pkts_too_long", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secytxHistories.MacsecMinute15secytxHistory.MacsecMinute15secytxTimeLineInstances.MacsecMinute15secytxTimeLineInstance.OutPktsTooLong))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                    ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                                    ('sample_count', (YLeaf(YType.uint64, 'sample-count'), ['int'])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear24_hr_time = None
                                                self.sec30_support = None
                                                self.sample_count = None

                                                self.out_pkts_protected = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secytxHistories.MacsecMinute15secytxHistory.MacsecMinute15secytxTimeLineInstances.MacsecMinute15secytxTimeLineInstance.OutPktsProtected()
                                                self.out_pkts_protected.parent = self
                                                self._children_name_map["out_pkts_protected"] = "out-pkts-protected"

                                                self.out_pkts_encrypted = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secytxHistories.MacsecMinute15secytxHistory.MacsecMinute15secytxTimeLineInstances.MacsecMinute15secytxTimeLineInstance.OutPktsEncrypted()
                                                self.out_pkts_encrypted.parent = self
                                                self._children_name_map["out_pkts_encrypted"] = "out-pkts-encrypted"

                                                self.out_octets_protected = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secytxHistories.MacsecMinute15secytxHistory.MacsecMinute15secytxTimeLineInstances.MacsecMinute15secytxTimeLineInstance.OutOctetsProtected()
                                                self.out_octets_protected.parent = self
                                                self._children_name_map["out_octets_protected"] = "out-octets-protected"

                                                self.out_octets_encrypted = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secytxHistories.MacsecMinute15secytxHistory.MacsecMinute15secytxTimeLineInstances.MacsecMinute15secytxTimeLineInstance.OutOctetsEncrypted()
                                                self.out_octets_encrypted.parent = self
                                                self._children_name_map["out_octets_encrypted"] = "out-octets-encrypted"

                                                self.out_pkts_too_long = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secytxHistories.MacsecMinute15secytxHistory.MacsecMinute15secytxTimeLineInstances.MacsecMinute15secytxTimeLineInstance.OutPktsTooLong()
                                                self.out_pkts_too_long.parent = self
                                                self._children_name_map["out_pkts_too_long"] = "out-pkts-too-long"
                                                self._segment_path = lambda: "macsec-minute15secytx-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secytxHistories.MacsecMinute15secytxHistory.MacsecMinute15secytxTimeLineInstances.MacsecMinute15secytxTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support', 'sample_count'], name, value)


                                            class OutPktsProtected(Entity):
                                                """
                                                Out Packets Protected
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secytxHistories.MacsecMinute15secytxHistory.MacsecMinute15secytxTimeLineInstances.MacsecMinute15secytxTimeLineInstance.OutPktsProtected, self).__init__()

                                                    self.yang_name = "out-pkts-protected"
                                                    self.yang_parent_name = "macsec-minute15secytx-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-pkts-protected"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secytxHistories.MacsecMinute15secytxHistory.MacsecMinute15secytxTimeLineInstances.MacsecMinute15secytxTimeLineInstance.OutPktsProtected, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutPktsEncrypted(Entity):
                                                """
                                                Out Packets Encrypted
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secytxHistories.MacsecMinute15secytxHistory.MacsecMinute15secytxTimeLineInstances.MacsecMinute15secytxTimeLineInstance.OutPktsEncrypted, self).__init__()

                                                    self.yang_name = "out-pkts-encrypted"
                                                    self.yang_parent_name = "macsec-minute15secytx-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-pkts-encrypted"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secytxHistories.MacsecMinute15secytxHistory.MacsecMinute15secytxTimeLineInstances.MacsecMinute15secytxTimeLineInstance.OutPktsEncrypted, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutOctetsProtected(Entity):
                                                """
                                                Out Octets Protected 
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secytxHistories.MacsecMinute15secytxHistory.MacsecMinute15secytxTimeLineInstances.MacsecMinute15secytxTimeLineInstance.OutOctetsProtected, self).__init__()

                                                    self.yang_name = "out-octets-protected"
                                                    self.yang_parent_name = "macsec-minute15secytx-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-octets-protected"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secytxHistories.MacsecMinute15secytxHistory.MacsecMinute15secytxTimeLineInstances.MacsecMinute15secytxTimeLineInstance.OutOctetsProtected, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutOctetsEncrypted(Entity):
                                                """
                                                Out Octets Encrypted
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secytxHistories.MacsecMinute15secytxHistory.MacsecMinute15secytxTimeLineInstances.MacsecMinute15secytxTimeLineInstance.OutOctetsEncrypted, self).__init__()

                                                    self.yang_name = "out-octets-encrypted"
                                                    self.yang_parent_name = "macsec-minute15secytx-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-octets-encrypted"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secytxHistories.MacsecMinute15secytxHistory.MacsecMinute15secytxTimeLineInstances.MacsecMinute15secytxTimeLineInstance.OutOctetsEncrypted, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutPktsTooLong(Entity):
                                                """
                                                Out Packets Too Long
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secytxHistories.MacsecMinute15secytxHistory.MacsecMinute15secytxTimeLineInstances.MacsecMinute15secytxTimeLineInstance.OutPktsTooLong, self).__init__()

                                                    self.yang_name = "out-pkts-too-long"
                                                    self.yang_parent_name = "macsec-minute15secytx-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-pkts-too-long"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secytxHistories.MacsecMinute15secytxHistory.MacsecMinute15secytxTimeLineInstances.MacsecMinute15secytxTimeLineInstance.OutPktsTooLong, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                            class MacsecMinute15secyifHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: macsec_minute15secyif_history
                                
                                	port 15\-minute secy\_if performance data
                                	**type**\: list of  		 :py:class:`MacsecMinute15secyifHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories, self).__init__()

                                    self.yang_name = "macsec-minute15secyif-histories"
                                    self.yang_parent_name = "macsec-minute15-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("macsec-minute15secyif-history", ("macsec_minute15secyif_history", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory))])
                                    self._leafs = OrderedDict()

                                    self.macsec_minute15secyif_history = YList(self)
                                    self._segment_path = lambda: "macsec-minute15secyif-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories, [], name, value)


                                class MacsecMinute15secyifHistory(Entity):
                                    """
                                    port 15\-minute secy\_if performance data
                                    
                                    .. attribute:: number  (key)
                                    
                                    	channel number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: macsec_minute15secyif_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`MacsecMinute15secyifTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory, self).__init__()

                                        self.yang_name = "macsec-minute15secyif-history"
                                        self.yang_parent_name = "macsec-minute15secyif-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([("macsec-minute15secyif-time-line-instances", ("macsec_minute15secyif_time_line_instances", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ])
                                        self.number = None

                                        self.macsec_minute15secyif_time_line_instances = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances()
                                        self.macsec_minute15secyif_time_line_instances.parent = self
                                        self._children_name_map["macsec_minute15secyif_time_line_instances"] = "macsec-minute15secyif-time-line-instances"
                                        self._segment_path = lambda: "macsec-minute15secyif-history" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory, ['number'], name, value)


                                    class MacsecMinute15secyifTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: macsec_minute15secyif_time_line_instance
                                        
                                        	port 15\-minute secy\_if performance data by index
                                        	**type**\: list of  		 :py:class:`MacsecMinute15secyifTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances, self).__init__()

                                            self.yang_name = "macsec-minute15secyif-time-line-instances"
                                            self.yang_parent_name = "macsec-minute15secyif-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("macsec-minute15secyif-time-line-instance", ("macsec_minute15secyif_time_line_instance", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.macsec_minute15secyif_time_line_instance = YList(self)
                                            self._segment_path = lambda: "macsec-minute15secyif-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances, [], name, value)


                                        class MacsecMinute15secyifTimeLineInstance(Entity):
                                            """
                                            port 15\-minute secy\_if performance data
                                            by index
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: in_pkts_untagged
                                            
                                            	In Packet Untagged
                                            	**type**\:  :py:class:`InPktsUntagged <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.InPktsUntagged>`
                                            
                                            .. attribute:: in_pkts_no_tag
                                            
                                            	In Packet No tag
                                            	**type**\:  :py:class:`InPktsNoTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.InPktsNoTag>`
                                            
                                            .. attribute:: in_pkts_bad_tag
                                            
                                            	In Packet Bad tag
                                            	**type**\:  :py:class:`InPktsBadTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.InPktsBadTag>`
                                            
                                            .. attribute:: in_pkts_unknown_sci
                                            
                                            	In Packet Unknown sci
                                            	**type**\:  :py:class:`InPktsUnknownSci <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.InPktsUnknownSci>`
                                            
                                            .. attribute:: in_pkts_no_sci
                                            
                                            	In Packet No sci
                                            	**type**\:  :py:class:`InPktsNoSci <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.InPktsNoSci>`
                                            
                                            .. attribute:: in_pkts_overrun
                                            
                                            	In Packet Overrun
                                            	**type**\:  :py:class:`InPktsOverrun <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.InPktsOverrun>`
                                            
                                            .. attribute:: in_octets_validated
                                            
                                            	In Octet Validated
                                            	**type**\:  :py:class:`InOctetsValidated <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.InOctetsValidated>`
                                            
                                            .. attribute:: in_octets_decrypted
                                            
                                            	In Octet Decrypted
                                            	**type**\:  :py:class:`InOctetsDecrypted <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.InOctetsDecrypted>`
                                            
                                            .. attribute:: out_pkts_untagged
                                            
                                            	Out Packet Untagged
                                            	**type**\:  :py:class:`OutPktsUntagged <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.OutPktsUntagged>`
                                            
                                            .. attribute:: out_pkts_too_long
                                            
                                            	Out Packet Too Long
                                            	**type**\:  :py:class:`OutPktsTooLong <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.OutPktsTooLong>`
                                            
                                            .. attribute:: out_octets_protected
                                            
                                            	Out Octet Protected
                                            	**type**\:  :py:class:`OutOctetsProtected <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.OutOctetsProtected>`
                                            
                                            .. attribute:: out_octets_encrypted
                                            
                                            	Out Octet encrypted
                                            	**type**\:  :py:class:`OutOctetsEncrypted <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.OutOctetsEncrypted>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\: bool
                                            
                                            .. attribute:: sample_count
                                            
                                            	Running Sample Count
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance, self).__init__()

                                                self.yang_name = "macsec-minute15secyif-time-line-instance"
                                                self.yang_parent_name = "macsec-minute15secyif-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("in-pkts-untagged", ("in_pkts_untagged", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.InPktsUntagged)), ("in-pkts-no-tag", ("in_pkts_no_tag", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.InPktsNoTag)), ("in-pkts-bad-tag", ("in_pkts_bad_tag", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.InPktsBadTag)), ("in-pkts-unknown-sci", ("in_pkts_unknown_sci", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.InPktsUnknownSci)), ("in-pkts-no-sci", ("in_pkts_no_sci", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.InPktsNoSci)), ("in-pkts-overrun", ("in_pkts_overrun", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.InPktsOverrun)), ("in-octets-validated", ("in_octets_validated", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.InOctetsValidated)), ("in-octets-decrypted", ("in_octets_decrypted", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.InOctetsDecrypted)), ("out-pkts-untagged", ("out_pkts_untagged", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.OutPktsUntagged)), ("out-pkts-too-long", ("out_pkts_too_long", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.OutPktsTooLong)), ("out-octets-protected", ("out_octets_protected", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.OutOctetsProtected)), ("out-octets-encrypted", ("out_octets_encrypted", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.OutOctetsEncrypted))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                    ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                                    ('sample_count', (YLeaf(YType.uint64, 'sample-count'), ['int'])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear24_hr_time = None
                                                self.sec30_support = None
                                                self.sample_count = None

                                                self.in_pkts_untagged = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.InPktsUntagged()
                                                self.in_pkts_untagged.parent = self
                                                self._children_name_map["in_pkts_untagged"] = "in-pkts-untagged"

                                                self.in_pkts_no_tag = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.InPktsNoTag()
                                                self.in_pkts_no_tag.parent = self
                                                self._children_name_map["in_pkts_no_tag"] = "in-pkts-no-tag"

                                                self.in_pkts_bad_tag = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.InPktsBadTag()
                                                self.in_pkts_bad_tag.parent = self
                                                self._children_name_map["in_pkts_bad_tag"] = "in-pkts-bad-tag"

                                                self.in_pkts_unknown_sci = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.InPktsUnknownSci()
                                                self.in_pkts_unknown_sci.parent = self
                                                self._children_name_map["in_pkts_unknown_sci"] = "in-pkts-unknown-sci"

                                                self.in_pkts_no_sci = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.InPktsNoSci()
                                                self.in_pkts_no_sci.parent = self
                                                self._children_name_map["in_pkts_no_sci"] = "in-pkts-no-sci"

                                                self.in_pkts_overrun = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.InPktsOverrun()
                                                self.in_pkts_overrun.parent = self
                                                self._children_name_map["in_pkts_overrun"] = "in-pkts-overrun"

                                                self.in_octets_validated = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.InOctetsValidated()
                                                self.in_octets_validated.parent = self
                                                self._children_name_map["in_octets_validated"] = "in-octets-validated"

                                                self.in_octets_decrypted = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.InOctetsDecrypted()
                                                self.in_octets_decrypted.parent = self
                                                self._children_name_map["in_octets_decrypted"] = "in-octets-decrypted"

                                                self.out_pkts_untagged = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.OutPktsUntagged()
                                                self.out_pkts_untagged.parent = self
                                                self._children_name_map["out_pkts_untagged"] = "out-pkts-untagged"

                                                self.out_pkts_too_long = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.OutPktsTooLong()
                                                self.out_pkts_too_long.parent = self
                                                self._children_name_map["out_pkts_too_long"] = "out-pkts-too-long"

                                                self.out_octets_protected = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.OutOctetsProtected()
                                                self.out_octets_protected.parent = self
                                                self._children_name_map["out_octets_protected"] = "out-octets-protected"

                                                self.out_octets_encrypted = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.OutOctetsEncrypted()
                                                self.out_octets_encrypted.parent = self
                                                self._children_name_map["out_octets_encrypted"] = "out-octets-encrypted"
                                                self._segment_path = lambda: "macsec-minute15secyif-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support', 'sample_count'], name, value)


                                            class InPktsUntagged(Entity):
                                                """
                                                In Packet Untagged
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.InPktsUntagged, self).__init__()

                                                    self.yang_name = "in-pkts-untagged"
                                                    self.yang_parent_name = "macsec-minute15secyif-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts-untagged"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.InPktsUntagged, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPktsNoTag(Entity):
                                                """
                                                In Packet No tag
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.InPktsNoTag, self).__init__()

                                                    self.yang_name = "in-pkts-no-tag"
                                                    self.yang_parent_name = "macsec-minute15secyif-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts-no-tag"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.InPktsNoTag, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPktsBadTag(Entity):
                                                """
                                                In Packet Bad tag
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.InPktsBadTag, self).__init__()

                                                    self.yang_name = "in-pkts-bad-tag"
                                                    self.yang_parent_name = "macsec-minute15secyif-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts-bad-tag"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.InPktsBadTag, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPktsUnknownSci(Entity):
                                                """
                                                In Packet Unknown sci
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.InPktsUnknownSci, self).__init__()

                                                    self.yang_name = "in-pkts-unknown-sci"
                                                    self.yang_parent_name = "macsec-minute15secyif-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts-unknown-sci"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.InPktsUnknownSci, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPktsNoSci(Entity):
                                                """
                                                In Packet No sci
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.InPktsNoSci, self).__init__()

                                                    self.yang_name = "in-pkts-no-sci"
                                                    self.yang_parent_name = "macsec-minute15secyif-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts-no-sci"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.InPktsNoSci, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPktsOverrun(Entity):
                                                """
                                                In Packet Overrun
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.InPktsOverrun, self).__init__()

                                                    self.yang_name = "in-pkts-overrun"
                                                    self.yang_parent_name = "macsec-minute15secyif-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts-overrun"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.InPktsOverrun, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InOctetsValidated(Entity):
                                                """
                                                In Octet Validated
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.InOctetsValidated, self).__init__()

                                                    self.yang_name = "in-octets-validated"
                                                    self.yang_parent_name = "macsec-minute15secyif-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-octets-validated"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.InOctetsValidated, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InOctetsDecrypted(Entity):
                                                """
                                                In Octet Decrypted
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.InOctetsDecrypted, self).__init__()

                                                    self.yang_name = "in-octets-decrypted"
                                                    self.yang_parent_name = "macsec-minute15secyif-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-octets-decrypted"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.InOctetsDecrypted, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutPktsUntagged(Entity):
                                                """
                                                Out Packet Untagged
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.OutPktsUntagged, self).__init__()

                                                    self.yang_name = "out-pkts-untagged"
                                                    self.yang_parent_name = "macsec-minute15secyif-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-pkts-untagged"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.OutPktsUntagged, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutPktsTooLong(Entity):
                                                """
                                                Out Packet Too Long
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.OutPktsTooLong, self).__init__()

                                                    self.yang_name = "out-pkts-too-long"
                                                    self.yang_parent_name = "macsec-minute15secyif-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-pkts-too-long"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.OutPktsTooLong, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutOctetsProtected(Entity):
                                                """
                                                Out Octet Protected
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.OutOctetsProtected, self).__init__()

                                                    self.yang_name = "out-octets-protected"
                                                    self.yang_parent_name = "macsec-minute15secyif-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-octets-protected"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.OutOctetsProtected, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutOctetsEncrypted(Entity):
                                                """
                                                Out Octet encrypted
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.OutOctetsEncrypted, self).__init__()

                                                    self.yang_name = "out-octets-encrypted"
                                                    self.yang_parent_name = "macsec-minute15secyif-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-octets-encrypted"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecMinute15History.MacsecMinute15secyifHistories.MacsecMinute15secyifHistory.MacsecMinute15secyifTimeLineInstances.MacsecMinute15secyifTimeLineInstance.OutOctetsEncrypted, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                        class MacsecHour24History(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: macsec_hour24_ether_histories
                            
                            	port current performance data
                            	**type**\:  :py:class:`MacsecHour24EtherHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories>`
                            
                            .. attribute:: macsec_hour24secytx_histories
                            
                            	port current performance data
                            	**type**\:  :py:class:`MacsecHour24secytxHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secytxHistories>`
                            
                            .. attribute:: macsec_hour24secyif_histories
                            
                            	port current performance data
                            	**type**\:  :py:class:`MacsecHour24secyifHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories>`
                            
                            .. attribute:: macsec_hour24secyrx_histories
                            
                            	port current performance data
                            	**type**\:  :py:class:`MacsecHour24secyrxHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History, self).__init__()

                                self.yang_name = "macsec-hour24-history"
                                self.yang_parent_name = "macsec-port-history"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("macsec-hour24-ether-histories", ("macsec_hour24_ether_histories", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories)), ("macsec-hour24secytx-histories", ("macsec_hour24secytx_histories", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secytxHistories)), ("macsec-hour24secyif-histories", ("macsec_hour24secyif_histories", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories)), ("macsec-hour24secyrx-histories", ("macsec_hour24secyrx_histories", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories))])
                                self._leafs = OrderedDict()

                                self.macsec_hour24_ether_histories = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories()
                                self.macsec_hour24_ether_histories.parent = self
                                self._children_name_map["macsec_hour24_ether_histories"] = "macsec-hour24-ether-histories"

                                self.macsec_hour24secytx_histories = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secytxHistories()
                                self.macsec_hour24secytx_histories.parent = self
                                self._children_name_map["macsec_hour24secytx_histories"] = "macsec-hour24secytx-histories"

                                self.macsec_hour24secyif_histories = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories()
                                self.macsec_hour24secyif_histories.parent = self
                                self._children_name_map["macsec_hour24secyif_histories"] = "macsec-hour24secyif-histories"

                                self.macsec_hour24secyrx_histories = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories()
                                self.macsec_hour24secyrx_histories.parent = self
                                self._children_name_map["macsec_hour24secyrx_histories"] = "macsec-hour24secyrx-histories"
                                self._segment_path = lambda: "macsec-hour24-history"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History, [], name, value)


                            class MacsecHour24EtherHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: macsec_hour24_ether_history
                                
                                	port 24 hour ether performance data
                                	**type**\: list of  		 :py:class:`MacsecHour24EtherHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories, self).__init__()

                                    self.yang_name = "macsec-hour24-ether-histories"
                                    self.yang_parent_name = "macsec-hour24-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("macsec-hour24-ether-history", ("macsec_hour24_ether_history", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory))])
                                    self._leafs = OrderedDict()

                                    self.macsec_hour24_ether_history = YList(self)
                                    self._segment_path = lambda: "macsec-hour24-ether-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories, [], name, value)


                                class MacsecHour24EtherHistory(Entity):
                                    """
                                    port 24 hour ether performance data
                                    
                                    .. attribute:: number  (key)
                                    
                                    	channel number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: macsec_hour24_ether_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`MacsecHour24EtherTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory, self).__init__()

                                        self.yang_name = "macsec-hour24-ether-history"
                                        self.yang_parent_name = "macsec-hour24-ether-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([("macsec-hour24-ether-time-line-instances", ("macsec_hour24_ether_time_line_instances", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ])
                                        self.number = None

                                        self.macsec_hour24_ether_time_line_instances = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances()
                                        self.macsec_hour24_ether_time_line_instances.parent = self
                                        self._children_name_map["macsec_hour24_ether_time_line_instances"] = "macsec-hour24-ether-time-line-instances"
                                        self._segment_path = lambda: "macsec-hour24-ether-history" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory, ['number'], name, value)


                                    class MacsecHour24EtherTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: macsec_hour24_ether_time_line_instance
                                        
                                        	port 24 hour ether performance data
                                        	**type**\: list of  		 :py:class:`MacsecHour24EtherTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances, self).__init__()

                                            self.yang_name = "macsec-hour24-ether-time-line-instances"
                                            self.yang_parent_name = "macsec-hour24-ether-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("macsec-hour24-ether-time-line-instance", ("macsec_hour24_ether_time_line_instance", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.macsec_hour24_ether_time_line_instance = YList(self)
                                            self._segment_path = lambda: "macsec-hour24-ether-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances, [], name, value)


                                        class MacsecHour24EtherTimeLineInstance(Entity):
                                            """
                                            port 24 hour ether performance data
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rx_pkt
                                            
                                            	RX PKT
                                            	**type**\:  :py:class:`RxPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.RxPkt>`
                                            
                                            .. attribute:: stat_pkt
                                            
                                            	STAT PKT
                                            	**type**\:  :py:class:`StatPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.StatPkt>`
                                            
                                            .. attribute:: octet_stat
                                            
                                            	OCTET STAT
                                            	**type**\:  :py:class:`OctetStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OctetStat>`
                                            
                                            .. attribute:: oversize_pkt_stat
                                            
                                            	OVERSIZE PKT
                                            	**type**\:  :py:class:`OversizePktStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OversizePktStat>`
                                            
                                            .. attribute:: fcs_errors_stat
                                            
                                            	FCS ERR
                                            	**type**\:  :py:class:`FcsErrorsStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.FcsErrorsStat>`
                                            
                                            .. attribute:: long_frames_stat
                                            
                                            	LONG FRAMES
                                            	**type**\:  :py:class:`LongFramesStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.LongFramesStat>`
                                            
                                            .. attribute:: jabber_stat
                                            
                                            	JABBER STATS
                                            	**type**\:  :py:class:`JabberStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.JabberStat>`
                                            
                                            .. attribute:: ether64_octets
                                            
                                            	SIXTY FOUR OCTET
                                            	**type**\:  :py:class:`Ether64Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.Ether64Octets>`
                                            
                                            .. attribute:: ether65127_octet
                                            
                                            	OCTET
                                            	**type**\:  :py:class:`Ether65127Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.Ether65127Octet>`
                                            
                                            .. attribute:: ether128255_octet
                                            
                                            	TFF OCTET
                                            	**type**\:  :py:class:`Ether128255Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.Ether128255Octet>`
                                            
                                            .. attribute:: ether256511_octet
                                            
                                            	FOO OCTET
                                            	**type**\:  :py:class:`Ether256511Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.Ether256511Octet>`
                                            
                                            .. attribute:: ether5121023_octet
                                            
                                            	OZTT OCTET
                                            	**type**\:  :py:class:`Ether5121023Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.Ether5121023Octet>`
                                            
                                            .. attribute:: ether10241518_octet
                                            
                                            	OFO OCTET
                                            	**type**\:  :py:class:`Ether10241518Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.Ether10241518Octet>`
                                            
                                            .. attribute:: in_ucast_pkt
                                            
                                            	IN UCAST
                                            	**type**\:  :py:class:`InUcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InUcastPkt>`
                                            
                                            .. attribute:: in_mcast_pkt
                                            
                                            	IN MCAST
                                            	**type**\:  :py:class:`InMcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InMcastPkt>`
                                            
                                            .. attribute:: in_bcast_pkt
                                            
                                            	IN BCAST
                                            	**type**\:  :py:class:`InBcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InBcastPkt>`
                                            
                                            .. attribute:: out_ucast_pkt
                                            
                                            	OUT UCAST
                                            	**type**\:  :py:class:`OutUcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutUcastPkt>`
                                            
                                            .. attribute:: out_bcast_pkt
                                            
                                            	OUT BCAST
                                            	**type**\:  :py:class:`OutBcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutBcastPkt>`
                                            
                                            .. attribute:: out_mcast_pkt
                                            
                                            	OUT MCAST
                                            	**type**\:  :py:class:`OutMcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutMcastPkt>`
                                            
                                            .. attribute:: tx_pkt
                                            
                                            	TX PKT
                                            	**type**\:  :py:class:`TxPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.TxPkt>`
                                            
                                            .. attribute:: if_in_errors
                                            
                                            	IFIN ERRORS
                                            	**type**\:  :py:class:`IfInErrors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.IfInErrors>`
                                            
                                            .. attribute:: if_in_octets
                                            
                                            	IFIN OCTETS
                                            	**type**\:  :py:class:`IfInOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.IfInOctets>`
                                            
                                            .. attribute:: ether_stat_multicast_pkt
                                            
                                            	ETHER STAT MULTICAST PKT
                                            	**type**\:  :py:class:`EtherStatMulticastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.EtherStatMulticastPkt>`
                                            
                                            .. attribute:: ether_stat_broadcast_pkt
                                            
                                            	ETHER STAT BROADCAST PKT
                                            	**type**\:  :py:class:`EtherStatBroadcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.EtherStatBroadcastPkt>`
                                            
                                            .. attribute:: ether_stat_undersized_pkt
                                            
                                            	ETHER STAT UNDERSIZED PKT
                                            	**type**\:  :py:class:`EtherStatUndersizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.EtherStatUndersizedPkt>`
                                            
                                            .. attribute:: out_octets
                                            
                                            	OUT OCTET
                                            	**type**\:  :py:class:`OutOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutOctets>`
                                            
                                            .. attribute:: in_pause_frame
                                            
                                            	INPUT PAUSE FRAME
                                            	**type**\:  :py:class:`InPauseFrame <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InPauseFrame>`
                                            
                                            .. attribute:: in_good_bytes
                                            
                                            	INPUT GOOD BYTES
                                            	**type**\:  :py:class:`InGoodBytes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InGoodBytes>`
                                            
                                            .. attribute:: in8021q_frames
                                            
                                            	INPUT 802 1Q FRAMES
                                            	**type**\:  :py:class:`In8021qFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.In8021qFrames>`
                                            
                                            .. attribute:: in_pkts1519_max_octets
                                            
                                            	INPUT PKTS 1519MAX OCTETS
                                            	**type**\:  :py:class:`InPkts1519MaxOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InPkts1519MaxOctets>`
                                            
                                            .. attribute:: in_good_pkts
                                            
                                            	INPUT GOOD PKTS
                                            	**type**\:  :py:class:`InGoodPkts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InGoodPkts>`
                                            
                                            .. attribute:: in_drop_overrun
                                            
                                            	INPUT DROP OVERRUN
                                            	**type**\:  :py:class:`InDropOverrun <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InDropOverrun>`
                                            
                                            .. attribute:: in_drop_abort
                                            
                                            	INPUT DROP ABORT
                                            	**type**\:  :py:class:`InDropAbort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InDropAbort>`
                                            
                                            .. attribute:: in_drop_invalid_vlan
                                            
                                            	INPUT DROP INVALID VLAN
                                            	**type**\:  :py:class:`InDropInvalidVlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InDropInvalidVlan>`
                                            
                                            .. attribute:: in_drop_invalid_dmac
                                            
                                            	INPUT DROP INVALID DMAC
                                            	**type**\:  :py:class:`InDropInvalidDmac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InDropInvalidDmac>`
                                            
                                            .. attribute:: in_drop_invalid_encap
                                            
                                            	INPUT DROP INVALID ENCAP
                                            	**type**\:  :py:class:`InDropInvalidEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InDropInvalidEncap>`
                                            
                                            .. attribute:: in_drop_other
                                            
                                            	INPUT DROP OTHER
                                            	**type**\:  :py:class:`InDropOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InDropOther>`
                                            
                                            .. attribute:: in_mib_giant
                                            
                                            	INPUT MIB GIANT
                                            	**type**\:  :py:class:`InMibGiant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InMibGiant>`
                                            
                                            .. attribute:: in_mib_jabber
                                            
                                            	INPUT MIB JABBER
                                            	**type**\:  :py:class:`InMibJabber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InMibJabber>`
                                            
                                            .. attribute:: in_mibcrc
                                            
                                            	IN MIB CRC
                                            	**type**\:  :py:class:`InMibcrc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InMibcrc>`
                                            
                                            .. attribute:: in_error_collisions
                                            
                                            	IN ERROR COLLISIONS
                                            	**type**\:  :py:class:`InErrorCollisions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InErrorCollisions>`
                                            
                                            .. attribute:: in_error_symbol
                                            
                                            	IN ERROR SYMBOL
                                            	**type**\:  :py:class:`InErrorSymbol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InErrorSymbol>`
                                            
                                            .. attribute:: out_good_bytes
                                            
                                            	OUT GOOD BYTES
                                            	**type**\:  :py:class:`OutGoodBytes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutGoodBytes>`
                                            
                                            .. attribute:: out8021q_frames
                                            
                                            	OUT 802 1Q FRAMES
                                            	**type**\:  :py:class:`Out8021qFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.Out8021qFrames>`
                                            
                                            .. attribute:: out_pause_frames
                                            
                                            	OUT PAUSE FRAMES
                                            	**type**\:  :py:class:`OutPauseFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutPauseFrames>`
                                            
                                            .. attribute:: out_pkts1519_max_octets
                                            
                                            	OUT PKTS 1519 MAX OCTETS
                                            	**type**\:  :py:class:`OutPkts1519MaxOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutPkts1519MaxOctets>`
                                            
                                            .. attribute:: out_good_pkts
                                            
                                            	OUT GOOD PKTS
                                            	**type**\:  :py:class:`OutGoodPkts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutGoodPkts>`
                                            
                                            .. attribute:: out_drop_underrun
                                            
                                            	OUT DROP UNDERRUN
                                            	**type**\:  :py:class:`OutDropUnderrun <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutDropUnderrun>`
                                            
                                            .. attribute:: out_drop_abort
                                            
                                            	OUT DROP ABORT
                                            	**type**\:  :py:class:`OutDropAbort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutDropAbort>`
                                            
                                            .. attribute:: out_drop_other
                                            
                                            	OUT DROP OTHER
                                            	**type**\:  :py:class:`OutDropOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutDropOther>`
                                            
                                            .. attribute:: out_error_other
                                            
                                            	OUT ERROR OTHER
                                            	**type**\:  :py:class:`OutErrorOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutErrorOther>`
                                            
                                            .. attribute:: in_error_giant
                                            
                                            	IN ERROR GIANT
                                            	**type**\:  :py:class:`InErrorGiant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InErrorGiant>`
                                            
                                            .. attribute:: in_error_runt
                                            
                                            	IN ERROR RUNT
                                            	**type**\:  :py:class:`InErrorRunt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InErrorRunt>`
                                            
                                            .. attribute:: in_error_jabbers
                                            
                                            	IN ERROR JABBERS
                                            	**type**\:  :py:class:`InErrorJabbers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InErrorJabbers>`
                                            
                                            .. attribute:: in_error_fragments
                                            
                                            	IN ERROR FRAGMENTS
                                            	**type**\:  :py:class:`InErrorFragments <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InErrorFragments>`
                                            
                                            .. attribute:: in_error_other
                                            
                                            	IN ERROR OTHER
                                            	**type**\:  :py:class:`InErrorOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InErrorOther>`
                                            
                                            .. attribute:: in_pkt64_octet
                                            
                                            	IN PKT 64 OCTET
                                            	**type**\:  :py:class:`InPkt64Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InPkt64Octet>`
                                            
                                            .. attribute:: in_pkts65_to127_octets
                                            
                                            	IN PKTS 65 127OCTETS
                                            	**type**\:  :py:class:`InPkts65To127Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InPkts65To127Octets>`
                                            
                                            .. attribute:: in_pkts128_to255_octets
                                            
                                            	IN PKTS 128 255 OCTETS
                                            	**type**\:  :py:class:`InPkts128To255Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InPkts128To255Octets>`
                                            
                                            .. attribute:: in_pkts256_to511_octets
                                            
                                            	IN PKTS 256 511 OCTETS
                                            	**type**\:  :py:class:`InPkts256To511Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InPkts256To511Octets>`
                                            
                                            .. attribute:: in_pkts512_to1023_octets
                                            
                                            	IN PKTS 512 1023 OCTETS
                                            	**type**\:  :py:class:`InPkts512To1023Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InPkts512To1023Octets>`
                                            
                                            .. attribute:: in_pkts1024_to1518_octets
                                            
                                            	IN PKTS 1024 1518 OCTETS
                                            	**type**\:  :py:class:`InPkts1024To1518Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InPkts1024To1518Octets>`
                                            
                                            .. attribute:: outpkt64octet
                                            
                                            	OUT PKT 64 OCTET
                                            	**type**\:  :py:class:`Outpkt64octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.Outpkt64octet>`
                                            
                                            .. attribute:: out_pkts65127_octets
                                            
                                            	OUT PKTS 65 127OCTETS
                                            	**type**\:  :py:class:`OutPkts65127Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutPkts65127Octets>`
                                            
                                            .. attribute:: out_pkts128255_octets
                                            
                                            	OUT PKTS 128 255 OCTETS
                                            	**type**\:  :py:class:`OutPkts128255Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutPkts128255Octets>`
                                            
                                            .. attribute:: out_pkts256511_octets
                                            
                                            	OUT PKTS 256 511 OCTETS
                                            	**type**\:  :py:class:`OutPkts256511Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutPkts256511Octets>`
                                            
                                            .. attribute:: out_pkts5121023_octets
                                            
                                            	OUT PKTS 512 1023 OCTETS
                                            	**type**\:  :py:class:`OutPkts5121023Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutPkts5121023Octets>`
                                            
                                            .. attribute:: out_pkts10241518_octets
                                            
                                            	OUT PKTS 1024 1518 OCTETS
                                            	**type**\:  :py:class:`OutPkts10241518Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutPkts10241518Octets>`
                                            
                                            .. attribute:: rx_util
                                            
                                            	Rx Utilization in Percent
                                            	**type**\:  :py:class:`RxUtil <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.RxUtil>`
                                            
                                            .. attribute:: tx_util
                                            
                                            	Tx Utilization in Percent
                                            	**type**\:  :py:class:`TxUtil <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.TxUtil>`
                                            
                                            .. attribute:: tx_undersized_pkt
                                            
                                            	TX Undersized Pkt
                                            	**type**\:  :py:class:`TxUndersizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.TxUndersizedPkt>`
                                            
                                            .. attribute:: tx_oversized_pkt
                                            
                                            	TX Oversized Pkt
                                            	**type**\:  :py:class:`TxOversizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.TxOversizedPkt>`
                                            
                                            .. attribute:: tx_fragments
                                            
                                            	TX Fragments
                                            	**type**\:  :py:class:`TxFragments <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.TxFragments>`
                                            
                                            .. attribute:: tx_jabber
                                            
                                            	TX Jabber
                                            	**type**\:  :py:class:`TxJabber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.TxJabber>`
                                            
                                            .. attribute:: tx_bad_fcs
                                            
                                            	TX Bad Fcs
                                            	**type**\:  :py:class:`TxBadFcs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.TxBadFcs>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance, self).__init__()

                                                self.yang_name = "macsec-hour24-ether-time-line-instance"
                                                self.yang_parent_name = "macsec-hour24-ether-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("rx-pkt", ("rx_pkt", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.RxPkt)), ("stat-pkt", ("stat_pkt", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.StatPkt)), ("octet-stat", ("octet_stat", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OctetStat)), ("oversize-pkt-stat", ("oversize_pkt_stat", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OversizePktStat)), ("fcs-errors-stat", ("fcs_errors_stat", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.FcsErrorsStat)), ("long-frames-stat", ("long_frames_stat", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.LongFramesStat)), ("jabber-stat", ("jabber_stat", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.JabberStat)), ("ether64-octets", ("ether64_octets", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.Ether64Octets)), ("ether65127-octet", ("ether65127_octet", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.Ether65127Octet)), ("ether128255-octet", ("ether128255_octet", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.Ether128255Octet)), ("ether256511-octet", ("ether256511_octet", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.Ether256511Octet)), ("ether5121023-octet", ("ether5121023_octet", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.Ether5121023Octet)), ("ether10241518-octet", ("ether10241518_octet", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.Ether10241518Octet)), ("in-ucast-pkt", ("in_ucast_pkt", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InUcastPkt)), ("in-mcast-pkt", ("in_mcast_pkt", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InMcastPkt)), ("in-bcast-pkt", ("in_bcast_pkt", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InBcastPkt)), ("out-ucast-pkt", ("out_ucast_pkt", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutUcastPkt)), ("out-bcast-pkt", ("out_bcast_pkt", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutBcastPkt)), ("out-mcast-pkt", ("out_mcast_pkt", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutMcastPkt)), ("tx-pkt", ("tx_pkt", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.TxPkt)), ("if-in-errors", ("if_in_errors", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.IfInErrors)), ("if-in-octets", ("if_in_octets", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.IfInOctets)), ("ether-stat-multicast-pkt", ("ether_stat_multicast_pkt", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.EtherStatMulticastPkt)), ("ether-stat-broadcast-pkt", ("ether_stat_broadcast_pkt", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.EtherStatBroadcastPkt)), ("ether-stat-undersized-pkt", ("ether_stat_undersized_pkt", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.EtherStatUndersizedPkt)), ("out-octets", ("out_octets", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutOctets)), ("in-pause-frame", ("in_pause_frame", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InPauseFrame)), ("in-good-bytes", ("in_good_bytes", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InGoodBytes)), ("in8021q-frames", ("in8021q_frames", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.In8021qFrames)), ("in-pkts1519-max-octets", ("in_pkts1519_max_octets", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InPkts1519MaxOctets)), ("in-good-pkts", ("in_good_pkts", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InGoodPkts)), ("in-drop-overrun", ("in_drop_overrun", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InDropOverrun)), ("in-drop-abort", ("in_drop_abort", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InDropAbort)), ("in-drop-invalid-vlan", ("in_drop_invalid_vlan", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InDropInvalidVlan)), ("in-drop-invalid-dmac", ("in_drop_invalid_dmac", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InDropInvalidDmac)), ("in-drop-invalid-encap", ("in_drop_invalid_encap", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InDropInvalidEncap)), ("in-drop-other", ("in_drop_other", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InDropOther)), ("in-mib-giant", ("in_mib_giant", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InMibGiant)), ("in-mib-jabber", ("in_mib_jabber", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InMibJabber)), ("in-mibcrc", ("in_mibcrc", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InMibcrc)), ("in-error-collisions", ("in_error_collisions", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InErrorCollisions)), ("in-error-symbol", ("in_error_symbol", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InErrorSymbol)), ("out-good-bytes", ("out_good_bytes", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutGoodBytes)), ("out8021q-frames", ("out8021q_frames", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.Out8021qFrames)), ("out-pause-frames", ("out_pause_frames", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutPauseFrames)), ("out-pkts1519-max-octets", ("out_pkts1519_max_octets", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutPkts1519MaxOctets)), ("out-good-pkts", ("out_good_pkts", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutGoodPkts)), ("out-drop-underrun", ("out_drop_underrun", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutDropUnderrun)), ("out-drop-abort", ("out_drop_abort", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutDropAbort)), ("out-drop-other", ("out_drop_other", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutDropOther)), ("out-error-other", ("out_error_other", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutErrorOther)), ("in-error-giant", ("in_error_giant", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InErrorGiant)), ("in-error-runt", ("in_error_runt", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InErrorRunt)), ("in-error-jabbers", ("in_error_jabbers", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InErrorJabbers)), ("in-error-fragments", ("in_error_fragments", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InErrorFragments)), ("in-error-other", ("in_error_other", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InErrorOther)), ("in-pkt64-octet", ("in_pkt64_octet", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InPkt64Octet)), ("in-pkts65-to127-octets", ("in_pkts65_to127_octets", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InPkts65To127Octets)), ("in-pkts128-to255-octets", ("in_pkts128_to255_octets", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InPkts128To255Octets)), ("in-pkts256-to511-octets", ("in_pkts256_to511_octets", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InPkts256To511Octets)), ("in-pkts512-to1023-octets", ("in_pkts512_to1023_octets", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InPkts512To1023Octets)), ("in-pkts1024-to1518-octets", ("in_pkts1024_to1518_octets", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InPkts1024To1518Octets)), ("outpkt64octet", ("outpkt64octet", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.Outpkt64octet)), ("out-pkts65127-octets", ("out_pkts65127_octets", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutPkts65127Octets)), ("out-pkts128255-octets", ("out_pkts128255_octets", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutPkts128255Octets)), ("out-pkts256511-octets", ("out_pkts256511_octets", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutPkts256511Octets)), ("out-pkts5121023-octets", ("out_pkts5121023_octets", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutPkts5121023Octets)), ("out-pkts10241518-octets", ("out_pkts10241518_octets", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutPkts10241518Octets)), ("rx-util", ("rx_util", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.RxUtil)), ("tx-util", ("tx_util", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.TxUtil)), ("tx-undersized-pkt", ("tx_undersized_pkt", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.TxUndersizedPkt)), ("tx-oversized-pkt", ("tx_oversized_pkt", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.TxOversizedPkt)), ("tx-fragments", ("tx_fragments", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.TxFragments)), ("tx-jabber", ("tx_jabber", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.TxJabber)), ("tx-bad-fcs", ("tx_bad_fcs", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.TxBadFcs))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                    ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None
                                                self.sec30_support = None

                                                self.rx_pkt = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.RxPkt()
                                                self.rx_pkt.parent = self
                                                self._children_name_map["rx_pkt"] = "rx-pkt"

                                                self.stat_pkt = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.StatPkt()
                                                self.stat_pkt.parent = self
                                                self._children_name_map["stat_pkt"] = "stat-pkt"

                                                self.octet_stat = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OctetStat()
                                                self.octet_stat.parent = self
                                                self._children_name_map["octet_stat"] = "octet-stat"

                                                self.oversize_pkt_stat = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OversizePktStat()
                                                self.oversize_pkt_stat.parent = self
                                                self._children_name_map["oversize_pkt_stat"] = "oversize-pkt-stat"

                                                self.fcs_errors_stat = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.FcsErrorsStat()
                                                self.fcs_errors_stat.parent = self
                                                self._children_name_map["fcs_errors_stat"] = "fcs-errors-stat"

                                                self.long_frames_stat = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.LongFramesStat()
                                                self.long_frames_stat.parent = self
                                                self._children_name_map["long_frames_stat"] = "long-frames-stat"

                                                self.jabber_stat = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.JabberStat()
                                                self.jabber_stat.parent = self
                                                self._children_name_map["jabber_stat"] = "jabber-stat"

                                                self.ether64_octets = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.Ether64Octets()
                                                self.ether64_octets.parent = self
                                                self._children_name_map["ether64_octets"] = "ether64-octets"

                                                self.ether65127_octet = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.Ether65127Octet()
                                                self.ether65127_octet.parent = self
                                                self._children_name_map["ether65127_octet"] = "ether65127-octet"

                                                self.ether128255_octet = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.Ether128255Octet()
                                                self.ether128255_octet.parent = self
                                                self._children_name_map["ether128255_octet"] = "ether128255-octet"

                                                self.ether256511_octet = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.Ether256511Octet()
                                                self.ether256511_octet.parent = self
                                                self._children_name_map["ether256511_octet"] = "ether256511-octet"

                                                self.ether5121023_octet = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.Ether5121023Octet()
                                                self.ether5121023_octet.parent = self
                                                self._children_name_map["ether5121023_octet"] = "ether5121023-octet"

                                                self.ether10241518_octet = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.Ether10241518Octet()
                                                self.ether10241518_octet.parent = self
                                                self._children_name_map["ether10241518_octet"] = "ether10241518-octet"

                                                self.in_ucast_pkt = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InUcastPkt()
                                                self.in_ucast_pkt.parent = self
                                                self._children_name_map["in_ucast_pkt"] = "in-ucast-pkt"

                                                self.in_mcast_pkt = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InMcastPkt()
                                                self.in_mcast_pkt.parent = self
                                                self._children_name_map["in_mcast_pkt"] = "in-mcast-pkt"

                                                self.in_bcast_pkt = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InBcastPkt()
                                                self.in_bcast_pkt.parent = self
                                                self._children_name_map["in_bcast_pkt"] = "in-bcast-pkt"

                                                self.out_ucast_pkt = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutUcastPkt()
                                                self.out_ucast_pkt.parent = self
                                                self._children_name_map["out_ucast_pkt"] = "out-ucast-pkt"

                                                self.out_bcast_pkt = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutBcastPkt()
                                                self.out_bcast_pkt.parent = self
                                                self._children_name_map["out_bcast_pkt"] = "out-bcast-pkt"

                                                self.out_mcast_pkt = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutMcastPkt()
                                                self.out_mcast_pkt.parent = self
                                                self._children_name_map["out_mcast_pkt"] = "out-mcast-pkt"

                                                self.tx_pkt = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.TxPkt()
                                                self.tx_pkt.parent = self
                                                self._children_name_map["tx_pkt"] = "tx-pkt"

                                                self.if_in_errors = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.IfInErrors()
                                                self.if_in_errors.parent = self
                                                self._children_name_map["if_in_errors"] = "if-in-errors"

                                                self.if_in_octets = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.IfInOctets()
                                                self.if_in_octets.parent = self
                                                self._children_name_map["if_in_octets"] = "if-in-octets"

                                                self.ether_stat_multicast_pkt = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.EtherStatMulticastPkt()
                                                self.ether_stat_multicast_pkt.parent = self
                                                self._children_name_map["ether_stat_multicast_pkt"] = "ether-stat-multicast-pkt"

                                                self.ether_stat_broadcast_pkt = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.EtherStatBroadcastPkt()
                                                self.ether_stat_broadcast_pkt.parent = self
                                                self._children_name_map["ether_stat_broadcast_pkt"] = "ether-stat-broadcast-pkt"

                                                self.ether_stat_undersized_pkt = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.EtherStatUndersizedPkt()
                                                self.ether_stat_undersized_pkt.parent = self
                                                self._children_name_map["ether_stat_undersized_pkt"] = "ether-stat-undersized-pkt"

                                                self.out_octets = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutOctets()
                                                self.out_octets.parent = self
                                                self._children_name_map["out_octets"] = "out-octets"

                                                self.in_pause_frame = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InPauseFrame()
                                                self.in_pause_frame.parent = self
                                                self._children_name_map["in_pause_frame"] = "in-pause-frame"

                                                self.in_good_bytes = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InGoodBytes()
                                                self.in_good_bytes.parent = self
                                                self._children_name_map["in_good_bytes"] = "in-good-bytes"

                                                self.in8021q_frames = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.In8021qFrames()
                                                self.in8021q_frames.parent = self
                                                self._children_name_map["in8021q_frames"] = "in8021q-frames"

                                                self.in_pkts1519_max_octets = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InPkts1519MaxOctets()
                                                self.in_pkts1519_max_octets.parent = self
                                                self._children_name_map["in_pkts1519_max_octets"] = "in-pkts1519-max-octets"

                                                self.in_good_pkts = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InGoodPkts()
                                                self.in_good_pkts.parent = self
                                                self._children_name_map["in_good_pkts"] = "in-good-pkts"

                                                self.in_drop_overrun = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InDropOverrun()
                                                self.in_drop_overrun.parent = self
                                                self._children_name_map["in_drop_overrun"] = "in-drop-overrun"

                                                self.in_drop_abort = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InDropAbort()
                                                self.in_drop_abort.parent = self
                                                self._children_name_map["in_drop_abort"] = "in-drop-abort"

                                                self.in_drop_invalid_vlan = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InDropInvalidVlan()
                                                self.in_drop_invalid_vlan.parent = self
                                                self._children_name_map["in_drop_invalid_vlan"] = "in-drop-invalid-vlan"

                                                self.in_drop_invalid_dmac = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InDropInvalidDmac()
                                                self.in_drop_invalid_dmac.parent = self
                                                self._children_name_map["in_drop_invalid_dmac"] = "in-drop-invalid-dmac"

                                                self.in_drop_invalid_encap = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InDropInvalidEncap()
                                                self.in_drop_invalid_encap.parent = self
                                                self._children_name_map["in_drop_invalid_encap"] = "in-drop-invalid-encap"

                                                self.in_drop_other = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InDropOther()
                                                self.in_drop_other.parent = self
                                                self._children_name_map["in_drop_other"] = "in-drop-other"

                                                self.in_mib_giant = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InMibGiant()
                                                self.in_mib_giant.parent = self
                                                self._children_name_map["in_mib_giant"] = "in-mib-giant"

                                                self.in_mib_jabber = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InMibJabber()
                                                self.in_mib_jabber.parent = self
                                                self._children_name_map["in_mib_jabber"] = "in-mib-jabber"

                                                self.in_mibcrc = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InMibcrc()
                                                self.in_mibcrc.parent = self
                                                self._children_name_map["in_mibcrc"] = "in-mibcrc"

                                                self.in_error_collisions = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InErrorCollisions()
                                                self.in_error_collisions.parent = self
                                                self._children_name_map["in_error_collisions"] = "in-error-collisions"

                                                self.in_error_symbol = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InErrorSymbol()
                                                self.in_error_symbol.parent = self
                                                self._children_name_map["in_error_symbol"] = "in-error-symbol"

                                                self.out_good_bytes = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutGoodBytes()
                                                self.out_good_bytes.parent = self
                                                self._children_name_map["out_good_bytes"] = "out-good-bytes"

                                                self.out8021q_frames = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.Out8021qFrames()
                                                self.out8021q_frames.parent = self
                                                self._children_name_map["out8021q_frames"] = "out8021q-frames"

                                                self.out_pause_frames = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutPauseFrames()
                                                self.out_pause_frames.parent = self
                                                self._children_name_map["out_pause_frames"] = "out-pause-frames"

                                                self.out_pkts1519_max_octets = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutPkts1519MaxOctets()
                                                self.out_pkts1519_max_octets.parent = self
                                                self._children_name_map["out_pkts1519_max_octets"] = "out-pkts1519-max-octets"

                                                self.out_good_pkts = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutGoodPkts()
                                                self.out_good_pkts.parent = self
                                                self._children_name_map["out_good_pkts"] = "out-good-pkts"

                                                self.out_drop_underrun = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutDropUnderrun()
                                                self.out_drop_underrun.parent = self
                                                self._children_name_map["out_drop_underrun"] = "out-drop-underrun"

                                                self.out_drop_abort = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutDropAbort()
                                                self.out_drop_abort.parent = self
                                                self._children_name_map["out_drop_abort"] = "out-drop-abort"

                                                self.out_drop_other = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutDropOther()
                                                self.out_drop_other.parent = self
                                                self._children_name_map["out_drop_other"] = "out-drop-other"

                                                self.out_error_other = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutErrorOther()
                                                self.out_error_other.parent = self
                                                self._children_name_map["out_error_other"] = "out-error-other"

                                                self.in_error_giant = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InErrorGiant()
                                                self.in_error_giant.parent = self
                                                self._children_name_map["in_error_giant"] = "in-error-giant"

                                                self.in_error_runt = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InErrorRunt()
                                                self.in_error_runt.parent = self
                                                self._children_name_map["in_error_runt"] = "in-error-runt"

                                                self.in_error_jabbers = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InErrorJabbers()
                                                self.in_error_jabbers.parent = self
                                                self._children_name_map["in_error_jabbers"] = "in-error-jabbers"

                                                self.in_error_fragments = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InErrorFragments()
                                                self.in_error_fragments.parent = self
                                                self._children_name_map["in_error_fragments"] = "in-error-fragments"

                                                self.in_error_other = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InErrorOther()
                                                self.in_error_other.parent = self
                                                self._children_name_map["in_error_other"] = "in-error-other"

                                                self.in_pkt64_octet = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InPkt64Octet()
                                                self.in_pkt64_octet.parent = self
                                                self._children_name_map["in_pkt64_octet"] = "in-pkt64-octet"

                                                self.in_pkts65_to127_octets = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InPkts65To127Octets()
                                                self.in_pkts65_to127_octets.parent = self
                                                self._children_name_map["in_pkts65_to127_octets"] = "in-pkts65-to127-octets"

                                                self.in_pkts128_to255_octets = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InPkts128To255Octets()
                                                self.in_pkts128_to255_octets.parent = self
                                                self._children_name_map["in_pkts128_to255_octets"] = "in-pkts128-to255-octets"

                                                self.in_pkts256_to511_octets = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InPkts256To511Octets()
                                                self.in_pkts256_to511_octets.parent = self
                                                self._children_name_map["in_pkts256_to511_octets"] = "in-pkts256-to511-octets"

                                                self.in_pkts512_to1023_octets = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InPkts512To1023Octets()
                                                self.in_pkts512_to1023_octets.parent = self
                                                self._children_name_map["in_pkts512_to1023_octets"] = "in-pkts512-to1023-octets"

                                                self.in_pkts1024_to1518_octets = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InPkts1024To1518Octets()
                                                self.in_pkts1024_to1518_octets.parent = self
                                                self._children_name_map["in_pkts1024_to1518_octets"] = "in-pkts1024-to1518-octets"

                                                self.outpkt64octet = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.Outpkt64octet()
                                                self.outpkt64octet.parent = self
                                                self._children_name_map["outpkt64octet"] = "outpkt64octet"

                                                self.out_pkts65127_octets = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutPkts65127Octets()
                                                self.out_pkts65127_octets.parent = self
                                                self._children_name_map["out_pkts65127_octets"] = "out-pkts65127-octets"

                                                self.out_pkts128255_octets = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutPkts128255Octets()
                                                self.out_pkts128255_octets.parent = self
                                                self._children_name_map["out_pkts128255_octets"] = "out-pkts128255-octets"

                                                self.out_pkts256511_octets = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutPkts256511Octets()
                                                self.out_pkts256511_octets.parent = self
                                                self._children_name_map["out_pkts256511_octets"] = "out-pkts256511-octets"

                                                self.out_pkts5121023_octets = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutPkts5121023Octets()
                                                self.out_pkts5121023_octets.parent = self
                                                self._children_name_map["out_pkts5121023_octets"] = "out-pkts5121023-octets"

                                                self.out_pkts10241518_octets = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutPkts10241518Octets()
                                                self.out_pkts10241518_octets.parent = self
                                                self._children_name_map["out_pkts10241518_octets"] = "out-pkts10241518-octets"

                                                self.rx_util = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.RxUtil()
                                                self.rx_util.parent = self
                                                self._children_name_map["rx_util"] = "rx-util"

                                                self.tx_util = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.TxUtil()
                                                self.tx_util.parent = self
                                                self._children_name_map["tx_util"] = "tx-util"

                                                self.tx_undersized_pkt = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.TxUndersizedPkt()
                                                self.tx_undersized_pkt.parent = self
                                                self._children_name_map["tx_undersized_pkt"] = "tx-undersized-pkt"

                                                self.tx_oversized_pkt = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.TxOversizedPkt()
                                                self.tx_oversized_pkt.parent = self
                                                self._children_name_map["tx_oversized_pkt"] = "tx-oversized-pkt"

                                                self.tx_fragments = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.TxFragments()
                                                self.tx_fragments.parent = self
                                                self._children_name_map["tx_fragments"] = "tx-fragments"

                                                self.tx_jabber = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.TxJabber()
                                                self.tx_jabber.parent = self
                                                self._children_name_map["tx_jabber"] = "tx-jabber"

                                                self.tx_bad_fcs = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.TxBadFcs()
                                                self.tx_bad_fcs.parent = self
                                                self._children_name_map["tx_bad_fcs"] = "tx-bad-fcs"
                                                self._segment_path = lambda: "macsec-hour24-ether-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear30_sec_time', 'last_clear15_min_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                            class RxPkt(Entity):
                                                """
                                                RX PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.RxPkt, self).__init__()

                                                    self.yang_name = "rx-pkt"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "rx-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.RxPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class StatPkt(Entity):
                                                """
                                                STAT PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.StatPkt, self).__init__()

                                                    self.yang_name = "stat-pkt"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "stat-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.StatPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OctetStat(Entity):
                                                """
                                                OCTET STAT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OctetStat, self).__init__()

                                                    self.yang_name = "octet-stat"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "octet-stat"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OctetStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OversizePktStat(Entity):
                                                """
                                                OVERSIZE PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OversizePktStat, self).__init__()

                                                    self.yang_name = "oversize-pkt-stat"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "oversize-pkt-stat"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OversizePktStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class FcsErrorsStat(Entity):
                                                """
                                                FCS ERR
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.FcsErrorsStat, self).__init__()

                                                    self.yang_name = "fcs-errors-stat"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "fcs-errors-stat"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.FcsErrorsStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class LongFramesStat(Entity):
                                                """
                                                LONG FRAMES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.LongFramesStat, self).__init__()

                                                    self.yang_name = "long-frames-stat"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "long-frames-stat"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.LongFramesStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class JabberStat(Entity):
                                                """
                                                JABBER STATS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.JabberStat, self).__init__()

                                                    self.yang_name = "jabber-stat"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "jabber-stat"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.JabberStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class Ether64Octets(Entity):
                                                """
                                                SIXTY FOUR OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.Ether64Octets, self).__init__()

                                                    self.yang_name = "ether64-octets"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ether64-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.Ether64Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class Ether65127Octet(Entity):
                                                """
                                                OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.Ether65127Octet, self).__init__()

                                                    self.yang_name = "ether65127-octet"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ether65127-octet"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.Ether65127Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class Ether128255Octet(Entity):
                                                """
                                                TFF OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.Ether128255Octet, self).__init__()

                                                    self.yang_name = "ether128255-octet"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ether128255-octet"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.Ether128255Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class Ether256511Octet(Entity):
                                                """
                                                FOO OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.Ether256511Octet, self).__init__()

                                                    self.yang_name = "ether256511-octet"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ether256511-octet"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.Ether256511Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class Ether5121023Octet(Entity):
                                                """
                                                OZTT OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.Ether5121023Octet, self).__init__()

                                                    self.yang_name = "ether5121023-octet"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ether5121023-octet"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.Ether5121023Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class Ether10241518Octet(Entity):
                                                """
                                                OFO OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.Ether10241518Octet, self).__init__()

                                                    self.yang_name = "ether10241518-octet"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ether10241518-octet"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.Ether10241518Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InUcastPkt(Entity):
                                                """
                                                IN UCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InUcastPkt, self).__init__()

                                                    self.yang_name = "in-ucast-pkt"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-ucast-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InUcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InMcastPkt(Entity):
                                                """
                                                IN MCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InMcastPkt, self).__init__()

                                                    self.yang_name = "in-mcast-pkt"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-mcast-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InMcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InBcastPkt(Entity):
                                                """
                                                IN BCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InBcastPkt, self).__init__()

                                                    self.yang_name = "in-bcast-pkt"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-bcast-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InBcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutUcastPkt(Entity):
                                                """
                                                OUT UCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutUcastPkt, self).__init__()

                                                    self.yang_name = "out-ucast-pkt"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-ucast-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutUcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutBcastPkt(Entity):
                                                """
                                                OUT BCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutBcastPkt, self).__init__()

                                                    self.yang_name = "out-bcast-pkt"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-bcast-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutBcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutMcastPkt(Entity):
                                                """
                                                OUT MCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutMcastPkt, self).__init__()

                                                    self.yang_name = "out-mcast-pkt"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-mcast-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutMcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class TxPkt(Entity):
                                                """
                                                TX PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.TxPkt, self).__init__()

                                                    self.yang_name = "tx-pkt"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "tx-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.TxPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class IfInErrors(Entity):
                                                """
                                                IFIN ERRORS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.IfInErrors, self).__init__()

                                                    self.yang_name = "if-in-errors"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "if-in-errors"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.IfInErrors, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class IfInOctets(Entity):
                                                """
                                                IFIN OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.IfInOctets, self).__init__()

                                                    self.yang_name = "if-in-octets"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "if-in-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.IfInOctets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class EtherStatMulticastPkt(Entity):
                                                """
                                                ETHER STAT MULTICAST PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.EtherStatMulticastPkt, self).__init__()

                                                    self.yang_name = "ether-stat-multicast-pkt"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ether-stat-multicast-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.EtherStatMulticastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class EtherStatBroadcastPkt(Entity):
                                                """
                                                ETHER STAT BROADCAST PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.EtherStatBroadcastPkt, self).__init__()

                                                    self.yang_name = "ether-stat-broadcast-pkt"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ether-stat-broadcast-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.EtherStatBroadcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class EtherStatUndersizedPkt(Entity):
                                                """
                                                ETHER STAT UNDERSIZED PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.EtherStatUndersizedPkt, self).__init__()

                                                    self.yang_name = "ether-stat-undersized-pkt"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ether-stat-undersized-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.EtherStatUndersizedPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutOctets(Entity):
                                                """
                                                OUT OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutOctets, self).__init__()

                                                    self.yang_name = "out-octets"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutOctets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPauseFrame(Entity):
                                                """
                                                INPUT PAUSE FRAME
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InPauseFrame, self).__init__()

                                                    self.yang_name = "in-pause-frame"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pause-frame"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InPauseFrame, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InGoodBytes(Entity):
                                                """
                                                INPUT GOOD BYTES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InGoodBytes, self).__init__()

                                                    self.yang_name = "in-good-bytes"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-good-bytes"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InGoodBytes, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class In8021qFrames(Entity):
                                                """
                                                INPUT 802 1Q FRAMES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.In8021qFrames, self).__init__()

                                                    self.yang_name = "in8021q-frames"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in8021q-frames"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.In8021qFrames, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPkts1519MaxOctets(Entity):
                                                """
                                                INPUT PKTS 1519MAX OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InPkts1519MaxOctets, self).__init__()

                                                    self.yang_name = "in-pkts1519-max-octets"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts1519-max-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InPkts1519MaxOctets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InGoodPkts(Entity):
                                                """
                                                INPUT GOOD PKTS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InGoodPkts, self).__init__()

                                                    self.yang_name = "in-good-pkts"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-good-pkts"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InGoodPkts, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InDropOverrun(Entity):
                                                """
                                                INPUT DROP OVERRUN
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InDropOverrun, self).__init__()

                                                    self.yang_name = "in-drop-overrun"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-drop-overrun"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InDropOverrun, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InDropAbort(Entity):
                                                """
                                                INPUT DROP ABORT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InDropAbort, self).__init__()

                                                    self.yang_name = "in-drop-abort"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-drop-abort"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InDropAbort, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InDropInvalidVlan(Entity):
                                                """
                                                INPUT DROP INVALID VLAN
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InDropInvalidVlan, self).__init__()

                                                    self.yang_name = "in-drop-invalid-vlan"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-drop-invalid-vlan"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InDropInvalidVlan, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InDropInvalidDmac(Entity):
                                                """
                                                INPUT DROP INVALID DMAC
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InDropInvalidDmac, self).__init__()

                                                    self.yang_name = "in-drop-invalid-dmac"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-drop-invalid-dmac"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InDropInvalidDmac, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InDropInvalidEncap(Entity):
                                                """
                                                INPUT DROP INVALID ENCAP
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InDropInvalidEncap, self).__init__()

                                                    self.yang_name = "in-drop-invalid-encap"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-drop-invalid-encap"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InDropInvalidEncap, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InDropOther(Entity):
                                                """
                                                INPUT DROP OTHER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InDropOther, self).__init__()

                                                    self.yang_name = "in-drop-other"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-drop-other"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InDropOther, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InMibGiant(Entity):
                                                """
                                                INPUT MIB GIANT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InMibGiant, self).__init__()

                                                    self.yang_name = "in-mib-giant"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-mib-giant"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InMibGiant, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InMibJabber(Entity):
                                                """
                                                INPUT MIB JABBER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InMibJabber, self).__init__()

                                                    self.yang_name = "in-mib-jabber"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-mib-jabber"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InMibJabber, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InMibcrc(Entity):
                                                """
                                                IN MIB CRC
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InMibcrc, self).__init__()

                                                    self.yang_name = "in-mibcrc"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-mibcrc"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InMibcrc, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InErrorCollisions(Entity):
                                                """
                                                IN ERROR COLLISIONS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InErrorCollisions, self).__init__()

                                                    self.yang_name = "in-error-collisions"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-error-collisions"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InErrorCollisions, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InErrorSymbol(Entity):
                                                """
                                                IN ERROR SYMBOL
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InErrorSymbol, self).__init__()

                                                    self.yang_name = "in-error-symbol"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-error-symbol"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InErrorSymbol, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutGoodBytes(Entity):
                                                """
                                                OUT GOOD BYTES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutGoodBytes, self).__init__()

                                                    self.yang_name = "out-good-bytes"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-good-bytes"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutGoodBytes, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class Out8021qFrames(Entity):
                                                """
                                                OUT 802 1Q FRAMES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.Out8021qFrames, self).__init__()

                                                    self.yang_name = "out8021q-frames"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out8021q-frames"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.Out8021qFrames, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutPauseFrames(Entity):
                                                """
                                                OUT PAUSE FRAMES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutPauseFrames, self).__init__()

                                                    self.yang_name = "out-pause-frames"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-pause-frames"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutPauseFrames, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutPkts1519MaxOctets(Entity):
                                                """
                                                OUT PKTS 1519 MAX OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutPkts1519MaxOctets, self).__init__()

                                                    self.yang_name = "out-pkts1519-max-octets"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-pkts1519-max-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutPkts1519MaxOctets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutGoodPkts(Entity):
                                                """
                                                OUT GOOD PKTS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutGoodPkts, self).__init__()

                                                    self.yang_name = "out-good-pkts"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-good-pkts"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutGoodPkts, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutDropUnderrun(Entity):
                                                """
                                                OUT DROP UNDERRUN
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutDropUnderrun, self).__init__()

                                                    self.yang_name = "out-drop-underrun"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-drop-underrun"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutDropUnderrun, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutDropAbort(Entity):
                                                """
                                                OUT DROP ABORT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutDropAbort, self).__init__()

                                                    self.yang_name = "out-drop-abort"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-drop-abort"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutDropAbort, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutDropOther(Entity):
                                                """
                                                OUT DROP OTHER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutDropOther, self).__init__()

                                                    self.yang_name = "out-drop-other"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-drop-other"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutDropOther, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutErrorOther(Entity):
                                                """
                                                OUT ERROR OTHER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutErrorOther, self).__init__()

                                                    self.yang_name = "out-error-other"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-error-other"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutErrorOther, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InErrorGiant(Entity):
                                                """
                                                IN ERROR GIANT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InErrorGiant, self).__init__()

                                                    self.yang_name = "in-error-giant"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-error-giant"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InErrorGiant, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InErrorRunt(Entity):
                                                """
                                                IN ERROR RUNT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InErrorRunt, self).__init__()

                                                    self.yang_name = "in-error-runt"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-error-runt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InErrorRunt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InErrorJabbers(Entity):
                                                """
                                                IN ERROR JABBERS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InErrorJabbers, self).__init__()

                                                    self.yang_name = "in-error-jabbers"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-error-jabbers"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InErrorJabbers, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InErrorFragments(Entity):
                                                """
                                                IN ERROR FRAGMENTS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InErrorFragments, self).__init__()

                                                    self.yang_name = "in-error-fragments"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-error-fragments"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InErrorFragments, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InErrorOther(Entity):
                                                """
                                                IN ERROR OTHER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InErrorOther, self).__init__()

                                                    self.yang_name = "in-error-other"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-error-other"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InErrorOther, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPkt64Octet(Entity):
                                                """
                                                IN PKT 64 OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InPkt64Octet, self).__init__()

                                                    self.yang_name = "in-pkt64-octet"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkt64-octet"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InPkt64Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPkts65To127Octets(Entity):
                                                """
                                                IN PKTS 65 127OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InPkts65To127Octets, self).__init__()

                                                    self.yang_name = "in-pkts65-to127-octets"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts65-to127-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InPkts65To127Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPkts128To255Octets(Entity):
                                                """
                                                IN PKTS 128 255 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InPkts128To255Octets, self).__init__()

                                                    self.yang_name = "in-pkts128-to255-octets"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts128-to255-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InPkts128To255Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPkts256To511Octets(Entity):
                                                """
                                                IN PKTS 256 511 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InPkts256To511Octets, self).__init__()

                                                    self.yang_name = "in-pkts256-to511-octets"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts256-to511-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InPkts256To511Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPkts512To1023Octets(Entity):
                                                """
                                                IN PKTS 512 1023 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InPkts512To1023Octets, self).__init__()

                                                    self.yang_name = "in-pkts512-to1023-octets"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts512-to1023-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InPkts512To1023Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPkts1024To1518Octets(Entity):
                                                """
                                                IN PKTS 1024 1518 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InPkts1024To1518Octets, self).__init__()

                                                    self.yang_name = "in-pkts1024-to1518-octets"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts1024-to1518-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.InPkts1024To1518Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class Outpkt64octet(Entity):
                                                """
                                                OUT PKT 64 OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.Outpkt64octet, self).__init__()

                                                    self.yang_name = "outpkt64octet"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "outpkt64octet"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.Outpkt64octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutPkts65127Octets(Entity):
                                                """
                                                OUT PKTS 65 127OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutPkts65127Octets, self).__init__()

                                                    self.yang_name = "out-pkts65127-octets"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-pkts65127-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutPkts65127Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutPkts128255Octets(Entity):
                                                """
                                                OUT PKTS 128 255 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutPkts128255Octets, self).__init__()

                                                    self.yang_name = "out-pkts128255-octets"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-pkts128255-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutPkts128255Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutPkts256511Octets(Entity):
                                                """
                                                OUT PKTS 256 511 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutPkts256511Octets, self).__init__()

                                                    self.yang_name = "out-pkts256511-octets"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-pkts256511-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutPkts256511Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutPkts5121023Octets(Entity):
                                                """
                                                OUT PKTS 512 1023 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutPkts5121023Octets, self).__init__()

                                                    self.yang_name = "out-pkts5121023-octets"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-pkts5121023-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutPkts5121023Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutPkts10241518Octets(Entity):
                                                """
                                                OUT PKTS 1024 1518 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutPkts10241518Octets, self).__init__()

                                                    self.yang_name = "out-pkts10241518-octets"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-pkts10241518-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.OutPkts10241518Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class RxUtil(Entity):
                                                """
                                                Rx Utilization in Percent
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: str
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.RxUtil, self).__init__()

                                                    self.yang_name = "rx-util"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                        ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "rx-util"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.RxUtil, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class TxUtil(Entity):
                                                """
                                                Tx Utilization in Percent
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: str
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.TxUtil, self).__init__()

                                                    self.yang_name = "tx-util"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                        ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "tx-util"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.TxUtil, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class TxUndersizedPkt(Entity):
                                                """
                                                TX Undersized Pkt
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.TxUndersizedPkt, self).__init__()

                                                    self.yang_name = "tx-undersized-pkt"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "tx-undersized-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.TxUndersizedPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class TxOversizedPkt(Entity):
                                                """
                                                TX Oversized Pkt
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.TxOversizedPkt, self).__init__()

                                                    self.yang_name = "tx-oversized-pkt"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "tx-oversized-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.TxOversizedPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class TxFragments(Entity):
                                                """
                                                TX Fragments
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.TxFragments, self).__init__()

                                                    self.yang_name = "tx-fragments"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "tx-fragments"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.TxFragments, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class TxJabber(Entity):
                                                """
                                                TX Jabber
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.TxJabber, self).__init__()

                                                    self.yang_name = "tx-jabber"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "tx-jabber"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.TxJabber, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class TxBadFcs(Entity):
                                                """
                                                TX Bad Fcs
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.TxBadFcs, self).__init__()

                                                    self.yang_name = "tx-bad-fcs"
                                                    self.yang_parent_name = "macsec-hour24-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "tx-bad-fcs"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24EtherHistories.MacsecHour24EtherHistory.MacsecHour24EtherTimeLineInstances.MacsecHour24EtherTimeLineInstance.TxBadFcs, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                            class MacsecHour24secytxHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: macsec_hour24secytx_history
                                
                                	port 24 hour secy\_tx performance data
                                	**type**\: list of  		 :py:class:`MacsecHour24secytxHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secytxHistories.MacsecHour24secytxHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secytxHistories, self).__init__()

                                    self.yang_name = "macsec-hour24secytx-histories"
                                    self.yang_parent_name = "macsec-hour24-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("macsec-hour24secytx-history", ("macsec_hour24secytx_history", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secytxHistories.MacsecHour24secytxHistory))])
                                    self._leafs = OrderedDict()

                                    self.macsec_hour24secytx_history = YList(self)
                                    self._segment_path = lambda: "macsec-hour24secytx-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secytxHistories, [], name, value)


                                class MacsecHour24secytxHistory(Entity):
                                    """
                                    port 24 hour secy\_tx performance data
                                    
                                    .. attribute:: number  (key)
                                    
                                    	channel number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: macsec_hour24secytx_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`MacsecHour24secytxTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secytxHistories.MacsecHour24secytxHistory.MacsecHour24secytxTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secytxHistories.MacsecHour24secytxHistory, self).__init__()

                                        self.yang_name = "macsec-hour24secytx-history"
                                        self.yang_parent_name = "macsec-hour24secytx-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([("macsec-hour24secytx-time-line-instances", ("macsec_hour24secytx_time_line_instances", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secytxHistories.MacsecHour24secytxHistory.MacsecHour24secytxTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ])
                                        self.number = None

                                        self.macsec_hour24secytx_time_line_instances = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secytxHistories.MacsecHour24secytxHistory.MacsecHour24secytxTimeLineInstances()
                                        self.macsec_hour24secytx_time_line_instances.parent = self
                                        self._children_name_map["macsec_hour24secytx_time_line_instances"] = "macsec-hour24secytx-time-line-instances"
                                        self._segment_path = lambda: "macsec-hour24secytx-history" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secytxHistories.MacsecHour24secytxHistory, ['number'], name, value)


                                    class MacsecHour24secytxTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: macsec_hour24secytx_time_line_instance
                                        
                                        	port 24 hour secy\_tx performance data
                                        	**type**\: list of  		 :py:class:`MacsecHour24secytxTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secytxHistories.MacsecHour24secytxHistory.MacsecHour24secytxTimeLineInstances.MacsecHour24secytxTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secytxHistories.MacsecHour24secytxHistory.MacsecHour24secytxTimeLineInstances, self).__init__()

                                            self.yang_name = "macsec-hour24secytx-time-line-instances"
                                            self.yang_parent_name = "macsec-hour24secytx-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("macsec-hour24secytx-time-line-instance", ("macsec_hour24secytx_time_line_instance", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secytxHistories.MacsecHour24secytxHistory.MacsecHour24secytxTimeLineInstances.MacsecHour24secytxTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.macsec_hour24secytx_time_line_instance = YList(self)
                                            self._segment_path = lambda: "macsec-hour24secytx-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secytxHistories.MacsecHour24secytxHistory.MacsecHour24secytxTimeLineInstances, [], name, value)


                                        class MacsecHour24secytxTimeLineInstance(Entity):
                                            """
                                            port 24 hour secy\_tx performance data
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: out_pkts_protected
                                            
                                            	Out Packets Protected
                                            	**type**\:  :py:class:`OutPktsProtected <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secytxHistories.MacsecHour24secytxHistory.MacsecHour24secytxTimeLineInstances.MacsecHour24secytxTimeLineInstance.OutPktsProtected>`
                                            
                                            .. attribute:: out_pkts_encrypted
                                            
                                            	Out Packets Encrypted
                                            	**type**\:  :py:class:`OutPktsEncrypted <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secytxHistories.MacsecHour24secytxHistory.MacsecHour24secytxTimeLineInstances.MacsecHour24secytxTimeLineInstance.OutPktsEncrypted>`
                                            
                                            .. attribute:: out_octets_protected
                                            
                                            	Out Octets Protected 
                                            	**type**\:  :py:class:`OutOctetsProtected <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secytxHistories.MacsecHour24secytxHistory.MacsecHour24secytxTimeLineInstances.MacsecHour24secytxTimeLineInstance.OutOctetsProtected>`
                                            
                                            .. attribute:: out_octets_encrypted
                                            
                                            	Out Octets Encrypted
                                            	**type**\:  :py:class:`OutOctetsEncrypted <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secytxHistories.MacsecHour24secytxHistory.MacsecHour24secytxTimeLineInstances.MacsecHour24secytxTimeLineInstance.OutOctetsEncrypted>`
                                            
                                            .. attribute:: out_pkts_too_long
                                            
                                            	Out Packets Too Long
                                            	**type**\:  :py:class:`OutPktsTooLong <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secytxHistories.MacsecHour24secytxHistory.MacsecHour24secytxTimeLineInstances.MacsecHour24secytxTimeLineInstance.OutPktsTooLong>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\: bool
                                            
                                            .. attribute:: sample_count
                                            
                                            	Running Sample Count
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secytxHistories.MacsecHour24secytxHistory.MacsecHour24secytxTimeLineInstances.MacsecHour24secytxTimeLineInstance, self).__init__()

                                                self.yang_name = "macsec-hour24secytx-time-line-instance"
                                                self.yang_parent_name = "macsec-hour24secytx-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("out-pkts-protected", ("out_pkts_protected", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secytxHistories.MacsecHour24secytxHistory.MacsecHour24secytxTimeLineInstances.MacsecHour24secytxTimeLineInstance.OutPktsProtected)), ("out-pkts-encrypted", ("out_pkts_encrypted", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secytxHistories.MacsecHour24secytxHistory.MacsecHour24secytxTimeLineInstances.MacsecHour24secytxTimeLineInstance.OutPktsEncrypted)), ("out-octets-protected", ("out_octets_protected", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secytxHistories.MacsecHour24secytxHistory.MacsecHour24secytxTimeLineInstances.MacsecHour24secytxTimeLineInstance.OutOctetsProtected)), ("out-octets-encrypted", ("out_octets_encrypted", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secytxHistories.MacsecHour24secytxHistory.MacsecHour24secytxTimeLineInstances.MacsecHour24secytxTimeLineInstance.OutOctetsEncrypted)), ("out-pkts-too-long", ("out_pkts_too_long", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secytxHistories.MacsecHour24secytxHistory.MacsecHour24secytxTimeLineInstances.MacsecHour24secytxTimeLineInstance.OutPktsTooLong))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                    ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                                    ('sample_count', (YLeaf(YType.uint64, 'sample-count'), ['int'])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear24_hr_time = None
                                                self.sec30_support = None
                                                self.sample_count = None

                                                self.out_pkts_protected = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secytxHistories.MacsecHour24secytxHistory.MacsecHour24secytxTimeLineInstances.MacsecHour24secytxTimeLineInstance.OutPktsProtected()
                                                self.out_pkts_protected.parent = self
                                                self._children_name_map["out_pkts_protected"] = "out-pkts-protected"

                                                self.out_pkts_encrypted = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secytxHistories.MacsecHour24secytxHistory.MacsecHour24secytxTimeLineInstances.MacsecHour24secytxTimeLineInstance.OutPktsEncrypted()
                                                self.out_pkts_encrypted.parent = self
                                                self._children_name_map["out_pkts_encrypted"] = "out-pkts-encrypted"

                                                self.out_octets_protected = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secytxHistories.MacsecHour24secytxHistory.MacsecHour24secytxTimeLineInstances.MacsecHour24secytxTimeLineInstance.OutOctetsProtected()
                                                self.out_octets_protected.parent = self
                                                self._children_name_map["out_octets_protected"] = "out-octets-protected"

                                                self.out_octets_encrypted = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secytxHistories.MacsecHour24secytxHistory.MacsecHour24secytxTimeLineInstances.MacsecHour24secytxTimeLineInstance.OutOctetsEncrypted()
                                                self.out_octets_encrypted.parent = self
                                                self._children_name_map["out_octets_encrypted"] = "out-octets-encrypted"

                                                self.out_pkts_too_long = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secytxHistories.MacsecHour24secytxHistory.MacsecHour24secytxTimeLineInstances.MacsecHour24secytxTimeLineInstance.OutPktsTooLong()
                                                self.out_pkts_too_long.parent = self
                                                self._children_name_map["out_pkts_too_long"] = "out-pkts-too-long"
                                                self._segment_path = lambda: "macsec-hour24secytx-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secytxHistories.MacsecHour24secytxHistory.MacsecHour24secytxTimeLineInstances.MacsecHour24secytxTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support', 'sample_count'], name, value)


                                            class OutPktsProtected(Entity):
                                                """
                                                Out Packets Protected
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secytxHistories.MacsecHour24secytxHistory.MacsecHour24secytxTimeLineInstances.MacsecHour24secytxTimeLineInstance.OutPktsProtected, self).__init__()

                                                    self.yang_name = "out-pkts-protected"
                                                    self.yang_parent_name = "macsec-hour24secytx-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-pkts-protected"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secytxHistories.MacsecHour24secytxHistory.MacsecHour24secytxTimeLineInstances.MacsecHour24secytxTimeLineInstance.OutPktsProtected, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutPktsEncrypted(Entity):
                                                """
                                                Out Packets Encrypted
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secytxHistories.MacsecHour24secytxHistory.MacsecHour24secytxTimeLineInstances.MacsecHour24secytxTimeLineInstance.OutPktsEncrypted, self).__init__()

                                                    self.yang_name = "out-pkts-encrypted"
                                                    self.yang_parent_name = "macsec-hour24secytx-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-pkts-encrypted"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secytxHistories.MacsecHour24secytxHistory.MacsecHour24secytxTimeLineInstances.MacsecHour24secytxTimeLineInstance.OutPktsEncrypted, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutOctetsProtected(Entity):
                                                """
                                                Out Octets Protected 
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secytxHistories.MacsecHour24secytxHistory.MacsecHour24secytxTimeLineInstances.MacsecHour24secytxTimeLineInstance.OutOctetsProtected, self).__init__()

                                                    self.yang_name = "out-octets-protected"
                                                    self.yang_parent_name = "macsec-hour24secytx-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-octets-protected"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secytxHistories.MacsecHour24secytxHistory.MacsecHour24secytxTimeLineInstances.MacsecHour24secytxTimeLineInstance.OutOctetsProtected, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutOctetsEncrypted(Entity):
                                                """
                                                Out Octets Encrypted
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secytxHistories.MacsecHour24secytxHistory.MacsecHour24secytxTimeLineInstances.MacsecHour24secytxTimeLineInstance.OutOctetsEncrypted, self).__init__()

                                                    self.yang_name = "out-octets-encrypted"
                                                    self.yang_parent_name = "macsec-hour24secytx-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-octets-encrypted"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secytxHistories.MacsecHour24secytxHistory.MacsecHour24secytxTimeLineInstances.MacsecHour24secytxTimeLineInstance.OutOctetsEncrypted, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutPktsTooLong(Entity):
                                                """
                                                Out Packets Too Long
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secytxHistories.MacsecHour24secytxHistory.MacsecHour24secytxTimeLineInstances.MacsecHour24secytxTimeLineInstance.OutPktsTooLong, self).__init__()

                                                    self.yang_name = "out-pkts-too-long"
                                                    self.yang_parent_name = "macsec-hour24secytx-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-pkts-too-long"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secytxHistories.MacsecHour24secytxHistory.MacsecHour24secytxTimeLineInstances.MacsecHour24secytxTimeLineInstance.OutPktsTooLong, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                            class MacsecHour24secyifHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: macsec_hour24secyif_history
                                
                                	port 24 hour secy\_if performance data
                                	**type**\: list of  		 :py:class:`MacsecHour24secyifHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories, self).__init__()

                                    self.yang_name = "macsec-hour24secyif-histories"
                                    self.yang_parent_name = "macsec-hour24-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("macsec-hour24secyif-history", ("macsec_hour24secyif_history", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory))])
                                    self._leafs = OrderedDict()

                                    self.macsec_hour24secyif_history = YList(self)
                                    self._segment_path = lambda: "macsec-hour24secyif-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories, [], name, value)


                                class MacsecHour24secyifHistory(Entity):
                                    """
                                    port 24 hour secy\_if performance data
                                    
                                    .. attribute:: number  (key)
                                    
                                    	channel number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: macsec_hour24secyif_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`MacsecHour24secyifTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory, self).__init__()

                                        self.yang_name = "macsec-hour24secyif-history"
                                        self.yang_parent_name = "macsec-hour24secyif-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([("macsec-hour24secyif-time-line-instances", ("macsec_hour24secyif_time_line_instances", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ])
                                        self.number = None

                                        self.macsec_hour24secyif_time_line_instances = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances()
                                        self.macsec_hour24secyif_time_line_instances.parent = self
                                        self._children_name_map["macsec_hour24secyif_time_line_instances"] = "macsec-hour24secyif-time-line-instances"
                                        self._segment_path = lambda: "macsec-hour24secyif-history" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory, ['number'], name, value)


                                    class MacsecHour24secyifTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: macsec_hour24secyif_time_line_instance
                                        
                                        	port 24 hour secy\_if performance data
                                        	**type**\: list of  		 :py:class:`MacsecHour24secyifTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances, self).__init__()

                                            self.yang_name = "macsec-hour24secyif-time-line-instances"
                                            self.yang_parent_name = "macsec-hour24secyif-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("macsec-hour24secyif-time-line-instance", ("macsec_hour24secyif_time_line_instance", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.macsec_hour24secyif_time_line_instance = YList(self)
                                            self._segment_path = lambda: "macsec-hour24secyif-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances, [], name, value)


                                        class MacsecHour24secyifTimeLineInstance(Entity):
                                            """
                                            port 24 hour secy\_if performance data
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: in_pkts_untagged
                                            
                                            	In Packet Untagged
                                            	**type**\:  :py:class:`InPktsUntagged <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.InPktsUntagged>`
                                            
                                            .. attribute:: in_pkts_no_tag
                                            
                                            	In Packet No tag
                                            	**type**\:  :py:class:`InPktsNoTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.InPktsNoTag>`
                                            
                                            .. attribute:: in_pkts_bad_tag
                                            
                                            	In Packet Bad tag
                                            	**type**\:  :py:class:`InPktsBadTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.InPktsBadTag>`
                                            
                                            .. attribute:: in_pkts_unknown_sci
                                            
                                            	In Packet Unknown sci
                                            	**type**\:  :py:class:`InPktsUnknownSci <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.InPktsUnknownSci>`
                                            
                                            .. attribute:: in_pkts_no_sci
                                            
                                            	In Packet No sci
                                            	**type**\:  :py:class:`InPktsNoSci <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.InPktsNoSci>`
                                            
                                            .. attribute:: in_pkts_overrun
                                            
                                            	In Packet Overrun
                                            	**type**\:  :py:class:`InPktsOverrun <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.InPktsOverrun>`
                                            
                                            .. attribute:: in_octets_validated
                                            
                                            	In Octet Validated
                                            	**type**\:  :py:class:`InOctetsValidated <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.InOctetsValidated>`
                                            
                                            .. attribute:: in_octets_decrypted
                                            
                                            	In Octet Decrypted
                                            	**type**\:  :py:class:`InOctetsDecrypted <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.InOctetsDecrypted>`
                                            
                                            .. attribute:: out_pkts_untagged
                                            
                                            	Out Packet Untagged
                                            	**type**\:  :py:class:`OutPktsUntagged <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.OutPktsUntagged>`
                                            
                                            .. attribute:: out_pkts_too_long
                                            
                                            	Out Packet Too Long
                                            	**type**\:  :py:class:`OutPktsTooLong <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.OutPktsTooLong>`
                                            
                                            .. attribute:: out_octets_protected
                                            
                                            	Out Octet Protected
                                            	**type**\:  :py:class:`OutOctetsProtected <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.OutOctetsProtected>`
                                            
                                            .. attribute:: out_octets_encrypted
                                            
                                            	Out Octet encrypted
                                            	**type**\:  :py:class:`OutOctetsEncrypted <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.OutOctetsEncrypted>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\: bool
                                            
                                            .. attribute:: sample_count
                                            
                                            	Running Sample Count
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance, self).__init__()

                                                self.yang_name = "macsec-hour24secyif-time-line-instance"
                                                self.yang_parent_name = "macsec-hour24secyif-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("in-pkts-untagged", ("in_pkts_untagged", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.InPktsUntagged)), ("in-pkts-no-tag", ("in_pkts_no_tag", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.InPktsNoTag)), ("in-pkts-bad-tag", ("in_pkts_bad_tag", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.InPktsBadTag)), ("in-pkts-unknown-sci", ("in_pkts_unknown_sci", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.InPktsUnknownSci)), ("in-pkts-no-sci", ("in_pkts_no_sci", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.InPktsNoSci)), ("in-pkts-overrun", ("in_pkts_overrun", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.InPktsOverrun)), ("in-octets-validated", ("in_octets_validated", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.InOctetsValidated)), ("in-octets-decrypted", ("in_octets_decrypted", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.InOctetsDecrypted)), ("out-pkts-untagged", ("out_pkts_untagged", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.OutPktsUntagged)), ("out-pkts-too-long", ("out_pkts_too_long", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.OutPktsTooLong)), ("out-octets-protected", ("out_octets_protected", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.OutOctetsProtected)), ("out-octets-encrypted", ("out_octets_encrypted", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.OutOctetsEncrypted))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                    ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                                    ('sample_count', (YLeaf(YType.uint64, 'sample-count'), ['int'])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear24_hr_time = None
                                                self.sec30_support = None
                                                self.sample_count = None

                                                self.in_pkts_untagged = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.InPktsUntagged()
                                                self.in_pkts_untagged.parent = self
                                                self._children_name_map["in_pkts_untagged"] = "in-pkts-untagged"

                                                self.in_pkts_no_tag = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.InPktsNoTag()
                                                self.in_pkts_no_tag.parent = self
                                                self._children_name_map["in_pkts_no_tag"] = "in-pkts-no-tag"

                                                self.in_pkts_bad_tag = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.InPktsBadTag()
                                                self.in_pkts_bad_tag.parent = self
                                                self._children_name_map["in_pkts_bad_tag"] = "in-pkts-bad-tag"

                                                self.in_pkts_unknown_sci = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.InPktsUnknownSci()
                                                self.in_pkts_unknown_sci.parent = self
                                                self._children_name_map["in_pkts_unknown_sci"] = "in-pkts-unknown-sci"

                                                self.in_pkts_no_sci = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.InPktsNoSci()
                                                self.in_pkts_no_sci.parent = self
                                                self._children_name_map["in_pkts_no_sci"] = "in-pkts-no-sci"

                                                self.in_pkts_overrun = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.InPktsOverrun()
                                                self.in_pkts_overrun.parent = self
                                                self._children_name_map["in_pkts_overrun"] = "in-pkts-overrun"

                                                self.in_octets_validated = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.InOctetsValidated()
                                                self.in_octets_validated.parent = self
                                                self._children_name_map["in_octets_validated"] = "in-octets-validated"

                                                self.in_octets_decrypted = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.InOctetsDecrypted()
                                                self.in_octets_decrypted.parent = self
                                                self._children_name_map["in_octets_decrypted"] = "in-octets-decrypted"

                                                self.out_pkts_untagged = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.OutPktsUntagged()
                                                self.out_pkts_untagged.parent = self
                                                self._children_name_map["out_pkts_untagged"] = "out-pkts-untagged"

                                                self.out_pkts_too_long = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.OutPktsTooLong()
                                                self.out_pkts_too_long.parent = self
                                                self._children_name_map["out_pkts_too_long"] = "out-pkts-too-long"

                                                self.out_octets_protected = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.OutOctetsProtected()
                                                self.out_octets_protected.parent = self
                                                self._children_name_map["out_octets_protected"] = "out-octets-protected"

                                                self.out_octets_encrypted = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.OutOctetsEncrypted()
                                                self.out_octets_encrypted.parent = self
                                                self._children_name_map["out_octets_encrypted"] = "out-octets-encrypted"
                                                self._segment_path = lambda: "macsec-hour24secyif-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support', 'sample_count'], name, value)


                                            class InPktsUntagged(Entity):
                                                """
                                                In Packet Untagged
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.InPktsUntagged, self).__init__()

                                                    self.yang_name = "in-pkts-untagged"
                                                    self.yang_parent_name = "macsec-hour24secyif-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts-untagged"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.InPktsUntagged, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPktsNoTag(Entity):
                                                """
                                                In Packet No tag
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.InPktsNoTag, self).__init__()

                                                    self.yang_name = "in-pkts-no-tag"
                                                    self.yang_parent_name = "macsec-hour24secyif-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts-no-tag"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.InPktsNoTag, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPktsBadTag(Entity):
                                                """
                                                In Packet Bad tag
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.InPktsBadTag, self).__init__()

                                                    self.yang_name = "in-pkts-bad-tag"
                                                    self.yang_parent_name = "macsec-hour24secyif-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts-bad-tag"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.InPktsBadTag, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPktsUnknownSci(Entity):
                                                """
                                                In Packet Unknown sci
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.InPktsUnknownSci, self).__init__()

                                                    self.yang_name = "in-pkts-unknown-sci"
                                                    self.yang_parent_name = "macsec-hour24secyif-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts-unknown-sci"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.InPktsUnknownSci, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPktsNoSci(Entity):
                                                """
                                                In Packet No sci
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.InPktsNoSci, self).__init__()

                                                    self.yang_name = "in-pkts-no-sci"
                                                    self.yang_parent_name = "macsec-hour24secyif-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts-no-sci"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.InPktsNoSci, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPktsOverrun(Entity):
                                                """
                                                In Packet Overrun
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.InPktsOverrun, self).__init__()

                                                    self.yang_name = "in-pkts-overrun"
                                                    self.yang_parent_name = "macsec-hour24secyif-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts-overrun"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.InPktsOverrun, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InOctetsValidated(Entity):
                                                """
                                                In Octet Validated
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.InOctetsValidated, self).__init__()

                                                    self.yang_name = "in-octets-validated"
                                                    self.yang_parent_name = "macsec-hour24secyif-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-octets-validated"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.InOctetsValidated, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InOctetsDecrypted(Entity):
                                                """
                                                In Octet Decrypted
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.InOctetsDecrypted, self).__init__()

                                                    self.yang_name = "in-octets-decrypted"
                                                    self.yang_parent_name = "macsec-hour24secyif-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-octets-decrypted"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.InOctetsDecrypted, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutPktsUntagged(Entity):
                                                """
                                                Out Packet Untagged
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.OutPktsUntagged, self).__init__()

                                                    self.yang_name = "out-pkts-untagged"
                                                    self.yang_parent_name = "macsec-hour24secyif-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-pkts-untagged"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.OutPktsUntagged, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutPktsTooLong(Entity):
                                                """
                                                Out Packet Too Long
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.OutPktsTooLong, self).__init__()

                                                    self.yang_name = "out-pkts-too-long"
                                                    self.yang_parent_name = "macsec-hour24secyif-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-pkts-too-long"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.OutPktsTooLong, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutOctetsProtected(Entity):
                                                """
                                                Out Octet Protected
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.OutOctetsProtected, self).__init__()

                                                    self.yang_name = "out-octets-protected"
                                                    self.yang_parent_name = "macsec-hour24secyif-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-octets-protected"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.OutOctetsProtected, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutOctetsEncrypted(Entity):
                                                """
                                                Out Octet encrypted
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.OutOctetsEncrypted, self).__init__()

                                                    self.yang_name = "out-octets-encrypted"
                                                    self.yang_parent_name = "macsec-hour24secyif-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-octets-encrypted"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyifHistories.MacsecHour24secyifHistory.MacsecHour24secyifTimeLineInstances.MacsecHour24secyifTimeLineInstance.OutOctetsEncrypted, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                            class MacsecHour24secyrxHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: macsec_hour24secyrx_history
                                
                                	port 24 hour secy\_rx performance data
                                	**type**\: list of  		 :py:class:`MacsecHour24secyrxHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories, self).__init__()

                                    self.yang_name = "macsec-hour24secyrx-histories"
                                    self.yang_parent_name = "macsec-hour24-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("macsec-hour24secyrx-history", ("macsec_hour24secyrx_history", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory))])
                                    self._leafs = OrderedDict()

                                    self.macsec_hour24secyrx_history = YList(self)
                                    self._segment_path = lambda: "macsec-hour24secyrx-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories, [], name, value)


                                class MacsecHour24secyrxHistory(Entity):
                                    """
                                    port 24 hour secy\_rx performance data
                                    
                                    .. attribute:: number  (key)
                                    
                                    	channel number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: macsec_hour24secyrx_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`MacsecHour24secyrxTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory, self).__init__()

                                        self.yang_name = "macsec-hour24secyrx-history"
                                        self.yang_parent_name = "macsec-hour24secyrx-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([("macsec-hour24secyrx-time-line-instances", ("macsec_hour24secyrx_time_line_instances", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ])
                                        self.number = None

                                        self.macsec_hour24secyrx_time_line_instances = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances()
                                        self.macsec_hour24secyrx_time_line_instances.parent = self
                                        self._children_name_map["macsec_hour24secyrx_time_line_instances"] = "macsec-hour24secyrx-time-line-instances"
                                        self._segment_path = lambda: "macsec-hour24secyrx-history" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory, ['number'], name, value)


                                    class MacsecHour24secyrxTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: macsec_hour24secyrx_time_line_instance
                                        
                                        	port 24 hour secy\_rx performance data
                                        	**type**\: list of  		 :py:class:`MacsecHour24secyrxTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances, self).__init__()

                                            self.yang_name = "macsec-hour24secyrx-time-line-instances"
                                            self.yang_parent_name = "macsec-hour24secyrx-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("macsec-hour24secyrx-time-line-instance", ("macsec_hour24secyrx_time_line_instance", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.macsec_hour24secyrx_time_line_instance = YList(self)
                                            self._segment_path = lambda: "macsec-hour24secyrx-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances, [], name, value)


                                        class MacsecHour24secyrxTimeLineInstance(Entity):
                                            """
                                            port 24 hour secy\_rx performance data
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: in_pkts_unchecked
                                            
                                            	In Packet Unchecked
                                            	**type**\:  :py:class:`InPktsUnchecked <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance.InPktsUnchecked>`
                                            
                                            .. attribute:: in_pkts_delayed
                                            
                                            	In Packet Delay
                                            	**type**\:  :py:class:`InPktsDelayed <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance.InPktsDelayed>`
                                            
                                            .. attribute:: in_pkts_late
                                            
                                            	In Packet Late
                                            	**type**\:  :py:class:`InPktsLate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance.InPktsLate>`
                                            
                                            .. attribute:: in_pkts_ok
                                            
                                            	In Packet Ok
                                            	**type**\:  :py:class:`InPktsOk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance.InPktsOk>`
                                            
                                            .. attribute:: in_pkts_invalid
                                            
                                            	In Packet Invalid
                                            	**type**\:  :py:class:`InPktsInvalid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance.InPktsInvalid>`
                                            
                                            .. attribute:: in_pkts_not_valid
                                            
                                            	In Packet Not Valid
                                            	**type**\:  :py:class:`InPktsNotValid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance.InPktsNotValid>`
                                            
                                            .. attribute:: in_pkts_not_using_sa
                                            
                                            	In Packet Not Using SA
                                            	**type**\:  :py:class:`InPktsNotUsingSa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance.InPktsNotUsingSa>`
                                            
                                            .. attribute:: in_pkts_unused_sa
                                            
                                            	In Packet Unused SA
                                            	**type**\:  :py:class:`InPktsUnusedSa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance.InPktsUnusedSa>`
                                            
                                            .. attribute:: in_pkts_untagged_hit
                                            
                                            	In Packet Untagged Hit
                                            	**type**\:  :py:class:`InPktsUntaggedHit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance.InPktsUntaggedHit>`
                                            
                                            .. attribute:: in_octets_validated
                                            
                                            	In Octet Validated
                                            	**type**\:  :py:class:`InOctetsValidated <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance.InOctetsValidated>`
                                            
                                            .. attribute:: in_octets_decrypted
                                            
                                            	In Octet Decrypted
                                            	**type**\:  :py:class:`InOctetsDecrypted <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance.InOctetsDecrypted>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\: bool
                                            
                                            .. attribute:: sample_count
                                            
                                            	Running Sample Count
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance, self).__init__()

                                                self.yang_name = "macsec-hour24secyrx-time-line-instance"
                                                self.yang_parent_name = "macsec-hour24secyrx-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("in-pkts-unchecked", ("in_pkts_unchecked", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance.InPktsUnchecked)), ("in-pkts-delayed", ("in_pkts_delayed", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance.InPktsDelayed)), ("in-pkts-late", ("in_pkts_late", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance.InPktsLate)), ("in-pkts-ok", ("in_pkts_ok", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance.InPktsOk)), ("in-pkts-invalid", ("in_pkts_invalid", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance.InPktsInvalid)), ("in-pkts-not-valid", ("in_pkts_not_valid", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance.InPktsNotValid)), ("in-pkts-not-using-sa", ("in_pkts_not_using_sa", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance.InPktsNotUsingSa)), ("in-pkts-unused-sa", ("in_pkts_unused_sa", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance.InPktsUnusedSa)), ("in-pkts-untagged-hit", ("in_pkts_untagged_hit", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance.InPktsUntaggedHit)), ("in-octets-validated", ("in_octets_validated", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance.InOctetsValidated)), ("in-octets-decrypted", ("in_octets_decrypted", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance.InOctetsDecrypted))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                    ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                                    ('sample_count', (YLeaf(YType.uint64, 'sample-count'), ['int'])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear24_hr_time = None
                                                self.sec30_support = None
                                                self.sample_count = None

                                                self.in_pkts_unchecked = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance.InPktsUnchecked()
                                                self.in_pkts_unchecked.parent = self
                                                self._children_name_map["in_pkts_unchecked"] = "in-pkts-unchecked"

                                                self.in_pkts_delayed = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance.InPktsDelayed()
                                                self.in_pkts_delayed.parent = self
                                                self._children_name_map["in_pkts_delayed"] = "in-pkts-delayed"

                                                self.in_pkts_late = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance.InPktsLate()
                                                self.in_pkts_late.parent = self
                                                self._children_name_map["in_pkts_late"] = "in-pkts-late"

                                                self.in_pkts_ok = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance.InPktsOk()
                                                self.in_pkts_ok.parent = self
                                                self._children_name_map["in_pkts_ok"] = "in-pkts-ok"

                                                self.in_pkts_invalid = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance.InPktsInvalid()
                                                self.in_pkts_invalid.parent = self
                                                self._children_name_map["in_pkts_invalid"] = "in-pkts-invalid"

                                                self.in_pkts_not_valid = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance.InPktsNotValid()
                                                self.in_pkts_not_valid.parent = self
                                                self._children_name_map["in_pkts_not_valid"] = "in-pkts-not-valid"

                                                self.in_pkts_not_using_sa = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance.InPktsNotUsingSa()
                                                self.in_pkts_not_using_sa.parent = self
                                                self._children_name_map["in_pkts_not_using_sa"] = "in-pkts-not-using-sa"

                                                self.in_pkts_unused_sa = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance.InPktsUnusedSa()
                                                self.in_pkts_unused_sa.parent = self
                                                self._children_name_map["in_pkts_unused_sa"] = "in-pkts-unused-sa"

                                                self.in_pkts_untagged_hit = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance.InPktsUntaggedHit()
                                                self.in_pkts_untagged_hit.parent = self
                                                self._children_name_map["in_pkts_untagged_hit"] = "in-pkts-untagged-hit"

                                                self.in_octets_validated = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance.InOctetsValidated()
                                                self.in_octets_validated.parent = self
                                                self._children_name_map["in_octets_validated"] = "in-octets-validated"

                                                self.in_octets_decrypted = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance.InOctetsDecrypted()
                                                self.in_octets_decrypted.parent = self
                                                self._children_name_map["in_octets_decrypted"] = "in-octets-decrypted"
                                                self._segment_path = lambda: "macsec-hour24secyrx-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support', 'sample_count'], name, value)


                                            class InPktsUnchecked(Entity):
                                                """
                                                In Packet Unchecked
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance.InPktsUnchecked, self).__init__()

                                                    self.yang_name = "in-pkts-unchecked"
                                                    self.yang_parent_name = "macsec-hour24secyrx-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts-unchecked"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance.InPktsUnchecked, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPktsDelayed(Entity):
                                                """
                                                In Packet Delay
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance.InPktsDelayed, self).__init__()

                                                    self.yang_name = "in-pkts-delayed"
                                                    self.yang_parent_name = "macsec-hour24secyrx-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts-delayed"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance.InPktsDelayed, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPktsLate(Entity):
                                                """
                                                In Packet Late
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance.InPktsLate, self).__init__()

                                                    self.yang_name = "in-pkts-late"
                                                    self.yang_parent_name = "macsec-hour24secyrx-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts-late"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance.InPktsLate, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPktsOk(Entity):
                                                """
                                                In Packet Ok
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance.InPktsOk, self).__init__()

                                                    self.yang_name = "in-pkts-ok"
                                                    self.yang_parent_name = "macsec-hour24secyrx-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts-ok"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance.InPktsOk, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPktsInvalid(Entity):
                                                """
                                                In Packet Invalid
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance.InPktsInvalid, self).__init__()

                                                    self.yang_name = "in-pkts-invalid"
                                                    self.yang_parent_name = "macsec-hour24secyrx-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts-invalid"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance.InPktsInvalid, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPktsNotValid(Entity):
                                                """
                                                In Packet Not Valid
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance.InPktsNotValid, self).__init__()

                                                    self.yang_name = "in-pkts-not-valid"
                                                    self.yang_parent_name = "macsec-hour24secyrx-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts-not-valid"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance.InPktsNotValid, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPktsNotUsingSa(Entity):
                                                """
                                                In Packet Not Using SA
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance.InPktsNotUsingSa, self).__init__()

                                                    self.yang_name = "in-pkts-not-using-sa"
                                                    self.yang_parent_name = "macsec-hour24secyrx-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts-not-using-sa"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance.InPktsNotUsingSa, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPktsUnusedSa(Entity):
                                                """
                                                In Packet Unused SA
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance.InPktsUnusedSa, self).__init__()

                                                    self.yang_name = "in-pkts-unused-sa"
                                                    self.yang_parent_name = "macsec-hour24secyrx-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts-unused-sa"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance.InPktsUnusedSa, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPktsUntaggedHit(Entity):
                                                """
                                                In Packet Untagged Hit
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance.InPktsUntaggedHit, self).__init__()

                                                    self.yang_name = "in-pkts-untagged-hit"
                                                    self.yang_parent_name = "macsec-hour24secyrx-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts-untagged-hit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance.InPktsUntaggedHit, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InOctetsValidated(Entity):
                                                """
                                                In Octet Validated
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance.InOctetsValidated, self).__init__()

                                                    self.yang_name = "in-octets-validated"
                                                    self.yang_parent_name = "macsec-hour24secyrx-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-octets-validated"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance.InOctetsValidated, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InOctetsDecrypted(Entity):
                                                """
                                                In Octet Decrypted
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance.InOctetsDecrypted, self).__init__()

                                                    self.yang_name = "in-octets-decrypted"
                                                    self.yang_parent_name = "macsec-hour24secyrx-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-octets-decrypted"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecHour24History.MacsecHour24secyrxHistories.MacsecHour24secyrxHistory.MacsecHour24secyrxTimeLineInstances.MacsecHour24secyrxTimeLineInstance.InOctetsDecrypted, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                        class MacsecSecond30History(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: macsec_second30secyrx_histories
                            
                            	port current performance data
                            	**type**\:  :py:class:`MacsecSecond30secyrxHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories>`
                            
                            .. attribute:: macsec_second30_ether_histories
                            
                            	port current performance data
                            	**type**\:  :py:class:`MacsecSecond30EtherHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories>`
                            
                            .. attribute:: macsec_second30secytx_histories
                            
                            	port current performance data
                            	**type**\:  :py:class:`MacsecSecond30secytxHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secytxHistories>`
                            
                            .. attribute:: macsec_second30secyif_histories
                            
                            	port current performance data
                            	**type**\:  :py:class:`MacsecSecond30secyifHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History, self).__init__()

                                self.yang_name = "macsec-second30-history"
                                self.yang_parent_name = "macsec-port-history"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("macsec-second30secyrx-histories", ("macsec_second30secyrx_histories", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories)), ("macsec-second30-ether-histories", ("macsec_second30_ether_histories", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories)), ("macsec-second30secytx-histories", ("macsec_second30secytx_histories", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secytxHistories)), ("macsec-second30secyif-histories", ("macsec_second30secyif_histories", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories))])
                                self._leafs = OrderedDict()

                                self.macsec_second30secyrx_histories = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories()
                                self.macsec_second30secyrx_histories.parent = self
                                self._children_name_map["macsec_second30secyrx_histories"] = "macsec-second30secyrx-histories"

                                self.macsec_second30_ether_histories = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories()
                                self.macsec_second30_ether_histories.parent = self
                                self._children_name_map["macsec_second30_ether_histories"] = "macsec-second30-ether-histories"

                                self.macsec_second30secytx_histories = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secytxHistories()
                                self.macsec_second30secytx_histories.parent = self
                                self._children_name_map["macsec_second30secytx_histories"] = "macsec-second30secytx-histories"

                                self.macsec_second30secyif_histories = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories()
                                self.macsec_second30secyif_histories.parent = self
                                self._children_name_map["macsec_second30secyif_histories"] = "macsec-second30secyif-histories"
                                self._segment_path = lambda: "macsec-second30-history"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History, [], name, value)


                            class MacsecSecond30secyrxHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: macsec_second30secyrx_history
                                
                                	port 30\-second secy\_rx performance data
                                	**type**\: list of  		 :py:class:`MacsecSecond30secyrxHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories, self).__init__()

                                    self.yang_name = "macsec-second30secyrx-histories"
                                    self.yang_parent_name = "macsec-second30-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("macsec-second30secyrx-history", ("macsec_second30secyrx_history", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory))])
                                    self._leafs = OrderedDict()

                                    self.macsec_second30secyrx_history = YList(self)
                                    self._segment_path = lambda: "macsec-second30secyrx-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories, [], name, value)


                                class MacsecSecond30secyrxHistory(Entity):
                                    """
                                    port 30\-second secy\_rx performance data
                                    
                                    .. attribute:: number  (key)
                                    
                                    	channel number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: macsec_second30secyrx_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`MacsecSecond30secyrxTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory, self).__init__()

                                        self.yang_name = "macsec-second30secyrx-history"
                                        self.yang_parent_name = "macsec-second30secyrx-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([("macsec-second30secyrx-time-line-instances", ("macsec_second30secyrx_time_line_instances", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ])
                                        self.number = None

                                        self.macsec_second30secyrx_time_line_instances = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances()
                                        self.macsec_second30secyrx_time_line_instances.parent = self
                                        self._children_name_map["macsec_second30secyrx_time_line_instances"] = "macsec-second30secyrx-time-line-instances"
                                        self._segment_path = lambda: "macsec-second30secyrx-history" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory, ['number'], name, value)


                                    class MacsecSecond30secyrxTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: macsec_second30secyrx_time_line_instance
                                        
                                        	port 30\-second secy\_rx performance data
                                        	**type**\: list of  		 :py:class:`MacsecSecond30secyrxTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances, self).__init__()

                                            self.yang_name = "macsec-second30secyrx-time-line-instances"
                                            self.yang_parent_name = "macsec-second30secyrx-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("macsec-second30secyrx-time-line-instance", ("macsec_second30secyrx_time_line_instance", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.macsec_second30secyrx_time_line_instance = YList(self)
                                            self._segment_path = lambda: "macsec-second30secyrx-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances, [], name, value)


                                        class MacsecSecond30secyrxTimeLineInstance(Entity):
                                            """
                                            port 30\-second secy\_rx performance data
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: in_pkts_unchecked
                                            
                                            	In Packet Unchecked
                                            	**type**\:  :py:class:`InPktsUnchecked <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance.InPktsUnchecked>`
                                            
                                            .. attribute:: in_pkts_delayed
                                            
                                            	In Packet Delay
                                            	**type**\:  :py:class:`InPktsDelayed <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance.InPktsDelayed>`
                                            
                                            .. attribute:: in_pkts_late
                                            
                                            	In Packet Late
                                            	**type**\:  :py:class:`InPktsLate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance.InPktsLate>`
                                            
                                            .. attribute:: in_pkts_ok
                                            
                                            	In Packet Ok
                                            	**type**\:  :py:class:`InPktsOk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance.InPktsOk>`
                                            
                                            .. attribute:: in_pkts_invalid
                                            
                                            	In Packet Invalid
                                            	**type**\:  :py:class:`InPktsInvalid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance.InPktsInvalid>`
                                            
                                            .. attribute:: in_pkts_not_valid
                                            
                                            	In Packet Not Valid
                                            	**type**\:  :py:class:`InPktsNotValid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance.InPktsNotValid>`
                                            
                                            .. attribute:: in_pkts_not_using_sa
                                            
                                            	In Packet Not Using SA
                                            	**type**\:  :py:class:`InPktsNotUsingSa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance.InPktsNotUsingSa>`
                                            
                                            .. attribute:: in_pkts_unused_sa
                                            
                                            	In Packet Unused SA
                                            	**type**\:  :py:class:`InPktsUnusedSa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance.InPktsUnusedSa>`
                                            
                                            .. attribute:: in_pkts_untagged_hit
                                            
                                            	In Packet Untagged Hit
                                            	**type**\:  :py:class:`InPktsUntaggedHit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance.InPktsUntaggedHit>`
                                            
                                            .. attribute:: in_octets_validated
                                            
                                            	In Octet Validated
                                            	**type**\:  :py:class:`InOctetsValidated <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance.InOctetsValidated>`
                                            
                                            .. attribute:: in_octets_decrypted
                                            
                                            	In Octet Decrypted
                                            	**type**\:  :py:class:`InOctetsDecrypted <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance.InOctetsDecrypted>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\: bool
                                            
                                            .. attribute:: sample_count
                                            
                                            	Running Sample Count
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance, self).__init__()

                                                self.yang_name = "macsec-second30secyrx-time-line-instance"
                                                self.yang_parent_name = "macsec-second30secyrx-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("in-pkts-unchecked", ("in_pkts_unchecked", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance.InPktsUnchecked)), ("in-pkts-delayed", ("in_pkts_delayed", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance.InPktsDelayed)), ("in-pkts-late", ("in_pkts_late", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance.InPktsLate)), ("in-pkts-ok", ("in_pkts_ok", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance.InPktsOk)), ("in-pkts-invalid", ("in_pkts_invalid", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance.InPktsInvalid)), ("in-pkts-not-valid", ("in_pkts_not_valid", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance.InPktsNotValid)), ("in-pkts-not-using-sa", ("in_pkts_not_using_sa", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance.InPktsNotUsingSa)), ("in-pkts-unused-sa", ("in_pkts_unused_sa", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance.InPktsUnusedSa)), ("in-pkts-untagged-hit", ("in_pkts_untagged_hit", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance.InPktsUntaggedHit)), ("in-octets-validated", ("in_octets_validated", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance.InOctetsValidated)), ("in-octets-decrypted", ("in_octets_decrypted", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance.InOctetsDecrypted))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                    ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                                    ('sample_count', (YLeaf(YType.uint64, 'sample-count'), ['int'])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear24_hr_time = None
                                                self.sec30_support = None
                                                self.sample_count = None

                                                self.in_pkts_unchecked = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance.InPktsUnchecked()
                                                self.in_pkts_unchecked.parent = self
                                                self._children_name_map["in_pkts_unchecked"] = "in-pkts-unchecked"

                                                self.in_pkts_delayed = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance.InPktsDelayed()
                                                self.in_pkts_delayed.parent = self
                                                self._children_name_map["in_pkts_delayed"] = "in-pkts-delayed"

                                                self.in_pkts_late = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance.InPktsLate()
                                                self.in_pkts_late.parent = self
                                                self._children_name_map["in_pkts_late"] = "in-pkts-late"

                                                self.in_pkts_ok = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance.InPktsOk()
                                                self.in_pkts_ok.parent = self
                                                self._children_name_map["in_pkts_ok"] = "in-pkts-ok"

                                                self.in_pkts_invalid = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance.InPktsInvalid()
                                                self.in_pkts_invalid.parent = self
                                                self._children_name_map["in_pkts_invalid"] = "in-pkts-invalid"

                                                self.in_pkts_not_valid = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance.InPktsNotValid()
                                                self.in_pkts_not_valid.parent = self
                                                self._children_name_map["in_pkts_not_valid"] = "in-pkts-not-valid"

                                                self.in_pkts_not_using_sa = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance.InPktsNotUsingSa()
                                                self.in_pkts_not_using_sa.parent = self
                                                self._children_name_map["in_pkts_not_using_sa"] = "in-pkts-not-using-sa"

                                                self.in_pkts_unused_sa = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance.InPktsUnusedSa()
                                                self.in_pkts_unused_sa.parent = self
                                                self._children_name_map["in_pkts_unused_sa"] = "in-pkts-unused-sa"

                                                self.in_pkts_untagged_hit = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance.InPktsUntaggedHit()
                                                self.in_pkts_untagged_hit.parent = self
                                                self._children_name_map["in_pkts_untagged_hit"] = "in-pkts-untagged-hit"

                                                self.in_octets_validated = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance.InOctetsValidated()
                                                self.in_octets_validated.parent = self
                                                self._children_name_map["in_octets_validated"] = "in-octets-validated"

                                                self.in_octets_decrypted = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance.InOctetsDecrypted()
                                                self.in_octets_decrypted.parent = self
                                                self._children_name_map["in_octets_decrypted"] = "in-octets-decrypted"
                                                self._segment_path = lambda: "macsec-second30secyrx-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support', 'sample_count'], name, value)


                                            class InPktsUnchecked(Entity):
                                                """
                                                In Packet Unchecked
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance.InPktsUnchecked, self).__init__()

                                                    self.yang_name = "in-pkts-unchecked"
                                                    self.yang_parent_name = "macsec-second30secyrx-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts-unchecked"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance.InPktsUnchecked, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPktsDelayed(Entity):
                                                """
                                                In Packet Delay
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance.InPktsDelayed, self).__init__()

                                                    self.yang_name = "in-pkts-delayed"
                                                    self.yang_parent_name = "macsec-second30secyrx-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts-delayed"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance.InPktsDelayed, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPktsLate(Entity):
                                                """
                                                In Packet Late
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance.InPktsLate, self).__init__()

                                                    self.yang_name = "in-pkts-late"
                                                    self.yang_parent_name = "macsec-second30secyrx-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts-late"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance.InPktsLate, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPktsOk(Entity):
                                                """
                                                In Packet Ok
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance.InPktsOk, self).__init__()

                                                    self.yang_name = "in-pkts-ok"
                                                    self.yang_parent_name = "macsec-second30secyrx-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts-ok"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance.InPktsOk, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPktsInvalid(Entity):
                                                """
                                                In Packet Invalid
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance.InPktsInvalid, self).__init__()

                                                    self.yang_name = "in-pkts-invalid"
                                                    self.yang_parent_name = "macsec-second30secyrx-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts-invalid"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance.InPktsInvalid, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPktsNotValid(Entity):
                                                """
                                                In Packet Not Valid
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance.InPktsNotValid, self).__init__()

                                                    self.yang_name = "in-pkts-not-valid"
                                                    self.yang_parent_name = "macsec-second30secyrx-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts-not-valid"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance.InPktsNotValid, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPktsNotUsingSa(Entity):
                                                """
                                                In Packet Not Using SA
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance.InPktsNotUsingSa, self).__init__()

                                                    self.yang_name = "in-pkts-not-using-sa"
                                                    self.yang_parent_name = "macsec-second30secyrx-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts-not-using-sa"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance.InPktsNotUsingSa, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPktsUnusedSa(Entity):
                                                """
                                                In Packet Unused SA
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance.InPktsUnusedSa, self).__init__()

                                                    self.yang_name = "in-pkts-unused-sa"
                                                    self.yang_parent_name = "macsec-second30secyrx-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts-unused-sa"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance.InPktsUnusedSa, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPktsUntaggedHit(Entity):
                                                """
                                                In Packet Untagged Hit
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance.InPktsUntaggedHit, self).__init__()

                                                    self.yang_name = "in-pkts-untagged-hit"
                                                    self.yang_parent_name = "macsec-second30secyrx-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts-untagged-hit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance.InPktsUntaggedHit, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InOctetsValidated(Entity):
                                                """
                                                In Octet Validated
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance.InOctetsValidated, self).__init__()

                                                    self.yang_name = "in-octets-validated"
                                                    self.yang_parent_name = "macsec-second30secyrx-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-octets-validated"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance.InOctetsValidated, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InOctetsDecrypted(Entity):
                                                """
                                                In Octet Decrypted
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance.InOctetsDecrypted, self).__init__()

                                                    self.yang_name = "in-octets-decrypted"
                                                    self.yang_parent_name = "macsec-second30secyrx-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-octets-decrypted"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyrxHistories.MacsecSecond30secyrxHistory.MacsecSecond30secyrxTimeLineInstances.MacsecSecond30secyrxTimeLineInstance.InOctetsDecrypted, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                            class MacsecSecond30EtherHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: macsec_second30_ether_history
                                
                                	port 30\-second ether performance data
                                	**type**\: list of  		 :py:class:`MacsecSecond30EtherHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories, self).__init__()

                                    self.yang_name = "macsec-second30-ether-histories"
                                    self.yang_parent_name = "macsec-second30-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("macsec-second30-ether-history", ("macsec_second30_ether_history", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory))])
                                    self._leafs = OrderedDict()

                                    self.macsec_second30_ether_history = YList(self)
                                    self._segment_path = lambda: "macsec-second30-ether-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories, [], name, value)


                                class MacsecSecond30EtherHistory(Entity):
                                    """
                                    port 30\-second ether performance data
                                    
                                    .. attribute:: number  (key)
                                    
                                    	channel number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: macsec_second30_ether_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`MacsecSecond30EtherTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory, self).__init__()

                                        self.yang_name = "macsec-second30-ether-history"
                                        self.yang_parent_name = "macsec-second30-ether-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([("macsec-second30-ether-time-line-instances", ("macsec_second30_ether_time_line_instances", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ])
                                        self.number = None

                                        self.macsec_second30_ether_time_line_instances = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances()
                                        self.macsec_second30_ether_time_line_instances.parent = self
                                        self._children_name_map["macsec_second30_ether_time_line_instances"] = "macsec-second30-ether-time-line-instances"
                                        self._segment_path = lambda: "macsec-second30-ether-history" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory, ['number'], name, value)


                                    class MacsecSecond30EtherTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: macsec_second30_ether_time_line_instance
                                        
                                        	port 30\-second ether performance data
                                        	**type**\: list of  		 :py:class:`MacsecSecond30EtherTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances, self).__init__()

                                            self.yang_name = "macsec-second30-ether-time-line-instances"
                                            self.yang_parent_name = "macsec-second30-ether-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("macsec-second30-ether-time-line-instance", ("macsec_second30_ether_time_line_instance", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.macsec_second30_ether_time_line_instance = YList(self)
                                            self._segment_path = lambda: "macsec-second30-ether-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances, [], name, value)


                                        class MacsecSecond30EtherTimeLineInstance(Entity):
                                            """
                                            port 30\-second ether performance data
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rx_pkt
                                            
                                            	RX PKT
                                            	**type**\:  :py:class:`RxPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.RxPkt>`
                                            
                                            .. attribute:: stat_pkt
                                            
                                            	STAT PKT
                                            	**type**\:  :py:class:`StatPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.StatPkt>`
                                            
                                            .. attribute:: octet_stat
                                            
                                            	OCTET STAT
                                            	**type**\:  :py:class:`OctetStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OctetStat>`
                                            
                                            .. attribute:: oversize_pkt_stat
                                            
                                            	OVERSIZE PKT
                                            	**type**\:  :py:class:`OversizePktStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OversizePktStat>`
                                            
                                            .. attribute:: fcs_errors_stat
                                            
                                            	FCS ERR
                                            	**type**\:  :py:class:`FcsErrorsStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.FcsErrorsStat>`
                                            
                                            .. attribute:: long_frames_stat
                                            
                                            	LONG FRAMES
                                            	**type**\:  :py:class:`LongFramesStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.LongFramesStat>`
                                            
                                            .. attribute:: jabber_stat
                                            
                                            	JABBER STATS
                                            	**type**\:  :py:class:`JabberStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.JabberStat>`
                                            
                                            .. attribute:: ether64_octets
                                            
                                            	SIXTY FOUR OCTET
                                            	**type**\:  :py:class:`Ether64Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.Ether64Octets>`
                                            
                                            .. attribute:: ether65127_octet
                                            
                                            	OCTET
                                            	**type**\:  :py:class:`Ether65127Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.Ether65127Octet>`
                                            
                                            .. attribute:: ether128255_octet
                                            
                                            	TFF OCTET
                                            	**type**\:  :py:class:`Ether128255Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.Ether128255Octet>`
                                            
                                            .. attribute:: ether256511_octet
                                            
                                            	FOO OCTET
                                            	**type**\:  :py:class:`Ether256511Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.Ether256511Octet>`
                                            
                                            .. attribute:: ether5121023_octet
                                            
                                            	OZTT OCTET
                                            	**type**\:  :py:class:`Ether5121023Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.Ether5121023Octet>`
                                            
                                            .. attribute:: ether10241518_octet
                                            
                                            	OFO OCTET
                                            	**type**\:  :py:class:`Ether10241518Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.Ether10241518Octet>`
                                            
                                            .. attribute:: in_ucast_pkt
                                            
                                            	IN UCAST
                                            	**type**\:  :py:class:`InUcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InUcastPkt>`
                                            
                                            .. attribute:: in_mcast_pkt
                                            
                                            	IN MCAST
                                            	**type**\:  :py:class:`InMcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InMcastPkt>`
                                            
                                            .. attribute:: in_bcast_pkt
                                            
                                            	IN BCAST
                                            	**type**\:  :py:class:`InBcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InBcastPkt>`
                                            
                                            .. attribute:: out_ucast_pkt
                                            
                                            	OUT UCAST
                                            	**type**\:  :py:class:`OutUcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutUcastPkt>`
                                            
                                            .. attribute:: out_bcast_pkt
                                            
                                            	OUT BCAST
                                            	**type**\:  :py:class:`OutBcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutBcastPkt>`
                                            
                                            .. attribute:: out_mcast_pkt
                                            
                                            	OUT MCAST
                                            	**type**\:  :py:class:`OutMcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutMcastPkt>`
                                            
                                            .. attribute:: tx_pkt
                                            
                                            	TX PKT
                                            	**type**\:  :py:class:`TxPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.TxPkt>`
                                            
                                            .. attribute:: if_in_errors
                                            
                                            	IFIN ERRORS
                                            	**type**\:  :py:class:`IfInErrors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.IfInErrors>`
                                            
                                            .. attribute:: if_in_octets
                                            
                                            	IFIN OCTETS
                                            	**type**\:  :py:class:`IfInOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.IfInOctets>`
                                            
                                            .. attribute:: ether_stat_multicast_pkt
                                            
                                            	ETHER STAT MULTICAST PKT
                                            	**type**\:  :py:class:`EtherStatMulticastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.EtherStatMulticastPkt>`
                                            
                                            .. attribute:: ether_stat_broadcast_pkt
                                            
                                            	ETHER STAT BROADCAST PKT
                                            	**type**\:  :py:class:`EtherStatBroadcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.EtherStatBroadcastPkt>`
                                            
                                            .. attribute:: ether_stat_undersized_pkt
                                            
                                            	ETHER STAT UNDERSIZED PKT
                                            	**type**\:  :py:class:`EtherStatUndersizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.EtherStatUndersizedPkt>`
                                            
                                            .. attribute:: out_octets
                                            
                                            	OUT OCTET
                                            	**type**\:  :py:class:`OutOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutOctets>`
                                            
                                            .. attribute:: in_pause_frame
                                            
                                            	INPUT PAUSE FRAME
                                            	**type**\:  :py:class:`InPauseFrame <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InPauseFrame>`
                                            
                                            .. attribute:: in_good_bytes
                                            
                                            	INPUT GOOD BYTES
                                            	**type**\:  :py:class:`InGoodBytes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InGoodBytes>`
                                            
                                            .. attribute:: in8021q_frames
                                            
                                            	INPUT 802 1Q FRAMES
                                            	**type**\:  :py:class:`In8021qFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.In8021qFrames>`
                                            
                                            .. attribute:: in_pkts1519_max_octets
                                            
                                            	INPUT PKTS 1519MAX OCTETS
                                            	**type**\:  :py:class:`InPkts1519MaxOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InPkts1519MaxOctets>`
                                            
                                            .. attribute:: in_good_pkts
                                            
                                            	INPUT GOOD PKTS
                                            	**type**\:  :py:class:`InGoodPkts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InGoodPkts>`
                                            
                                            .. attribute:: in_drop_overrun
                                            
                                            	INPUT DROP OVERRUN
                                            	**type**\:  :py:class:`InDropOverrun <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InDropOverrun>`
                                            
                                            .. attribute:: in_drop_abort
                                            
                                            	INPUT DROP ABORT
                                            	**type**\:  :py:class:`InDropAbort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InDropAbort>`
                                            
                                            .. attribute:: in_drop_invalid_vlan
                                            
                                            	INPUT DROP INVALID VLAN
                                            	**type**\:  :py:class:`InDropInvalidVlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InDropInvalidVlan>`
                                            
                                            .. attribute:: in_drop_invalid_dmac
                                            
                                            	INPUT DROP INVALID DMAC
                                            	**type**\:  :py:class:`InDropInvalidDmac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InDropInvalidDmac>`
                                            
                                            .. attribute:: in_drop_invalid_encap
                                            
                                            	INPUT DROP INVALID ENCAP
                                            	**type**\:  :py:class:`InDropInvalidEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InDropInvalidEncap>`
                                            
                                            .. attribute:: in_drop_other
                                            
                                            	INPUT DROP OTHER
                                            	**type**\:  :py:class:`InDropOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InDropOther>`
                                            
                                            .. attribute:: in_mib_giant
                                            
                                            	INPUT MIB GIANT
                                            	**type**\:  :py:class:`InMibGiant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InMibGiant>`
                                            
                                            .. attribute:: in_mib_jabber
                                            
                                            	INPUT MIB JABBER
                                            	**type**\:  :py:class:`InMibJabber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InMibJabber>`
                                            
                                            .. attribute:: in_mibcrc
                                            
                                            	IN MIB CRC
                                            	**type**\:  :py:class:`InMibcrc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InMibcrc>`
                                            
                                            .. attribute:: in_error_collisions
                                            
                                            	IN ERROR COLLISIONS
                                            	**type**\:  :py:class:`InErrorCollisions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InErrorCollisions>`
                                            
                                            .. attribute:: in_error_symbol
                                            
                                            	IN ERROR SYMBOL
                                            	**type**\:  :py:class:`InErrorSymbol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InErrorSymbol>`
                                            
                                            .. attribute:: out_good_bytes
                                            
                                            	OUT GOOD BYTES
                                            	**type**\:  :py:class:`OutGoodBytes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutGoodBytes>`
                                            
                                            .. attribute:: out8021q_frames
                                            
                                            	OUT 802 1Q FRAMES
                                            	**type**\:  :py:class:`Out8021qFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.Out8021qFrames>`
                                            
                                            .. attribute:: out_pause_frames
                                            
                                            	OUT PAUSE FRAMES
                                            	**type**\:  :py:class:`OutPauseFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutPauseFrames>`
                                            
                                            .. attribute:: out_pkts1519_max_octets
                                            
                                            	OUT PKTS 1519 MAX OCTETS
                                            	**type**\:  :py:class:`OutPkts1519MaxOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutPkts1519MaxOctets>`
                                            
                                            .. attribute:: out_good_pkts
                                            
                                            	OUT GOOD PKTS
                                            	**type**\:  :py:class:`OutGoodPkts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutGoodPkts>`
                                            
                                            .. attribute:: out_drop_underrun
                                            
                                            	OUT DROP UNDERRUN
                                            	**type**\:  :py:class:`OutDropUnderrun <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutDropUnderrun>`
                                            
                                            .. attribute:: out_drop_abort
                                            
                                            	OUT DROP ABORT
                                            	**type**\:  :py:class:`OutDropAbort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutDropAbort>`
                                            
                                            .. attribute:: out_drop_other
                                            
                                            	OUT DROP OTHER
                                            	**type**\:  :py:class:`OutDropOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutDropOther>`
                                            
                                            .. attribute:: out_error_other
                                            
                                            	OUT ERROR OTHER
                                            	**type**\:  :py:class:`OutErrorOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutErrorOther>`
                                            
                                            .. attribute:: in_error_giant
                                            
                                            	IN ERROR GIANT
                                            	**type**\:  :py:class:`InErrorGiant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InErrorGiant>`
                                            
                                            .. attribute:: in_error_runt
                                            
                                            	IN ERROR RUNT
                                            	**type**\:  :py:class:`InErrorRunt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InErrorRunt>`
                                            
                                            .. attribute:: in_error_jabbers
                                            
                                            	IN ERROR JABBERS
                                            	**type**\:  :py:class:`InErrorJabbers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InErrorJabbers>`
                                            
                                            .. attribute:: in_error_fragments
                                            
                                            	IN ERROR FRAGMENTS
                                            	**type**\:  :py:class:`InErrorFragments <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InErrorFragments>`
                                            
                                            .. attribute:: in_error_other
                                            
                                            	IN ERROR OTHER
                                            	**type**\:  :py:class:`InErrorOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InErrorOther>`
                                            
                                            .. attribute:: in_pkt64_octet
                                            
                                            	IN PKT 64 OCTET
                                            	**type**\:  :py:class:`InPkt64Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InPkt64Octet>`
                                            
                                            .. attribute:: in_pkts65_to127_octets
                                            
                                            	IN PKTS 65 127OCTETS
                                            	**type**\:  :py:class:`InPkts65To127Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InPkts65To127Octets>`
                                            
                                            .. attribute:: in_pkts128_to255_octets
                                            
                                            	IN PKTS 128 255 OCTETS
                                            	**type**\:  :py:class:`InPkts128To255Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InPkts128To255Octets>`
                                            
                                            .. attribute:: in_pkts256_to511_octets
                                            
                                            	IN PKTS 256 511 OCTETS
                                            	**type**\:  :py:class:`InPkts256To511Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InPkts256To511Octets>`
                                            
                                            .. attribute:: in_pkts512_to1023_octets
                                            
                                            	IN PKTS 512 1023 OCTETS
                                            	**type**\:  :py:class:`InPkts512To1023Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InPkts512To1023Octets>`
                                            
                                            .. attribute:: in_pkts1024_to1518_octets
                                            
                                            	IN PKTS 1024 1518 OCTETS
                                            	**type**\:  :py:class:`InPkts1024To1518Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InPkts1024To1518Octets>`
                                            
                                            .. attribute:: outpkt64octet
                                            
                                            	OUT PKT 64 OCTET
                                            	**type**\:  :py:class:`Outpkt64octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.Outpkt64octet>`
                                            
                                            .. attribute:: out_pkts65127_octets
                                            
                                            	OUT PKTS 65 127OCTETS
                                            	**type**\:  :py:class:`OutPkts65127Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutPkts65127Octets>`
                                            
                                            .. attribute:: out_pkts128255_octets
                                            
                                            	OUT PKTS 128 255 OCTETS
                                            	**type**\:  :py:class:`OutPkts128255Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutPkts128255Octets>`
                                            
                                            .. attribute:: out_pkts256511_octets
                                            
                                            	OUT PKTS 256 511 OCTETS
                                            	**type**\:  :py:class:`OutPkts256511Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutPkts256511Octets>`
                                            
                                            .. attribute:: out_pkts5121023_octets
                                            
                                            	OUT PKTS 512 1023 OCTETS
                                            	**type**\:  :py:class:`OutPkts5121023Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutPkts5121023Octets>`
                                            
                                            .. attribute:: out_pkts10241518_octets
                                            
                                            	OUT PKTS 1024 1518 OCTETS
                                            	**type**\:  :py:class:`OutPkts10241518Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutPkts10241518Octets>`
                                            
                                            .. attribute:: rx_util
                                            
                                            	Rx Utilization in Percent
                                            	**type**\:  :py:class:`RxUtil <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.RxUtil>`
                                            
                                            .. attribute:: tx_util
                                            
                                            	Tx Utilization in Percent
                                            	**type**\:  :py:class:`TxUtil <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.TxUtil>`
                                            
                                            .. attribute:: tx_undersized_pkt
                                            
                                            	TX Undersized Pkt
                                            	**type**\:  :py:class:`TxUndersizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.TxUndersizedPkt>`
                                            
                                            .. attribute:: tx_oversized_pkt
                                            
                                            	TX Oversized Pkt
                                            	**type**\:  :py:class:`TxOversizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.TxOversizedPkt>`
                                            
                                            .. attribute:: tx_fragments
                                            
                                            	TX Fragments
                                            	**type**\:  :py:class:`TxFragments <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.TxFragments>`
                                            
                                            .. attribute:: tx_jabber
                                            
                                            	TX Jabber
                                            	**type**\:  :py:class:`TxJabber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.TxJabber>`
                                            
                                            .. attribute:: tx_bad_fcs
                                            
                                            	TX Bad Fcs
                                            	**type**\:  :py:class:`TxBadFcs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.TxBadFcs>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance, self).__init__()

                                                self.yang_name = "macsec-second30-ether-time-line-instance"
                                                self.yang_parent_name = "macsec-second30-ether-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("rx-pkt", ("rx_pkt", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.RxPkt)), ("stat-pkt", ("stat_pkt", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.StatPkt)), ("octet-stat", ("octet_stat", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OctetStat)), ("oversize-pkt-stat", ("oversize_pkt_stat", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OversizePktStat)), ("fcs-errors-stat", ("fcs_errors_stat", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.FcsErrorsStat)), ("long-frames-stat", ("long_frames_stat", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.LongFramesStat)), ("jabber-stat", ("jabber_stat", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.JabberStat)), ("ether64-octets", ("ether64_octets", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.Ether64Octets)), ("ether65127-octet", ("ether65127_octet", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.Ether65127Octet)), ("ether128255-octet", ("ether128255_octet", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.Ether128255Octet)), ("ether256511-octet", ("ether256511_octet", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.Ether256511Octet)), ("ether5121023-octet", ("ether5121023_octet", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.Ether5121023Octet)), ("ether10241518-octet", ("ether10241518_octet", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.Ether10241518Octet)), ("in-ucast-pkt", ("in_ucast_pkt", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InUcastPkt)), ("in-mcast-pkt", ("in_mcast_pkt", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InMcastPkt)), ("in-bcast-pkt", ("in_bcast_pkt", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InBcastPkt)), ("out-ucast-pkt", ("out_ucast_pkt", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutUcastPkt)), ("out-bcast-pkt", ("out_bcast_pkt", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutBcastPkt)), ("out-mcast-pkt", ("out_mcast_pkt", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutMcastPkt)), ("tx-pkt", ("tx_pkt", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.TxPkt)), ("if-in-errors", ("if_in_errors", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.IfInErrors)), ("if-in-octets", ("if_in_octets", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.IfInOctets)), ("ether-stat-multicast-pkt", ("ether_stat_multicast_pkt", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.EtherStatMulticastPkt)), ("ether-stat-broadcast-pkt", ("ether_stat_broadcast_pkt", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.EtherStatBroadcastPkt)), ("ether-stat-undersized-pkt", ("ether_stat_undersized_pkt", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.EtherStatUndersizedPkt)), ("out-octets", ("out_octets", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutOctets)), ("in-pause-frame", ("in_pause_frame", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InPauseFrame)), ("in-good-bytes", ("in_good_bytes", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InGoodBytes)), ("in8021q-frames", ("in8021q_frames", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.In8021qFrames)), ("in-pkts1519-max-octets", ("in_pkts1519_max_octets", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InPkts1519MaxOctets)), ("in-good-pkts", ("in_good_pkts", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InGoodPkts)), ("in-drop-overrun", ("in_drop_overrun", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InDropOverrun)), ("in-drop-abort", ("in_drop_abort", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InDropAbort)), ("in-drop-invalid-vlan", ("in_drop_invalid_vlan", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InDropInvalidVlan)), ("in-drop-invalid-dmac", ("in_drop_invalid_dmac", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InDropInvalidDmac)), ("in-drop-invalid-encap", ("in_drop_invalid_encap", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InDropInvalidEncap)), ("in-drop-other", ("in_drop_other", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InDropOther)), ("in-mib-giant", ("in_mib_giant", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InMibGiant)), ("in-mib-jabber", ("in_mib_jabber", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InMibJabber)), ("in-mibcrc", ("in_mibcrc", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InMibcrc)), ("in-error-collisions", ("in_error_collisions", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InErrorCollisions)), ("in-error-symbol", ("in_error_symbol", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InErrorSymbol)), ("out-good-bytes", ("out_good_bytes", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutGoodBytes)), ("out8021q-frames", ("out8021q_frames", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.Out8021qFrames)), ("out-pause-frames", ("out_pause_frames", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutPauseFrames)), ("out-pkts1519-max-octets", ("out_pkts1519_max_octets", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutPkts1519MaxOctets)), ("out-good-pkts", ("out_good_pkts", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutGoodPkts)), ("out-drop-underrun", ("out_drop_underrun", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutDropUnderrun)), ("out-drop-abort", ("out_drop_abort", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutDropAbort)), ("out-drop-other", ("out_drop_other", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutDropOther)), ("out-error-other", ("out_error_other", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutErrorOther)), ("in-error-giant", ("in_error_giant", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InErrorGiant)), ("in-error-runt", ("in_error_runt", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InErrorRunt)), ("in-error-jabbers", ("in_error_jabbers", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InErrorJabbers)), ("in-error-fragments", ("in_error_fragments", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InErrorFragments)), ("in-error-other", ("in_error_other", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InErrorOther)), ("in-pkt64-octet", ("in_pkt64_octet", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InPkt64Octet)), ("in-pkts65-to127-octets", ("in_pkts65_to127_octets", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InPkts65To127Octets)), ("in-pkts128-to255-octets", ("in_pkts128_to255_octets", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InPkts128To255Octets)), ("in-pkts256-to511-octets", ("in_pkts256_to511_octets", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InPkts256To511Octets)), ("in-pkts512-to1023-octets", ("in_pkts512_to1023_octets", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InPkts512To1023Octets)), ("in-pkts1024-to1518-octets", ("in_pkts1024_to1518_octets", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InPkts1024To1518Octets)), ("outpkt64octet", ("outpkt64octet", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.Outpkt64octet)), ("out-pkts65127-octets", ("out_pkts65127_octets", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutPkts65127Octets)), ("out-pkts128255-octets", ("out_pkts128255_octets", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutPkts128255Octets)), ("out-pkts256511-octets", ("out_pkts256511_octets", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutPkts256511Octets)), ("out-pkts5121023-octets", ("out_pkts5121023_octets", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutPkts5121023Octets)), ("out-pkts10241518-octets", ("out_pkts10241518_octets", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutPkts10241518Octets)), ("rx-util", ("rx_util", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.RxUtil)), ("tx-util", ("tx_util", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.TxUtil)), ("tx-undersized-pkt", ("tx_undersized_pkt", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.TxUndersizedPkt)), ("tx-oversized-pkt", ("tx_oversized_pkt", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.TxOversizedPkt)), ("tx-fragments", ("tx_fragments", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.TxFragments)), ("tx-jabber", ("tx_jabber", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.TxJabber)), ("tx-bad-fcs", ("tx_bad_fcs", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.TxBadFcs))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                    ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None
                                                self.sec30_support = None

                                                self.rx_pkt = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.RxPkt()
                                                self.rx_pkt.parent = self
                                                self._children_name_map["rx_pkt"] = "rx-pkt"

                                                self.stat_pkt = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.StatPkt()
                                                self.stat_pkt.parent = self
                                                self._children_name_map["stat_pkt"] = "stat-pkt"

                                                self.octet_stat = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OctetStat()
                                                self.octet_stat.parent = self
                                                self._children_name_map["octet_stat"] = "octet-stat"

                                                self.oversize_pkt_stat = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OversizePktStat()
                                                self.oversize_pkt_stat.parent = self
                                                self._children_name_map["oversize_pkt_stat"] = "oversize-pkt-stat"

                                                self.fcs_errors_stat = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.FcsErrorsStat()
                                                self.fcs_errors_stat.parent = self
                                                self._children_name_map["fcs_errors_stat"] = "fcs-errors-stat"

                                                self.long_frames_stat = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.LongFramesStat()
                                                self.long_frames_stat.parent = self
                                                self._children_name_map["long_frames_stat"] = "long-frames-stat"

                                                self.jabber_stat = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.JabberStat()
                                                self.jabber_stat.parent = self
                                                self._children_name_map["jabber_stat"] = "jabber-stat"

                                                self.ether64_octets = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.Ether64Octets()
                                                self.ether64_octets.parent = self
                                                self._children_name_map["ether64_octets"] = "ether64-octets"

                                                self.ether65127_octet = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.Ether65127Octet()
                                                self.ether65127_octet.parent = self
                                                self._children_name_map["ether65127_octet"] = "ether65127-octet"

                                                self.ether128255_octet = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.Ether128255Octet()
                                                self.ether128255_octet.parent = self
                                                self._children_name_map["ether128255_octet"] = "ether128255-octet"

                                                self.ether256511_octet = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.Ether256511Octet()
                                                self.ether256511_octet.parent = self
                                                self._children_name_map["ether256511_octet"] = "ether256511-octet"

                                                self.ether5121023_octet = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.Ether5121023Octet()
                                                self.ether5121023_octet.parent = self
                                                self._children_name_map["ether5121023_octet"] = "ether5121023-octet"

                                                self.ether10241518_octet = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.Ether10241518Octet()
                                                self.ether10241518_octet.parent = self
                                                self._children_name_map["ether10241518_octet"] = "ether10241518-octet"

                                                self.in_ucast_pkt = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InUcastPkt()
                                                self.in_ucast_pkt.parent = self
                                                self._children_name_map["in_ucast_pkt"] = "in-ucast-pkt"

                                                self.in_mcast_pkt = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InMcastPkt()
                                                self.in_mcast_pkt.parent = self
                                                self._children_name_map["in_mcast_pkt"] = "in-mcast-pkt"

                                                self.in_bcast_pkt = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InBcastPkt()
                                                self.in_bcast_pkt.parent = self
                                                self._children_name_map["in_bcast_pkt"] = "in-bcast-pkt"

                                                self.out_ucast_pkt = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutUcastPkt()
                                                self.out_ucast_pkt.parent = self
                                                self._children_name_map["out_ucast_pkt"] = "out-ucast-pkt"

                                                self.out_bcast_pkt = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutBcastPkt()
                                                self.out_bcast_pkt.parent = self
                                                self._children_name_map["out_bcast_pkt"] = "out-bcast-pkt"

                                                self.out_mcast_pkt = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutMcastPkt()
                                                self.out_mcast_pkt.parent = self
                                                self._children_name_map["out_mcast_pkt"] = "out-mcast-pkt"

                                                self.tx_pkt = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.TxPkt()
                                                self.tx_pkt.parent = self
                                                self._children_name_map["tx_pkt"] = "tx-pkt"

                                                self.if_in_errors = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.IfInErrors()
                                                self.if_in_errors.parent = self
                                                self._children_name_map["if_in_errors"] = "if-in-errors"

                                                self.if_in_octets = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.IfInOctets()
                                                self.if_in_octets.parent = self
                                                self._children_name_map["if_in_octets"] = "if-in-octets"

                                                self.ether_stat_multicast_pkt = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.EtherStatMulticastPkt()
                                                self.ether_stat_multicast_pkt.parent = self
                                                self._children_name_map["ether_stat_multicast_pkt"] = "ether-stat-multicast-pkt"

                                                self.ether_stat_broadcast_pkt = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.EtherStatBroadcastPkt()
                                                self.ether_stat_broadcast_pkt.parent = self
                                                self._children_name_map["ether_stat_broadcast_pkt"] = "ether-stat-broadcast-pkt"

                                                self.ether_stat_undersized_pkt = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.EtherStatUndersizedPkt()
                                                self.ether_stat_undersized_pkt.parent = self
                                                self._children_name_map["ether_stat_undersized_pkt"] = "ether-stat-undersized-pkt"

                                                self.out_octets = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutOctets()
                                                self.out_octets.parent = self
                                                self._children_name_map["out_octets"] = "out-octets"

                                                self.in_pause_frame = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InPauseFrame()
                                                self.in_pause_frame.parent = self
                                                self._children_name_map["in_pause_frame"] = "in-pause-frame"

                                                self.in_good_bytes = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InGoodBytes()
                                                self.in_good_bytes.parent = self
                                                self._children_name_map["in_good_bytes"] = "in-good-bytes"

                                                self.in8021q_frames = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.In8021qFrames()
                                                self.in8021q_frames.parent = self
                                                self._children_name_map["in8021q_frames"] = "in8021q-frames"

                                                self.in_pkts1519_max_octets = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InPkts1519MaxOctets()
                                                self.in_pkts1519_max_octets.parent = self
                                                self._children_name_map["in_pkts1519_max_octets"] = "in-pkts1519-max-octets"

                                                self.in_good_pkts = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InGoodPkts()
                                                self.in_good_pkts.parent = self
                                                self._children_name_map["in_good_pkts"] = "in-good-pkts"

                                                self.in_drop_overrun = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InDropOverrun()
                                                self.in_drop_overrun.parent = self
                                                self._children_name_map["in_drop_overrun"] = "in-drop-overrun"

                                                self.in_drop_abort = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InDropAbort()
                                                self.in_drop_abort.parent = self
                                                self._children_name_map["in_drop_abort"] = "in-drop-abort"

                                                self.in_drop_invalid_vlan = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InDropInvalidVlan()
                                                self.in_drop_invalid_vlan.parent = self
                                                self._children_name_map["in_drop_invalid_vlan"] = "in-drop-invalid-vlan"

                                                self.in_drop_invalid_dmac = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InDropInvalidDmac()
                                                self.in_drop_invalid_dmac.parent = self
                                                self._children_name_map["in_drop_invalid_dmac"] = "in-drop-invalid-dmac"

                                                self.in_drop_invalid_encap = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InDropInvalidEncap()
                                                self.in_drop_invalid_encap.parent = self
                                                self._children_name_map["in_drop_invalid_encap"] = "in-drop-invalid-encap"

                                                self.in_drop_other = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InDropOther()
                                                self.in_drop_other.parent = self
                                                self._children_name_map["in_drop_other"] = "in-drop-other"

                                                self.in_mib_giant = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InMibGiant()
                                                self.in_mib_giant.parent = self
                                                self._children_name_map["in_mib_giant"] = "in-mib-giant"

                                                self.in_mib_jabber = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InMibJabber()
                                                self.in_mib_jabber.parent = self
                                                self._children_name_map["in_mib_jabber"] = "in-mib-jabber"

                                                self.in_mibcrc = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InMibcrc()
                                                self.in_mibcrc.parent = self
                                                self._children_name_map["in_mibcrc"] = "in-mibcrc"

                                                self.in_error_collisions = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InErrorCollisions()
                                                self.in_error_collisions.parent = self
                                                self._children_name_map["in_error_collisions"] = "in-error-collisions"

                                                self.in_error_symbol = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InErrorSymbol()
                                                self.in_error_symbol.parent = self
                                                self._children_name_map["in_error_symbol"] = "in-error-symbol"

                                                self.out_good_bytes = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutGoodBytes()
                                                self.out_good_bytes.parent = self
                                                self._children_name_map["out_good_bytes"] = "out-good-bytes"

                                                self.out8021q_frames = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.Out8021qFrames()
                                                self.out8021q_frames.parent = self
                                                self._children_name_map["out8021q_frames"] = "out8021q-frames"

                                                self.out_pause_frames = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutPauseFrames()
                                                self.out_pause_frames.parent = self
                                                self._children_name_map["out_pause_frames"] = "out-pause-frames"

                                                self.out_pkts1519_max_octets = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutPkts1519MaxOctets()
                                                self.out_pkts1519_max_octets.parent = self
                                                self._children_name_map["out_pkts1519_max_octets"] = "out-pkts1519-max-octets"

                                                self.out_good_pkts = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutGoodPkts()
                                                self.out_good_pkts.parent = self
                                                self._children_name_map["out_good_pkts"] = "out-good-pkts"

                                                self.out_drop_underrun = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutDropUnderrun()
                                                self.out_drop_underrun.parent = self
                                                self._children_name_map["out_drop_underrun"] = "out-drop-underrun"

                                                self.out_drop_abort = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutDropAbort()
                                                self.out_drop_abort.parent = self
                                                self._children_name_map["out_drop_abort"] = "out-drop-abort"

                                                self.out_drop_other = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutDropOther()
                                                self.out_drop_other.parent = self
                                                self._children_name_map["out_drop_other"] = "out-drop-other"

                                                self.out_error_other = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutErrorOther()
                                                self.out_error_other.parent = self
                                                self._children_name_map["out_error_other"] = "out-error-other"

                                                self.in_error_giant = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InErrorGiant()
                                                self.in_error_giant.parent = self
                                                self._children_name_map["in_error_giant"] = "in-error-giant"

                                                self.in_error_runt = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InErrorRunt()
                                                self.in_error_runt.parent = self
                                                self._children_name_map["in_error_runt"] = "in-error-runt"

                                                self.in_error_jabbers = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InErrorJabbers()
                                                self.in_error_jabbers.parent = self
                                                self._children_name_map["in_error_jabbers"] = "in-error-jabbers"

                                                self.in_error_fragments = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InErrorFragments()
                                                self.in_error_fragments.parent = self
                                                self._children_name_map["in_error_fragments"] = "in-error-fragments"

                                                self.in_error_other = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InErrorOther()
                                                self.in_error_other.parent = self
                                                self._children_name_map["in_error_other"] = "in-error-other"

                                                self.in_pkt64_octet = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InPkt64Octet()
                                                self.in_pkt64_octet.parent = self
                                                self._children_name_map["in_pkt64_octet"] = "in-pkt64-octet"

                                                self.in_pkts65_to127_octets = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InPkts65To127Octets()
                                                self.in_pkts65_to127_octets.parent = self
                                                self._children_name_map["in_pkts65_to127_octets"] = "in-pkts65-to127-octets"

                                                self.in_pkts128_to255_octets = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InPkts128To255Octets()
                                                self.in_pkts128_to255_octets.parent = self
                                                self._children_name_map["in_pkts128_to255_octets"] = "in-pkts128-to255-octets"

                                                self.in_pkts256_to511_octets = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InPkts256To511Octets()
                                                self.in_pkts256_to511_octets.parent = self
                                                self._children_name_map["in_pkts256_to511_octets"] = "in-pkts256-to511-octets"

                                                self.in_pkts512_to1023_octets = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InPkts512To1023Octets()
                                                self.in_pkts512_to1023_octets.parent = self
                                                self._children_name_map["in_pkts512_to1023_octets"] = "in-pkts512-to1023-octets"

                                                self.in_pkts1024_to1518_octets = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InPkts1024To1518Octets()
                                                self.in_pkts1024_to1518_octets.parent = self
                                                self._children_name_map["in_pkts1024_to1518_octets"] = "in-pkts1024-to1518-octets"

                                                self.outpkt64octet = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.Outpkt64octet()
                                                self.outpkt64octet.parent = self
                                                self._children_name_map["outpkt64octet"] = "outpkt64octet"

                                                self.out_pkts65127_octets = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutPkts65127Octets()
                                                self.out_pkts65127_octets.parent = self
                                                self._children_name_map["out_pkts65127_octets"] = "out-pkts65127-octets"

                                                self.out_pkts128255_octets = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutPkts128255Octets()
                                                self.out_pkts128255_octets.parent = self
                                                self._children_name_map["out_pkts128255_octets"] = "out-pkts128255-octets"

                                                self.out_pkts256511_octets = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutPkts256511Octets()
                                                self.out_pkts256511_octets.parent = self
                                                self._children_name_map["out_pkts256511_octets"] = "out-pkts256511-octets"

                                                self.out_pkts5121023_octets = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutPkts5121023Octets()
                                                self.out_pkts5121023_octets.parent = self
                                                self._children_name_map["out_pkts5121023_octets"] = "out-pkts5121023-octets"

                                                self.out_pkts10241518_octets = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutPkts10241518Octets()
                                                self.out_pkts10241518_octets.parent = self
                                                self._children_name_map["out_pkts10241518_octets"] = "out-pkts10241518-octets"

                                                self.rx_util = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.RxUtil()
                                                self.rx_util.parent = self
                                                self._children_name_map["rx_util"] = "rx-util"

                                                self.tx_util = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.TxUtil()
                                                self.tx_util.parent = self
                                                self._children_name_map["tx_util"] = "tx-util"

                                                self.tx_undersized_pkt = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.TxUndersizedPkt()
                                                self.tx_undersized_pkt.parent = self
                                                self._children_name_map["tx_undersized_pkt"] = "tx-undersized-pkt"

                                                self.tx_oversized_pkt = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.TxOversizedPkt()
                                                self.tx_oversized_pkt.parent = self
                                                self._children_name_map["tx_oversized_pkt"] = "tx-oversized-pkt"

                                                self.tx_fragments = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.TxFragments()
                                                self.tx_fragments.parent = self
                                                self._children_name_map["tx_fragments"] = "tx-fragments"

                                                self.tx_jabber = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.TxJabber()
                                                self.tx_jabber.parent = self
                                                self._children_name_map["tx_jabber"] = "tx-jabber"

                                                self.tx_bad_fcs = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.TxBadFcs()
                                                self.tx_bad_fcs.parent = self
                                                self._children_name_map["tx_bad_fcs"] = "tx-bad-fcs"
                                                self._segment_path = lambda: "macsec-second30-ether-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear30_sec_time', 'last_clear15_min_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                            class RxPkt(Entity):
                                                """
                                                RX PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.RxPkt, self).__init__()

                                                    self.yang_name = "rx-pkt"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "rx-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.RxPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class StatPkt(Entity):
                                                """
                                                STAT PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.StatPkt, self).__init__()

                                                    self.yang_name = "stat-pkt"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "stat-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.StatPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OctetStat(Entity):
                                                """
                                                OCTET STAT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OctetStat, self).__init__()

                                                    self.yang_name = "octet-stat"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "octet-stat"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OctetStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OversizePktStat(Entity):
                                                """
                                                OVERSIZE PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OversizePktStat, self).__init__()

                                                    self.yang_name = "oversize-pkt-stat"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "oversize-pkt-stat"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OversizePktStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class FcsErrorsStat(Entity):
                                                """
                                                FCS ERR
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.FcsErrorsStat, self).__init__()

                                                    self.yang_name = "fcs-errors-stat"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "fcs-errors-stat"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.FcsErrorsStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class LongFramesStat(Entity):
                                                """
                                                LONG FRAMES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.LongFramesStat, self).__init__()

                                                    self.yang_name = "long-frames-stat"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "long-frames-stat"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.LongFramesStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class JabberStat(Entity):
                                                """
                                                JABBER STATS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.JabberStat, self).__init__()

                                                    self.yang_name = "jabber-stat"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "jabber-stat"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.JabberStat, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class Ether64Octets(Entity):
                                                """
                                                SIXTY FOUR OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.Ether64Octets, self).__init__()

                                                    self.yang_name = "ether64-octets"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ether64-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.Ether64Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class Ether65127Octet(Entity):
                                                """
                                                OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.Ether65127Octet, self).__init__()

                                                    self.yang_name = "ether65127-octet"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ether65127-octet"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.Ether65127Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class Ether128255Octet(Entity):
                                                """
                                                TFF OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.Ether128255Octet, self).__init__()

                                                    self.yang_name = "ether128255-octet"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ether128255-octet"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.Ether128255Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class Ether256511Octet(Entity):
                                                """
                                                FOO OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.Ether256511Octet, self).__init__()

                                                    self.yang_name = "ether256511-octet"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ether256511-octet"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.Ether256511Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class Ether5121023Octet(Entity):
                                                """
                                                OZTT OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.Ether5121023Octet, self).__init__()

                                                    self.yang_name = "ether5121023-octet"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ether5121023-octet"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.Ether5121023Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class Ether10241518Octet(Entity):
                                                """
                                                OFO OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.Ether10241518Octet, self).__init__()

                                                    self.yang_name = "ether10241518-octet"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ether10241518-octet"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.Ether10241518Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InUcastPkt(Entity):
                                                """
                                                IN UCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InUcastPkt, self).__init__()

                                                    self.yang_name = "in-ucast-pkt"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-ucast-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InUcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InMcastPkt(Entity):
                                                """
                                                IN MCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InMcastPkt, self).__init__()

                                                    self.yang_name = "in-mcast-pkt"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-mcast-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InMcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InBcastPkt(Entity):
                                                """
                                                IN BCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InBcastPkt, self).__init__()

                                                    self.yang_name = "in-bcast-pkt"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-bcast-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InBcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutUcastPkt(Entity):
                                                """
                                                OUT UCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutUcastPkt, self).__init__()

                                                    self.yang_name = "out-ucast-pkt"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-ucast-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutUcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutBcastPkt(Entity):
                                                """
                                                OUT BCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutBcastPkt, self).__init__()

                                                    self.yang_name = "out-bcast-pkt"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-bcast-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutBcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutMcastPkt(Entity):
                                                """
                                                OUT MCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutMcastPkt, self).__init__()

                                                    self.yang_name = "out-mcast-pkt"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-mcast-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutMcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class TxPkt(Entity):
                                                """
                                                TX PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.TxPkt, self).__init__()

                                                    self.yang_name = "tx-pkt"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "tx-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.TxPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class IfInErrors(Entity):
                                                """
                                                IFIN ERRORS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.IfInErrors, self).__init__()

                                                    self.yang_name = "if-in-errors"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "if-in-errors"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.IfInErrors, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class IfInOctets(Entity):
                                                """
                                                IFIN OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.IfInOctets, self).__init__()

                                                    self.yang_name = "if-in-octets"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "if-in-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.IfInOctets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class EtherStatMulticastPkt(Entity):
                                                """
                                                ETHER STAT MULTICAST PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.EtherStatMulticastPkt, self).__init__()

                                                    self.yang_name = "ether-stat-multicast-pkt"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ether-stat-multicast-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.EtherStatMulticastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class EtherStatBroadcastPkt(Entity):
                                                """
                                                ETHER STAT BROADCAST PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.EtherStatBroadcastPkt, self).__init__()

                                                    self.yang_name = "ether-stat-broadcast-pkt"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ether-stat-broadcast-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.EtherStatBroadcastPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class EtherStatUndersizedPkt(Entity):
                                                """
                                                ETHER STAT UNDERSIZED PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.EtherStatUndersizedPkt, self).__init__()

                                                    self.yang_name = "ether-stat-undersized-pkt"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ether-stat-undersized-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.EtherStatUndersizedPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutOctets(Entity):
                                                """
                                                OUT OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutOctets, self).__init__()

                                                    self.yang_name = "out-octets"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutOctets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPauseFrame(Entity):
                                                """
                                                INPUT PAUSE FRAME
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InPauseFrame, self).__init__()

                                                    self.yang_name = "in-pause-frame"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pause-frame"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InPauseFrame, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InGoodBytes(Entity):
                                                """
                                                INPUT GOOD BYTES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InGoodBytes, self).__init__()

                                                    self.yang_name = "in-good-bytes"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-good-bytes"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InGoodBytes, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class In8021qFrames(Entity):
                                                """
                                                INPUT 802 1Q FRAMES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.In8021qFrames, self).__init__()

                                                    self.yang_name = "in8021q-frames"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in8021q-frames"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.In8021qFrames, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPkts1519MaxOctets(Entity):
                                                """
                                                INPUT PKTS 1519MAX OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InPkts1519MaxOctets, self).__init__()

                                                    self.yang_name = "in-pkts1519-max-octets"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts1519-max-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InPkts1519MaxOctets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InGoodPkts(Entity):
                                                """
                                                INPUT GOOD PKTS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InGoodPkts, self).__init__()

                                                    self.yang_name = "in-good-pkts"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-good-pkts"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InGoodPkts, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InDropOverrun(Entity):
                                                """
                                                INPUT DROP OVERRUN
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InDropOverrun, self).__init__()

                                                    self.yang_name = "in-drop-overrun"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-drop-overrun"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InDropOverrun, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InDropAbort(Entity):
                                                """
                                                INPUT DROP ABORT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InDropAbort, self).__init__()

                                                    self.yang_name = "in-drop-abort"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-drop-abort"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InDropAbort, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InDropInvalidVlan(Entity):
                                                """
                                                INPUT DROP INVALID VLAN
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InDropInvalidVlan, self).__init__()

                                                    self.yang_name = "in-drop-invalid-vlan"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-drop-invalid-vlan"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InDropInvalidVlan, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InDropInvalidDmac(Entity):
                                                """
                                                INPUT DROP INVALID DMAC
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InDropInvalidDmac, self).__init__()

                                                    self.yang_name = "in-drop-invalid-dmac"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-drop-invalid-dmac"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InDropInvalidDmac, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InDropInvalidEncap(Entity):
                                                """
                                                INPUT DROP INVALID ENCAP
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InDropInvalidEncap, self).__init__()

                                                    self.yang_name = "in-drop-invalid-encap"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-drop-invalid-encap"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InDropInvalidEncap, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InDropOther(Entity):
                                                """
                                                INPUT DROP OTHER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InDropOther, self).__init__()

                                                    self.yang_name = "in-drop-other"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-drop-other"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InDropOther, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InMibGiant(Entity):
                                                """
                                                INPUT MIB GIANT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InMibGiant, self).__init__()

                                                    self.yang_name = "in-mib-giant"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-mib-giant"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InMibGiant, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InMibJabber(Entity):
                                                """
                                                INPUT MIB JABBER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InMibJabber, self).__init__()

                                                    self.yang_name = "in-mib-jabber"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-mib-jabber"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InMibJabber, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InMibcrc(Entity):
                                                """
                                                IN MIB CRC
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InMibcrc, self).__init__()

                                                    self.yang_name = "in-mibcrc"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-mibcrc"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InMibcrc, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InErrorCollisions(Entity):
                                                """
                                                IN ERROR COLLISIONS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InErrorCollisions, self).__init__()

                                                    self.yang_name = "in-error-collisions"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-error-collisions"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InErrorCollisions, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InErrorSymbol(Entity):
                                                """
                                                IN ERROR SYMBOL
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InErrorSymbol, self).__init__()

                                                    self.yang_name = "in-error-symbol"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-error-symbol"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InErrorSymbol, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutGoodBytes(Entity):
                                                """
                                                OUT GOOD BYTES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutGoodBytes, self).__init__()

                                                    self.yang_name = "out-good-bytes"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-good-bytes"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutGoodBytes, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class Out8021qFrames(Entity):
                                                """
                                                OUT 802 1Q FRAMES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.Out8021qFrames, self).__init__()

                                                    self.yang_name = "out8021q-frames"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out8021q-frames"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.Out8021qFrames, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutPauseFrames(Entity):
                                                """
                                                OUT PAUSE FRAMES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutPauseFrames, self).__init__()

                                                    self.yang_name = "out-pause-frames"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-pause-frames"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutPauseFrames, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutPkts1519MaxOctets(Entity):
                                                """
                                                OUT PKTS 1519 MAX OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutPkts1519MaxOctets, self).__init__()

                                                    self.yang_name = "out-pkts1519-max-octets"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-pkts1519-max-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutPkts1519MaxOctets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutGoodPkts(Entity):
                                                """
                                                OUT GOOD PKTS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutGoodPkts, self).__init__()

                                                    self.yang_name = "out-good-pkts"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-good-pkts"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutGoodPkts, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutDropUnderrun(Entity):
                                                """
                                                OUT DROP UNDERRUN
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutDropUnderrun, self).__init__()

                                                    self.yang_name = "out-drop-underrun"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-drop-underrun"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutDropUnderrun, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutDropAbort(Entity):
                                                """
                                                OUT DROP ABORT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutDropAbort, self).__init__()

                                                    self.yang_name = "out-drop-abort"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-drop-abort"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutDropAbort, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutDropOther(Entity):
                                                """
                                                OUT DROP OTHER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutDropOther, self).__init__()

                                                    self.yang_name = "out-drop-other"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-drop-other"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutDropOther, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutErrorOther(Entity):
                                                """
                                                OUT ERROR OTHER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutErrorOther, self).__init__()

                                                    self.yang_name = "out-error-other"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-error-other"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutErrorOther, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InErrorGiant(Entity):
                                                """
                                                IN ERROR GIANT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InErrorGiant, self).__init__()

                                                    self.yang_name = "in-error-giant"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-error-giant"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InErrorGiant, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InErrorRunt(Entity):
                                                """
                                                IN ERROR RUNT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InErrorRunt, self).__init__()

                                                    self.yang_name = "in-error-runt"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-error-runt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InErrorRunt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InErrorJabbers(Entity):
                                                """
                                                IN ERROR JABBERS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InErrorJabbers, self).__init__()

                                                    self.yang_name = "in-error-jabbers"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-error-jabbers"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InErrorJabbers, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InErrorFragments(Entity):
                                                """
                                                IN ERROR FRAGMENTS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InErrorFragments, self).__init__()

                                                    self.yang_name = "in-error-fragments"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-error-fragments"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InErrorFragments, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InErrorOther(Entity):
                                                """
                                                IN ERROR OTHER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InErrorOther, self).__init__()

                                                    self.yang_name = "in-error-other"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-error-other"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InErrorOther, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPkt64Octet(Entity):
                                                """
                                                IN PKT 64 OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InPkt64Octet, self).__init__()

                                                    self.yang_name = "in-pkt64-octet"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkt64-octet"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InPkt64Octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPkts65To127Octets(Entity):
                                                """
                                                IN PKTS 65 127OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InPkts65To127Octets, self).__init__()

                                                    self.yang_name = "in-pkts65-to127-octets"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts65-to127-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InPkts65To127Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPkts128To255Octets(Entity):
                                                """
                                                IN PKTS 128 255 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InPkts128To255Octets, self).__init__()

                                                    self.yang_name = "in-pkts128-to255-octets"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts128-to255-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InPkts128To255Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPkts256To511Octets(Entity):
                                                """
                                                IN PKTS 256 511 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InPkts256To511Octets, self).__init__()

                                                    self.yang_name = "in-pkts256-to511-octets"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts256-to511-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InPkts256To511Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPkts512To1023Octets(Entity):
                                                """
                                                IN PKTS 512 1023 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InPkts512To1023Octets, self).__init__()

                                                    self.yang_name = "in-pkts512-to1023-octets"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts512-to1023-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InPkts512To1023Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPkts1024To1518Octets(Entity):
                                                """
                                                IN PKTS 1024 1518 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InPkts1024To1518Octets, self).__init__()

                                                    self.yang_name = "in-pkts1024-to1518-octets"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts1024-to1518-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.InPkts1024To1518Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class Outpkt64octet(Entity):
                                                """
                                                OUT PKT 64 OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.Outpkt64octet, self).__init__()

                                                    self.yang_name = "outpkt64octet"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "outpkt64octet"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.Outpkt64octet, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutPkts65127Octets(Entity):
                                                """
                                                OUT PKTS 65 127OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutPkts65127Octets, self).__init__()

                                                    self.yang_name = "out-pkts65127-octets"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-pkts65127-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutPkts65127Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutPkts128255Octets(Entity):
                                                """
                                                OUT PKTS 128 255 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutPkts128255Octets, self).__init__()

                                                    self.yang_name = "out-pkts128255-octets"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-pkts128255-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutPkts128255Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutPkts256511Octets(Entity):
                                                """
                                                OUT PKTS 256 511 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutPkts256511Octets, self).__init__()

                                                    self.yang_name = "out-pkts256511-octets"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-pkts256511-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutPkts256511Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutPkts5121023Octets(Entity):
                                                """
                                                OUT PKTS 512 1023 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutPkts5121023Octets, self).__init__()

                                                    self.yang_name = "out-pkts5121023-octets"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-pkts5121023-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutPkts5121023Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutPkts10241518Octets(Entity):
                                                """
                                                OUT PKTS 1024 1518 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutPkts10241518Octets, self).__init__()

                                                    self.yang_name = "out-pkts10241518-octets"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-pkts10241518-octets"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.OutPkts10241518Octets, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class RxUtil(Entity):
                                                """
                                                Rx Utilization in Percent
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: str
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.RxUtil, self).__init__()

                                                    self.yang_name = "rx-util"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                        ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "rx-util"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.RxUtil, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class TxUtil(Entity):
                                                """
                                                Tx Utilization in Percent
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: str
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.TxUtil, self).__init__()

                                                    self.yang_name = "tx-util"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                        ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "tx-util"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.TxUtil, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class TxUndersizedPkt(Entity):
                                                """
                                                TX Undersized Pkt
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.TxUndersizedPkt, self).__init__()

                                                    self.yang_name = "tx-undersized-pkt"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "tx-undersized-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.TxUndersizedPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class TxOversizedPkt(Entity):
                                                """
                                                TX Oversized Pkt
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.TxOversizedPkt, self).__init__()

                                                    self.yang_name = "tx-oversized-pkt"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "tx-oversized-pkt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.TxOversizedPkt, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class TxFragments(Entity):
                                                """
                                                TX Fragments
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.TxFragments, self).__init__()

                                                    self.yang_name = "tx-fragments"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "tx-fragments"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.TxFragments, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class TxJabber(Entity):
                                                """
                                                TX Jabber
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.TxJabber, self).__init__()

                                                    self.yang_name = "tx-jabber"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "tx-jabber"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.TxJabber, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class TxBadFcs(Entity):
                                                """
                                                TX Bad Fcs
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.TxBadFcs, self).__init__()

                                                    self.yang_name = "tx-bad-fcs"
                                                    self.yang_parent_name = "macsec-second30-ether-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "tx-bad-fcs"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30EtherHistories.MacsecSecond30EtherHistory.MacsecSecond30EtherTimeLineInstances.MacsecSecond30EtherTimeLineInstance.TxBadFcs, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                            class MacsecSecond30secytxHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: macsec_second30secytx_history
                                
                                	port 30\-second secy\_tx performance data
                                	**type**\: list of  		 :py:class:`MacsecSecond30secytxHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secytxHistories.MacsecSecond30secytxHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secytxHistories, self).__init__()

                                    self.yang_name = "macsec-second30secytx-histories"
                                    self.yang_parent_name = "macsec-second30-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("macsec-second30secytx-history", ("macsec_second30secytx_history", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secytxHistories.MacsecSecond30secytxHistory))])
                                    self._leafs = OrderedDict()

                                    self.macsec_second30secytx_history = YList(self)
                                    self._segment_path = lambda: "macsec-second30secytx-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secytxHistories, [], name, value)


                                class MacsecSecond30secytxHistory(Entity):
                                    """
                                    port 30\-second secy\_tx performance data
                                    
                                    .. attribute:: number  (key)
                                    
                                    	channel number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: macsec_second30secytx_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`MacsecSecond30secytxTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secytxHistories.MacsecSecond30secytxHistory.MacsecSecond30secytxTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secytxHistories.MacsecSecond30secytxHistory, self).__init__()

                                        self.yang_name = "macsec-second30secytx-history"
                                        self.yang_parent_name = "macsec-second30secytx-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([("macsec-second30secytx-time-line-instances", ("macsec_second30secytx_time_line_instances", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secytxHistories.MacsecSecond30secytxHistory.MacsecSecond30secytxTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ])
                                        self.number = None

                                        self.macsec_second30secytx_time_line_instances = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secytxHistories.MacsecSecond30secytxHistory.MacsecSecond30secytxTimeLineInstances()
                                        self.macsec_second30secytx_time_line_instances.parent = self
                                        self._children_name_map["macsec_second30secytx_time_line_instances"] = "macsec-second30secytx-time-line-instances"
                                        self._segment_path = lambda: "macsec-second30secytx-history" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secytxHistories.MacsecSecond30secytxHistory, ['number'], name, value)


                                    class MacsecSecond30secytxTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: macsec_second30secytx_time_line_instance
                                        
                                        	port 30\-second secy\_tx performance data
                                        	**type**\: list of  		 :py:class:`MacsecSecond30secytxTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secytxHistories.MacsecSecond30secytxHistory.MacsecSecond30secytxTimeLineInstances.MacsecSecond30secytxTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secytxHistories.MacsecSecond30secytxHistory.MacsecSecond30secytxTimeLineInstances, self).__init__()

                                            self.yang_name = "macsec-second30secytx-time-line-instances"
                                            self.yang_parent_name = "macsec-second30secytx-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("macsec-second30secytx-time-line-instance", ("macsec_second30secytx_time_line_instance", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secytxHistories.MacsecSecond30secytxHistory.MacsecSecond30secytxTimeLineInstances.MacsecSecond30secytxTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.macsec_second30secytx_time_line_instance = YList(self)
                                            self._segment_path = lambda: "macsec-second30secytx-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secytxHistories.MacsecSecond30secytxHistory.MacsecSecond30secytxTimeLineInstances, [], name, value)


                                        class MacsecSecond30secytxTimeLineInstance(Entity):
                                            """
                                            port 30\-second secy\_tx performance data
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: out_pkts_protected
                                            
                                            	Out Packets Protected
                                            	**type**\:  :py:class:`OutPktsProtected <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secytxHistories.MacsecSecond30secytxHistory.MacsecSecond30secytxTimeLineInstances.MacsecSecond30secytxTimeLineInstance.OutPktsProtected>`
                                            
                                            .. attribute:: out_pkts_encrypted
                                            
                                            	Out Packets Encrypted
                                            	**type**\:  :py:class:`OutPktsEncrypted <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secytxHistories.MacsecSecond30secytxHistory.MacsecSecond30secytxTimeLineInstances.MacsecSecond30secytxTimeLineInstance.OutPktsEncrypted>`
                                            
                                            .. attribute:: out_octets_protected
                                            
                                            	Out Octets Protected 
                                            	**type**\:  :py:class:`OutOctetsProtected <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secytxHistories.MacsecSecond30secytxHistory.MacsecSecond30secytxTimeLineInstances.MacsecSecond30secytxTimeLineInstance.OutOctetsProtected>`
                                            
                                            .. attribute:: out_octets_encrypted
                                            
                                            	Out Octets Encrypted
                                            	**type**\:  :py:class:`OutOctetsEncrypted <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secytxHistories.MacsecSecond30secytxHistory.MacsecSecond30secytxTimeLineInstances.MacsecSecond30secytxTimeLineInstance.OutOctetsEncrypted>`
                                            
                                            .. attribute:: out_pkts_too_long
                                            
                                            	Out Packets Too Long
                                            	**type**\:  :py:class:`OutPktsTooLong <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secytxHistories.MacsecSecond30secytxHistory.MacsecSecond30secytxTimeLineInstances.MacsecSecond30secytxTimeLineInstance.OutPktsTooLong>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\: bool
                                            
                                            .. attribute:: sample_count
                                            
                                            	Running Sample Count
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secytxHistories.MacsecSecond30secytxHistory.MacsecSecond30secytxTimeLineInstances.MacsecSecond30secytxTimeLineInstance, self).__init__()

                                                self.yang_name = "macsec-second30secytx-time-line-instance"
                                                self.yang_parent_name = "macsec-second30secytx-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("out-pkts-protected", ("out_pkts_protected", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secytxHistories.MacsecSecond30secytxHistory.MacsecSecond30secytxTimeLineInstances.MacsecSecond30secytxTimeLineInstance.OutPktsProtected)), ("out-pkts-encrypted", ("out_pkts_encrypted", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secytxHistories.MacsecSecond30secytxHistory.MacsecSecond30secytxTimeLineInstances.MacsecSecond30secytxTimeLineInstance.OutPktsEncrypted)), ("out-octets-protected", ("out_octets_protected", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secytxHistories.MacsecSecond30secytxHistory.MacsecSecond30secytxTimeLineInstances.MacsecSecond30secytxTimeLineInstance.OutOctetsProtected)), ("out-octets-encrypted", ("out_octets_encrypted", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secytxHistories.MacsecSecond30secytxHistory.MacsecSecond30secytxTimeLineInstances.MacsecSecond30secytxTimeLineInstance.OutOctetsEncrypted)), ("out-pkts-too-long", ("out_pkts_too_long", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secytxHistories.MacsecSecond30secytxHistory.MacsecSecond30secytxTimeLineInstances.MacsecSecond30secytxTimeLineInstance.OutPktsTooLong))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                    ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                                    ('sample_count', (YLeaf(YType.uint64, 'sample-count'), ['int'])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear24_hr_time = None
                                                self.sec30_support = None
                                                self.sample_count = None

                                                self.out_pkts_protected = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secytxHistories.MacsecSecond30secytxHistory.MacsecSecond30secytxTimeLineInstances.MacsecSecond30secytxTimeLineInstance.OutPktsProtected()
                                                self.out_pkts_protected.parent = self
                                                self._children_name_map["out_pkts_protected"] = "out-pkts-protected"

                                                self.out_pkts_encrypted = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secytxHistories.MacsecSecond30secytxHistory.MacsecSecond30secytxTimeLineInstances.MacsecSecond30secytxTimeLineInstance.OutPktsEncrypted()
                                                self.out_pkts_encrypted.parent = self
                                                self._children_name_map["out_pkts_encrypted"] = "out-pkts-encrypted"

                                                self.out_octets_protected = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secytxHistories.MacsecSecond30secytxHistory.MacsecSecond30secytxTimeLineInstances.MacsecSecond30secytxTimeLineInstance.OutOctetsProtected()
                                                self.out_octets_protected.parent = self
                                                self._children_name_map["out_octets_protected"] = "out-octets-protected"

                                                self.out_octets_encrypted = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secytxHistories.MacsecSecond30secytxHistory.MacsecSecond30secytxTimeLineInstances.MacsecSecond30secytxTimeLineInstance.OutOctetsEncrypted()
                                                self.out_octets_encrypted.parent = self
                                                self._children_name_map["out_octets_encrypted"] = "out-octets-encrypted"

                                                self.out_pkts_too_long = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secytxHistories.MacsecSecond30secytxHistory.MacsecSecond30secytxTimeLineInstances.MacsecSecond30secytxTimeLineInstance.OutPktsTooLong()
                                                self.out_pkts_too_long.parent = self
                                                self._children_name_map["out_pkts_too_long"] = "out-pkts-too-long"
                                                self._segment_path = lambda: "macsec-second30secytx-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secytxHistories.MacsecSecond30secytxHistory.MacsecSecond30secytxTimeLineInstances.MacsecSecond30secytxTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support', 'sample_count'], name, value)


                                            class OutPktsProtected(Entity):
                                                """
                                                Out Packets Protected
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secytxHistories.MacsecSecond30secytxHistory.MacsecSecond30secytxTimeLineInstances.MacsecSecond30secytxTimeLineInstance.OutPktsProtected, self).__init__()

                                                    self.yang_name = "out-pkts-protected"
                                                    self.yang_parent_name = "macsec-second30secytx-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-pkts-protected"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secytxHistories.MacsecSecond30secytxHistory.MacsecSecond30secytxTimeLineInstances.MacsecSecond30secytxTimeLineInstance.OutPktsProtected, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutPktsEncrypted(Entity):
                                                """
                                                Out Packets Encrypted
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secytxHistories.MacsecSecond30secytxHistory.MacsecSecond30secytxTimeLineInstances.MacsecSecond30secytxTimeLineInstance.OutPktsEncrypted, self).__init__()

                                                    self.yang_name = "out-pkts-encrypted"
                                                    self.yang_parent_name = "macsec-second30secytx-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-pkts-encrypted"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secytxHistories.MacsecSecond30secytxHistory.MacsecSecond30secytxTimeLineInstances.MacsecSecond30secytxTimeLineInstance.OutPktsEncrypted, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutOctetsProtected(Entity):
                                                """
                                                Out Octets Protected 
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secytxHistories.MacsecSecond30secytxHistory.MacsecSecond30secytxTimeLineInstances.MacsecSecond30secytxTimeLineInstance.OutOctetsProtected, self).__init__()

                                                    self.yang_name = "out-octets-protected"
                                                    self.yang_parent_name = "macsec-second30secytx-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-octets-protected"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secytxHistories.MacsecSecond30secytxHistory.MacsecSecond30secytxTimeLineInstances.MacsecSecond30secytxTimeLineInstance.OutOctetsProtected, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutOctetsEncrypted(Entity):
                                                """
                                                Out Octets Encrypted
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secytxHistories.MacsecSecond30secytxHistory.MacsecSecond30secytxTimeLineInstances.MacsecSecond30secytxTimeLineInstance.OutOctetsEncrypted, self).__init__()

                                                    self.yang_name = "out-octets-encrypted"
                                                    self.yang_parent_name = "macsec-second30secytx-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-octets-encrypted"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secytxHistories.MacsecSecond30secytxHistory.MacsecSecond30secytxTimeLineInstances.MacsecSecond30secytxTimeLineInstance.OutOctetsEncrypted, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutPktsTooLong(Entity):
                                                """
                                                Out Packets Too Long
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secytxHistories.MacsecSecond30secytxHistory.MacsecSecond30secytxTimeLineInstances.MacsecSecond30secytxTimeLineInstance.OutPktsTooLong, self).__init__()

                                                    self.yang_name = "out-pkts-too-long"
                                                    self.yang_parent_name = "macsec-second30secytx-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-pkts-too-long"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secytxHistories.MacsecSecond30secytxHistory.MacsecSecond30secytxTimeLineInstances.MacsecSecond30secytxTimeLineInstance.OutPktsTooLong, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                            class MacsecSecond30secyifHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: macsec_second30secyif_history
                                
                                	port 30\-second secy\_if performance data
                                	**type**\: list of  		 :py:class:`MacsecSecond30secyifHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories, self).__init__()

                                    self.yang_name = "macsec-second30secyif-histories"
                                    self.yang_parent_name = "macsec-second30-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("macsec-second30secyif-history", ("macsec_second30secyif_history", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory))])
                                    self._leafs = OrderedDict()

                                    self.macsec_second30secyif_history = YList(self)
                                    self._segment_path = lambda: "macsec-second30secyif-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories, [], name, value)


                                class MacsecSecond30secyifHistory(Entity):
                                    """
                                    port 30\-second secy\_if performance data
                                    
                                    .. attribute:: number  (key)
                                    
                                    	channel number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: macsec_second30secyif_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`MacsecSecond30secyifTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory, self).__init__()

                                        self.yang_name = "macsec-second30secyif-history"
                                        self.yang_parent_name = "macsec-second30secyif-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([("macsec-second30secyif-time-line-instances", ("macsec_second30secyif_time_line_instances", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ])
                                        self.number = None

                                        self.macsec_second30secyif_time_line_instances = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances()
                                        self.macsec_second30secyif_time_line_instances.parent = self
                                        self._children_name_map["macsec_second30secyif_time_line_instances"] = "macsec-second30secyif-time-line-instances"
                                        self._segment_path = lambda: "macsec-second30secyif-history" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory, ['number'], name, value)


                                    class MacsecSecond30secyifTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: macsec_second30secyif_time_line_instance
                                        
                                        	port 30\-second secy\_if performance data
                                        	**type**\: list of  		 :py:class:`MacsecSecond30secyifTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances, self).__init__()

                                            self.yang_name = "macsec-second30secyif-time-line-instances"
                                            self.yang_parent_name = "macsec-second30secyif-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("macsec-second30secyif-time-line-instance", ("macsec_second30secyif_time_line_instance", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.macsec_second30secyif_time_line_instance = YList(self)
                                            self._segment_path = lambda: "macsec-second30secyif-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances, [], name, value)


                                        class MacsecSecond30secyifTimeLineInstance(Entity):
                                            """
                                            port 30\-second secy\_if performance data
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: in_pkts_untagged
                                            
                                            	In Packet Untagged
                                            	**type**\:  :py:class:`InPktsUntagged <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.InPktsUntagged>`
                                            
                                            .. attribute:: in_pkts_no_tag
                                            
                                            	In Packet No tag
                                            	**type**\:  :py:class:`InPktsNoTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.InPktsNoTag>`
                                            
                                            .. attribute:: in_pkts_bad_tag
                                            
                                            	In Packet Bad tag
                                            	**type**\:  :py:class:`InPktsBadTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.InPktsBadTag>`
                                            
                                            .. attribute:: in_pkts_unknown_sci
                                            
                                            	In Packet Unknown sci
                                            	**type**\:  :py:class:`InPktsUnknownSci <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.InPktsUnknownSci>`
                                            
                                            .. attribute:: in_pkts_no_sci
                                            
                                            	In Packet No sci
                                            	**type**\:  :py:class:`InPktsNoSci <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.InPktsNoSci>`
                                            
                                            .. attribute:: in_pkts_overrun
                                            
                                            	In Packet Overrun
                                            	**type**\:  :py:class:`InPktsOverrun <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.InPktsOverrun>`
                                            
                                            .. attribute:: in_octets_validated
                                            
                                            	In Octet Validated
                                            	**type**\:  :py:class:`InOctetsValidated <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.InOctetsValidated>`
                                            
                                            .. attribute:: in_octets_decrypted
                                            
                                            	In Octet Decrypted
                                            	**type**\:  :py:class:`InOctetsDecrypted <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.InOctetsDecrypted>`
                                            
                                            .. attribute:: out_pkts_untagged
                                            
                                            	Out Packet Untagged
                                            	**type**\:  :py:class:`OutPktsUntagged <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.OutPktsUntagged>`
                                            
                                            .. attribute:: out_pkts_too_long
                                            
                                            	Out Packet Too Long
                                            	**type**\:  :py:class:`OutPktsTooLong <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.OutPktsTooLong>`
                                            
                                            .. attribute:: out_octets_protected
                                            
                                            	Out Octet Protected
                                            	**type**\:  :py:class:`OutOctetsProtected <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.OutOctetsProtected>`
                                            
                                            .. attribute:: out_octets_encrypted
                                            
                                            	Out Octet encrypted
                                            	**type**\:  :py:class:`OutOctetsEncrypted <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.OutOctetsEncrypted>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\: bool
                                            
                                            .. attribute:: sample_count
                                            
                                            	Running Sample Count
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance, self).__init__()

                                                self.yang_name = "macsec-second30secyif-time-line-instance"
                                                self.yang_parent_name = "macsec-second30secyif-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("in-pkts-untagged", ("in_pkts_untagged", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.InPktsUntagged)), ("in-pkts-no-tag", ("in_pkts_no_tag", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.InPktsNoTag)), ("in-pkts-bad-tag", ("in_pkts_bad_tag", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.InPktsBadTag)), ("in-pkts-unknown-sci", ("in_pkts_unknown_sci", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.InPktsUnknownSci)), ("in-pkts-no-sci", ("in_pkts_no_sci", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.InPktsNoSci)), ("in-pkts-overrun", ("in_pkts_overrun", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.InPktsOverrun)), ("in-octets-validated", ("in_octets_validated", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.InOctetsValidated)), ("in-octets-decrypted", ("in_octets_decrypted", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.InOctetsDecrypted)), ("out-pkts-untagged", ("out_pkts_untagged", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.OutPktsUntagged)), ("out-pkts-too-long", ("out_pkts_too_long", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.OutPktsTooLong)), ("out-octets-protected", ("out_octets_protected", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.OutOctetsProtected)), ("out-octets-encrypted", ("out_octets_encrypted", PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.OutOctetsEncrypted))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                    ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                                    ('sample_count', (YLeaf(YType.uint64, 'sample-count'), ['int'])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear24_hr_time = None
                                                self.sec30_support = None
                                                self.sample_count = None

                                                self.in_pkts_untagged = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.InPktsUntagged()
                                                self.in_pkts_untagged.parent = self
                                                self._children_name_map["in_pkts_untagged"] = "in-pkts-untagged"

                                                self.in_pkts_no_tag = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.InPktsNoTag()
                                                self.in_pkts_no_tag.parent = self
                                                self._children_name_map["in_pkts_no_tag"] = "in-pkts-no-tag"

                                                self.in_pkts_bad_tag = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.InPktsBadTag()
                                                self.in_pkts_bad_tag.parent = self
                                                self._children_name_map["in_pkts_bad_tag"] = "in-pkts-bad-tag"

                                                self.in_pkts_unknown_sci = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.InPktsUnknownSci()
                                                self.in_pkts_unknown_sci.parent = self
                                                self._children_name_map["in_pkts_unknown_sci"] = "in-pkts-unknown-sci"

                                                self.in_pkts_no_sci = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.InPktsNoSci()
                                                self.in_pkts_no_sci.parent = self
                                                self._children_name_map["in_pkts_no_sci"] = "in-pkts-no-sci"

                                                self.in_pkts_overrun = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.InPktsOverrun()
                                                self.in_pkts_overrun.parent = self
                                                self._children_name_map["in_pkts_overrun"] = "in-pkts-overrun"

                                                self.in_octets_validated = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.InOctetsValidated()
                                                self.in_octets_validated.parent = self
                                                self._children_name_map["in_octets_validated"] = "in-octets-validated"

                                                self.in_octets_decrypted = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.InOctetsDecrypted()
                                                self.in_octets_decrypted.parent = self
                                                self._children_name_map["in_octets_decrypted"] = "in-octets-decrypted"

                                                self.out_pkts_untagged = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.OutPktsUntagged()
                                                self.out_pkts_untagged.parent = self
                                                self._children_name_map["out_pkts_untagged"] = "out-pkts-untagged"

                                                self.out_pkts_too_long = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.OutPktsTooLong()
                                                self.out_pkts_too_long.parent = self
                                                self._children_name_map["out_pkts_too_long"] = "out-pkts-too-long"

                                                self.out_octets_protected = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.OutOctetsProtected()
                                                self.out_octets_protected.parent = self
                                                self._children_name_map["out_octets_protected"] = "out-octets-protected"

                                                self.out_octets_encrypted = PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.OutOctetsEncrypted()
                                                self.out_octets_encrypted.parent = self
                                                self._children_name_map["out_octets_encrypted"] = "out-octets-encrypted"
                                                self._segment_path = lambda: "macsec-second30secyif-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support', 'sample_count'], name, value)


                                            class InPktsUntagged(Entity):
                                                """
                                                In Packet Untagged
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.InPktsUntagged, self).__init__()

                                                    self.yang_name = "in-pkts-untagged"
                                                    self.yang_parent_name = "macsec-second30secyif-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts-untagged"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.InPktsUntagged, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPktsNoTag(Entity):
                                                """
                                                In Packet No tag
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.InPktsNoTag, self).__init__()

                                                    self.yang_name = "in-pkts-no-tag"
                                                    self.yang_parent_name = "macsec-second30secyif-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts-no-tag"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.InPktsNoTag, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPktsBadTag(Entity):
                                                """
                                                In Packet Bad tag
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.InPktsBadTag, self).__init__()

                                                    self.yang_name = "in-pkts-bad-tag"
                                                    self.yang_parent_name = "macsec-second30secyif-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts-bad-tag"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.InPktsBadTag, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPktsUnknownSci(Entity):
                                                """
                                                In Packet Unknown sci
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.InPktsUnknownSci, self).__init__()

                                                    self.yang_name = "in-pkts-unknown-sci"
                                                    self.yang_parent_name = "macsec-second30secyif-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts-unknown-sci"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.InPktsUnknownSci, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPktsNoSci(Entity):
                                                """
                                                In Packet No sci
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.InPktsNoSci, self).__init__()

                                                    self.yang_name = "in-pkts-no-sci"
                                                    self.yang_parent_name = "macsec-second30secyif-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts-no-sci"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.InPktsNoSci, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InPktsOverrun(Entity):
                                                """
                                                In Packet Overrun
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.InPktsOverrun, self).__init__()

                                                    self.yang_name = "in-pkts-overrun"
                                                    self.yang_parent_name = "macsec-second30secyif-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-pkts-overrun"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.InPktsOverrun, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InOctetsValidated(Entity):
                                                """
                                                In Octet Validated
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.InOctetsValidated, self).__init__()

                                                    self.yang_name = "in-octets-validated"
                                                    self.yang_parent_name = "macsec-second30secyif-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-octets-validated"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.InOctetsValidated, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class InOctetsDecrypted(Entity):
                                                """
                                                In Octet Decrypted
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.InOctetsDecrypted, self).__init__()

                                                    self.yang_name = "in-octets-decrypted"
                                                    self.yang_parent_name = "macsec-second30secyif-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "in-octets-decrypted"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.InOctetsDecrypted, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutPktsUntagged(Entity):
                                                """
                                                Out Packet Untagged
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.OutPktsUntagged, self).__init__()

                                                    self.yang_name = "out-pkts-untagged"
                                                    self.yang_parent_name = "macsec-second30secyif-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-pkts-untagged"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.OutPktsUntagged, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutPktsTooLong(Entity):
                                                """
                                                Out Packet Too Long
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.OutPktsTooLong, self).__init__()

                                                    self.yang_name = "out-pkts-too-long"
                                                    self.yang_parent_name = "macsec-second30secyif-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-pkts-too-long"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.OutPktsTooLong, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutOctetsProtected(Entity):
                                                """
                                                Out Octet Protected
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.OutOctetsProtected, self).__init__()

                                                    self.yang_name = "out-octets-protected"
                                                    self.yang_parent_name = "macsec-second30secyif-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-octets-protected"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.OutOctetsProtected, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class OutOctetsEncrypted(Entity):
                                                """
                                                Out Octet encrypted
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.OutOctetsEncrypted, self).__init__()

                                                    self.yang_name = "out-octets-encrypted"
                                                    self.yang_parent_name = "macsec-second30secyif-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "out-octets-encrypted"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.MacsecHistory.MacsecPortHistories.MacsecPortHistory.MacsecSecond30History.MacsecSecond30secyifHistories.MacsecSecond30secyifHistory.MacsecSecond30secyifTimeLineInstances.MacsecSecond30secyifTimeLineInstance.OutOctetsEncrypted, ['data', 'threshold', 'tca_report', 'valid'], name, value)


            class OduHistory(Entity):
                """
                ODU controller History performance data
                
                .. attribute:: odu_port_histories
                
                	Port performance data
                	**type**\:  :py:class:`OduPortHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(PerformanceManagementHistory.Global.Periodic.OduHistory, self).__init__()

                    self.yang_name = "odu-history"
                    self.yang_parent_name = "periodic"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("odu-port-histories", ("odu_port_histories", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories))])
                    self._leafs = OrderedDict()

                    self.odu_port_histories = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories()
                    self.odu_port_histories.parent = self
                    self._children_name_map["odu_port_histories"] = "odu-port-histories"
                    self._segment_path = lambda: "odu-history"
                    self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory, [], name, value)


                class OduPortHistories(Entity):
                    """
                    Port performance data
                    
                    .. attribute:: odu_port_history
                    
                    	Port performance data
                    	**type**\: list of  		 :py:class:`OduPortHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories, self).__init__()

                        self.yang_name = "odu-port-histories"
                        self.yang_parent_name = "odu-history"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("odu-port-history", ("odu_port_history", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory))])
                        self._leafs = OrderedDict()

                        self.odu_port_history = YList(self)
                        self._segment_path = lambda: "odu-port-histories"
                        self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/odu-history/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories, [], name, value)


                    class OduPortHistory(Entity):
                        """
                        Port performance data
                        
                        .. attribute:: name  (key)
                        
                        	Port name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: odu_hour24_history
                        
                        	port current performance data
                        	**type**\:  :py:class:`OduHour24History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History>`
                        
                        .. attribute:: odu_minute15_history
                        
                        	port current performance data
                        	**type**\:  :py:class:`OduMinute15History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory, self).__init__()

                            self.yang_name = "odu-port-history"
                            self.yang_parent_name = "odu-port-histories"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("odu-hour24-history", ("odu_hour24_history", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History)), ("odu-minute15-history", ("odu_minute15_history", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None

                            self.odu_hour24_history = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History()
                            self.odu_hour24_history.parent = self
                            self._children_name_map["odu_hour24_history"] = "odu-hour24-history"

                            self.odu_minute15_history = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History()
                            self.odu_minute15_history.parent = self
                            self._children_name_map["odu_minute15_history"] = "odu-minute15-history"
                            self._segment_path = lambda: "odu-port-history" + "[name='" + str(self.name) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/odu-history/odu-port-histories/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory, ['name'], name, value)


                        class OduHour24History(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: odu_hour24gfp_histories
                            
                            	port 24 hour performance data
                            	**type**\:  :py:class:`OduHour24gfpHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24gfpHistories>`
                            
                            .. attribute:: odu_hour24prbs_histories
                            
                            	port 24 hour performance data
                            	**type**\:  :py:class:`OduHour24prbsHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24prbsHistories>`
                            
                            .. attribute:: odu_hour24otn_histories
                            
                            	port 24 hour performance data
                            	**type**\:  :py:class:`OduHour24otnHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History, self).__init__()

                                self.yang_name = "odu-hour24-history"
                                self.yang_parent_name = "odu-port-history"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("odu-hour24gfp-histories", ("odu_hour24gfp_histories", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24gfpHistories)), ("odu-hour24prbs-histories", ("odu_hour24prbs_histories", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24prbsHistories)), ("odu-hour24otn-histories", ("odu_hour24otn_histories", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories))])
                                self._leafs = OrderedDict()

                                self.odu_hour24gfp_histories = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24gfpHistories()
                                self.odu_hour24gfp_histories.parent = self
                                self._children_name_map["odu_hour24gfp_histories"] = "odu-hour24gfp-histories"

                                self.odu_hour24prbs_histories = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24prbsHistories()
                                self.odu_hour24prbs_histories.parent = self
                                self._children_name_map["odu_hour24prbs_histories"] = "odu-hour24prbs-histories"

                                self.odu_hour24otn_histories = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories()
                                self.odu_hour24otn_histories.parent = self
                                self._children_name_map["odu_hour24otn_histories"] = "odu-hour24otn-histories"
                                self._segment_path = lambda: "odu-hour24-history"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History, [], name, value)


                            class OduHour24gfpHistories(Entity):
                                """
                                port 24 hour performance data
                                
                                .. attribute:: odu_hour24gfp_history
                                
                                	port 24 hour otn performance data
                                	**type**\: list of  		 :py:class:`OduHour24gfpHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24gfpHistories.OduHour24gfpHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24gfpHistories, self).__init__()

                                    self.yang_name = "odu-hour24gfp-histories"
                                    self.yang_parent_name = "odu-hour24-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("odu-hour24gfp-history", ("odu_hour24gfp_history", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24gfpHistories.OduHour24gfpHistory))])
                                    self._leafs = OrderedDict()

                                    self.odu_hour24gfp_history = YList(self)
                                    self._segment_path = lambda: "odu-hour24gfp-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24gfpHistories, [], name, value)


                                class OduHour24gfpHistory(Entity):
                                    """
                                    port 24 hour otn performance data
                                    
                                    .. attribute:: number  (key)
                                    
                                    	channel number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: odu_hour24gfp_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`OduHour24gfpTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24gfpHistories.OduHour24gfpHistory.OduHour24gfpTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24gfpHistories.OduHour24gfpHistory, self).__init__()

                                        self.yang_name = "odu-hour24gfp-history"
                                        self.yang_parent_name = "odu-hour24gfp-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([("odu-hour24gfp-time-line-instances", ("odu_hour24gfp_time_line_instances", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24gfpHistories.OduHour24gfpHistory.OduHour24gfpTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ])
                                        self.number = None

                                        self.odu_hour24gfp_time_line_instances = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24gfpHistories.OduHour24gfpHistory.OduHour24gfpTimeLineInstances()
                                        self.odu_hour24gfp_time_line_instances.parent = self
                                        self._children_name_map["odu_hour24gfp_time_line_instances"] = "odu-hour24gfp-time-line-instances"
                                        self._segment_path = lambda: "odu-hour24gfp-history" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24gfpHistories.OduHour24gfpHistory, ['number'], name, value)


                                    class OduHour24gfpTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: odu_hour24gfp_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of  		 :py:class:`OduHour24gfpTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24gfpHistories.OduHour24gfpHistory.OduHour24gfpTimeLineInstances.OduHour24gfpTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24gfpHistories.OduHour24gfpHistory.OduHour24gfpTimeLineInstances, self).__init__()

                                            self.yang_name = "odu-hour24gfp-time-line-instances"
                                            self.yang_parent_name = "odu-hour24gfp-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("odu-hour24gfp-time-line-instance", ("odu_hour24gfp_time_line_instance", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24gfpHistories.OduHour24gfpHistory.OduHour24gfpTimeLineInstances.OduHour24gfpTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.odu_hour24gfp_time_line_instance = YList(self)
                                            self._segment_path = lambda: "odu-hour24gfp-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24gfpHistories.OduHour24gfpHistory.OduHour24gfpTimeLineInstances, [], name, value)


                                        class OduHour24gfpTimeLineInstance(Entity):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rx_bit_err
                                            
                                            	RX BIT ERR
                                            	**type**\:  :py:class:`RxBitErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24gfpHistories.OduHour24gfpHistory.OduHour24gfpTimeLineInstances.OduHour24gfpTimeLineInstance.RxBitErr>`
                                            
                                            .. attribute:: rx_inv_typ
                                            
                                            	RX INV TYP
                                            	**type**\:  :py:class:`RxInvTyp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24gfpHistories.OduHour24gfpHistory.OduHour24gfpTimeLineInstances.OduHour24gfpTimeLineInstance.RxInvTyp>`
                                            
                                            .. attribute:: rx_crc
                                            
                                            	RX CRC
                                            	**type**\:  :py:class:`RxCrc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24gfpHistories.OduHour24gfpHistory.OduHour24gfpTimeLineInstances.OduHour24gfpTimeLineInstance.RxCrc>`
                                            
                                            .. attribute:: rx_lfd
                                            
                                            	RX LFD
                                            	**type**\:  :py:class:`RxLfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24gfpHistories.OduHour24gfpHistory.OduHour24gfpTimeLineInstances.OduHour24gfpTimeLineInstance.RxLfd>`
                                            
                                            .. attribute:: rx_csf
                                            
                                            	RX CSF
                                            	**type**\:  :py:class:`RxCsf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24gfpHistories.OduHour24gfpHistory.OduHour24gfpTimeLineInstances.OduHour24gfpTimeLineInstance.RxCsf>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24gfpHistories.OduHour24gfpHistory.OduHour24gfpTimeLineInstances.OduHour24gfpTimeLineInstance, self).__init__()

                                                self.yang_name = "odu-hour24gfp-time-line-instance"
                                                self.yang_parent_name = "odu-hour24gfp-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("rx-bit-err", ("rx_bit_err", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24gfpHistories.OduHour24gfpHistory.OduHour24gfpTimeLineInstances.OduHour24gfpTimeLineInstance.RxBitErr)), ("rx-inv-typ", ("rx_inv_typ", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24gfpHistories.OduHour24gfpHistory.OduHour24gfpTimeLineInstances.OduHour24gfpTimeLineInstance.RxInvTyp)), ("rx-crc", ("rx_crc", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24gfpHistories.OduHour24gfpHistory.OduHour24gfpTimeLineInstances.OduHour24gfpTimeLineInstance.RxCrc)), ("rx-lfd", ("rx_lfd", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24gfpHistories.OduHour24gfpHistory.OduHour24gfpTimeLineInstances.OduHour24gfpTimeLineInstance.RxLfd)), ("rx-csf", ("rx_csf", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24gfpHistories.OduHour24gfpHistory.OduHour24gfpTimeLineInstances.OduHour24gfpTimeLineInstance.RxCsf))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                    ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear24_hr_time = None
                                                self.sec30_support = None

                                                self.rx_bit_err = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24gfpHistories.OduHour24gfpHistory.OduHour24gfpTimeLineInstances.OduHour24gfpTimeLineInstance.RxBitErr()
                                                self.rx_bit_err.parent = self
                                                self._children_name_map["rx_bit_err"] = "rx-bit-err"

                                                self.rx_inv_typ = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24gfpHistories.OduHour24gfpHistory.OduHour24gfpTimeLineInstances.OduHour24gfpTimeLineInstance.RxInvTyp()
                                                self.rx_inv_typ.parent = self
                                                self._children_name_map["rx_inv_typ"] = "rx-inv-typ"

                                                self.rx_crc = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24gfpHistories.OduHour24gfpHistory.OduHour24gfpTimeLineInstances.OduHour24gfpTimeLineInstance.RxCrc()
                                                self.rx_crc.parent = self
                                                self._children_name_map["rx_crc"] = "rx-crc"

                                                self.rx_lfd = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24gfpHistories.OduHour24gfpHistory.OduHour24gfpTimeLineInstances.OduHour24gfpTimeLineInstance.RxLfd()
                                                self.rx_lfd.parent = self
                                                self._children_name_map["rx_lfd"] = "rx-lfd"

                                                self.rx_csf = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24gfpHistories.OduHour24gfpHistory.OduHour24gfpTimeLineInstances.OduHour24gfpTimeLineInstance.RxCsf()
                                                self.rx_csf.parent = self
                                                self._children_name_map["rx_csf"] = "rx-csf"
                                                self._segment_path = lambda: "odu-hour24gfp-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24gfpHistories.OduHour24gfpHistory.OduHour24gfpTimeLineInstances.OduHour24gfpTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                            class RxBitErr(Entity):
                                                """
                                                RX BIT ERR
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24gfpHistories.OduHour24gfpHistory.OduHour24gfpTimeLineInstances.OduHour24gfpTimeLineInstance.RxBitErr, self).__init__()

                                                    self.yang_name = "rx-bit-err"
                                                    self.yang_parent_name = "odu-hour24gfp-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "rx-bit-err"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24gfpHistories.OduHour24gfpHistory.OduHour24gfpTimeLineInstances.OduHour24gfpTimeLineInstance.RxBitErr, ['data', 'threshold', 'tca_report'], name, value)


                                            class RxInvTyp(Entity):
                                                """
                                                RX INV TYP
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24gfpHistories.OduHour24gfpHistory.OduHour24gfpTimeLineInstances.OduHour24gfpTimeLineInstance.RxInvTyp, self).__init__()

                                                    self.yang_name = "rx-inv-typ"
                                                    self.yang_parent_name = "odu-hour24gfp-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "rx-inv-typ"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24gfpHistories.OduHour24gfpHistory.OduHour24gfpTimeLineInstances.OduHour24gfpTimeLineInstance.RxInvTyp, ['data', 'threshold', 'tca_report'], name, value)


                                            class RxCrc(Entity):
                                                """
                                                RX CRC
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24gfpHistories.OduHour24gfpHistory.OduHour24gfpTimeLineInstances.OduHour24gfpTimeLineInstance.RxCrc, self).__init__()

                                                    self.yang_name = "rx-crc"
                                                    self.yang_parent_name = "odu-hour24gfp-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "rx-crc"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24gfpHistories.OduHour24gfpHistory.OduHour24gfpTimeLineInstances.OduHour24gfpTimeLineInstance.RxCrc, ['data', 'threshold', 'tca_report'], name, value)


                                            class RxLfd(Entity):
                                                """
                                                RX LFD
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24gfpHistories.OduHour24gfpHistory.OduHour24gfpTimeLineInstances.OduHour24gfpTimeLineInstance.RxLfd, self).__init__()

                                                    self.yang_name = "rx-lfd"
                                                    self.yang_parent_name = "odu-hour24gfp-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "rx-lfd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24gfpHistories.OduHour24gfpHistory.OduHour24gfpTimeLineInstances.OduHour24gfpTimeLineInstance.RxLfd, ['data', 'threshold', 'tca_report'], name, value)


                                            class RxCsf(Entity):
                                                """
                                                RX CSF
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24gfpHistories.OduHour24gfpHistory.OduHour24gfpTimeLineInstances.OduHour24gfpTimeLineInstance.RxCsf, self).__init__()

                                                    self.yang_name = "rx-csf"
                                                    self.yang_parent_name = "odu-hour24gfp-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "rx-csf"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24gfpHistories.OduHour24gfpHistory.OduHour24gfpTimeLineInstances.OduHour24gfpTimeLineInstance.RxCsf, ['data', 'threshold', 'tca_report'], name, value)


                            class OduHour24prbsHistories(Entity):
                                """
                                port 24 hour performance data
                                
                                .. attribute:: odu_hour24prbs_history
                                
                                	port 24 hour prbs performance data
                                	**type**\: list of  		 :py:class:`OduHour24prbsHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24prbsHistories.OduHour24prbsHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24prbsHistories, self).__init__()

                                    self.yang_name = "odu-hour24prbs-histories"
                                    self.yang_parent_name = "odu-hour24-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("odu-hour24prbs-history", ("odu_hour24prbs_history", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24prbsHistories.OduHour24prbsHistory))])
                                    self._leafs = OrderedDict()

                                    self.odu_hour24prbs_history = YList(self)
                                    self._segment_path = lambda: "odu-hour24prbs-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24prbsHistories, [], name, value)


                                class OduHour24prbsHistory(Entity):
                                    """
                                    port 24 hour prbs performance data
                                    
                                    .. attribute:: number  (key)
                                    
                                    	channel number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: odu_hour24prbs_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`OduHour24prbsTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24prbsHistories.OduHour24prbsHistory.OduHour24prbsTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24prbsHistories.OduHour24prbsHistory, self).__init__()

                                        self.yang_name = "odu-hour24prbs-history"
                                        self.yang_parent_name = "odu-hour24prbs-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([("odu-hour24prbs-time-line-instances", ("odu_hour24prbs_time_line_instances", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24prbsHistories.OduHour24prbsHistory.OduHour24prbsTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ])
                                        self.number = None

                                        self.odu_hour24prbs_time_line_instances = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24prbsHistories.OduHour24prbsHistory.OduHour24prbsTimeLineInstances()
                                        self.odu_hour24prbs_time_line_instances.parent = self
                                        self._children_name_map["odu_hour24prbs_time_line_instances"] = "odu-hour24prbs-time-line-instances"
                                        self._segment_path = lambda: "odu-hour24prbs-history" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24prbsHistories.OduHour24prbsHistory, ['number'], name, value)


                                    class OduHour24prbsTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: odu_hour24prbs_time_line_instance
                                        
                                        	port 15\-minute prbs performance data
                                        	**type**\: list of  		 :py:class:`OduHour24prbsTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24prbsHistories.OduHour24prbsHistory.OduHour24prbsTimeLineInstances.OduHour24prbsTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24prbsHistories.OduHour24prbsHistory.OduHour24prbsTimeLineInstances, self).__init__()

                                            self.yang_name = "odu-hour24prbs-time-line-instances"
                                            self.yang_parent_name = "odu-hour24prbs-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("odu-hour24prbs-time-line-instance", ("odu_hour24prbs_time_line_instance", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24prbsHistories.OduHour24prbsHistory.OduHour24prbsTimeLineInstances.OduHour24prbsTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.odu_hour24prbs_time_line_instance = YList(self)
                                            self._segment_path = lambda: "odu-hour24prbs-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24prbsHistories.OduHour24prbsHistory.OduHour24prbsTimeLineInstances, [], name, value)


                                        class OduHour24prbsTimeLineInstance(Entity):
                                            """
                                            port 15\-minute prbs performance data
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcv_patt
                                            
                                            	RCVD PTRN
                                            	**type**\:  :py:class:`RcvPatt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24prbsHistories.OduHour24prbsHistory.OduHour24prbsTimeLineInstances.OduHour24prbsTimeLineInstance.RcvPatt>`
                                            
                                            .. attribute:: prbs_status
                                            
                                            	PRBS STATUS
                                            	**type**\:  :py:class:`PrbsStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24prbsHistories.OduHour24prbsHistory.OduHour24prbsTimeLineInstances.OduHour24prbsTimeLineInstance.PrbsStatus>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: ebc
                                            
                                            	EBC
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: found_count
                                            
                                            	FOUND COUNT
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lost_count
                                            
                                            	LOST COUNT
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: found_at_time
                                            
                                            	FOUND AT TS
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: lost_at_time
                                            
                                            	LOST AT TS
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: conf_patt
                                            
                                            	CONFIG PTRN
                                            	**type**\:  :py:class:`PmPrbsPatternEt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmPrbsPatternEt>`
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24prbsHistories.OduHour24prbsHistory.OduHour24prbsTimeLineInstances.OduHour24prbsTimeLineInstance, self).__init__()

                                                self.yang_name = "odu-hour24prbs-time-line-instance"
                                                self.yang_parent_name = "odu-hour24prbs-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("rcv-patt", ("rcv_patt", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24prbsHistories.OduHour24prbsHistory.OduHour24prbsTimeLineInstances.OduHour24prbsTimeLineInstance.RcvPatt)), ("prbs-status", ("prbs_status", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24prbsHistories.OduHour24prbsHistory.OduHour24prbsTimeLineInstances.OduHour24prbsTimeLineInstance.PrbsStatus))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                    ('ebc', (YLeaf(YType.uint64, 'ebc'), ['int'])),
                                                    ('found_count', (YLeaf(YType.uint32, 'found-count'), ['int'])),
                                                    ('lost_count', (YLeaf(YType.uint32, 'lost-count'), ['int'])),
                                                    ('found_at_time', (YLeaf(YType.uint64, 'found-at-time'), ['int'])),
                                                    ('lost_at_time', (YLeaf(YType.uint64, 'lost-at-time'), ['int'])),
                                                    ('conf_patt', (YLeaf(YType.enumeration, 'conf-patt'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper', 'PmPrbsPatternEt', '')])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None
                                                self.ebc = None
                                                self.found_count = None
                                                self.lost_count = None
                                                self.found_at_time = None
                                                self.lost_at_time = None
                                                self.conf_patt = None

                                                self.rcv_patt = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24prbsHistories.OduHour24prbsHistory.OduHour24prbsTimeLineInstances.OduHour24prbsTimeLineInstance.RcvPatt()
                                                self.rcv_patt.parent = self
                                                self._children_name_map["rcv_patt"] = "rcv-patt"

                                                self.prbs_status = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24prbsHistories.OduHour24prbsHistory.OduHour24prbsTimeLineInstances.OduHour24prbsTimeLineInstance.PrbsStatus()
                                                self.prbs_status.parent = self
                                                self._children_name_map["prbs_status"] = "prbs-status"
                                                self._segment_path = lambda: "odu-hour24prbs-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24prbsHistories.OduHour24prbsHistory.OduHour24prbsTimeLineInstances.OduHour24prbsTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear24_hr_time', 'ebc', 'found_count', 'lost_count', 'found_at_time', 'lost_at_time', 'conf_patt'], name, value)


                                            class RcvPatt(Entity):
                                                """
                                                RCVD PTRN
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: rcv_patt
                                                
                                                	RCVD PTRN
                                                	**type**\:  :py:class:`PmPrbsPatternEt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmPrbsPatternEt>`
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24prbsHistories.OduHour24prbsHistory.OduHour24prbsTimeLineInstances.OduHour24prbsTimeLineInstance.RcvPatt, self).__init__()

                                                    self.yang_name = "rcv-patt"
                                                    self.yang_parent_name = "odu-hour24prbs-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('rcv_patt', (YLeaf(YType.enumeration, 'rcv-patt'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper', 'PmPrbsPatternEt', '')])),
                                                    ])
                                                    self.valid = None
                                                    self.rcv_patt = None
                                                    self._segment_path = lambda: "rcv-patt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24prbsHistories.OduHour24prbsHistory.OduHour24prbsTimeLineInstances.OduHour24prbsTimeLineInstance.RcvPatt, ['valid', 'rcv_patt'], name, value)


                                            class PrbsStatus(Entity):
                                                """
                                                PRBS STATUS
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: prbs_status
                                                
                                                	Prbs Status
                                                	**type**\:  :py:class:`PmPrbsStatusEt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmPrbsStatusEt>`
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24prbsHistories.OduHour24prbsHistory.OduHour24prbsTimeLineInstances.OduHour24prbsTimeLineInstance.PrbsStatus, self).__init__()

                                                    self.yang_name = "prbs-status"
                                                    self.yang_parent_name = "odu-hour24prbs-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('prbs_status', (YLeaf(YType.enumeration, 'prbs-status'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper', 'PmPrbsStatusEt', '')])),
                                                    ])
                                                    self.valid = None
                                                    self.prbs_status = None
                                                    self._segment_path = lambda: "prbs-status"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24prbsHistories.OduHour24prbsHistory.OduHour24prbsTimeLineInstances.OduHour24prbsTimeLineInstance.PrbsStatus, ['valid', 'prbs_status'], name, value)


                            class OduHour24otnHistories(Entity):
                                """
                                port 24 hour performance data
                                
                                .. attribute:: odu_hour24otn_history
                                
                                	port 24 hour otn performance data
                                	**type**\: list of  		 :py:class:`OduHour24otnHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories, self).__init__()

                                    self.yang_name = "odu-hour24otn-histories"
                                    self.yang_parent_name = "odu-hour24-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("odu-hour24otn-history", ("odu_hour24otn_history", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory))])
                                    self._leafs = OrderedDict()

                                    self.odu_hour24otn_history = YList(self)
                                    self._segment_path = lambda: "odu-hour24otn-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories, [], name, value)


                                class OduHour24otnHistory(Entity):
                                    """
                                    port 24 hour otn performance data
                                    
                                    .. attribute:: number  (key)
                                    
                                    	channel number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: odu_hour24otn_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`OduHour24otnTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory, self).__init__()

                                        self.yang_name = "odu-hour24otn-history"
                                        self.yang_parent_name = "odu-hour24otn-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([("odu-hour24otn-time-line-instances", ("odu_hour24otn_time_line_instances", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ])
                                        self.number = None

                                        self.odu_hour24otn_time_line_instances = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances()
                                        self.odu_hour24otn_time_line_instances.parent = self
                                        self._children_name_map["odu_hour24otn_time_line_instances"] = "odu-hour24otn-time-line-instances"
                                        self._segment_path = lambda: "odu-hour24otn-history" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory, ['number'], name, value)


                                    class OduHour24otnTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: odu_hour24otn_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of  		 :py:class:`OduHour24otnTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances, self).__init__()

                                            self.yang_name = "odu-hour24otn-time-line-instances"
                                            self.yang_parent_name = "odu-hour24otn-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("odu-hour24otn-time-line-instance", ("odu_hour24otn_time_line_instance", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.odu_hour24otn_time_line_instance = YList(self)
                                            self._segment_path = lambda: "odu-hour24otn-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances, [], name, value)


                                        class OduHour24otnTimeLineInstance(Entity):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lbc
                                            
                                            	LBC
                                            	**type**\:  :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.Lbc>`
                                            
                                            .. attribute:: es_ne
                                            
                                            	ES SM NE
                                            	**type**\:  :py:class:`EsNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.EsNe>`
                                            
                                            .. attribute:: esr_ne
                                            
                                            	ESR PM NE
                                            	**type**\:  :py:class:`EsrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.EsrNe>`
                                            
                                            .. attribute:: ses_ne
                                            
                                            	SES SM NE
                                            	**type**\:  :py:class:`SesNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.SesNe>`
                                            
                                            .. attribute:: sesr_ne
                                            
                                            	SESR SM NE
                                            	**type**\:  :py:class:`SesrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.SesrNe>`
                                            
                                            .. attribute:: uas_ne
                                            
                                            	UAS SM NE
                                            	**type**\:  :py:class:`UasNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.UasNe>`
                                            
                                            .. attribute:: bbe_ne
                                            
                                            	BBE SM NE
                                            	**type**\:  :py:class:`BbeNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.BbeNe>`
                                            
                                            .. attribute:: bber_ne
                                            
                                            	BBER SM NE
                                            	**type**\:  :py:class:`BberNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.BberNe>`
                                            
                                            .. attribute:: fc_ne
                                            
                                            	FC SM NE
                                            	**type**\:  :py:class:`FcNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.FcNe>`
                                            
                                            .. attribute:: es_fe
                                            
                                            	ES SM FE
                                            	**type**\:  :py:class:`EsFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.EsFe>`
                                            
                                            .. attribute:: esr_fe
                                            
                                            	ESR PM FE
                                            	**type**\:  :py:class:`EsrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.EsrFe>`
                                            
                                            .. attribute:: ses_fe
                                            
                                            	SES SM FE
                                            	**type**\:  :py:class:`SesFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.SesFe>`
                                            
                                            .. attribute:: sesr_fe
                                            
                                            	SESR SM FE
                                            	**type**\:  :py:class:`SesrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.SesrFe>`
                                            
                                            .. attribute:: uas_fe
                                            
                                            	UAS SM FE
                                            	**type**\:  :py:class:`UasFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.UasFe>`
                                            
                                            .. attribute:: bbe_fe
                                            
                                            	BBE SM FE
                                            	**type**\:  :py:class:`BbeFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.BbeFe>`
                                            
                                            .. attribute:: bber_fe
                                            
                                            	BBER SM FE
                                            	**type**\:  :py:class:`BberFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.BberFe>`
                                            
                                            .. attribute:: fc_fe
                                            
                                            	FC SM FE
                                            	**type**\:  :py:class:`FcFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.FcFe>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance, self).__init__()

                                                self.yang_name = "odu-hour24otn-time-line-instance"
                                                self.yang_parent_name = "odu-hour24otn-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("lbc", ("lbc", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.Lbc)), ("es-ne", ("es_ne", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.EsNe)), ("esr-ne", ("esr_ne", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.EsrNe)), ("ses-ne", ("ses_ne", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.SesNe)), ("sesr-ne", ("sesr_ne", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.SesrNe)), ("uas-ne", ("uas_ne", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.UasNe)), ("bbe-ne", ("bbe_ne", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.BbeNe)), ("bber-ne", ("bber_ne", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.BberNe)), ("fc-ne", ("fc_ne", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.FcNe)), ("es-fe", ("es_fe", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.EsFe)), ("esr-fe", ("esr_fe", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.EsrFe)), ("ses-fe", ("ses_fe", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.SesFe)), ("sesr-fe", ("sesr_fe", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.SesrFe)), ("uas-fe", ("uas_fe", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.UasFe)), ("bbe-fe", ("bbe_fe", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.BbeFe)), ("bber-fe", ("bber_fe", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.BberFe)), ("fc-fe", ("fc_fe", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.FcFe))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                    ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear24_hr_time = None
                                                self.sec30_support = None

                                                self.lbc = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.Lbc()
                                                self.lbc.parent = self
                                                self._children_name_map["lbc"] = "lbc"

                                                self.es_ne = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.EsNe()
                                                self.es_ne.parent = self
                                                self._children_name_map["es_ne"] = "es-ne"

                                                self.esr_ne = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.EsrNe()
                                                self.esr_ne.parent = self
                                                self._children_name_map["esr_ne"] = "esr-ne"

                                                self.ses_ne = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.SesNe()
                                                self.ses_ne.parent = self
                                                self._children_name_map["ses_ne"] = "ses-ne"

                                                self.sesr_ne = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.SesrNe()
                                                self.sesr_ne.parent = self
                                                self._children_name_map["sesr_ne"] = "sesr-ne"

                                                self.uas_ne = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.UasNe()
                                                self.uas_ne.parent = self
                                                self._children_name_map["uas_ne"] = "uas-ne"

                                                self.bbe_ne = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.BbeNe()
                                                self.bbe_ne.parent = self
                                                self._children_name_map["bbe_ne"] = "bbe-ne"

                                                self.bber_ne = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.BberNe()
                                                self.bber_ne.parent = self
                                                self._children_name_map["bber_ne"] = "bber-ne"

                                                self.fc_ne = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.FcNe()
                                                self.fc_ne.parent = self
                                                self._children_name_map["fc_ne"] = "fc-ne"

                                                self.es_fe = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.EsFe()
                                                self.es_fe.parent = self
                                                self._children_name_map["es_fe"] = "es-fe"

                                                self.esr_fe = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.EsrFe()
                                                self.esr_fe.parent = self
                                                self._children_name_map["esr_fe"] = "esr-fe"

                                                self.ses_fe = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.SesFe()
                                                self.ses_fe.parent = self
                                                self._children_name_map["ses_fe"] = "ses-fe"

                                                self.sesr_fe = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.SesrFe()
                                                self.sesr_fe.parent = self
                                                self._children_name_map["sesr_fe"] = "sesr-fe"

                                                self.uas_fe = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.UasFe()
                                                self.uas_fe.parent = self
                                                self._children_name_map["uas_fe"] = "uas-fe"

                                                self.bbe_fe = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.BbeFe()
                                                self.bbe_fe.parent = self
                                                self._children_name_map["bbe_fe"] = "bbe-fe"

                                                self.bber_fe = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.BberFe()
                                                self.bber_fe.parent = self
                                                self._children_name_map["bber_fe"] = "bber-fe"

                                                self.fc_fe = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.FcFe()
                                                self.fc_fe.parent = self
                                                self._children_name_map["fc_fe"] = "fc-fe"
                                                self._segment_path = lambda: "odu-hour24otn-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                            class Lbc(Entity):
                                                """
                                                LBC
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.Lbc, self).__init__()

                                                    self.yang_name = "lbc"
                                                    self.yang_parent_name = "odu-hour24otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "lbc"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.Lbc, ['data', 'threshold', 'tca_report'], name, value)


                                            class EsNe(Entity):
                                                """
                                                ES SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.EsNe, self).__init__()

                                                    self.yang_name = "es-ne"
                                                    self.yang_parent_name = "odu-hour24otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "es-ne"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.EsNe, ['data', 'threshold', 'tca_report'], name, value)


                                            class EsrNe(Entity):
                                                """
                                                ESR PM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: str
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.EsrNe, self).__init__()

                                                    self.yang_name = "esr-ne"
                                                    self.yang_parent_name = "odu-hour24otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                        ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "esr-ne"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.EsrNe, ['data', 'threshold', 'tca_report'], name, value)


                                            class SesNe(Entity):
                                                """
                                                SES SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.SesNe, self).__init__()

                                                    self.yang_name = "ses-ne"
                                                    self.yang_parent_name = "odu-hour24otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "ses-ne"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.SesNe, ['data', 'threshold', 'tca_report'], name, value)


                                            class SesrNe(Entity):
                                                """
                                                SESR SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: str
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.SesrNe, self).__init__()

                                                    self.yang_name = "sesr-ne"
                                                    self.yang_parent_name = "odu-hour24otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                        ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "sesr-ne"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.SesrNe, ['data', 'threshold', 'tca_report'], name, value)


                                            class UasNe(Entity):
                                                """
                                                UAS SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.UasNe, self).__init__()

                                                    self.yang_name = "uas-ne"
                                                    self.yang_parent_name = "odu-hour24otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "uas-ne"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.UasNe, ['data', 'threshold', 'tca_report'], name, value)


                                            class BbeNe(Entity):
                                                """
                                                BBE SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.BbeNe, self).__init__()

                                                    self.yang_name = "bbe-ne"
                                                    self.yang_parent_name = "odu-hour24otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "bbe-ne"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.BbeNe, ['data', 'threshold', 'tca_report'], name, value)


                                            class BberNe(Entity):
                                                """
                                                BBER SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: str
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.BberNe, self).__init__()

                                                    self.yang_name = "bber-ne"
                                                    self.yang_parent_name = "odu-hour24otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                        ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "bber-ne"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.BberNe, ['data', 'threshold', 'tca_report'], name, value)


                                            class FcNe(Entity):
                                                """
                                                FC SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.FcNe, self).__init__()

                                                    self.yang_name = "fc-ne"
                                                    self.yang_parent_name = "odu-hour24otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "fc-ne"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.FcNe, ['data', 'threshold', 'tca_report'], name, value)


                                            class EsFe(Entity):
                                                """
                                                ES SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.EsFe, self).__init__()

                                                    self.yang_name = "es-fe"
                                                    self.yang_parent_name = "odu-hour24otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "es-fe"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.EsFe, ['data', 'threshold', 'tca_report'], name, value)


                                            class EsrFe(Entity):
                                                """
                                                ESR PM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: str
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.EsrFe, self).__init__()

                                                    self.yang_name = "esr-fe"
                                                    self.yang_parent_name = "odu-hour24otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                        ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "esr-fe"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.EsrFe, ['data', 'threshold', 'tca_report'], name, value)


                                            class SesFe(Entity):
                                                """
                                                SES SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.SesFe, self).__init__()

                                                    self.yang_name = "ses-fe"
                                                    self.yang_parent_name = "odu-hour24otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "ses-fe"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.SesFe, ['data', 'threshold', 'tca_report'], name, value)


                                            class SesrFe(Entity):
                                                """
                                                SESR SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: str
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.SesrFe, self).__init__()

                                                    self.yang_name = "sesr-fe"
                                                    self.yang_parent_name = "odu-hour24otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                        ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "sesr-fe"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.SesrFe, ['data', 'threshold', 'tca_report'], name, value)


                                            class UasFe(Entity):
                                                """
                                                UAS SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.UasFe, self).__init__()

                                                    self.yang_name = "uas-fe"
                                                    self.yang_parent_name = "odu-hour24otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "uas-fe"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.UasFe, ['data', 'threshold', 'tca_report'], name, value)


                                            class BbeFe(Entity):
                                                """
                                                BBE SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.BbeFe, self).__init__()

                                                    self.yang_name = "bbe-fe"
                                                    self.yang_parent_name = "odu-hour24otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "bbe-fe"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.BbeFe, ['data', 'threshold', 'tca_report'], name, value)


                                            class BberFe(Entity):
                                                """
                                                BBER SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: str
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.BberFe, self).__init__()

                                                    self.yang_name = "bber-fe"
                                                    self.yang_parent_name = "odu-hour24otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                        ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "bber-fe"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.BberFe, ['data', 'threshold', 'tca_report'], name, value)


                                            class FcFe(Entity):
                                                """
                                                FC SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.FcFe, self).__init__()

                                                    self.yang_name = "fc-fe"
                                                    self.yang_parent_name = "odu-hour24otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "fc-fe"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24otnHistories.OduHour24otnHistory.OduHour24otnTimeLineInstances.OduHour24otnTimeLineInstance.FcFe, ['data', 'threshold', 'tca_report'], name, value)


                        class OduMinute15History(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: odu_minute15prbs_histories
                            
                            	port current performance data
                            	**type**\:  :py:class:`OduMinute15prbsHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15prbsHistories>`
                            
                            .. attribute:: odu_minute15gfp_histories
                            
                            	port current performance data
                            	**type**\:  :py:class:`OduMinute15gfpHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15gfpHistories>`
                            
                            .. attribute:: odu_minute15otn_histories
                            
                            	port current performance data
                            	**type**\:  :py:class:`OduMinute15otnHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History, self).__init__()

                                self.yang_name = "odu-minute15-history"
                                self.yang_parent_name = "odu-port-history"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("odu-minute15prbs-histories", ("odu_minute15prbs_histories", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15prbsHistories)), ("odu-minute15gfp-histories", ("odu_minute15gfp_histories", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15gfpHistories)), ("odu-minute15otn-histories", ("odu_minute15otn_histories", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories))])
                                self._leafs = OrderedDict()

                                self.odu_minute15prbs_histories = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15prbsHistories()
                                self.odu_minute15prbs_histories.parent = self
                                self._children_name_map["odu_minute15prbs_histories"] = "odu-minute15prbs-histories"

                                self.odu_minute15gfp_histories = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15gfpHistories()
                                self.odu_minute15gfp_histories.parent = self
                                self._children_name_map["odu_minute15gfp_histories"] = "odu-minute15gfp-histories"

                                self.odu_minute15otn_histories = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories()
                                self.odu_minute15otn_histories.parent = self
                                self._children_name_map["odu_minute15otn_histories"] = "odu-minute15otn-histories"
                                self._segment_path = lambda: "odu-minute15-history"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History, [], name, value)


                            class OduMinute15prbsHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: odu_minute15prbs_history
                                
                                	port 15\-minute prbs performance data
                                	**type**\: list of  		 :py:class:`OduMinute15prbsHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15prbsHistories.OduMinute15prbsHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15prbsHistories, self).__init__()

                                    self.yang_name = "odu-minute15prbs-histories"
                                    self.yang_parent_name = "odu-minute15-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("odu-minute15prbs-history", ("odu_minute15prbs_history", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15prbsHistories.OduMinute15prbsHistory))])
                                    self._leafs = OrderedDict()

                                    self.odu_minute15prbs_history = YList(self)
                                    self._segment_path = lambda: "odu-minute15prbs-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15prbsHistories, [], name, value)


                                class OduMinute15prbsHistory(Entity):
                                    """
                                    port 15\-minute prbs performance data
                                    
                                    .. attribute:: number  (key)
                                    
                                    	channel number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: odu_minute15prbs_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`OduMinute15prbsTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15prbsHistories.OduMinute15prbsHistory.OduMinute15prbsTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15prbsHistories.OduMinute15prbsHistory, self).__init__()

                                        self.yang_name = "odu-minute15prbs-history"
                                        self.yang_parent_name = "odu-minute15prbs-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([("odu-minute15prbs-time-line-instances", ("odu_minute15prbs_time_line_instances", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15prbsHistories.OduMinute15prbsHistory.OduMinute15prbsTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ])
                                        self.number = None

                                        self.odu_minute15prbs_time_line_instances = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15prbsHistories.OduMinute15prbsHistory.OduMinute15prbsTimeLineInstances()
                                        self.odu_minute15prbs_time_line_instances.parent = self
                                        self._children_name_map["odu_minute15prbs_time_line_instances"] = "odu-minute15prbs-time-line-instances"
                                        self._segment_path = lambda: "odu-minute15prbs-history" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15prbsHistories.OduMinute15prbsHistory, ['number'], name, value)


                                    class OduMinute15prbsTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: odu_minute15prbs_time_line_instance
                                        
                                        	port 15\-minute prbs performance data
                                        	**type**\: list of  		 :py:class:`OduMinute15prbsTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15prbsHistories.OduMinute15prbsHistory.OduMinute15prbsTimeLineInstances.OduMinute15prbsTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15prbsHistories.OduMinute15prbsHistory.OduMinute15prbsTimeLineInstances, self).__init__()

                                            self.yang_name = "odu-minute15prbs-time-line-instances"
                                            self.yang_parent_name = "odu-minute15prbs-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("odu-minute15prbs-time-line-instance", ("odu_minute15prbs_time_line_instance", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15prbsHistories.OduMinute15prbsHistory.OduMinute15prbsTimeLineInstances.OduMinute15prbsTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.odu_minute15prbs_time_line_instance = YList(self)
                                            self._segment_path = lambda: "odu-minute15prbs-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15prbsHistories.OduMinute15prbsHistory.OduMinute15prbsTimeLineInstances, [], name, value)


                                        class OduMinute15prbsTimeLineInstance(Entity):
                                            """
                                            port 15\-minute prbs performance data
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcv_patt
                                            
                                            	RCVD PTRN
                                            	**type**\:  :py:class:`RcvPatt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15prbsHistories.OduMinute15prbsHistory.OduMinute15prbsTimeLineInstances.OduMinute15prbsTimeLineInstance.RcvPatt>`
                                            
                                            .. attribute:: prbs_status
                                            
                                            	PRBS STATUS
                                            	**type**\:  :py:class:`PrbsStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15prbsHistories.OduMinute15prbsHistory.OduMinute15prbsTimeLineInstances.OduMinute15prbsTimeLineInstance.PrbsStatus>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: ebc
                                            
                                            	EBC
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: found_count
                                            
                                            	FOUND COUNT
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lost_count
                                            
                                            	LOST COUNT
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: found_at_time
                                            
                                            	FOUND AT TS
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: lost_at_time
                                            
                                            	LOST AT TS
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: conf_patt
                                            
                                            	CONFIG PTRN
                                            	**type**\:  :py:class:`PmPrbsPatternEt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmPrbsPatternEt>`
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15prbsHistories.OduMinute15prbsHistory.OduMinute15prbsTimeLineInstances.OduMinute15prbsTimeLineInstance, self).__init__()

                                                self.yang_name = "odu-minute15prbs-time-line-instance"
                                                self.yang_parent_name = "odu-minute15prbs-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("rcv-patt", ("rcv_patt", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15prbsHistories.OduMinute15prbsHistory.OduMinute15prbsTimeLineInstances.OduMinute15prbsTimeLineInstance.RcvPatt)), ("prbs-status", ("prbs_status", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15prbsHistories.OduMinute15prbsHistory.OduMinute15prbsTimeLineInstances.OduMinute15prbsTimeLineInstance.PrbsStatus))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                    ('ebc', (YLeaf(YType.uint64, 'ebc'), ['int'])),
                                                    ('found_count', (YLeaf(YType.uint32, 'found-count'), ['int'])),
                                                    ('lost_count', (YLeaf(YType.uint32, 'lost-count'), ['int'])),
                                                    ('found_at_time', (YLeaf(YType.uint64, 'found-at-time'), ['int'])),
                                                    ('lost_at_time', (YLeaf(YType.uint64, 'lost-at-time'), ['int'])),
                                                    ('conf_patt', (YLeaf(YType.enumeration, 'conf-patt'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper', 'PmPrbsPatternEt', '')])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None
                                                self.ebc = None
                                                self.found_count = None
                                                self.lost_count = None
                                                self.found_at_time = None
                                                self.lost_at_time = None
                                                self.conf_patt = None

                                                self.rcv_patt = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15prbsHistories.OduMinute15prbsHistory.OduMinute15prbsTimeLineInstances.OduMinute15prbsTimeLineInstance.RcvPatt()
                                                self.rcv_patt.parent = self
                                                self._children_name_map["rcv_patt"] = "rcv-patt"

                                                self.prbs_status = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15prbsHistories.OduMinute15prbsHistory.OduMinute15prbsTimeLineInstances.OduMinute15prbsTimeLineInstance.PrbsStatus()
                                                self.prbs_status.parent = self
                                                self._children_name_map["prbs_status"] = "prbs-status"
                                                self._segment_path = lambda: "odu-minute15prbs-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15prbsHistories.OduMinute15prbsHistory.OduMinute15prbsTimeLineInstances.OduMinute15prbsTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear24_hr_time', 'ebc', 'found_count', 'lost_count', 'found_at_time', 'lost_at_time', 'conf_patt'], name, value)


                                            class RcvPatt(Entity):
                                                """
                                                RCVD PTRN
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: rcv_patt
                                                
                                                	RCVD PTRN
                                                	**type**\:  :py:class:`PmPrbsPatternEt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmPrbsPatternEt>`
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15prbsHistories.OduMinute15prbsHistory.OduMinute15prbsTimeLineInstances.OduMinute15prbsTimeLineInstance.RcvPatt, self).__init__()

                                                    self.yang_name = "rcv-patt"
                                                    self.yang_parent_name = "odu-minute15prbs-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('rcv_patt', (YLeaf(YType.enumeration, 'rcv-patt'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper', 'PmPrbsPatternEt', '')])),
                                                    ])
                                                    self.valid = None
                                                    self.rcv_patt = None
                                                    self._segment_path = lambda: "rcv-patt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15prbsHistories.OduMinute15prbsHistory.OduMinute15prbsTimeLineInstances.OduMinute15prbsTimeLineInstance.RcvPatt, ['valid', 'rcv_patt'], name, value)


                                            class PrbsStatus(Entity):
                                                """
                                                PRBS STATUS
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: prbs_status
                                                
                                                	Prbs Status
                                                	**type**\:  :py:class:`PmPrbsStatusEt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmPrbsStatusEt>`
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15prbsHistories.OduMinute15prbsHistory.OduMinute15prbsTimeLineInstances.OduMinute15prbsTimeLineInstance.PrbsStatus, self).__init__()

                                                    self.yang_name = "prbs-status"
                                                    self.yang_parent_name = "odu-minute15prbs-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('prbs_status', (YLeaf(YType.enumeration, 'prbs-status'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper', 'PmPrbsStatusEt', '')])),
                                                    ])
                                                    self.valid = None
                                                    self.prbs_status = None
                                                    self._segment_path = lambda: "prbs-status"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15prbsHistories.OduMinute15prbsHistory.OduMinute15prbsTimeLineInstances.OduMinute15prbsTimeLineInstance.PrbsStatus, ['valid', 'prbs_status'], name, value)


                            class OduMinute15gfpHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: odu_minute15gfp_history
                                
                                	port 15\-minute otn performance data
                                	**type**\: list of  		 :py:class:`OduMinute15gfpHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15gfpHistories.OduMinute15gfpHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15gfpHistories, self).__init__()

                                    self.yang_name = "odu-minute15gfp-histories"
                                    self.yang_parent_name = "odu-minute15-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("odu-minute15gfp-history", ("odu_minute15gfp_history", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15gfpHistories.OduMinute15gfpHistory))])
                                    self._leafs = OrderedDict()

                                    self.odu_minute15gfp_history = YList(self)
                                    self._segment_path = lambda: "odu-minute15gfp-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15gfpHistories, [], name, value)


                                class OduMinute15gfpHistory(Entity):
                                    """
                                    port 15\-minute otn performance data
                                    
                                    .. attribute:: number  (key)
                                    
                                    	channel number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: odu_minute15gfp_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`OduMinute15gfpTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15gfpHistories.OduMinute15gfpHistory.OduMinute15gfpTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15gfpHistories.OduMinute15gfpHistory, self).__init__()

                                        self.yang_name = "odu-minute15gfp-history"
                                        self.yang_parent_name = "odu-minute15gfp-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([("odu-minute15gfp-time-line-instances", ("odu_minute15gfp_time_line_instances", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15gfpHistories.OduMinute15gfpHistory.OduMinute15gfpTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ])
                                        self.number = None

                                        self.odu_minute15gfp_time_line_instances = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15gfpHistories.OduMinute15gfpHistory.OduMinute15gfpTimeLineInstances()
                                        self.odu_minute15gfp_time_line_instances.parent = self
                                        self._children_name_map["odu_minute15gfp_time_line_instances"] = "odu-minute15gfp-time-line-instances"
                                        self._segment_path = lambda: "odu-minute15gfp-history" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15gfpHistories.OduMinute15gfpHistory, ['number'], name, value)


                                    class OduMinute15gfpTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: odu_minute15gfp_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of  		 :py:class:`OduMinute15gfpTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15gfpHistories.OduMinute15gfpHistory.OduMinute15gfpTimeLineInstances.OduMinute15gfpTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15gfpHistories.OduMinute15gfpHistory.OduMinute15gfpTimeLineInstances, self).__init__()

                                            self.yang_name = "odu-minute15gfp-time-line-instances"
                                            self.yang_parent_name = "odu-minute15gfp-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("odu-minute15gfp-time-line-instance", ("odu_minute15gfp_time_line_instance", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15gfpHistories.OduMinute15gfpHistory.OduMinute15gfpTimeLineInstances.OduMinute15gfpTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.odu_minute15gfp_time_line_instance = YList(self)
                                            self._segment_path = lambda: "odu-minute15gfp-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15gfpHistories.OduMinute15gfpHistory.OduMinute15gfpTimeLineInstances, [], name, value)


                                        class OduMinute15gfpTimeLineInstance(Entity):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rx_bit_err
                                            
                                            	RX BIT ERR
                                            	**type**\:  :py:class:`RxBitErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15gfpHistories.OduMinute15gfpHistory.OduMinute15gfpTimeLineInstances.OduMinute15gfpTimeLineInstance.RxBitErr>`
                                            
                                            .. attribute:: rx_inv_typ
                                            
                                            	RX INV TYP
                                            	**type**\:  :py:class:`RxInvTyp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15gfpHistories.OduMinute15gfpHistory.OduMinute15gfpTimeLineInstances.OduMinute15gfpTimeLineInstance.RxInvTyp>`
                                            
                                            .. attribute:: rx_crc
                                            
                                            	RX CRC
                                            	**type**\:  :py:class:`RxCrc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15gfpHistories.OduMinute15gfpHistory.OduMinute15gfpTimeLineInstances.OduMinute15gfpTimeLineInstance.RxCrc>`
                                            
                                            .. attribute:: rx_lfd
                                            
                                            	RX LFD
                                            	**type**\:  :py:class:`RxLfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15gfpHistories.OduMinute15gfpHistory.OduMinute15gfpTimeLineInstances.OduMinute15gfpTimeLineInstance.RxLfd>`
                                            
                                            .. attribute:: rx_csf
                                            
                                            	RX CSF
                                            	**type**\:  :py:class:`RxCsf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15gfpHistories.OduMinute15gfpHistory.OduMinute15gfpTimeLineInstances.OduMinute15gfpTimeLineInstance.RxCsf>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15gfpHistories.OduMinute15gfpHistory.OduMinute15gfpTimeLineInstances.OduMinute15gfpTimeLineInstance, self).__init__()

                                                self.yang_name = "odu-minute15gfp-time-line-instance"
                                                self.yang_parent_name = "odu-minute15gfp-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("rx-bit-err", ("rx_bit_err", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15gfpHistories.OduMinute15gfpHistory.OduMinute15gfpTimeLineInstances.OduMinute15gfpTimeLineInstance.RxBitErr)), ("rx-inv-typ", ("rx_inv_typ", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15gfpHistories.OduMinute15gfpHistory.OduMinute15gfpTimeLineInstances.OduMinute15gfpTimeLineInstance.RxInvTyp)), ("rx-crc", ("rx_crc", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15gfpHistories.OduMinute15gfpHistory.OduMinute15gfpTimeLineInstances.OduMinute15gfpTimeLineInstance.RxCrc)), ("rx-lfd", ("rx_lfd", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15gfpHistories.OduMinute15gfpHistory.OduMinute15gfpTimeLineInstances.OduMinute15gfpTimeLineInstance.RxLfd)), ("rx-csf", ("rx_csf", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15gfpHistories.OduMinute15gfpHistory.OduMinute15gfpTimeLineInstances.OduMinute15gfpTimeLineInstance.RxCsf))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                    ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear24_hr_time = None
                                                self.sec30_support = None

                                                self.rx_bit_err = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15gfpHistories.OduMinute15gfpHistory.OduMinute15gfpTimeLineInstances.OduMinute15gfpTimeLineInstance.RxBitErr()
                                                self.rx_bit_err.parent = self
                                                self._children_name_map["rx_bit_err"] = "rx-bit-err"

                                                self.rx_inv_typ = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15gfpHistories.OduMinute15gfpHistory.OduMinute15gfpTimeLineInstances.OduMinute15gfpTimeLineInstance.RxInvTyp()
                                                self.rx_inv_typ.parent = self
                                                self._children_name_map["rx_inv_typ"] = "rx-inv-typ"

                                                self.rx_crc = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15gfpHistories.OduMinute15gfpHistory.OduMinute15gfpTimeLineInstances.OduMinute15gfpTimeLineInstance.RxCrc()
                                                self.rx_crc.parent = self
                                                self._children_name_map["rx_crc"] = "rx-crc"

                                                self.rx_lfd = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15gfpHistories.OduMinute15gfpHistory.OduMinute15gfpTimeLineInstances.OduMinute15gfpTimeLineInstance.RxLfd()
                                                self.rx_lfd.parent = self
                                                self._children_name_map["rx_lfd"] = "rx-lfd"

                                                self.rx_csf = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15gfpHistories.OduMinute15gfpHistory.OduMinute15gfpTimeLineInstances.OduMinute15gfpTimeLineInstance.RxCsf()
                                                self.rx_csf.parent = self
                                                self._children_name_map["rx_csf"] = "rx-csf"
                                                self._segment_path = lambda: "odu-minute15gfp-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15gfpHistories.OduMinute15gfpHistory.OduMinute15gfpTimeLineInstances.OduMinute15gfpTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                            class RxBitErr(Entity):
                                                """
                                                RX BIT ERR
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15gfpHistories.OduMinute15gfpHistory.OduMinute15gfpTimeLineInstances.OduMinute15gfpTimeLineInstance.RxBitErr, self).__init__()

                                                    self.yang_name = "rx-bit-err"
                                                    self.yang_parent_name = "odu-minute15gfp-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "rx-bit-err"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15gfpHistories.OduMinute15gfpHistory.OduMinute15gfpTimeLineInstances.OduMinute15gfpTimeLineInstance.RxBitErr, ['data', 'threshold', 'tca_report'], name, value)


                                            class RxInvTyp(Entity):
                                                """
                                                RX INV TYP
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15gfpHistories.OduMinute15gfpHistory.OduMinute15gfpTimeLineInstances.OduMinute15gfpTimeLineInstance.RxInvTyp, self).__init__()

                                                    self.yang_name = "rx-inv-typ"
                                                    self.yang_parent_name = "odu-minute15gfp-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "rx-inv-typ"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15gfpHistories.OduMinute15gfpHistory.OduMinute15gfpTimeLineInstances.OduMinute15gfpTimeLineInstance.RxInvTyp, ['data', 'threshold', 'tca_report'], name, value)


                                            class RxCrc(Entity):
                                                """
                                                RX CRC
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15gfpHistories.OduMinute15gfpHistory.OduMinute15gfpTimeLineInstances.OduMinute15gfpTimeLineInstance.RxCrc, self).__init__()

                                                    self.yang_name = "rx-crc"
                                                    self.yang_parent_name = "odu-minute15gfp-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "rx-crc"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15gfpHistories.OduMinute15gfpHistory.OduMinute15gfpTimeLineInstances.OduMinute15gfpTimeLineInstance.RxCrc, ['data', 'threshold', 'tca_report'], name, value)


                                            class RxLfd(Entity):
                                                """
                                                RX LFD
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15gfpHistories.OduMinute15gfpHistory.OduMinute15gfpTimeLineInstances.OduMinute15gfpTimeLineInstance.RxLfd, self).__init__()

                                                    self.yang_name = "rx-lfd"
                                                    self.yang_parent_name = "odu-minute15gfp-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "rx-lfd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15gfpHistories.OduMinute15gfpHistory.OduMinute15gfpTimeLineInstances.OduMinute15gfpTimeLineInstance.RxLfd, ['data', 'threshold', 'tca_report'], name, value)


                                            class RxCsf(Entity):
                                                """
                                                RX CSF
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15gfpHistories.OduMinute15gfpHistory.OduMinute15gfpTimeLineInstances.OduMinute15gfpTimeLineInstance.RxCsf, self).__init__()

                                                    self.yang_name = "rx-csf"
                                                    self.yang_parent_name = "odu-minute15gfp-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "rx-csf"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15gfpHistories.OduMinute15gfpHistory.OduMinute15gfpTimeLineInstances.OduMinute15gfpTimeLineInstance.RxCsf, ['data', 'threshold', 'tca_report'], name, value)


                            class OduMinute15otnHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: odu_minute15otn_history
                                
                                	port 15\-minute otn performance data
                                	**type**\: list of  		 :py:class:`OduMinute15otnHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories, self).__init__()

                                    self.yang_name = "odu-minute15otn-histories"
                                    self.yang_parent_name = "odu-minute15-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("odu-minute15otn-history", ("odu_minute15otn_history", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory))])
                                    self._leafs = OrderedDict()

                                    self.odu_minute15otn_history = YList(self)
                                    self._segment_path = lambda: "odu-minute15otn-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories, [], name, value)


                                class OduMinute15otnHistory(Entity):
                                    """
                                    port 15\-minute otn performance data
                                    
                                    .. attribute:: number  (key)
                                    
                                    	channel number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: odu_minute15otn_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`OduMinute15otnTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory, self).__init__()

                                        self.yang_name = "odu-minute15otn-history"
                                        self.yang_parent_name = "odu-minute15otn-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([("odu-minute15otn-time-line-instances", ("odu_minute15otn_time_line_instances", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ])
                                        self.number = None

                                        self.odu_minute15otn_time_line_instances = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances()
                                        self.odu_minute15otn_time_line_instances.parent = self
                                        self._children_name_map["odu_minute15otn_time_line_instances"] = "odu-minute15otn-time-line-instances"
                                        self._segment_path = lambda: "odu-minute15otn-history" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory, ['number'], name, value)


                                    class OduMinute15otnTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: odu_minute15otn_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of  		 :py:class:`OduMinute15otnTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances, self).__init__()

                                            self.yang_name = "odu-minute15otn-time-line-instances"
                                            self.yang_parent_name = "odu-minute15otn-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("odu-minute15otn-time-line-instance", ("odu_minute15otn_time_line_instance", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.odu_minute15otn_time_line_instance = YList(self)
                                            self._segment_path = lambda: "odu-minute15otn-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances, [], name, value)


                                        class OduMinute15otnTimeLineInstance(Entity):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lbc
                                            
                                            	LBC
                                            	**type**\:  :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.Lbc>`
                                            
                                            .. attribute:: es_ne
                                            
                                            	ES SM NE
                                            	**type**\:  :py:class:`EsNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.EsNe>`
                                            
                                            .. attribute:: esr_ne
                                            
                                            	ESR PM NE
                                            	**type**\:  :py:class:`EsrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.EsrNe>`
                                            
                                            .. attribute:: ses_ne
                                            
                                            	SES SM NE
                                            	**type**\:  :py:class:`SesNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.SesNe>`
                                            
                                            .. attribute:: sesr_ne
                                            
                                            	SESR SM NE
                                            	**type**\:  :py:class:`SesrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.SesrNe>`
                                            
                                            .. attribute:: uas_ne
                                            
                                            	UAS SM NE
                                            	**type**\:  :py:class:`UasNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.UasNe>`
                                            
                                            .. attribute:: bbe_ne
                                            
                                            	BBE SM NE
                                            	**type**\:  :py:class:`BbeNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.BbeNe>`
                                            
                                            .. attribute:: bber_ne
                                            
                                            	BBER SM NE
                                            	**type**\:  :py:class:`BberNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.BberNe>`
                                            
                                            .. attribute:: fc_ne
                                            
                                            	FC SM NE
                                            	**type**\:  :py:class:`FcNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.FcNe>`
                                            
                                            .. attribute:: es_fe
                                            
                                            	ES SM FE
                                            	**type**\:  :py:class:`EsFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.EsFe>`
                                            
                                            .. attribute:: esr_fe
                                            
                                            	ESR PM FE
                                            	**type**\:  :py:class:`EsrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.EsrFe>`
                                            
                                            .. attribute:: ses_fe
                                            
                                            	SES SM FE
                                            	**type**\:  :py:class:`SesFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.SesFe>`
                                            
                                            .. attribute:: sesr_fe
                                            
                                            	SESR SM FE
                                            	**type**\:  :py:class:`SesrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.SesrFe>`
                                            
                                            .. attribute:: uas_fe
                                            
                                            	UAS SM FE
                                            	**type**\:  :py:class:`UasFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.UasFe>`
                                            
                                            .. attribute:: bbe_fe
                                            
                                            	BBE SM FE
                                            	**type**\:  :py:class:`BbeFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.BbeFe>`
                                            
                                            .. attribute:: bber_fe
                                            
                                            	BBER SM FE
                                            	**type**\:  :py:class:`BberFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.BberFe>`
                                            
                                            .. attribute:: fc_fe
                                            
                                            	FC SM FE
                                            	**type**\:  :py:class:`FcFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.FcFe>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance, self).__init__()

                                                self.yang_name = "odu-minute15otn-time-line-instance"
                                                self.yang_parent_name = "odu-minute15otn-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("lbc", ("lbc", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.Lbc)), ("es-ne", ("es_ne", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.EsNe)), ("esr-ne", ("esr_ne", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.EsrNe)), ("ses-ne", ("ses_ne", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.SesNe)), ("sesr-ne", ("sesr_ne", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.SesrNe)), ("uas-ne", ("uas_ne", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.UasNe)), ("bbe-ne", ("bbe_ne", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.BbeNe)), ("bber-ne", ("bber_ne", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.BberNe)), ("fc-ne", ("fc_ne", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.FcNe)), ("es-fe", ("es_fe", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.EsFe)), ("esr-fe", ("esr_fe", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.EsrFe)), ("ses-fe", ("ses_fe", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.SesFe)), ("sesr-fe", ("sesr_fe", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.SesrFe)), ("uas-fe", ("uas_fe", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.UasFe)), ("bbe-fe", ("bbe_fe", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.BbeFe)), ("bber-fe", ("bber_fe", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.BberFe)), ("fc-fe", ("fc_fe", PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.FcFe))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                    ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear24_hr_time = None
                                                self.sec30_support = None

                                                self.lbc = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.Lbc()
                                                self.lbc.parent = self
                                                self._children_name_map["lbc"] = "lbc"

                                                self.es_ne = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.EsNe()
                                                self.es_ne.parent = self
                                                self._children_name_map["es_ne"] = "es-ne"

                                                self.esr_ne = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.EsrNe()
                                                self.esr_ne.parent = self
                                                self._children_name_map["esr_ne"] = "esr-ne"

                                                self.ses_ne = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.SesNe()
                                                self.ses_ne.parent = self
                                                self._children_name_map["ses_ne"] = "ses-ne"

                                                self.sesr_ne = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.SesrNe()
                                                self.sesr_ne.parent = self
                                                self._children_name_map["sesr_ne"] = "sesr-ne"

                                                self.uas_ne = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.UasNe()
                                                self.uas_ne.parent = self
                                                self._children_name_map["uas_ne"] = "uas-ne"

                                                self.bbe_ne = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.BbeNe()
                                                self.bbe_ne.parent = self
                                                self._children_name_map["bbe_ne"] = "bbe-ne"

                                                self.bber_ne = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.BberNe()
                                                self.bber_ne.parent = self
                                                self._children_name_map["bber_ne"] = "bber-ne"

                                                self.fc_ne = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.FcNe()
                                                self.fc_ne.parent = self
                                                self._children_name_map["fc_ne"] = "fc-ne"

                                                self.es_fe = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.EsFe()
                                                self.es_fe.parent = self
                                                self._children_name_map["es_fe"] = "es-fe"

                                                self.esr_fe = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.EsrFe()
                                                self.esr_fe.parent = self
                                                self._children_name_map["esr_fe"] = "esr-fe"

                                                self.ses_fe = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.SesFe()
                                                self.ses_fe.parent = self
                                                self._children_name_map["ses_fe"] = "ses-fe"

                                                self.sesr_fe = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.SesrFe()
                                                self.sesr_fe.parent = self
                                                self._children_name_map["sesr_fe"] = "sesr-fe"

                                                self.uas_fe = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.UasFe()
                                                self.uas_fe.parent = self
                                                self._children_name_map["uas_fe"] = "uas-fe"

                                                self.bbe_fe = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.BbeFe()
                                                self.bbe_fe.parent = self
                                                self._children_name_map["bbe_fe"] = "bbe-fe"

                                                self.bber_fe = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.BberFe()
                                                self.bber_fe.parent = self
                                                self._children_name_map["bber_fe"] = "bber-fe"

                                                self.fc_fe = PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.FcFe()
                                                self.fc_fe.parent = self
                                                self._children_name_map["fc_fe"] = "fc-fe"
                                                self._segment_path = lambda: "odu-minute15otn-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                            class Lbc(Entity):
                                                """
                                                LBC
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.Lbc, self).__init__()

                                                    self.yang_name = "lbc"
                                                    self.yang_parent_name = "odu-minute15otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "lbc"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.Lbc, ['data', 'threshold', 'tca_report'], name, value)


                                            class EsNe(Entity):
                                                """
                                                ES SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.EsNe, self).__init__()

                                                    self.yang_name = "es-ne"
                                                    self.yang_parent_name = "odu-minute15otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "es-ne"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.EsNe, ['data', 'threshold', 'tca_report'], name, value)


                                            class EsrNe(Entity):
                                                """
                                                ESR PM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: str
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.EsrNe, self).__init__()

                                                    self.yang_name = "esr-ne"
                                                    self.yang_parent_name = "odu-minute15otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                        ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "esr-ne"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.EsrNe, ['data', 'threshold', 'tca_report'], name, value)


                                            class SesNe(Entity):
                                                """
                                                SES SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.SesNe, self).__init__()

                                                    self.yang_name = "ses-ne"
                                                    self.yang_parent_name = "odu-minute15otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "ses-ne"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.SesNe, ['data', 'threshold', 'tca_report'], name, value)


                                            class SesrNe(Entity):
                                                """
                                                SESR SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: str
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.SesrNe, self).__init__()

                                                    self.yang_name = "sesr-ne"
                                                    self.yang_parent_name = "odu-minute15otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                        ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "sesr-ne"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.SesrNe, ['data', 'threshold', 'tca_report'], name, value)


                                            class UasNe(Entity):
                                                """
                                                UAS SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.UasNe, self).__init__()

                                                    self.yang_name = "uas-ne"
                                                    self.yang_parent_name = "odu-minute15otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "uas-ne"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.UasNe, ['data', 'threshold', 'tca_report'], name, value)


                                            class BbeNe(Entity):
                                                """
                                                BBE SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.BbeNe, self).__init__()

                                                    self.yang_name = "bbe-ne"
                                                    self.yang_parent_name = "odu-minute15otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "bbe-ne"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.BbeNe, ['data', 'threshold', 'tca_report'], name, value)


                                            class BberNe(Entity):
                                                """
                                                BBER SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: str
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.BberNe, self).__init__()

                                                    self.yang_name = "bber-ne"
                                                    self.yang_parent_name = "odu-minute15otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                        ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "bber-ne"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.BberNe, ['data', 'threshold', 'tca_report'], name, value)


                                            class FcNe(Entity):
                                                """
                                                FC SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.FcNe, self).__init__()

                                                    self.yang_name = "fc-ne"
                                                    self.yang_parent_name = "odu-minute15otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "fc-ne"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.FcNe, ['data', 'threshold', 'tca_report'], name, value)


                                            class EsFe(Entity):
                                                """
                                                ES SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.EsFe, self).__init__()

                                                    self.yang_name = "es-fe"
                                                    self.yang_parent_name = "odu-minute15otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "es-fe"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.EsFe, ['data', 'threshold', 'tca_report'], name, value)


                                            class EsrFe(Entity):
                                                """
                                                ESR PM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: str
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.EsrFe, self).__init__()

                                                    self.yang_name = "esr-fe"
                                                    self.yang_parent_name = "odu-minute15otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                        ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "esr-fe"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.EsrFe, ['data', 'threshold', 'tca_report'], name, value)


                                            class SesFe(Entity):
                                                """
                                                SES SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.SesFe, self).__init__()

                                                    self.yang_name = "ses-fe"
                                                    self.yang_parent_name = "odu-minute15otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "ses-fe"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.SesFe, ['data', 'threshold', 'tca_report'], name, value)


                                            class SesrFe(Entity):
                                                """
                                                SESR SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: str
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.SesrFe, self).__init__()

                                                    self.yang_name = "sesr-fe"
                                                    self.yang_parent_name = "odu-minute15otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                        ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "sesr-fe"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.SesrFe, ['data', 'threshold', 'tca_report'], name, value)


                                            class UasFe(Entity):
                                                """
                                                UAS SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.UasFe, self).__init__()

                                                    self.yang_name = "uas-fe"
                                                    self.yang_parent_name = "odu-minute15otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "uas-fe"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.UasFe, ['data', 'threshold', 'tca_report'], name, value)


                                            class BbeFe(Entity):
                                                """
                                                BBE SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.BbeFe, self).__init__()

                                                    self.yang_name = "bbe-fe"
                                                    self.yang_parent_name = "odu-minute15otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "bbe-fe"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.BbeFe, ['data', 'threshold', 'tca_report'], name, value)


                                            class BberFe(Entity):
                                                """
                                                BBER SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: str
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.BberFe, self).__init__()

                                                    self.yang_name = "bber-fe"
                                                    self.yang_parent_name = "odu-minute15otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                        ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "bber-fe"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.BberFe, ['data', 'threshold', 'tca_report'], name, value)


                                            class FcFe(Entity):
                                                """
                                                FC SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.FcFe, self).__init__()

                                                    self.yang_name = "fc-fe"
                                                    self.yang_parent_name = "odu-minute15otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "fc-fe"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15otnHistories.OduMinute15otnHistory.OduMinute15otnTimeLineInstances.OduMinute15otnTimeLineInstance.FcFe, ['data', 'threshold', 'tca_report'], name, value)


            class OtuHistory(Entity):
                """
                OTU controller History performance data
                
                .. attribute:: otu_port_histories
                
                	Port performance data
                	**type**\:  :py:class:`OtuPortHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory, self).__init__()

                    self.yang_name = "otu-history"
                    self.yang_parent_name = "periodic"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("otu-port-histories", ("otu_port_histories", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories))])
                    self._leafs = OrderedDict()

                    self.otu_port_histories = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories()
                    self.otu_port_histories.parent = self
                    self._children_name_map["otu_port_histories"] = "otu-port-histories"
                    self._segment_path = lambda: "otu-history"
                    self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory, [], name, value)


                class OtuPortHistories(Entity):
                    """
                    Port performance data
                    
                    .. attribute:: otu_port_history
                    
                    	Port performance data
                    	**type**\: list of  		 :py:class:`OtuPortHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories, self).__init__()

                        self.yang_name = "otu-port-histories"
                        self.yang_parent_name = "otu-history"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("otu-port-history", ("otu_port_history", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory))])
                        self._leafs = OrderedDict()

                        self.otu_port_history = YList(self)
                        self._segment_path = lambda: "otu-port-histories"
                        self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/otu-history/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories, [], name, value)


                    class OtuPortHistory(Entity):
                        """
                        Port performance data
                        
                        .. attribute:: name  (key)
                        
                        	Port name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: otu_second30_history
                        
                        	port current performance data
                        	**type**\:  :py:class:`OtuSecond30History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History>`
                        
                        .. attribute:: otu_minute15_history
                        
                        	port current performance data
                        	**type**\:  :py:class:`OtuMinute15History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History>`
                        
                        .. attribute:: otu_hour24_history
                        
                        	port current performance data
                        	**type**\:  :py:class:`OtuHour24History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory, self).__init__()

                            self.yang_name = "otu-port-history"
                            self.yang_parent_name = "otu-port-histories"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("otu-second30-history", ("otu_second30_history", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History)), ("otu-minute15-history", ("otu_minute15_history", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History)), ("otu-hour24-history", ("otu_hour24_history", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None

                            self.otu_second30_history = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History()
                            self.otu_second30_history.parent = self
                            self._children_name_map["otu_second30_history"] = "otu-second30-history"

                            self.otu_minute15_history = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History()
                            self.otu_minute15_history.parent = self
                            self._children_name_map["otu_minute15_history"] = "otu-minute15-history"

                            self.otu_hour24_history = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History()
                            self.otu_hour24_history.parent = self
                            self._children_name_map["otu_hour24_history"] = "otu-hour24-history"
                            self._segment_path = lambda: "otu-port-history" + "[name='" + str(self.name) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/otu-history/otu-port-histories/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory, ['name'], name, value)


                        class OtuSecond30History(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: otu_second30fec_histories
                            
                            	port current performance data
                            	**type**\:  :py:class:`OtuSecond30fecHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30fecHistories>`
                            
                            .. attribute:: otu_second30otn_histories
                            
                            	port current performance data
                            	**type**\:  :py:class:`OtuSecond30otnHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History, self).__init__()

                                self.yang_name = "otu-second30-history"
                                self.yang_parent_name = "otu-port-history"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("otu-second30fec-histories", ("otu_second30fec_histories", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30fecHistories)), ("otu-second30otn-histories", ("otu_second30otn_histories", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories))])
                                self._leafs = OrderedDict()

                                self.otu_second30fec_histories = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30fecHistories()
                                self.otu_second30fec_histories.parent = self
                                self._children_name_map["otu_second30fec_histories"] = "otu-second30fec-histories"

                                self.otu_second30otn_histories = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories()
                                self.otu_second30otn_histories.parent = self
                                self._children_name_map["otu_second30otn_histories"] = "otu-second30otn-histories"
                                self._segment_path = lambda: "otu-second30-history"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History, [], name, value)


                            class OtuSecond30fecHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: otu_second30fec_history
                                
                                	port 30\-second fec performance data
                                	**type**\: list of  		 :py:class:`OtuSecond30fecHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30fecHistories.OtuSecond30fecHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30fecHistories, self).__init__()

                                    self.yang_name = "otu-second30fec-histories"
                                    self.yang_parent_name = "otu-second30-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("otu-second30fec-history", ("otu_second30fec_history", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30fecHistories.OtuSecond30fecHistory))])
                                    self._leafs = OrderedDict()

                                    self.otu_second30fec_history = YList(self)
                                    self._segment_path = lambda: "otu-second30fec-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30fecHistories, [], name, value)


                                class OtuSecond30fecHistory(Entity):
                                    """
                                    port 30\-second fec performance data
                                    
                                    .. attribute:: number  (key)
                                    
                                    	channel number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: otu_second30fec_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`OtuSecond30fecTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30fecHistories.OtuSecond30fecHistory.OtuSecond30fecTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30fecHistories.OtuSecond30fecHistory, self).__init__()

                                        self.yang_name = "otu-second30fec-history"
                                        self.yang_parent_name = "otu-second30fec-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([("otu-second30fec-time-line-instances", ("otu_second30fec_time_line_instances", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30fecHistories.OtuSecond30fecHistory.OtuSecond30fecTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ])
                                        self.number = None

                                        self.otu_second30fec_time_line_instances = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30fecHistories.OtuSecond30fecHistory.OtuSecond30fecTimeLineInstances()
                                        self.otu_second30fec_time_line_instances.parent = self
                                        self._children_name_map["otu_second30fec_time_line_instances"] = "otu-second30fec-time-line-instances"
                                        self._segment_path = lambda: "otu-second30fec-history" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30fecHistories.OtuSecond30fecHistory, ['number'], name, value)


                                    class OtuSecond30fecTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: otu_second30fec_time_line_instance
                                        
                                        	port 30\-second fec performance data
                                        	**type**\: list of  		 :py:class:`OtuSecond30fecTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30fecHistories.OtuSecond30fecHistory.OtuSecond30fecTimeLineInstances.OtuSecond30fecTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30fecHistories.OtuSecond30fecHistory.OtuSecond30fecTimeLineInstances, self).__init__()

                                            self.yang_name = "otu-second30fec-time-line-instances"
                                            self.yang_parent_name = "otu-second30fec-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("otu-second30fec-time-line-instance", ("otu_second30fec_time_line_instance", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30fecHistories.OtuSecond30fecHistory.OtuSecond30fecTimeLineInstances.OtuSecond30fecTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.otu_second30fec_time_line_instance = YList(self)
                                            self._segment_path = lambda: "otu-second30fec-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30fecHistories.OtuSecond30fecHistory.OtuSecond30fecTimeLineInstances, [], name, value)


                                        class OtuSecond30fecTimeLineInstance(Entity):
                                            """
                                            port 30\-second fec performance data
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ec_bits
                                            
                                            	EC BITS
                                            	**type**\:  :py:class:`EcBits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30fecHistories.OtuSecond30fecHistory.OtuSecond30fecTimeLineInstances.OtuSecond30fecTimeLineInstance.EcBits>`
                                            
                                            .. attribute:: uc_words
                                            
                                            	UC WORDS
                                            	**type**\:  :py:class:`UcWords <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30fecHistories.OtuSecond30fecHistory.OtuSecond30fecTimeLineInstances.OtuSecond30fecTimeLineInstance.UcWords>`
                                            
                                            .. attribute:: pre_fec_ber
                                            
                                            	Pre FEC BER
                                            	**type**\:  :py:class:`PreFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30fecHistories.OtuSecond30fecHistory.OtuSecond30fecTimeLineInstances.OtuSecond30fecTimeLineInstance.PreFecBer>`
                                            
                                            .. attribute:: post_fec_ber
                                            
                                            	Post FEC BER
                                            	**type**\:  :py:class:`PostFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30fecHistories.OtuSecond30fecHistory.OtuSecond30fecTimeLineInstances.OtuSecond30fecTimeLineInstance.PostFecBer>`
                                            
                                            .. attribute:: q
                                            
                                            	Q
                                            	**type**\:  :py:class:`Q <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30fecHistories.OtuSecond30fecHistory.OtuSecond30fecTimeLineInstances.OtuSecond30fecTimeLineInstance.Q>`
                                            
                                            .. attribute:: qmargin
                                            
                                            	Q Margin
                                            	**type**\:  :py:class:`Qmargin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30fecHistories.OtuSecond30fecHistory.OtuSecond30fecTimeLineInstances.OtuSecond30fecTimeLineInstance.Qmargin>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30fecHistories.OtuSecond30fecHistory.OtuSecond30fecTimeLineInstances.OtuSecond30fecTimeLineInstance, self).__init__()

                                                self.yang_name = "otu-second30fec-time-line-instance"
                                                self.yang_parent_name = "otu-second30fec-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("ec-bits", ("ec_bits", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30fecHistories.OtuSecond30fecHistory.OtuSecond30fecTimeLineInstances.OtuSecond30fecTimeLineInstance.EcBits)), ("uc-words", ("uc_words", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30fecHistories.OtuSecond30fecHistory.OtuSecond30fecTimeLineInstances.OtuSecond30fecTimeLineInstance.UcWords)), ("pre-fec-ber", ("pre_fec_ber", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30fecHistories.OtuSecond30fecHistory.OtuSecond30fecTimeLineInstances.OtuSecond30fecTimeLineInstance.PreFecBer)), ("post-fec-ber", ("post_fec_ber", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30fecHistories.OtuSecond30fecHistory.OtuSecond30fecTimeLineInstances.OtuSecond30fecTimeLineInstance.PostFecBer)), ("q", ("q", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30fecHistories.OtuSecond30fecHistory.OtuSecond30fecTimeLineInstances.OtuSecond30fecTimeLineInstance.Q)), ("qmargin", ("qmargin", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30fecHistories.OtuSecond30fecHistory.OtuSecond30fecTimeLineInstances.OtuSecond30fecTimeLineInstance.Qmargin))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                    ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear24_hr_time = None
                                                self.sec30_support = None

                                                self.ec_bits = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30fecHistories.OtuSecond30fecHistory.OtuSecond30fecTimeLineInstances.OtuSecond30fecTimeLineInstance.EcBits()
                                                self.ec_bits.parent = self
                                                self._children_name_map["ec_bits"] = "ec-bits"

                                                self.uc_words = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30fecHistories.OtuSecond30fecHistory.OtuSecond30fecTimeLineInstances.OtuSecond30fecTimeLineInstance.UcWords()
                                                self.uc_words.parent = self
                                                self._children_name_map["uc_words"] = "uc-words"

                                                self.pre_fec_ber = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30fecHistories.OtuSecond30fecHistory.OtuSecond30fecTimeLineInstances.OtuSecond30fecTimeLineInstance.PreFecBer()
                                                self.pre_fec_ber.parent = self
                                                self._children_name_map["pre_fec_ber"] = "pre-fec-ber"

                                                self.post_fec_ber = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30fecHistories.OtuSecond30fecHistory.OtuSecond30fecTimeLineInstances.OtuSecond30fecTimeLineInstance.PostFecBer()
                                                self.post_fec_ber.parent = self
                                                self._children_name_map["post_fec_ber"] = "post-fec-ber"

                                                self.q = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30fecHistories.OtuSecond30fecHistory.OtuSecond30fecTimeLineInstances.OtuSecond30fecTimeLineInstance.Q()
                                                self.q.parent = self
                                                self._children_name_map["q"] = "q"

                                                self.qmargin = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30fecHistories.OtuSecond30fecHistory.OtuSecond30fecTimeLineInstances.OtuSecond30fecTimeLineInstance.Qmargin()
                                                self.qmargin.parent = self
                                                self._children_name_map["qmargin"] = "qmargin"
                                                self._segment_path = lambda: "otu-second30fec-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30fecHistories.OtuSecond30fecHistory.OtuSecond30fecTimeLineInstances.OtuSecond30fecTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                            class EcBits(Entity):
                                                """
                                                EC BITS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30fecHistories.OtuSecond30fecHistory.OtuSecond30fecTimeLineInstances.OtuSecond30fecTimeLineInstance.EcBits, self).__init__()

                                                    self.yang_name = "ec-bits"
                                                    self.yang_parent_name = "otu-second30fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ec-bits"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30fecHistories.OtuSecond30fecHistory.OtuSecond30fecTimeLineInstances.OtuSecond30fecTimeLineInstance.EcBits, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class UcWords(Entity):
                                                """
                                                UC WORDS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30fecHistories.OtuSecond30fecHistory.OtuSecond30fecTimeLineInstances.OtuSecond30fecTimeLineInstance.UcWords, self).__init__()

                                                    self.yang_name = "uc-words"
                                                    self.yang_parent_name = "otu-second30fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "uc-words"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30fecHistories.OtuSecond30fecHistory.OtuSecond30fecTimeLineInstances.OtuSecond30fecTimeLineInstance.UcWords, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class PreFecBer(Entity):
                                                """
                                                Pre FEC BER
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30fecHistories.OtuSecond30fecHistory.OtuSecond30fecTimeLineInstances.OtuSecond30fecTimeLineInstance.PreFecBer, self).__init__()

                                                    self.yang_name = "pre-fec-ber"
                                                    self.yang_parent_name = "otu-second30fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.maximum_tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "pre-fec-ber"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30fecHistories.OtuSecond30fecHistory.OtuSecond30fecTimeLineInstances.OtuSecond30fecTimeLineInstance.PreFecBer, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                            class PostFecBer(Entity):
                                                """
                                                Post FEC BER
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30fecHistories.OtuSecond30fecHistory.OtuSecond30fecTimeLineInstances.OtuSecond30fecTimeLineInstance.PostFecBer, self).__init__()

                                                    self.yang_name = "post-fec-ber"
                                                    self.yang_parent_name = "otu-second30fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.maximum_tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "post-fec-ber"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30fecHistories.OtuSecond30fecHistory.OtuSecond30fecTimeLineInstances.OtuSecond30fecTimeLineInstance.PostFecBer, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                            class Q(Entity):
                                                """
                                                Q
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30fecHistories.OtuSecond30fecHistory.OtuSecond30fecTimeLineInstances.OtuSecond30fecTimeLineInstance.Q, self).__init__()

                                                    self.yang_name = "q"
                                                    self.yang_parent_name = "otu-second30fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.maximum_tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "q"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30fecHistories.OtuSecond30fecHistory.OtuSecond30fecTimeLineInstances.OtuSecond30fecTimeLineInstance.Q, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                            class Qmargin(Entity):
                                                """
                                                Q Margin
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30fecHistories.OtuSecond30fecHistory.OtuSecond30fecTimeLineInstances.OtuSecond30fecTimeLineInstance.Qmargin, self).__init__()

                                                    self.yang_name = "qmargin"
                                                    self.yang_parent_name = "otu-second30fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.maximum_tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "qmargin"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30fecHistories.OtuSecond30fecHistory.OtuSecond30fecTimeLineInstances.OtuSecond30fecTimeLineInstance.Qmargin, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                            class OtuSecond30otnHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: otu_second30otn_history
                                
                                	port 30\-second otn performance data
                                	**type**\: list of  		 :py:class:`OtuSecond30otnHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories, self).__init__()

                                    self.yang_name = "otu-second30otn-histories"
                                    self.yang_parent_name = "otu-second30-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("otu-second30otn-history", ("otu_second30otn_history", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory))])
                                    self._leafs = OrderedDict()

                                    self.otu_second30otn_history = YList(self)
                                    self._segment_path = lambda: "otu-second30otn-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories, [], name, value)


                                class OtuSecond30otnHistory(Entity):
                                    """
                                    port 30\-second otn performance data
                                    
                                    .. attribute:: number  (key)
                                    
                                    	channel number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: otu_second30otn_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`OtuSecond30otnTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory, self).__init__()

                                        self.yang_name = "otu-second30otn-history"
                                        self.yang_parent_name = "otu-second30otn-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([("otu-second30otn-time-line-instances", ("otu_second30otn_time_line_instances", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ])
                                        self.number = None

                                        self.otu_second30otn_time_line_instances = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances()
                                        self.otu_second30otn_time_line_instances.parent = self
                                        self._children_name_map["otu_second30otn_time_line_instances"] = "otu-second30otn-time-line-instances"
                                        self._segment_path = lambda: "otu-second30otn-history" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory, ['number'], name, value)


                                    class OtuSecond30otnTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: otu_second30otn_time_line_instance
                                        
                                        	port 30\-second otn performance data
                                        	**type**\: list of  		 :py:class:`OtuSecond30otnTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances, self).__init__()

                                            self.yang_name = "otu-second30otn-time-line-instances"
                                            self.yang_parent_name = "otu-second30otn-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("otu-second30otn-time-line-instance", ("otu_second30otn_time_line_instance", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.otu_second30otn_time_line_instance = YList(self)
                                            self._segment_path = lambda: "otu-second30otn-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances, [], name, value)


                                        class OtuSecond30otnTimeLineInstance(Entity):
                                            """
                                            port 30\-second otn performance data
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lbc
                                            
                                            	LBC
                                            	**type**\:  :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.Lbc>`
                                            
                                            .. attribute:: es_ne
                                            
                                            	ES SM NE
                                            	**type**\:  :py:class:`EsNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.EsNe>`
                                            
                                            .. attribute:: esr_ne
                                            
                                            	ESR PM NE
                                            	**type**\:  :py:class:`EsrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.EsrNe>`
                                            
                                            .. attribute:: ses_ne
                                            
                                            	SES SM NE
                                            	**type**\:  :py:class:`SesNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.SesNe>`
                                            
                                            .. attribute:: sesr_ne
                                            
                                            	SESR SM NE
                                            	**type**\:  :py:class:`SesrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.SesrNe>`
                                            
                                            .. attribute:: uas_ne
                                            
                                            	UAS SM NE
                                            	**type**\:  :py:class:`UasNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.UasNe>`
                                            
                                            .. attribute:: bbe_ne
                                            
                                            	BBE SM NE
                                            	**type**\:  :py:class:`BbeNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.BbeNe>`
                                            
                                            .. attribute:: bber_ne
                                            
                                            	BBER SM NE
                                            	**type**\:  :py:class:`BberNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.BberNe>`
                                            
                                            .. attribute:: fc_ne
                                            
                                            	FC SM NE
                                            	**type**\:  :py:class:`FcNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.FcNe>`
                                            
                                            .. attribute:: es_fe
                                            
                                            	ES SM FE
                                            	**type**\:  :py:class:`EsFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.EsFe>`
                                            
                                            .. attribute:: esr_fe
                                            
                                            	ESR PM FE
                                            	**type**\:  :py:class:`EsrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.EsrFe>`
                                            
                                            .. attribute:: ses_fe
                                            
                                            	SES SM FE
                                            	**type**\:  :py:class:`SesFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.SesFe>`
                                            
                                            .. attribute:: sesr_fe
                                            
                                            	SESR SM FE
                                            	**type**\:  :py:class:`SesrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.SesrFe>`
                                            
                                            .. attribute:: uas_fe
                                            
                                            	UAS SM FE
                                            	**type**\:  :py:class:`UasFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.UasFe>`
                                            
                                            .. attribute:: bbe_fe
                                            
                                            	BBE SM FE
                                            	**type**\:  :py:class:`BbeFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.BbeFe>`
                                            
                                            .. attribute:: bber_fe
                                            
                                            	BBER SM FE
                                            	**type**\:  :py:class:`BberFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.BberFe>`
                                            
                                            .. attribute:: fc_fe
                                            
                                            	FC SM FE
                                            	**type**\:  :py:class:`FcFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.FcFe>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance, self).__init__()

                                                self.yang_name = "otu-second30otn-time-line-instance"
                                                self.yang_parent_name = "otu-second30otn-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("lbc", ("lbc", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.Lbc)), ("es-ne", ("es_ne", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.EsNe)), ("esr-ne", ("esr_ne", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.EsrNe)), ("ses-ne", ("ses_ne", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.SesNe)), ("sesr-ne", ("sesr_ne", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.SesrNe)), ("uas-ne", ("uas_ne", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.UasNe)), ("bbe-ne", ("bbe_ne", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.BbeNe)), ("bber-ne", ("bber_ne", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.BberNe)), ("fc-ne", ("fc_ne", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.FcNe)), ("es-fe", ("es_fe", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.EsFe)), ("esr-fe", ("esr_fe", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.EsrFe)), ("ses-fe", ("ses_fe", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.SesFe)), ("sesr-fe", ("sesr_fe", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.SesrFe)), ("uas-fe", ("uas_fe", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.UasFe)), ("bbe-fe", ("bbe_fe", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.BbeFe)), ("bber-fe", ("bber_fe", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.BberFe)), ("fc-fe", ("fc_fe", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.FcFe))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                    ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear24_hr_time = None
                                                self.sec30_support = None

                                                self.lbc = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.Lbc()
                                                self.lbc.parent = self
                                                self._children_name_map["lbc"] = "lbc"

                                                self.es_ne = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.EsNe()
                                                self.es_ne.parent = self
                                                self._children_name_map["es_ne"] = "es-ne"

                                                self.esr_ne = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.EsrNe()
                                                self.esr_ne.parent = self
                                                self._children_name_map["esr_ne"] = "esr-ne"

                                                self.ses_ne = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.SesNe()
                                                self.ses_ne.parent = self
                                                self._children_name_map["ses_ne"] = "ses-ne"

                                                self.sesr_ne = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.SesrNe()
                                                self.sesr_ne.parent = self
                                                self._children_name_map["sesr_ne"] = "sesr-ne"

                                                self.uas_ne = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.UasNe()
                                                self.uas_ne.parent = self
                                                self._children_name_map["uas_ne"] = "uas-ne"

                                                self.bbe_ne = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.BbeNe()
                                                self.bbe_ne.parent = self
                                                self._children_name_map["bbe_ne"] = "bbe-ne"

                                                self.bber_ne = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.BberNe()
                                                self.bber_ne.parent = self
                                                self._children_name_map["bber_ne"] = "bber-ne"

                                                self.fc_ne = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.FcNe()
                                                self.fc_ne.parent = self
                                                self._children_name_map["fc_ne"] = "fc-ne"

                                                self.es_fe = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.EsFe()
                                                self.es_fe.parent = self
                                                self._children_name_map["es_fe"] = "es-fe"

                                                self.esr_fe = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.EsrFe()
                                                self.esr_fe.parent = self
                                                self._children_name_map["esr_fe"] = "esr-fe"

                                                self.ses_fe = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.SesFe()
                                                self.ses_fe.parent = self
                                                self._children_name_map["ses_fe"] = "ses-fe"

                                                self.sesr_fe = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.SesrFe()
                                                self.sesr_fe.parent = self
                                                self._children_name_map["sesr_fe"] = "sesr-fe"

                                                self.uas_fe = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.UasFe()
                                                self.uas_fe.parent = self
                                                self._children_name_map["uas_fe"] = "uas-fe"

                                                self.bbe_fe = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.BbeFe()
                                                self.bbe_fe.parent = self
                                                self._children_name_map["bbe_fe"] = "bbe-fe"

                                                self.bber_fe = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.BberFe()
                                                self.bber_fe.parent = self
                                                self._children_name_map["bber_fe"] = "bber-fe"

                                                self.fc_fe = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.FcFe()
                                                self.fc_fe.parent = self
                                                self._children_name_map["fc_fe"] = "fc-fe"
                                                self._segment_path = lambda: "otu-second30otn-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                            class Lbc(Entity):
                                                """
                                                LBC
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.Lbc, self).__init__()

                                                    self.yang_name = "lbc"
                                                    self.yang_parent_name = "otu-second30otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "lbc"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.Lbc, ['data', 'threshold', 'tca_report'], name, value)


                                            class EsNe(Entity):
                                                """
                                                ES SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.EsNe, self).__init__()

                                                    self.yang_name = "es-ne"
                                                    self.yang_parent_name = "otu-second30otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "es-ne"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.EsNe, ['data', 'threshold', 'tca_report'], name, value)


                                            class EsrNe(Entity):
                                                """
                                                ESR PM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: str
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.EsrNe, self).__init__()

                                                    self.yang_name = "esr-ne"
                                                    self.yang_parent_name = "otu-second30otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                        ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "esr-ne"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.EsrNe, ['data', 'threshold', 'tca_report'], name, value)


                                            class SesNe(Entity):
                                                """
                                                SES SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.SesNe, self).__init__()

                                                    self.yang_name = "ses-ne"
                                                    self.yang_parent_name = "otu-second30otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "ses-ne"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.SesNe, ['data', 'threshold', 'tca_report'], name, value)


                                            class SesrNe(Entity):
                                                """
                                                SESR SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: str
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.SesrNe, self).__init__()

                                                    self.yang_name = "sesr-ne"
                                                    self.yang_parent_name = "otu-second30otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                        ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "sesr-ne"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.SesrNe, ['data', 'threshold', 'tca_report'], name, value)


                                            class UasNe(Entity):
                                                """
                                                UAS SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.UasNe, self).__init__()

                                                    self.yang_name = "uas-ne"
                                                    self.yang_parent_name = "otu-second30otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "uas-ne"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.UasNe, ['data', 'threshold', 'tca_report'], name, value)


                                            class BbeNe(Entity):
                                                """
                                                BBE SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.BbeNe, self).__init__()

                                                    self.yang_name = "bbe-ne"
                                                    self.yang_parent_name = "otu-second30otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "bbe-ne"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.BbeNe, ['data', 'threshold', 'tca_report'], name, value)


                                            class BberNe(Entity):
                                                """
                                                BBER SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: str
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.BberNe, self).__init__()

                                                    self.yang_name = "bber-ne"
                                                    self.yang_parent_name = "otu-second30otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                        ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "bber-ne"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.BberNe, ['data', 'threshold', 'tca_report'], name, value)


                                            class FcNe(Entity):
                                                """
                                                FC SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.FcNe, self).__init__()

                                                    self.yang_name = "fc-ne"
                                                    self.yang_parent_name = "otu-second30otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "fc-ne"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.FcNe, ['data', 'threshold', 'tca_report'], name, value)


                                            class EsFe(Entity):
                                                """
                                                ES SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.EsFe, self).__init__()

                                                    self.yang_name = "es-fe"
                                                    self.yang_parent_name = "otu-second30otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "es-fe"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.EsFe, ['data', 'threshold', 'tca_report'], name, value)


                                            class EsrFe(Entity):
                                                """
                                                ESR PM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: str
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.EsrFe, self).__init__()

                                                    self.yang_name = "esr-fe"
                                                    self.yang_parent_name = "otu-second30otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                        ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "esr-fe"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.EsrFe, ['data', 'threshold', 'tca_report'], name, value)


                                            class SesFe(Entity):
                                                """
                                                SES SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.SesFe, self).__init__()

                                                    self.yang_name = "ses-fe"
                                                    self.yang_parent_name = "otu-second30otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "ses-fe"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.SesFe, ['data', 'threshold', 'tca_report'], name, value)


                                            class SesrFe(Entity):
                                                """
                                                SESR SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: str
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.SesrFe, self).__init__()

                                                    self.yang_name = "sesr-fe"
                                                    self.yang_parent_name = "otu-second30otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                        ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "sesr-fe"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.SesrFe, ['data', 'threshold', 'tca_report'], name, value)


                                            class UasFe(Entity):
                                                """
                                                UAS SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.UasFe, self).__init__()

                                                    self.yang_name = "uas-fe"
                                                    self.yang_parent_name = "otu-second30otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "uas-fe"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.UasFe, ['data', 'threshold', 'tca_report'], name, value)


                                            class BbeFe(Entity):
                                                """
                                                BBE SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.BbeFe, self).__init__()

                                                    self.yang_name = "bbe-fe"
                                                    self.yang_parent_name = "otu-second30otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "bbe-fe"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.BbeFe, ['data', 'threshold', 'tca_report'], name, value)


                                            class BberFe(Entity):
                                                """
                                                BBER SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: str
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.BberFe, self).__init__()

                                                    self.yang_name = "bber-fe"
                                                    self.yang_parent_name = "otu-second30otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                        ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "bber-fe"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.BberFe, ['data', 'threshold', 'tca_report'], name, value)


                                            class FcFe(Entity):
                                                """
                                                FC SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.FcFe, self).__init__()

                                                    self.yang_name = "fc-fe"
                                                    self.yang_parent_name = "otu-second30otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "fc-fe"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30otnHistories.OtuSecond30otnHistory.OtuSecond30otnTimeLineInstances.OtuSecond30otnTimeLineInstance.FcFe, ['data', 'threshold', 'tca_report'], name, value)


                        class OtuMinute15History(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: otu_minute15fec_histories
                            
                            	port current performance data
                            	**type**\:  :py:class:`OtuMinute15fecHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15fecHistories>`
                            
                            .. attribute:: otu_minute15prbs_histories
                            
                            	port current performance data
                            	**type**\:  :py:class:`OtuMinute15prbsHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15prbsHistories>`
                            
                            .. attribute:: otu_minute15otn_histories
                            
                            	port current performance data
                            	**type**\:  :py:class:`OtuMinute15otnHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History, self).__init__()

                                self.yang_name = "otu-minute15-history"
                                self.yang_parent_name = "otu-port-history"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("otu-minute15fec-histories", ("otu_minute15fec_histories", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15fecHistories)), ("otu-minute15prbs-histories", ("otu_minute15prbs_histories", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15prbsHistories)), ("otu-minute15otn-histories", ("otu_minute15otn_histories", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories))])
                                self._leafs = OrderedDict()

                                self.otu_minute15fec_histories = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15fecHistories()
                                self.otu_minute15fec_histories.parent = self
                                self._children_name_map["otu_minute15fec_histories"] = "otu-minute15fec-histories"

                                self.otu_minute15prbs_histories = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15prbsHistories()
                                self.otu_minute15prbs_histories.parent = self
                                self._children_name_map["otu_minute15prbs_histories"] = "otu-minute15prbs-histories"

                                self.otu_minute15otn_histories = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories()
                                self.otu_minute15otn_histories.parent = self
                                self._children_name_map["otu_minute15otn_histories"] = "otu-minute15otn-histories"
                                self._segment_path = lambda: "otu-minute15-history"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History, [], name, value)


                            class OtuMinute15fecHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: otu_minute15fec_history
                                
                                	port 15\-minute fec performance data
                                	**type**\: list of  		 :py:class:`OtuMinute15fecHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15fecHistories.OtuMinute15fecHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15fecHistories, self).__init__()

                                    self.yang_name = "otu-minute15fec-histories"
                                    self.yang_parent_name = "otu-minute15-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("otu-minute15fec-history", ("otu_minute15fec_history", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15fecHistories.OtuMinute15fecHistory))])
                                    self._leafs = OrderedDict()

                                    self.otu_minute15fec_history = YList(self)
                                    self._segment_path = lambda: "otu-minute15fec-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15fecHistories, [], name, value)


                                class OtuMinute15fecHistory(Entity):
                                    """
                                    port 15\-minute fec performance data
                                    
                                    .. attribute:: number  (key)
                                    
                                    	channel number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: otu_minute15fec_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`OtuMinute15fecTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15fecHistories.OtuMinute15fecHistory.OtuMinute15fecTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15fecHistories.OtuMinute15fecHistory, self).__init__()

                                        self.yang_name = "otu-minute15fec-history"
                                        self.yang_parent_name = "otu-minute15fec-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([("otu-minute15fec-time-line-instances", ("otu_minute15fec_time_line_instances", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15fecHistories.OtuMinute15fecHistory.OtuMinute15fecTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ])
                                        self.number = None

                                        self.otu_minute15fec_time_line_instances = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15fecHistories.OtuMinute15fecHistory.OtuMinute15fecTimeLineInstances()
                                        self.otu_minute15fec_time_line_instances.parent = self
                                        self._children_name_map["otu_minute15fec_time_line_instances"] = "otu-minute15fec-time-line-instances"
                                        self._segment_path = lambda: "otu-minute15fec-history" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15fecHistories.OtuMinute15fecHistory, ['number'], name, value)


                                    class OtuMinute15fecTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: otu_minute15fec_time_line_instance
                                        
                                        	port 15\-minute fec performance data
                                        	**type**\: list of  		 :py:class:`OtuMinute15fecTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15fecHistories.OtuMinute15fecHistory.OtuMinute15fecTimeLineInstances.OtuMinute15fecTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15fecHistories.OtuMinute15fecHistory.OtuMinute15fecTimeLineInstances, self).__init__()

                                            self.yang_name = "otu-minute15fec-time-line-instances"
                                            self.yang_parent_name = "otu-minute15fec-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("otu-minute15fec-time-line-instance", ("otu_minute15fec_time_line_instance", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15fecHistories.OtuMinute15fecHistory.OtuMinute15fecTimeLineInstances.OtuMinute15fecTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.otu_minute15fec_time_line_instance = YList(self)
                                            self._segment_path = lambda: "otu-minute15fec-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15fecHistories.OtuMinute15fecHistory.OtuMinute15fecTimeLineInstances, [], name, value)


                                        class OtuMinute15fecTimeLineInstance(Entity):
                                            """
                                            port 15\-minute fec performance data
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ec_bits
                                            
                                            	EC BITS
                                            	**type**\:  :py:class:`EcBits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15fecHistories.OtuMinute15fecHistory.OtuMinute15fecTimeLineInstances.OtuMinute15fecTimeLineInstance.EcBits>`
                                            
                                            .. attribute:: uc_words
                                            
                                            	UC WORDS
                                            	**type**\:  :py:class:`UcWords <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15fecHistories.OtuMinute15fecHistory.OtuMinute15fecTimeLineInstances.OtuMinute15fecTimeLineInstance.UcWords>`
                                            
                                            .. attribute:: pre_fec_ber
                                            
                                            	Pre FEC BER
                                            	**type**\:  :py:class:`PreFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15fecHistories.OtuMinute15fecHistory.OtuMinute15fecTimeLineInstances.OtuMinute15fecTimeLineInstance.PreFecBer>`
                                            
                                            .. attribute:: post_fec_ber
                                            
                                            	Post FEC BER
                                            	**type**\:  :py:class:`PostFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15fecHistories.OtuMinute15fecHistory.OtuMinute15fecTimeLineInstances.OtuMinute15fecTimeLineInstance.PostFecBer>`
                                            
                                            .. attribute:: q
                                            
                                            	Q
                                            	**type**\:  :py:class:`Q <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15fecHistories.OtuMinute15fecHistory.OtuMinute15fecTimeLineInstances.OtuMinute15fecTimeLineInstance.Q>`
                                            
                                            .. attribute:: qmargin
                                            
                                            	Q Margin
                                            	**type**\:  :py:class:`Qmargin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15fecHistories.OtuMinute15fecHistory.OtuMinute15fecTimeLineInstances.OtuMinute15fecTimeLineInstance.Qmargin>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15fecHistories.OtuMinute15fecHistory.OtuMinute15fecTimeLineInstances.OtuMinute15fecTimeLineInstance, self).__init__()

                                                self.yang_name = "otu-minute15fec-time-line-instance"
                                                self.yang_parent_name = "otu-minute15fec-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("ec-bits", ("ec_bits", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15fecHistories.OtuMinute15fecHistory.OtuMinute15fecTimeLineInstances.OtuMinute15fecTimeLineInstance.EcBits)), ("uc-words", ("uc_words", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15fecHistories.OtuMinute15fecHistory.OtuMinute15fecTimeLineInstances.OtuMinute15fecTimeLineInstance.UcWords)), ("pre-fec-ber", ("pre_fec_ber", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15fecHistories.OtuMinute15fecHistory.OtuMinute15fecTimeLineInstances.OtuMinute15fecTimeLineInstance.PreFecBer)), ("post-fec-ber", ("post_fec_ber", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15fecHistories.OtuMinute15fecHistory.OtuMinute15fecTimeLineInstances.OtuMinute15fecTimeLineInstance.PostFecBer)), ("q", ("q", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15fecHistories.OtuMinute15fecHistory.OtuMinute15fecTimeLineInstances.OtuMinute15fecTimeLineInstance.Q)), ("qmargin", ("qmargin", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15fecHistories.OtuMinute15fecHistory.OtuMinute15fecTimeLineInstances.OtuMinute15fecTimeLineInstance.Qmargin))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                    ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear24_hr_time = None
                                                self.sec30_support = None

                                                self.ec_bits = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15fecHistories.OtuMinute15fecHistory.OtuMinute15fecTimeLineInstances.OtuMinute15fecTimeLineInstance.EcBits()
                                                self.ec_bits.parent = self
                                                self._children_name_map["ec_bits"] = "ec-bits"

                                                self.uc_words = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15fecHistories.OtuMinute15fecHistory.OtuMinute15fecTimeLineInstances.OtuMinute15fecTimeLineInstance.UcWords()
                                                self.uc_words.parent = self
                                                self._children_name_map["uc_words"] = "uc-words"

                                                self.pre_fec_ber = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15fecHistories.OtuMinute15fecHistory.OtuMinute15fecTimeLineInstances.OtuMinute15fecTimeLineInstance.PreFecBer()
                                                self.pre_fec_ber.parent = self
                                                self._children_name_map["pre_fec_ber"] = "pre-fec-ber"

                                                self.post_fec_ber = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15fecHistories.OtuMinute15fecHistory.OtuMinute15fecTimeLineInstances.OtuMinute15fecTimeLineInstance.PostFecBer()
                                                self.post_fec_ber.parent = self
                                                self._children_name_map["post_fec_ber"] = "post-fec-ber"

                                                self.q = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15fecHistories.OtuMinute15fecHistory.OtuMinute15fecTimeLineInstances.OtuMinute15fecTimeLineInstance.Q()
                                                self.q.parent = self
                                                self._children_name_map["q"] = "q"

                                                self.qmargin = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15fecHistories.OtuMinute15fecHistory.OtuMinute15fecTimeLineInstances.OtuMinute15fecTimeLineInstance.Qmargin()
                                                self.qmargin.parent = self
                                                self._children_name_map["qmargin"] = "qmargin"
                                                self._segment_path = lambda: "otu-minute15fec-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15fecHistories.OtuMinute15fecHistory.OtuMinute15fecTimeLineInstances.OtuMinute15fecTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                            class EcBits(Entity):
                                                """
                                                EC BITS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15fecHistories.OtuMinute15fecHistory.OtuMinute15fecTimeLineInstances.OtuMinute15fecTimeLineInstance.EcBits, self).__init__()

                                                    self.yang_name = "ec-bits"
                                                    self.yang_parent_name = "otu-minute15fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ec-bits"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15fecHistories.OtuMinute15fecHistory.OtuMinute15fecTimeLineInstances.OtuMinute15fecTimeLineInstance.EcBits, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class UcWords(Entity):
                                                """
                                                UC WORDS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15fecHistories.OtuMinute15fecHistory.OtuMinute15fecTimeLineInstances.OtuMinute15fecTimeLineInstance.UcWords, self).__init__()

                                                    self.yang_name = "uc-words"
                                                    self.yang_parent_name = "otu-minute15fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "uc-words"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15fecHistories.OtuMinute15fecHistory.OtuMinute15fecTimeLineInstances.OtuMinute15fecTimeLineInstance.UcWords, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class PreFecBer(Entity):
                                                """
                                                Pre FEC BER
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15fecHistories.OtuMinute15fecHistory.OtuMinute15fecTimeLineInstances.OtuMinute15fecTimeLineInstance.PreFecBer, self).__init__()

                                                    self.yang_name = "pre-fec-ber"
                                                    self.yang_parent_name = "otu-minute15fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.maximum_tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "pre-fec-ber"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15fecHistories.OtuMinute15fecHistory.OtuMinute15fecTimeLineInstances.OtuMinute15fecTimeLineInstance.PreFecBer, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                            class PostFecBer(Entity):
                                                """
                                                Post FEC BER
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15fecHistories.OtuMinute15fecHistory.OtuMinute15fecTimeLineInstances.OtuMinute15fecTimeLineInstance.PostFecBer, self).__init__()

                                                    self.yang_name = "post-fec-ber"
                                                    self.yang_parent_name = "otu-minute15fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.maximum_tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "post-fec-ber"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15fecHistories.OtuMinute15fecHistory.OtuMinute15fecTimeLineInstances.OtuMinute15fecTimeLineInstance.PostFecBer, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                            class Q(Entity):
                                                """
                                                Q
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15fecHistories.OtuMinute15fecHistory.OtuMinute15fecTimeLineInstances.OtuMinute15fecTimeLineInstance.Q, self).__init__()

                                                    self.yang_name = "q"
                                                    self.yang_parent_name = "otu-minute15fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.maximum_tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "q"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15fecHistories.OtuMinute15fecHistory.OtuMinute15fecTimeLineInstances.OtuMinute15fecTimeLineInstance.Q, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                            class Qmargin(Entity):
                                                """
                                                Q Margin
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15fecHistories.OtuMinute15fecHistory.OtuMinute15fecTimeLineInstances.OtuMinute15fecTimeLineInstance.Qmargin, self).__init__()

                                                    self.yang_name = "qmargin"
                                                    self.yang_parent_name = "otu-minute15fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.maximum_tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "qmargin"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15fecHistories.OtuMinute15fecHistory.OtuMinute15fecTimeLineInstances.OtuMinute15fecTimeLineInstance.Qmargin, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                            class OtuMinute15prbsHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: otu_minute15prbs_history
                                
                                	port 15\-minute prbs performance data
                                	**type**\: list of  		 :py:class:`OtuMinute15prbsHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15prbsHistories.OtuMinute15prbsHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15prbsHistories, self).__init__()

                                    self.yang_name = "otu-minute15prbs-histories"
                                    self.yang_parent_name = "otu-minute15-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("otu-minute15prbs-history", ("otu_minute15prbs_history", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15prbsHistories.OtuMinute15prbsHistory))])
                                    self._leafs = OrderedDict()

                                    self.otu_minute15prbs_history = YList(self)
                                    self._segment_path = lambda: "otu-minute15prbs-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15prbsHistories, [], name, value)


                                class OtuMinute15prbsHistory(Entity):
                                    """
                                    port 15\-minute prbs performance data
                                    
                                    .. attribute:: number  (key)
                                    
                                    	channel number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: otu_minute15prbs_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`OtuMinute15prbsTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15prbsHistories.OtuMinute15prbsHistory.OtuMinute15prbsTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15prbsHistories.OtuMinute15prbsHistory, self).__init__()

                                        self.yang_name = "otu-minute15prbs-history"
                                        self.yang_parent_name = "otu-minute15prbs-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([("otu-minute15prbs-time-line-instances", ("otu_minute15prbs_time_line_instances", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15prbsHistories.OtuMinute15prbsHistory.OtuMinute15prbsTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ])
                                        self.number = None

                                        self.otu_minute15prbs_time_line_instances = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15prbsHistories.OtuMinute15prbsHistory.OtuMinute15prbsTimeLineInstances()
                                        self.otu_minute15prbs_time_line_instances.parent = self
                                        self._children_name_map["otu_minute15prbs_time_line_instances"] = "otu-minute15prbs-time-line-instances"
                                        self._segment_path = lambda: "otu-minute15prbs-history" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15prbsHistories.OtuMinute15prbsHistory, ['number'], name, value)


                                    class OtuMinute15prbsTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: otu_minute15prbs_time_line_instance
                                        
                                        	port 15\-minute prbs performance data
                                        	**type**\: list of  		 :py:class:`OtuMinute15prbsTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15prbsHistories.OtuMinute15prbsHistory.OtuMinute15prbsTimeLineInstances.OtuMinute15prbsTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15prbsHistories.OtuMinute15prbsHistory.OtuMinute15prbsTimeLineInstances, self).__init__()

                                            self.yang_name = "otu-minute15prbs-time-line-instances"
                                            self.yang_parent_name = "otu-minute15prbs-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("otu-minute15prbs-time-line-instance", ("otu_minute15prbs_time_line_instance", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15prbsHistories.OtuMinute15prbsHistory.OtuMinute15prbsTimeLineInstances.OtuMinute15prbsTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.otu_minute15prbs_time_line_instance = YList(self)
                                            self._segment_path = lambda: "otu-minute15prbs-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15prbsHistories.OtuMinute15prbsHistory.OtuMinute15prbsTimeLineInstances, [], name, value)


                                        class OtuMinute15prbsTimeLineInstance(Entity):
                                            """
                                            port 15\-minute prbs performance data
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcv_patt
                                            
                                            	RCVD PTRN
                                            	**type**\:  :py:class:`RcvPatt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15prbsHistories.OtuMinute15prbsHistory.OtuMinute15prbsTimeLineInstances.OtuMinute15prbsTimeLineInstance.RcvPatt>`
                                            
                                            .. attribute:: prbs_status
                                            
                                            	PRBS STATUS
                                            	**type**\:  :py:class:`PrbsStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15prbsHistories.OtuMinute15prbsHistory.OtuMinute15prbsTimeLineInstances.OtuMinute15prbsTimeLineInstance.PrbsStatus>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: ebc
                                            
                                            	EBC
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: found_count
                                            
                                            	FOUND COUNT
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lost_count
                                            
                                            	LOST COUNT
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: found_at_time
                                            
                                            	FOUND AT TS
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: lost_at_time
                                            
                                            	LOST AT TS
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: conf_patt
                                            
                                            	CONFIG PTRN
                                            	**type**\:  :py:class:`PmPrbsPatternEt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmPrbsPatternEt>`
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15prbsHistories.OtuMinute15prbsHistory.OtuMinute15prbsTimeLineInstances.OtuMinute15prbsTimeLineInstance, self).__init__()

                                                self.yang_name = "otu-minute15prbs-time-line-instance"
                                                self.yang_parent_name = "otu-minute15prbs-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("rcv-patt", ("rcv_patt", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15prbsHistories.OtuMinute15prbsHistory.OtuMinute15prbsTimeLineInstances.OtuMinute15prbsTimeLineInstance.RcvPatt)), ("prbs-status", ("prbs_status", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15prbsHistories.OtuMinute15prbsHistory.OtuMinute15prbsTimeLineInstances.OtuMinute15prbsTimeLineInstance.PrbsStatus))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                    ('ebc', (YLeaf(YType.uint64, 'ebc'), ['int'])),
                                                    ('found_count', (YLeaf(YType.uint32, 'found-count'), ['int'])),
                                                    ('lost_count', (YLeaf(YType.uint32, 'lost-count'), ['int'])),
                                                    ('found_at_time', (YLeaf(YType.uint64, 'found-at-time'), ['int'])),
                                                    ('lost_at_time', (YLeaf(YType.uint64, 'lost-at-time'), ['int'])),
                                                    ('conf_patt', (YLeaf(YType.enumeration, 'conf-patt'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper', 'PmPrbsPatternEt', '')])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None
                                                self.ebc = None
                                                self.found_count = None
                                                self.lost_count = None
                                                self.found_at_time = None
                                                self.lost_at_time = None
                                                self.conf_patt = None

                                                self.rcv_patt = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15prbsHistories.OtuMinute15prbsHistory.OtuMinute15prbsTimeLineInstances.OtuMinute15prbsTimeLineInstance.RcvPatt()
                                                self.rcv_patt.parent = self
                                                self._children_name_map["rcv_patt"] = "rcv-patt"

                                                self.prbs_status = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15prbsHistories.OtuMinute15prbsHistory.OtuMinute15prbsTimeLineInstances.OtuMinute15prbsTimeLineInstance.PrbsStatus()
                                                self.prbs_status.parent = self
                                                self._children_name_map["prbs_status"] = "prbs-status"
                                                self._segment_path = lambda: "otu-minute15prbs-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15prbsHistories.OtuMinute15prbsHistory.OtuMinute15prbsTimeLineInstances.OtuMinute15prbsTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear24_hr_time', 'ebc', 'found_count', 'lost_count', 'found_at_time', 'lost_at_time', 'conf_patt'], name, value)


                                            class RcvPatt(Entity):
                                                """
                                                RCVD PTRN
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: rcv_patt
                                                
                                                	RCVD PTRN
                                                	**type**\:  :py:class:`PmPrbsPatternEt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmPrbsPatternEt>`
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15prbsHistories.OtuMinute15prbsHistory.OtuMinute15prbsTimeLineInstances.OtuMinute15prbsTimeLineInstance.RcvPatt, self).__init__()

                                                    self.yang_name = "rcv-patt"
                                                    self.yang_parent_name = "otu-minute15prbs-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('rcv_patt', (YLeaf(YType.enumeration, 'rcv-patt'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper', 'PmPrbsPatternEt', '')])),
                                                    ])
                                                    self.valid = None
                                                    self.rcv_patt = None
                                                    self._segment_path = lambda: "rcv-patt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15prbsHistories.OtuMinute15prbsHistory.OtuMinute15prbsTimeLineInstances.OtuMinute15prbsTimeLineInstance.RcvPatt, ['valid', 'rcv_patt'], name, value)


                                            class PrbsStatus(Entity):
                                                """
                                                PRBS STATUS
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: prbs_status
                                                
                                                	Prbs Status
                                                	**type**\:  :py:class:`PmPrbsStatusEt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmPrbsStatusEt>`
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15prbsHistories.OtuMinute15prbsHistory.OtuMinute15prbsTimeLineInstances.OtuMinute15prbsTimeLineInstance.PrbsStatus, self).__init__()

                                                    self.yang_name = "prbs-status"
                                                    self.yang_parent_name = "otu-minute15prbs-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('prbs_status', (YLeaf(YType.enumeration, 'prbs-status'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper', 'PmPrbsStatusEt', '')])),
                                                    ])
                                                    self.valid = None
                                                    self.prbs_status = None
                                                    self._segment_path = lambda: "prbs-status"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15prbsHistories.OtuMinute15prbsHistory.OtuMinute15prbsTimeLineInstances.OtuMinute15prbsTimeLineInstance.PrbsStatus, ['valid', 'prbs_status'], name, value)


                            class OtuMinute15otnHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: otu_minute15otn_history
                                
                                	port 15\-minute otn performance data
                                	**type**\: list of  		 :py:class:`OtuMinute15otnHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories, self).__init__()

                                    self.yang_name = "otu-minute15otn-histories"
                                    self.yang_parent_name = "otu-minute15-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("otu-minute15otn-history", ("otu_minute15otn_history", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory))])
                                    self._leafs = OrderedDict()

                                    self.otu_minute15otn_history = YList(self)
                                    self._segment_path = lambda: "otu-minute15otn-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories, [], name, value)


                                class OtuMinute15otnHistory(Entity):
                                    """
                                    port 15\-minute otn performance data
                                    
                                    .. attribute:: number  (key)
                                    
                                    	channel number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: otu_minute15otn_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`OtuMinute15otnTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory, self).__init__()

                                        self.yang_name = "otu-minute15otn-history"
                                        self.yang_parent_name = "otu-minute15otn-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([("otu-minute15otn-time-line-instances", ("otu_minute15otn_time_line_instances", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ])
                                        self.number = None

                                        self.otu_minute15otn_time_line_instances = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances()
                                        self.otu_minute15otn_time_line_instances.parent = self
                                        self._children_name_map["otu_minute15otn_time_line_instances"] = "otu-minute15otn-time-line-instances"
                                        self._segment_path = lambda: "otu-minute15otn-history" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory, ['number'], name, value)


                                    class OtuMinute15otnTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: otu_minute15otn_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of  		 :py:class:`OtuMinute15otnTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances, self).__init__()

                                            self.yang_name = "otu-minute15otn-time-line-instances"
                                            self.yang_parent_name = "otu-minute15otn-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("otu-minute15otn-time-line-instance", ("otu_minute15otn_time_line_instance", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.otu_minute15otn_time_line_instance = YList(self)
                                            self._segment_path = lambda: "otu-minute15otn-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances, [], name, value)


                                        class OtuMinute15otnTimeLineInstance(Entity):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lbc
                                            
                                            	LBC
                                            	**type**\:  :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.Lbc>`
                                            
                                            .. attribute:: es_ne
                                            
                                            	ES SM NE
                                            	**type**\:  :py:class:`EsNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.EsNe>`
                                            
                                            .. attribute:: esr_ne
                                            
                                            	ESR PM NE
                                            	**type**\:  :py:class:`EsrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.EsrNe>`
                                            
                                            .. attribute:: ses_ne
                                            
                                            	SES SM NE
                                            	**type**\:  :py:class:`SesNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.SesNe>`
                                            
                                            .. attribute:: sesr_ne
                                            
                                            	SESR SM NE
                                            	**type**\:  :py:class:`SesrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.SesrNe>`
                                            
                                            .. attribute:: uas_ne
                                            
                                            	UAS SM NE
                                            	**type**\:  :py:class:`UasNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.UasNe>`
                                            
                                            .. attribute:: bbe_ne
                                            
                                            	BBE SM NE
                                            	**type**\:  :py:class:`BbeNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.BbeNe>`
                                            
                                            .. attribute:: bber_ne
                                            
                                            	BBER SM NE
                                            	**type**\:  :py:class:`BberNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.BberNe>`
                                            
                                            .. attribute:: fc_ne
                                            
                                            	FC SM NE
                                            	**type**\:  :py:class:`FcNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.FcNe>`
                                            
                                            .. attribute:: es_fe
                                            
                                            	ES SM FE
                                            	**type**\:  :py:class:`EsFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.EsFe>`
                                            
                                            .. attribute:: esr_fe
                                            
                                            	ESR PM FE
                                            	**type**\:  :py:class:`EsrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.EsrFe>`
                                            
                                            .. attribute:: ses_fe
                                            
                                            	SES SM FE
                                            	**type**\:  :py:class:`SesFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.SesFe>`
                                            
                                            .. attribute:: sesr_fe
                                            
                                            	SESR SM FE
                                            	**type**\:  :py:class:`SesrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.SesrFe>`
                                            
                                            .. attribute:: uas_fe
                                            
                                            	UAS SM FE
                                            	**type**\:  :py:class:`UasFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.UasFe>`
                                            
                                            .. attribute:: bbe_fe
                                            
                                            	BBE SM FE
                                            	**type**\:  :py:class:`BbeFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.BbeFe>`
                                            
                                            .. attribute:: bber_fe
                                            
                                            	BBER SM FE
                                            	**type**\:  :py:class:`BberFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.BberFe>`
                                            
                                            .. attribute:: fc_fe
                                            
                                            	FC SM FE
                                            	**type**\:  :py:class:`FcFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.FcFe>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance, self).__init__()

                                                self.yang_name = "otu-minute15otn-time-line-instance"
                                                self.yang_parent_name = "otu-minute15otn-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("lbc", ("lbc", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.Lbc)), ("es-ne", ("es_ne", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.EsNe)), ("esr-ne", ("esr_ne", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.EsrNe)), ("ses-ne", ("ses_ne", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.SesNe)), ("sesr-ne", ("sesr_ne", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.SesrNe)), ("uas-ne", ("uas_ne", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.UasNe)), ("bbe-ne", ("bbe_ne", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.BbeNe)), ("bber-ne", ("bber_ne", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.BberNe)), ("fc-ne", ("fc_ne", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.FcNe)), ("es-fe", ("es_fe", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.EsFe)), ("esr-fe", ("esr_fe", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.EsrFe)), ("ses-fe", ("ses_fe", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.SesFe)), ("sesr-fe", ("sesr_fe", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.SesrFe)), ("uas-fe", ("uas_fe", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.UasFe)), ("bbe-fe", ("bbe_fe", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.BbeFe)), ("bber-fe", ("bber_fe", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.BberFe)), ("fc-fe", ("fc_fe", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.FcFe))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                    ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear24_hr_time = None
                                                self.sec30_support = None

                                                self.lbc = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.Lbc()
                                                self.lbc.parent = self
                                                self._children_name_map["lbc"] = "lbc"

                                                self.es_ne = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.EsNe()
                                                self.es_ne.parent = self
                                                self._children_name_map["es_ne"] = "es-ne"

                                                self.esr_ne = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.EsrNe()
                                                self.esr_ne.parent = self
                                                self._children_name_map["esr_ne"] = "esr-ne"

                                                self.ses_ne = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.SesNe()
                                                self.ses_ne.parent = self
                                                self._children_name_map["ses_ne"] = "ses-ne"

                                                self.sesr_ne = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.SesrNe()
                                                self.sesr_ne.parent = self
                                                self._children_name_map["sesr_ne"] = "sesr-ne"

                                                self.uas_ne = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.UasNe()
                                                self.uas_ne.parent = self
                                                self._children_name_map["uas_ne"] = "uas-ne"

                                                self.bbe_ne = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.BbeNe()
                                                self.bbe_ne.parent = self
                                                self._children_name_map["bbe_ne"] = "bbe-ne"

                                                self.bber_ne = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.BberNe()
                                                self.bber_ne.parent = self
                                                self._children_name_map["bber_ne"] = "bber-ne"

                                                self.fc_ne = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.FcNe()
                                                self.fc_ne.parent = self
                                                self._children_name_map["fc_ne"] = "fc-ne"

                                                self.es_fe = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.EsFe()
                                                self.es_fe.parent = self
                                                self._children_name_map["es_fe"] = "es-fe"

                                                self.esr_fe = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.EsrFe()
                                                self.esr_fe.parent = self
                                                self._children_name_map["esr_fe"] = "esr-fe"

                                                self.ses_fe = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.SesFe()
                                                self.ses_fe.parent = self
                                                self._children_name_map["ses_fe"] = "ses-fe"

                                                self.sesr_fe = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.SesrFe()
                                                self.sesr_fe.parent = self
                                                self._children_name_map["sesr_fe"] = "sesr-fe"

                                                self.uas_fe = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.UasFe()
                                                self.uas_fe.parent = self
                                                self._children_name_map["uas_fe"] = "uas-fe"

                                                self.bbe_fe = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.BbeFe()
                                                self.bbe_fe.parent = self
                                                self._children_name_map["bbe_fe"] = "bbe-fe"

                                                self.bber_fe = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.BberFe()
                                                self.bber_fe.parent = self
                                                self._children_name_map["bber_fe"] = "bber-fe"

                                                self.fc_fe = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.FcFe()
                                                self.fc_fe.parent = self
                                                self._children_name_map["fc_fe"] = "fc-fe"
                                                self._segment_path = lambda: "otu-minute15otn-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                            class Lbc(Entity):
                                                """
                                                LBC
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.Lbc, self).__init__()

                                                    self.yang_name = "lbc"
                                                    self.yang_parent_name = "otu-minute15otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "lbc"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.Lbc, ['data', 'threshold', 'tca_report'], name, value)


                                            class EsNe(Entity):
                                                """
                                                ES SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.EsNe, self).__init__()

                                                    self.yang_name = "es-ne"
                                                    self.yang_parent_name = "otu-minute15otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "es-ne"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.EsNe, ['data', 'threshold', 'tca_report'], name, value)


                                            class EsrNe(Entity):
                                                """
                                                ESR PM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: str
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.EsrNe, self).__init__()

                                                    self.yang_name = "esr-ne"
                                                    self.yang_parent_name = "otu-minute15otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                        ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "esr-ne"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.EsrNe, ['data', 'threshold', 'tca_report'], name, value)


                                            class SesNe(Entity):
                                                """
                                                SES SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.SesNe, self).__init__()

                                                    self.yang_name = "ses-ne"
                                                    self.yang_parent_name = "otu-minute15otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "ses-ne"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.SesNe, ['data', 'threshold', 'tca_report'], name, value)


                                            class SesrNe(Entity):
                                                """
                                                SESR SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: str
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.SesrNe, self).__init__()

                                                    self.yang_name = "sesr-ne"
                                                    self.yang_parent_name = "otu-minute15otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                        ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "sesr-ne"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.SesrNe, ['data', 'threshold', 'tca_report'], name, value)


                                            class UasNe(Entity):
                                                """
                                                UAS SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.UasNe, self).__init__()

                                                    self.yang_name = "uas-ne"
                                                    self.yang_parent_name = "otu-minute15otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "uas-ne"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.UasNe, ['data', 'threshold', 'tca_report'], name, value)


                                            class BbeNe(Entity):
                                                """
                                                BBE SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.BbeNe, self).__init__()

                                                    self.yang_name = "bbe-ne"
                                                    self.yang_parent_name = "otu-minute15otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "bbe-ne"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.BbeNe, ['data', 'threshold', 'tca_report'], name, value)


                                            class BberNe(Entity):
                                                """
                                                BBER SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: str
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.BberNe, self).__init__()

                                                    self.yang_name = "bber-ne"
                                                    self.yang_parent_name = "otu-minute15otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                        ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "bber-ne"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.BberNe, ['data', 'threshold', 'tca_report'], name, value)


                                            class FcNe(Entity):
                                                """
                                                FC SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.FcNe, self).__init__()

                                                    self.yang_name = "fc-ne"
                                                    self.yang_parent_name = "otu-minute15otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "fc-ne"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.FcNe, ['data', 'threshold', 'tca_report'], name, value)


                                            class EsFe(Entity):
                                                """
                                                ES SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.EsFe, self).__init__()

                                                    self.yang_name = "es-fe"
                                                    self.yang_parent_name = "otu-minute15otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "es-fe"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.EsFe, ['data', 'threshold', 'tca_report'], name, value)


                                            class EsrFe(Entity):
                                                """
                                                ESR PM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: str
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.EsrFe, self).__init__()

                                                    self.yang_name = "esr-fe"
                                                    self.yang_parent_name = "otu-minute15otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                        ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "esr-fe"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.EsrFe, ['data', 'threshold', 'tca_report'], name, value)


                                            class SesFe(Entity):
                                                """
                                                SES SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.SesFe, self).__init__()

                                                    self.yang_name = "ses-fe"
                                                    self.yang_parent_name = "otu-minute15otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "ses-fe"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.SesFe, ['data', 'threshold', 'tca_report'], name, value)


                                            class SesrFe(Entity):
                                                """
                                                SESR SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: str
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.SesrFe, self).__init__()

                                                    self.yang_name = "sesr-fe"
                                                    self.yang_parent_name = "otu-minute15otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                        ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "sesr-fe"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.SesrFe, ['data', 'threshold', 'tca_report'], name, value)


                                            class UasFe(Entity):
                                                """
                                                UAS SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.UasFe, self).__init__()

                                                    self.yang_name = "uas-fe"
                                                    self.yang_parent_name = "otu-minute15otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "uas-fe"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.UasFe, ['data', 'threshold', 'tca_report'], name, value)


                                            class BbeFe(Entity):
                                                """
                                                BBE SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.BbeFe, self).__init__()

                                                    self.yang_name = "bbe-fe"
                                                    self.yang_parent_name = "otu-minute15otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "bbe-fe"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.BbeFe, ['data', 'threshold', 'tca_report'], name, value)


                                            class BberFe(Entity):
                                                """
                                                BBER SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: str
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.BberFe, self).__init__()

                                                    self.yang_name = "bber-fe"
                                                    self.yang_parent_name = "otu-minute15otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                        ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "bber-fe"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.BberFe, ['data', 'threshold', 'tca_report'], name, value)


                                            class FcFe(Entity):
                                                """
                                                FC SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.FcFe, self).__init__()

                                                    self.yang_name = "fc-fe"
                                                    self.yang_parent_name = "otu-minute15otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "fc-fe"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15otnHistories.OtuMinute15otnHistory.OtuMinute15otnTimeLineInstances.OtuMinute15otnTimeLineInstance.FcFe, ['data', 'threshold', 'tca_report'], name, value)


                        class OtuHour24History(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: otu_hour24prbs_histories
                            
                            	port 24 hour performance data
                            	**type**\:  :py:class:`OtuHour24prbsHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24prbsHistories>`
                            
                            .. attribute:: otu_hour24otn_histories
                            
                            	port 24 hour performance data
                            	**type**\:  :py:class:`OtuHour24otnHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories>`
                            
                            .. attribute:: otu_hour24fec_histories
                            
                            	port current performance data
                            	**type**\:  :py:class:`OtuHour24fecHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24fecHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History, self).__init__()

                                self.yang_name = "otu-hour24-history"
                                self.yang_parent_name = "otu-port-history"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("otu-hour24prbs-histories", ("otu_hour24prbs_histories", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24prbsHistories)), ("otu-hour24otn-histories", ("otu_hour24otn_histories", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories)), ("otu-hour24fec-histories", ("otu_hour24fec_histories", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24fecHistories))])
                                self._leafs = OrderedDict()

                                self.otu_hour24prbs_histories = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24prbsHistories()
                                self.otu_hour24prbs_histories.parent = self
                                self._children_name_map["otu_hour24prbs_histories"] = "otu-hour24prbs-histories"

                                self.otu_hour24otn_histories = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories()
                                self.otu_hour24otn_histories.parent = self
                                self._children_name_map["otu_hour24otn_histories"] = "otu-hour24otn-histories"

                                self.otu_hour24fec_histories = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24fecHistories()
                                self.otu_hour24fec_histories.parent = self
                                self._children_name_map["otu_hour24fec_histories"] = "otu-hour24fec-histories"
                                self._segment_path = lambda: "otu-hour24-history"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History, [], name, value)


                            class OtuHour24prbsHistories(Entity):
                                """
                                port 24 hour performance data
                                
                                .. attribute:: otu_hour24prbs_history
                                
                                	port 24 hour prbs performance data
                                	**type**\: list of  		 :py:class:`OtuHour24prbsHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24prbsHistories.OtuHour24prbsHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24prbsHistories, self).__init__()

                                    self.yang_name = "otu-hour24prbs-histories"
                                    self.yang_parent_name = "otu-hour24-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("otu-hour24prbs-history", ("otu_hour24prbs_history", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24prbsHistories.OtuHour24prbsHistory))])
                                    self._leafs = OrderedDict()

                                    self.otu_hour24prbs_history = YList(self)
                                    self._segment_path = lambda: "otu-hour24prbs-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24prbsHistories, [], name, value)


                                class OtuHour24prbsHistory(Entity):
                                    """
                                    port 24 hour prbs performance data
                                    
                                    .. attribute:: number  (key)
                                    
                                    	channel number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: otu_hour24prbs_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`OtuHour24prbsTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24prbsHistories.OtuHour24prbsHistory.OtuHour24prbsTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24prbsHistories.OtuHour24prbsHistory, self).__init__()

                                        self.yang_name = "otu-hour24prbs-history"
                                        self.yang_parent_name = "otu-hour24prbs-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([("otu-hour24prbs-time-line-instances", ("otu_hour24prbs_time_line_instances", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24prbsHistories.OtuHour24prbsHistory.OtuHour24prbsTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ])
                                        self.number = None

                                        self.otu_hour24prbs_time_line_instances = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24prbsHistories.OtuHour24prbsHistory.OtuHour24prbsTimeLineInstances()
                                        self.otu_hour24prbs_time_line_instances.parent = self
                                        self._children_name_map["otu_hour24prbs_time_line_instances"] = "otu-hour24prbs-time-line-instances"
                                        self._segment_path = lambda: "otu-hour24prbs-history" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24prbsHistories.OtuHour24prbsHistory, ['number'], name, value)


                                    class OtuHour24prbsTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: otu_hour24prbs_time_line_instance
                                        
                                        	port 15\-minute prbs performance data
                                        	**type**\: list of  		 :py:class:`OtuHour24prbsTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24prbsHistories.OtuHour24prbsHistory.OtuHour24prbsTimeLineInstances.OtuHour24prbsTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24prbsHistories.OtuHour24prbsHistory.OtuHour24prbsTimeLineInstances, self).__init__()

                                            self.yang_name = "otu-hour24prbs-time-line-instances"
                                            self.yang_parent_name = "otu-hour24prbs-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("otu-hour24prbs-time-line-instance", ("otu_hour24prbs_time_line_instance", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24prbsHistories.OtuHour24prbsHistory.OtuHour24prbsTimeLineInstances.OtuHour24prbsTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.otu_hour24prbs_time_line_instance = YList(self)
                                            self._segment_path = lambda: "otu-hour24prbs-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24prbsHistories.OtuHour24prbsHistory.OtuHour24prbsTimeLineInstances, [], name, value)


                                        class OtuHour24prbsTimeLineInstance(Entity):
                                            """
                                            port 15\-minute prbs performance data
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcv_patt
                                            
                                            	RCVD PTRN
                                            	**type**\:  :py:class:`RcvPatt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24prbsHistories.OtuHour24prbsHistory.OtuHour24prbsTimeLineInstances.OtuHour24prbsTimeLineInstance.RcvPatt>`
                                            
                                            .. attribute:: prbs_status
                                            
                                            	PRBS STATUS
                                            	**type**\:  :py:class:`PrbsStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24prbsHistories.OtuHour24prbsHistory.OtuHour24prbsTimeLineInstances.OtuHour24prbsTimeLineInstance.PrbsStatus>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: ebc
                                            
                                            	EBC
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: found_count
                                            
                                            	FOUND COUNT
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lost_count
                                            
                                            	LOST COUNT
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: found_at_time
                                            
                                            	FOUND AT TS
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: lost_at_time
                                            
                                            	LOST AT TS
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: conf_patt
                                            
                                            	CONFIG PTRN
                                            	**type**\:  :py:class:`PmPrbsPatternEt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmPrbsPatternEt>`
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24prbsHistories.OtuHour24prbsHistory.OtuHour24prbsTimeLineInstances.OtuHour24prbsTimeLineInstance, self).__init__()

                                                self.yang_name = "otu-hour24prbs-time-line-instance"
                                                self.yang_parent_name = "otu-hour24prbs-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("rcv-patt", ("rcv_patt", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24prbsHistories.OtuHour24prbsHistory.OtuHour24prbsTimeLineInstances.OtuHour24prbsTimeLineInstance.RcvPatt)), ("prbs-status", ("prbs_status", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24prbsHistories.OtuHour24prbsHistory.OtuHour24prbsTimeLineInstances.OtuHour24prbsTimeLineInstance.PrbsStatus))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                    ('ebc', (YLeaf(YType.uint64, 'ebc'), ['int'])),
                                                    ('found_count', (YLeaf(YType.uint32, 'found-count'), ['int'])),
                                                    ('lost_count', (YLeaf(YType.uint32, 'lost-count'), ['int'])),
                                                    ('found_at_time', (YLeaf(YType.uint64, 'found-at-time'), ['int'])),
                                                    ('lost_at_time', (YLeaf(YType.uint64, 'lost-at-time'), ['int'])),
                                                    ('conf_patt', (YLeaf(YType.enumeration, 'conf-patt'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper', 'PmPrbsPatternEt', '')])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None
                                                self.ebc = None
                                                self.found_count = None
                                                self.lost_count = None
                                                self.found_at_time = None
                                                self.lost_at_time = None
                                                self.conf_patt = None

                                                self.rcv_patt = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24prbsHistories.OtuHour24prbsHistory.OtuHour24prbsTimeLineInstances.OtuHour24prbsTimeLineInstance.RcvPatt()
                                                self.rcv_patt.parent = self
                                                self._children_name_map["rcv_patt"] = "rcv-patt"

                                                self.prbs_status = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24prbsHistories.OtuHour24prbsHistory.OtuHour24prbsTimeLineInstances.OtuHour24prbsTimeLineInstance.PrbsStatus()
                                                self.prbs_status.parent = self
                                                self._children_name_map["prbs_status"] = "prbs-status"
                                                self._segment_path = lambda: "otu-hour24prbs-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24prbsHistories.OtuHour24prbsHistory.OtuHour24prbsTimeLineInstances.OtuHour24prbsTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear24_hr_time', 'ebc', 'found_count', 'lost_count', 'found_at_time', 'lost_at_time', 'conf_patt'], name, value)


                                            class RcvPatt(Entity):
                                                """
                                                RCVD PTRN
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: rcv_patt
                                                
                                                	RCVD PTRN
                                                	**type**\:  :py:class:`PmPrbsPatternEt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmPrbsPatternEt>`
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24prbsHistories.OtuHour24prbsHistory.OtuHour24prbsTimeLineInstances.OtuHour24prbsTimeLineInstance.RcvPatt, self).__init__()

                                                    self.yang_name = "rcv-patt"
                                                    self.yang_parent_name = "otu-hour24prbs-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('rcv_patt', (YLeaf(YType.enumeration, 'rcv-patt'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper', 'PmPrbsPatternEt', '')])),
                                                    ])
                                                    self.valid = None
                                                    self.rcv_patt = None
                                                    self._segment_path = lambda: "rcv-patt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24prbsHistories.OtuHour24prbsHistory.OtuHour24prbsTimeLineInstances.OtuHour24prbsTimeLineInstance.RcvPatt, ['valid', 'rcv_patt'], name, value)


                                            class PrbsStatus(Entity):
                                                """
                                                PRBS STATUS
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: prbs_status
                                                
                                                	Prbs Status
                                                	**type**\:  :py:class:`PmPrbsStatusEt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmPrbsStatusEt>`
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24prbsHistories.OtuHour24prbsHistory.OtuHour24prbsTimeLineInstances.OtuHour24prbsTimeLineInstance.PrbsStatus, self).__init__()

                                                    self.yang_name = "prbs-status"
                                                    self.yang_parent_name = "otu-hour24prbs-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('prbs_status', (YLeaf(YType.enumeration, 'prbs-status'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper', 'PmPrbsStatusEt', '')])),
                                                    ])
                                                    self.valid = None
                                                    self.prbs_status = None
                                                    self._segment_path = lambda: "prbs-status"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24prbsHistories.OtuHour24prbsHistory.OtuHour24prbsTimeLineInstances.OtuHour24prbsTimeLineInstance.PrbsStatus, ['valid', 'prbs_status'], name, value)


                            class OtuHour24otnHistories(Entity):
                                """
                                port 24 hour performance data
                                
                                .. attribute:: otu_hour24otn_history
                                
                                	port 24 hour otn performance data
                                	**type**\: list of  		 :py:class:`OtuHour24otnHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories, self).__init__()

                                    self.yang_name = "otu-hour24otn-histories"
                                    self.yang_parent_name = "otu-hour24-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("otu-hour24otn-history", ("otu_hour24otn_history", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory))])
                                    self._leafs = OrderedDict()

                                    self.otu_hour24otn_history = YList(self)
                                    self._segment_path = lambda: "otu-hour24otn-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories, [], name, value)


                                class OtuHour24otnHistory(Entity):
                                    """
                                    port 24 hour otn performance data
                                    
                                    .. attribute:: number  (key)
                                    
                                    	channel number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: otu_hour24otn_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`OtuHour24otnTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory, self).__init__()

                                        self.yang_name = "otu-hour24otn-history"
                                        self.yang_parent_name = "otu-hour24otn-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([("otu-hour24otn-time-line-instances", ("otu_hour24otn_time_line_instances", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ])
                                        self.number = None

                                        self.otu_hour24otn_time_line_instances = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances()
                                        self.otu_hour24otn_time_line_instances.parent = self
                                        self._children_name_map["otu_hour24otn_time_line_instances"] = "otu-hour24otn-time-line-instances"
                                        self._segment_path = lambda: "otu-hour24otn-history" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory, ['number'], name, value)


                                    class OtuHour24otnTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: otu_hour24otn_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of  		 :py:class:`OtuHour24otnTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances, self).__init__()

                                            self.yang_name = "otu-hour24otn-time-line-instances"
                                            self.yang_parent_name = "otu-hour24otn-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("otu-hour24otn-time-line-instance", ("otu_hour24otn_time_line_instance", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.otu_hour24otn_time_line_instance = YList(self)
                                            self._segment_path = lambda: "otu-hour24otn-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances, [], name, value)


                                        class OtuHour24otnTimeLineInstance(Entity):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lbc
                                            
                                            	LBC
                                            	**type**\:  :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.Lbc>`
                                            
                                            .. attribute:: es_ne
                                            
                                            	ES SM NE
                                            	**type**\:  :py:class:`EsNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.EsNe>`
                                            
                                            .. attribute:: esr_ne
                                            
                                            	ESR PM NE
                                            	**type**\:  :py:class:`EsrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.EsrNe>`
                                            
                                            .. attribute:: ses_ne
                                            
                                            	SES SM NE
                                            	**type**\:  :py:class:`SesNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.SesNe>`
                                            
                                            .. attribute:: sesr_ne
                                            
                                            	SESR SM NE
                                            	**type**\:  :py:class:`SesrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.SesrNe>`
                                            
                                            .. attribute:: uas_ne
                                            
                                            	UAS SM NE
                                            	**type**\:  :py:class:`UasNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.UasNe>`
                                            
                                            .. attribute:: bbe_ne
                                            
                                            	BBE SM NE
                                            	**type**\:  :py:class:`BbeNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.BbeNe>`
                                            
                                            .. attribute:: bber_ne
                                            
                                            	BBER SM NE
                                            	**type**\:  :py:class:`BberNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.BberNe>`
                                            
                                            .. attribute:: fc_ne
                                            
                                            	FC SM NE
                                            	**type**\:  :py:class:`FcNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.FcNe>`
                                            
                                            .. attribute:: es_fe
                                            
                                            	ES SM FE
                                            	**type**\:  :py:class:`EsFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.EsFe>`
                                            
                                            .. attribute:: esr_fe
                                            
                                            	ESR PM FE
                                            	**type**\:  :py:class:`EsrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.EsrFe>`
                                            
                                            .. attribute:: ses_fe
                                            
                                            	SES SM FE
                                            	**type**\:  :py:class:`SesFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.SesFe>`
                                            
                                            .. attribute:: sesr_fe
                                            
                                            	SESR SM FE
                                            	**type**\:  :py:class:`SesrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.SesrFe>`
                                            
                                            .. attribute:: uas_fe
                                            
                                            	UAS SM FE
                                            	**type**\:  :py:class:`UasFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.UasFe>`
                                            
                                            .. attribute:: bbe_fe
                                            
                                            	BBE SM FE
                                            	**type**\:  :py:class:`BbeFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.BbeFe>`
                                            
                                            .. attribute:: bber_fe
                                            
                                            	BBER SM FE
                                            	**type**\:  :py:class:`BberFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.BberFe>`
                                            
                                            .. attribute:: fc_fe
                                            
                                            	FC SM FE
                                            	**type**\:  :py:class:`FcFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.FcFe>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance, self).__init__()

                                                self.yang_name = "otu-hour24otn-time-line-instance"
                                                self.yang_parent_name = "otu-hour24otn-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("lbc", ("lbc", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.Lbc)), ("es-ne", ("es_ne", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.EsNe)), ("esr-ne", ("esr_ne", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.EsrNe)), ("ses-ne", ("ses_ne", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.SesNe)), ("sesr-ne", ("sesr_ne", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.SesrNe)), ("uas-ne", ("uas_ne", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.UasNe)), ("bbe-ne", ("bbe_ne", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.BbeNe)), ("bber-ne", ("bber_ne", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.BberNe)), ("fc-ne", ("fc_ne", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.FcNe)), ("es-fe", ("es_fe", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.EsFe)), ("esr-fe", ("esr_fe", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.EsrFe)), ("ses-fe", ("ses_fe", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.SesFe)), ("sesr-fe", ("sesr_fe", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.SesrFe)), ("uas-fe", ("uas_fe", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.UasFe)), ("bbe-fe", ("bbe_fe", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.BbeFe)), ("bber-fe", ("bber_fe", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.BberFe)), ("fc-fe", ("fc_fe", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.FcFe))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                    ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear24_hr_time = None
                                                self.sec30_support = None

                                                self.lbc = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.Lbc()
                                                self.lbc.parent = self
                                                self._children_name_map["lbc"] = "lbc"

                                                self.es_ne = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.EsNe()
                                                self.es_ne.parent = self
                                                self._children_name_map["es_ne"] = "es-ne"

                                                self.esr_ne = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.EsrNe()
                                                self.esr_ne.parent = self
                                                self._children_name_map["esr_ne"] = "esr-ne"

                                                self.ses_ne = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.SesNe()
                                                self.ses_ne.parent = self
                                                self._children_name_map["ses_ne"] = "ses-ne"

                                                self.sesr_ne = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.SesrNe()
                                                self.sesr_ne.parent = self
                                                self._children_name_map["sesr_ne"] = "sesr-ne"

                                                self.uas_ne = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.UasNe()
                                                self.uas_ne.parent = self
                                                self._children_name_map["uas_ne"] = "uas-ne"

                                                self.bbe_ne = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.BbeNe()
                                                self.bbe_ne.parent = self
                                                self._children_name_map["bbe_ne"] = "bbe-ne"

                                                self.bber_ne = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.BberNe()
                                                self.bber_ne.parent = self
                                                self._children_name_map["bber_ne"] = "bber-ne"

                                                self.fc_ne = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.FcNe()
                                                self.fc_ne.parent = self
                                                self._children_name_map["fc_ne"] = "fc-ne"

                                                self.es_fe = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.EsFe()
                                                self.es_fe.parent = self
                                                self._children_name_map["es_fe"] = "es-fe"

                                                self.esr_fe = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.EsrFe()
                                                self.esr_fe.parent = self
                                                self._children_name_map["esr_fe"] = "esr-fe"

                                                self.ses_fe = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.SesFe()
                                                self.ses_fe.parent = self
                                                self._children_name_map["ses_fe"] = "ses-fe"

                                                self.sesr_fe = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.SesrFe()
                                                self.sesr_fe.parent = self
                                                self._children_name_map["sesr_fe"] = "sesr-fe"

                                                self.uas_fe = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.UasFe()
                                                self.uas_fe.parent = self
                                                self._children_name_map["uas_fe"] = "uas-fe"

                                                self.bbe_fe = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.BbeFe()
                                                self.bbe_fe.parent = self
                                                self._children_name_map["bbe_fe"] = "bbe-fe"

                                                self.bber_fe = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.BberFe()
                                                self.bber_fe.parent = self
                                                self._children_name_map["bber_fe"] = "bber-fe"

                                                self.fc_fe = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.FcFe()
                                                self.fc_fe.parent = self
                                                self._children_name_map["fc_fe"] = "fc-fe"
                                                self._segment_path = lambda: "otu-hour24otn-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                            class Lbc(Entity):
                                                """
                                                LBC
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.Lbc, self).__init__()

                                                    self.yang_name = "lbc"
                                                    self.yang_parent_name = "otu-hour24otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "lbc"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.Lbc, ['data', 'threshold', 'tca_report'], name, value)


                                            class EsNe(Entity):
                                                """
                                                ES SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.EsNe, self).__init__()

                                                    self.yang_name = "es-ne"
                                                    self.yang_parent_name = "otu-hour24otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "es-ne"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.EsNe, ['data', 'threshold', 'tca_report'], name, value)


                                            class EsrNe(Entity):
                                                """
                                                ESR PM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: str
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.EsrNe, self).__init__()

                                                    self.yang_name = "esr-ne"
                                                    self.yang_parent_name = "otu-hour24otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                        ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "esr-ne"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.EsrNe, ['data', 'threshold', 'tca_report'], name, value)


                                            class SesNe(Entity):
                                                """
                                                SES SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.SesNe, self).__init__()

                                                    self.yang_name = "ses-ne"
                                                    self.yang_parent_name = "otu-hour24otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "ses-ne"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.SesNe, ['data', 'threshold', 'tca_report'], name, value)


                                            class SesrNe(Entity):
                                                """
                                                SESR SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: str
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.SesrNe, self).__init__()

                                                    self.yang_name = "sesr-ne"
                                                    self.yang_parent_name = "otu-hour24otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                        ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "sesr-ne"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.SesrNe, ['data', 'threshold', 'tca_report'], name, value)


                                            class UasNe(Entity):
                                                """
                                                UAS SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.UasNe, self).__init__()

                                                    self.yang_name = "uas-ne"
                                                    self.yang_parent_name = "otu-hour24otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "uas-ne"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.UasNe, ['data', 'threshold', 'tca_report'], name, value)


                                            class BbeNe(Entity):
                                                """
                                                BBE SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.BbeNe, self).__init__()

                                                    self.yang_name = "bbe-ne"
                                                    self.yang_parent_name = "otu-hour24otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "bbe-ne"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.BbeNe, ['data', 'threshold', 'tca_report'], name, value)


                                            class BberNe(Entity):
                                                """
                                                BBER SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: str
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.BberNe, self).__init__()

                                                    self.yang_name = "bber-ne"
                                                    self.yang_parent_name = "otu-hour24otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                        ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "bber-ne"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.BberNe, ['data', 'threshold', 'tca_report'], name, value)


                                            class FcNe(Entity):
                                                """
                                                FC SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.FcNe, self).__init__()

                                                    self.yang_name = "fc-ne"
                                                    self.yang_parent_name = "otu-hour24otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "fc-ne"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.FcNe, ['data', 'threshold', 'tca_report'], name, value)


                                            class EsFe(Entity):
                                                """
                                                ES SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.EsFe, self).__init__()

                                                    self.yang_name = "es-fe"
                                                    self.yang_parent_name = "otu-hour24otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "es-fe"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.EsFe, ['data', 'threshold', 'tca_report'], name, value)


                                            class EsrFe(Entity):
                                                """
                                                ESR PM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: str
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.EsrFe, self).__init__()

                                                    self.yang_name = "esr-fe"
                                                    self.yang_parent_name = "otu-hour24otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                        ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "esr-fe"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.EsrFe, ['data', 'threshold', 'tca_report'], name, value)


                                            class SesFe(Entity):
                                                """
                                                SES SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.SesFe, self).__init__()

                                                    self.yang_name = "ses-fe"
                                                    self.yang_parent_name = "otu-hour24otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "ses-fe"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.SesFe, ['data', 'threshold', 'tca_report'], name, value)


                                            class SesrFe(Entity):
                                                """
                                                SESR SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: str
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.SesrFe, self).__init__()

                                                    self.yang_name = "sesr-fe"
                                                    self.yang_parent_name = "otu-hour24otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                        ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "sesr-fe"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.SesrFe, ['data', 'threshold', 'tca_report'], name, value)


                                            class UasFe(Entity):
                                                """
                                                UAS SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.UasFe, self).__init__()

                                                    self.yang_name = "uas-fe"
                                                    self.yang_parent_name = "otu-hour24otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "uas-fe"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.UasFe, ['data', 'threshold', 'tca_report'], name, value)


                                            class BbeFe(Entity):
                                                """
                                                BBE SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.BbeFe, self).__init__()

                                                    self.yang_name = "bbe-fe"
                                                    self.yang_parent_name = "otu-hour24otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "bbe-fe"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.BbeFe, ['data', 'threshold', 'tca_report'], name, value)


                                            class BberFe(Entity):
                                                """
                                                BBER SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: str
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.BberFe, self).__init__()

                                                    self.yang_name = "bber-fe"
                                                    self.yang_parent_name = "otu-hour24otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                        ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "bber-fe"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.BberFe, ['data', 'threshold', 'tca_report'], name, value)


                                            class FcFe(Entity):
                                                """
                                                FC SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.FcFe, self).__init__()

                                                    self.yang_name = "fc-fe"
                                                    self.yang_parent_name = "otu-hour24otn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self._segment_path = lambda: "fc-fe"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24otnHistories.OtuHour24otnHistory.OtuHour24otnTimeLineInstances.OtuHour24otnTimeLineInstance.FcFe, ['data', 'threshold', 'tca_report'], name, value)


                            class OtuHour24fecHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: otu_hour24fec_history
                                
                                	port 24 hour fec performance data
                                	**type**\: list of  		 :py:class:`OtuHour24fecHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24fecHistories.OtuHour24fecHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24fecHistories, self).__init__()

                                    self.yang_name = "otu-hour24fec-histories"
                                    self.yang_parent_name = "otu-hour24-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("otu-hour24fec-history", ("otu_hour24fec_history", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24fecHistories.OtuHour24fecHistory))])
                                    self._leafs = OrderedDict()

                                    self.otu_hour24fec_history = YList(self)
                                    self._segment_path = lambda: "otu-hour24fec-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24fecHistories, [], name, value)


                                class OtuHour24fecHistory(Entity):
                                    """
                                    port 24 hour fec performance data
                                    
                                    .. attribute:: number  (key)
                                    
                                    	channel number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: otu_hour24fec_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`OtuHour24fecTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24fecHistories.OtuHour24fecHistory.OtuHour24fecTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24fecHistories.OtuHour24fecHistory, self).__init__()

                                        self.yang_name = "otu-hour24fec-history"
                                        self.yang_parent_name = "otu-hour24fec-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([("otu-hour24fec-time-line-instances", ("otu_hour24fec_time_line_instances", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24fecHistories.OtuHour24fecHistory.OtuHour24fecTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ])
                                        self.number = None

                                        self.otu_hour24fec_time_line_instances = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24fecHistories.OtuHour24fecHistory.OtuHour24fecTimeLineInstances()
                                        self.otu_hour24fec_time_line_instances.parent = self
                                        self._children_name_map["otu_hour24fec_time_line_instances"] = "otu-hour24fec-time-line-instances"
                                        self._segment_path = lambda: "otu-hour24fec-history" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24fecHistories.OtuHour24fecHistory, ['number'], name, value)


                                    class OtuHour24fecTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: otu_hour24fec_time_line_instance
                                        
                                        	port 15\-minute fec performance data
                                        	**type**\: list of  		 :py:class:`OtuHour24fecTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24fecHistories.OtuHour24fecHistory.OtuHour24fecTimeLineInstances.OtuHour24fecTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24fecHistories.OtuHour24fecHistory.OtuHour24fecTimeLineInstances, self).__init__()

                                            self.yang_name = "otu-hour24fec-time-line-instances"
                                            self.yang_parent_name = "otu-hour24fec-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("otu-hour24fec-time-line-instance", ("otu_hour24fec_time_line_instance", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24fecHistories.OtuHour24fecHistory.OtuHour24fecTimeLineInstances.OtuHour24fecTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.otu_hour24fec_time_line_instance = YList(self)
                                            self._segment_path = lambda: "otu-hour24fec-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24fecHistories.OtuHour24fecHistory.OtuHour24fecTimeLineInstances, [], name, value)


                                        class OtuHour24fecTimeLineInstance(Entity):
                                            """
                                            port 15\-minute fec performance data
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ec_bits
                                            
                                            	EC BITS
                                            	**type**\:  :py:class:`EcBits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24fecHistories.OtuHour24fecHistory.OtuHour24fecTimeLineInstances.OtuHour24fecTimeLineInstance.EcBits>`
                                            
                                            .. attribute:: uc_words
                                            
                                            	UC WORDS
                                            	**type**\:  :py:class:`UcWords <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24fecHistories.OtuHour24fecHistory.OtuHour24fecTimeLineInstances.OtuHour24fecTimeLineInstance.UcWords>`
                                            
                                            .. attribute:: pre_fec_ber
                                            
                                            	Pre FEC BER
                                            	**type**\:  :py:class:`PreFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24fecHistories.OtuHour24fecHistory.OtuHour24fecTimeLineInstances.OtuHour24fecTimeLineInstance.PreFecBer>`
                                            
                                            .. attribute:: post_fec_ber
                                            
                                            	Post FEC BER
                                            	**type**\:  :py:class:`PostFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24fecHistories.OtuHour24fecHistory.OtuHour24fecTimeLineInstances.OtuHour24fecTimeLineInstance.PostFecBer>`
                                            
                                            .. attribute:: q
                                            
                                            	Q
                                            	**type**\:  :py:class:`Q <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24fecHistories.OtuHour24fecHistory.OtuHour24fecTimeLineInstances.OtuHour24fecTimeLineInstance.Q>`
                                            
                                            .. attribute:: qmargin
                                            
                                            	Q Margin
                                            	**type**\:  :py:class:`Qmargin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24fecHistories.OtuHour24fecHistory.OtuHour24fecTimeLineInstances.OtuHour24fecTimeLineInstance.Qmargin>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24fecHistories.OtuHour24fecHistory.OtuHour24fecTimeLineInstances.OtuHour24fecTimeLineInstance, self).__init__()

                                                self.yang_name = "otu-hour24fec-time-line-instance"
                                                self.yang_parent_name = "otu-hour24fec-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("ec-bits", ("ec_bits", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24fecHistories.OtuHour24fecHistory.OtuHour24fecTimeLineInstances.OtuHour24fecTimeLineInstance.EcBits)), ("uc-words", ("uc_words", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24fecHistories.OtuHour24fecHistory.OtuHour24fecTimeLineInstances.OtuHour24fecTimeLineInstance.UcWords)), ("pre-fec-ber", ("pre_fec_ber", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24fecHistories.OtuHour24fecHistory.OtuHour24fecTimeLineInstances.OtuHour24fecTimeLineInstance.PreFecBer)), ("post-fec-ber", ("post_fec_ber", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24fecHistories.OtuHour24fecHistory.OtuHour24fecTimeLineInstances.OtuHour24fecTimeLineInstance.PostFecBer)), ("q", ("q", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24fecHistories.OtuHour24fecHistory.OtuHour24fecTimeLineInstances.OtuHour24fecTimeLineInstance.Q)), ("qmargin", ("qmargin", PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24fecHistories.OtuHour24fecHistory.OtuHour24fecTimeLineInstances.OtuHour24fecTimeLineInstance.Qmargin))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                    ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear24_hr_time = None
                                                self.sec30_support = None

                                                self.ec_bits = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24fecHistories.OtuHour24fecHistory.OtuHour24fecTimeLineInstances.OtuHour24fecTimeLineInstance.EcBits()
                                                self.ec_bits.parent = self
                                                self._children_name_map["ec_bits"] = "ec-bits"

                                                self.uc_words = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24fecHistories.OtuHour24fecHistory.OtuHour24fecTimeLineInstances.OtuHour24fecTimeLineInstance.UcWords()
                                                self.uc_words.parent = self
                                                self._children_name_map["uc_words"] = "uc-words"

                                                self.pre_fec_ber = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24fecHistories.OtuHour24fecHistory.OtuHour24fecTimeLineInstances.OtuHour24fecTimeLineInstance.PreFecBer()
                                                self.pre_fec_ber.parent = self
                                                self._children_name_map["pre_fec_ber"] = "pre-fec-ber"

                                                self.post_fec_ber = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24fecHistories.OtuHour24fecHistory.OtuHour24fecTimeLineInstances.OtuHour24fecTimeLineInstance.PostFecBer()
                                                self.post_fec_ber.parent = self
                                                self._children_name_map["post_fec_ber"] = "post-fec-ber"

                                                self.q = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24fecHistories.OtuHour24fecHistory.OtuHour24fecTimeLineInstances.OtuHour24fecTimeLineInstance.Q()
                                                self.q.parent = self
                                                self._children_name_map["q"] = "q"

                                                self.qmargin = PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24fecHistories.OtuHour24fecHistory.OtuHour24fecTimeLineInstances.OtuHour24fecTimeLineInstance.Qmargin()
                                                self.qmargin.parent = self
                                                self._children_name_map["qmargin"] = "qmargin"
                                                self._segment_path = lambda: "otu-hour24fec-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24fecHistories.OtuHour24fecHistory.OtuHour24fecTimeLineInstances.OtuHour24fecTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                            class EcBits(Entity):
                                                """
                                                EC BITS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24fecHistories.OtuHour24fecHistory.OtuHour24fecTimeLineInstances.OtuHour24fecTimeLineInstance.EcBits, self).__init__()

                                                    self.yang_name = "ec-bits"
                                                    self.yang_parent_name = "otu-hour24fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ec-bits"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24fecHistories.OtuHour24fecHistory.OtuHour24fecTimeLineInstances.OtuHour24fecTimeLineInstance.EcBits, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class UcWords(Entity):
                                                """
                                                UC WORDS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24fecHistories.OtuHour24fecHistory.OtuHour24fecTimeLineInstances.OtuHour24fecTimeLineInstance.UcWords, self).__init__()

                                                    self.yang_name = "uc-words"
                                                    self.yang_parent_name = "otu-hour24fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "uc-words"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24fecHistories.OtuHour24fecHistory.OtuHour24fecTimeLineInstances.OtuHour24fecTimeLineInstance.UcWords, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class PreFecBer(Entity):
                                                """
                                                Pre FEC BER
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24fecHistories.OtuHour24fecHistory.OtuHour24fecTimeLineInstances.OtuHour24fecTimeLineInstance.PreFecBer, self).__init__()

                                                    self.yang_name = "pre-fec-ber"
                                                    self.yang_parent_name = "otu-hour24fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.maximum_tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "pre-fec-ber"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24fecHistories.OtuHour24fecHistory.OtuHour24fecTimeLineInstances.OtuHour24fecTimeLineInstance.PreFecBer, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                            class PostFecBer(Entity):
                                                """
                                                Post FEC BER
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24fecHistories.OtuHour24fecHistory.OtuHour24fecTimeLineInstances.OtuHour24fecTimeLineInstance.PostFecBer, self).__init__()

                                                    self.yang_name = "post-fec-ber"
                                                    self.yang_parent_name = "otu-hour24fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.maximum_tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "post-fec-ber"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24fecHistories.OtuHour24fecHistory.OtuHour24fecTimeLineInstances.OtuHour24fecTimeLineInstance.PostFecBer, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                            class Q(Entity):
                                                """
                                                Q
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24fecHistories.OtuHour24fecHistory.OtuHour24fecTimeLineInstances.OtuHour24fecTimeLineInstance.Q, self).__init__()

                                                    self.yang_name = "q"
                                                    self.yang_parent_name = "otu-hour24fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.maximum_tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "q"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24fecHistories.OtuHour24fecHistory.OtuHour24fecTimeLineInstances.OtuHour24fecTimeLineInstance.Q, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                            class Qmargin(Entity):
                                                """
                                                Q Margin
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24fecHistories.OtuHour24fecHistory.OtuHour24fecTimeLineInstances.OtuHour24fecTimeLineInstance.Qmargin, self).__init__()

                                                    self.yang_name = "qmargin"
                                                    self.yang_parent_name = "otu-hour24fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.maximum_tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "qmargin"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24fecHistories.OtuHour24fecHistory.OtuHour24fecTimeLineInstances.OtuHour24fecTimeLineInstance.Qmargin, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


            class HoVcHistory(Entity):
                """
                HO\_VC controller History performance data
                
                .. attribute:: ho_vc_port_histories
                
                	Port performance data
                	**type**\:  :py:class:`HoVcPortHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(PerformanceManagementHistory.Global.Periodic.HoVcHistory, self).__init__()

                    self.yang_name = "ho-vc-history"
                    self.yang_parent_name = "periodic"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ho-vc-port-histories", ("ho_vc_port_histories", PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories))])
                    self._leafs = OrderedDict()

                    self.ho_vc_port_histories = PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories()
                    self.ho_vc_port_histories.parent = self
                    self._children_name_map["ho_vc_port_histories"] = "ho-vc-port-histories"
                    self._segment_path = lambda: "ho-vc-history"
                    self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.HoVcHistory, [], name, value)


                class HoVcPortHistories(Entity):
                    """
                    Port performance data
                    
                    .. attribute:: ho_vc_port_history
                    
                    	Port performance data
                    	**type**\: list of  		 :py:class:`HoVcPortHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories, self).__init__()

                        self.yang_name = "ho-vc-port-histories"
                        self.yang_parent_name = "ho-vc-history"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ho-vc-port-history", ("ho_vc_port_history", PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory))])
                        self._leafs = OrderedDict()

                        self.ho_vc_port_history = YList(self)
                        self._segment_path = lambda: "ho-vc-port-histories"
                        self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/ho-vc-history/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories, [], name, value)


                    class HoVcPortHistory(Entity):
                        """
                        Port performance data
                        
                        .. attribute:: name  (key)
                        
                        	Port name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: ho_vc_minute15_history
                        
                        	port current performance data
                        	**type**\:  :py:class:`HoVcMinute15History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History>`
                        
                        .. attribute:: ho_vc_hour24_history
                        
                        	port current performance data
                        	**type**\:  :py:class:`HoVcHour24History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory, self).__init__()

                            self.yang_name = "ho-vc-port-history"
                            self.yang_parent_name = "ho-vc-port-histories"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("ho-vc-minute15-history", ("ho_vc_minute15_history", PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History)), ("ho-vc-hour24-history", ("ho_vc_hour24_history", PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None

                            self.ho_vc_minute15_history = PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History()
                            self.ho_vc_minute15_history.parent = self
                            self._children_name_map["ho_vc_minute15_history"] = "ho-vc-minute15-history"

                            self.ho_vc_hour24_history = PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History()
                            self.ho_vc_hour24_history.parent = self
                            self._children_name_map["ho_vc_hour24_history"] = "ho-vc-hour24-history"
                            self._segment_path = lambda: "ho-vc-port-history" + "[name='" + str(self.name) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/ho-vc-history/ho-vc-port-histories/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory, ['name'], name, value)


                        class HoVcMinute15History(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: ho_vc_minute15_path_histories
                            
                            	port current performance data
                            	**type**\:  :py:class:`HoVcMinute15PathHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History, self).__init__()

                                self.yang_name = "ho-vc-minute15-history"
                                self.yang_parent_name = "ho-vc-port-history"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ho-vc-minute15-path-histories", ("ho_vc_minute15_path_histories", PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories))])
                                self._leafs = OrderedDict()

                                self.ho_vc_minute15_path_histories = PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories()
                                self.ho_vc_minute15_path_histories.parent = self
                                self._children_name_map["ho_vc_minute15_path_histories"] = "ho-vc-minute15-path-histories"
                                self._segment_path = lambda: "ho-vc-minute15-history"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History, [], name, value)


                            class HoVcMinute15PathHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: ho_vc_minute15_path_history
                                
                                	port 15\-minute Path performance data
                                	**type**\: list of  		 :py:class:`HoVcMinute15PathHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories, self).__init__()

                                    self.yang_name = "ho-vc-minute15-path-histories"
                                    self.yang_parent_name = "ho-vc-minute15-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ho-vc-minute15-path-history", ("ho_vc_minute15_path_history", PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory))])
                                    self._leafs = OrderedDict()

                                    self.ho_vc_minute15_path_history = YList(self)
                                    self._segment_path = lambda: "ho-vc-minute15-path-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories, [], name, value)


                                class HoVcMinute15PathHistory(Entity):
                                    """
                                    port 15\-minute Path performance data
                                    
                                    .. attribute:: number  (key)
                                    
                                    	channel number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ho_vc_minute15_path_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`HoVcMinute15PathTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory, self).__init__()

                                        self.yang_name = "ho-vc-minute15-path-history"
                                        self.yang_parent_name = "ho-vc-minute15-path-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([("ho-vc-minute15-path-time-line-instances", ("ho_vc_minute15_path_time_line_instances", PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ])
                                        self.number = None

                                        self.ho_vc_minute15_path_time_line_instances = PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances()
                                        self.ho_vc_minute15_path_time_line_instances.parent = self
                                        self._children_name_map["ho_vc_minute15_path_time_line_instances"] = "ho-vc-minute15-path-time-line-instances"
                                        self._segment_path = lambda: "ho-vc-minute15-path-history" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory, ['number'], name, value)


                                    class HoVcMinute15PathTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: ho_vc_minute15_path_time_line_instance
                                        
                                        	port 15\-minute ho\_vc performance data
                                        	**type**\: list of  		 :py:class:`HoVcMinute15PathTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances, self).__init__()

                                            self.yang_name = "ho-vc-minute15-path-time-line-instances"
                                            self.yang_parent_name = "ho-vc-minute15-path-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("ho-vc-minute15-path-time-line-instance", ("ho_vc_minute15_path_time_line_instance", PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.ho_vc_minute15_path_time_line_instance = YList(self)
                                            self._segment_path = lambda: "ho-vc-minute15-path-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances, [], name, value)


                                        class HoVcMinute15PathTimeLineInstance(Entity):
                                            """
                                            port 15\-minute ho\_vc performance data
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path
                                            
                                            	PATH
                                            	**type**\:  :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path>`
                                            
                                            .. attribute:: fe_path
                                            
                                            	Far End PATH
                                            	**type**\:  :py:class:`FePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.FePath>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance, self).__init__()

                                                self.yang_name = "ho-vc-minute15-path-time-line-instance"
                                                self.yang_parent_name = "ho-vc-minute15-path-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("path", ("path", PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path)), ("fe-path", ("fe_path", PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.FePath))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None

                                                self.path = PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path()
                                                self.path.parent = self
                                                self._children_name_map["path"] = "path"

                                                self.fe_path = PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.FePath()
                                                self.fe_path.parent = self
                                                self._children_name_map["fe_path"] = "fe-path"
                                                self._segment_path = lambda: "ho-vc-minute15-path-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear24_hr_time'], name, value)


                                            class Path(Entity):
                                                """
                                                PATH
                                                
                                                .. attribute:: path_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:  :py:class:`PathESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathESs>`
                                                
                                                .. attribute:: path_es_rs
                                                
                                                	The number of Errored Seconds
                                                	**type**\:  :py:class:`PathEsRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathEsRs>`
                                                
                                                .. attribute:: path_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:  :py:class:`PathSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathSeSs>`
                                                
                                                .. attribute:: path_ses_rs
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:  :py:class:`PathSesRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathSesRs>`
                                                
                                                .. attribute:: path_e_bs
                                                
                                                	The number of Errored blocks
                                                	**type**\:  :py:class:`PathEBs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathEBs>`
                                                
                                                .. attribute:: path_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\:  :py:class:`PathUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathUaSs>`
                                                
                                                .. attribute:: path_bb_es
                                                
                                                	The number of background block errors
                                                	**type**\:  :py:class:`PathBbEs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathBbEs>`
                                                
                                                .. attribute:: path_bbe_rs
                                                
                                                	The number of background block errors
                                                	**type**\:  :py:class:`PathBbeRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathBbeRs>`
                                                
                                                .. attribute:: path_status
                                                
                                                	 status of the interface
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path, self).__init__()

                                                    self.yang_name = "path"
                                                    self.yang_parent_name = "ho-vc-minute15-path-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("path-e-ss", ("path_e_ss", PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathESs)), ("path-es-rs", ("path_es_rs", PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathEsRs)), ("path-se-ss", ("path_se_ss", PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathSeSs)), ("path-ses-rs", ("path_ses_rs", PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathSesRs)), ("path-e-bs", ("path_e_bs", PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathEBs)), ("path-ua-ss", ("path_ua_ss", PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathUaSs)), ("path-bb-es", ("path_bb_es", PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathBbEs)), ("path-bbe-rs", ("path_bbe_rs", PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathBbeRs))])
                                                    self._leafs = OrderedDict([
                                                        ('path_status', (YLeaf(YType.int32, 'path-status'), ['int'])),
                                                    ])
                                                    self.path_status = None

                                                    self.path_e_ss = PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathESs()
                                                    self.path_e_ss.parent = self
                                                    self._children_name_map["path_e_ss"] = "path-e-ss"

                                                    self.path_es_rs = PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathEsRs()
                                                    self.path_es_rs.parent = self
                                                    self._children_name_map["path_es_rs"] = "path-es-rs"

                                                    self.path_se_ss = PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathSeSs()
                                                    self.path_se_ss.parent = self
                                                    self._children_name_map["path_se_ss"] = "path-se-ss"

                                                    self.path_ses_rs = PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathSesRs()
                                                    self.path_ses_rs.parent = self
                                                    self._children_name_map["path_ses_rs"] = "path-ses-rs"

                                                    self.path_e_bs = PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathEBs()
                                                    self.path_e_bs.parent = self
                                                    self._children_name_map["path_e_bs"] = "path-e-bs"

                                                    self.path_ua_ss = PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathUaSs()
                                                    self.path_ua_ss.parent = self
                                                    self._children_name_map["path_ua_ss"] = "path-ua-ss"

                                                    self.path_bb_es = PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathBbEs()
                                                    self.path_bb_es.parent = self
                                                    self._children_name_map["path_bb_es"] = "path-bb-es"

                                                    self.path_bbe_rs = PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathBbeRs()
                                                    self.path_bbe_rs.parent = self
                                                    self._children_name_map["path_bbe_rs"] = "path-bbe-rs"
                                                    self._segment_path = lambda: "path"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path, ['path_status'], name, value)


                                                class PathESs(Entity):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathESs, self).__init__()

                                                        self.yang_name = "path-e-ss"
                                                        self.yang_parent_name = "path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "path-e-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathESs, ['data', 'threshold', 'tca_report'], name, value)


                                                class PathEsRs(Entity):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathEsRs, self).__init__()

                                                        self.yang_name = "path-es-rs"
                                                        self.yang_parent_name = "path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "path-es-rs"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathEsRs, ['data', 'threshold', 'tca_report'], name, value)


                                                class PathSeSs(Entity):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathSeSs, self).__init__()

                                                        self.yang_name = "path-se-ss"
                                                        self.yang_parent_name = "path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "path-se-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathSeSs, ['data', 'threshold', 'tca_report'], name, value)


                                                class PathSesRs(Entity):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathSesRs, self).__init__()

                                                        self.yang_name = "path-ses-rs"
                                                        self.yang_parent_name = "path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "path-ses-rs"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathSesRs, ['data', 'threshold', 'tca_report'], name, value)


                                                class PathEBs(Entity):
                                                    """
                                                    The number of Errored blocks
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathEBs, self).__init__()

                                                        self.yang_name = "path-e-bs"
                                                        self.yang_parent_name = "path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "path-e-bs"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathEBs, ['data', 'threshold', 'tca_report'], name, value)


                                                class PathUaSs(Entity):
                                                    """
                                                    The number of Unavailable Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathUaSs, self).__init__()

                                                        self.yang_name = "path-ua-ss"
                                                        self.yang_parent_name = "path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "path-ua-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathUaSs, ['data', 'threshold', 'tca_report'], name, value)


                                                class PathBbEs(Entity):
                                                    """
                                                    The number of background block errors
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathBbEs, self).__init__()

                                                        self.yang_name = "path-bb-es"
                                                        self.yang_parent_name = "path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "path-bb-es"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathBbEs, ['data', 'threshold', 'tca_report'], name, value)


                                                class PathBbeRs(Entity):
                                                    """
                                                    The number of background block errors
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathBbeRs, self).__init__()

                                                        self.yang_name = "path-bbe-rs"
                                                        self.yang_parent_name = "path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "path-bbe-rs"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathBbeRs, ['data', 'threshold', 'tca_report'], name, value)


                                            class FePath(Entity):
                                                """
                                                Far End PATH
                                                
                                                .. attribute:: far_end_path_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: far_end_path_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: far_end_path_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: far_end_path_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.FePath, self).__init__()

                                                    self.yang_name = "fe-path"
                                                    self.yang_parent_name = "ho-vc-minute15-path-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('far_end_path_e_ss', (YLeaf(YType.uint32, 'far-end-path-e-ss'), ['int'])),
                                                        ('far_end_path_se_ss', (YLeaf(YType.uint32, 'far-end-path-se-ss'), ['int'])),
                                                        ('far_end_path_c_vs', (YLeaf(YType.uint32, 'far-end-path-c-vs'), ['int'])),
                                                        ('far_end_path_ua_ss', (YLeaf(YType.uint32, 'far-end-path-ua-ss'), ['int'])),
                                                    ])
                                                    self.far_end_path_e_ss = None
                                                    self.far_end_path_se_ss = None
                                                    self.far_end_path_c_vs = None
                                                    self.far_end_path_ua_ss = None
                                                    self._segment_path = lambda: "fe-path"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.FePath, ['far_end_path_e_ss', 'far_end_path_se_ss', 'far_end_path_c_vs', 'far_end_path_ua_ss'], name, value)


                        class HoVcHour24History(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: ho_vc_hour24_path_histories
                            
                            	port current performance data
                            	**type**\:  :py:class:`HoVcHour24PathHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History, self).__init__()

                                self.yang_name = "ho-vc-hour24-history"
                                self.yang_parent_name = "ho-vc-port-history"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ho-vc-hour24-path-histories", ("ho_vc_hour24_path_histories", PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories))])
                                self._leafs = OrderedDict()

                                self.ho_vc_hour24_path_histories = PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories()
                                self.ho_vc_hour24_path_histories.parent = self
                                self._children_name_map["ho_vc_hour24_path_histories"] = "ho-vc-hour24-path-histories"
                                self._segment_path = lambda: "ho-vc-hour24-history"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History, [], name, value)


                            class HoVcHour24PathHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: ho_vc_hour24_path_history
                                
                                	port 24 hour Path performance data
                                	**type**\: list of  		 :py:class:`HoVcHour24PathHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories, self).__init__()

                                    self.yang_name = "ho-vc-hour24-path-histories"
                                    self.yang_parent_name = "ho-vc-hour24-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ho-vc-hour24-path-history", ("ho_vc_hour24_path_history", PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory))])
                                    self._leafs = OrderedDict()

                                    self.ho_vc_hour24_path_history = YList(self)
                                    self._segment_path = lambda: "ho-vc-hour24-path-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories, [], name, value)


                                class HoVcHour24PathHistory(Entity):
                                    """
                                    port 24 hour Path performance data
                                    
                                    .. attribute:: number  (key)
                                    
                                    	channel number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ho_vc_hour24_path_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`HoVcHour24PathTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory, self).__init__()

                                        self.yang_name = "ho-vc-hour24-path-history"
                                        self.yang_parent_name = "ho-vc-hour24-path-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([("ho-vc-hour24-path-time-line-instances", ("ho_vc_hour24_path_time_line_instances", PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ])
                                        self.number = None

                                        self.ho_vc_hour24_path_time_line_instances = PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances()
                                        self.ho_vc_hour24_path_time_line_instances.parent = self
                                        self._children_name_map["ho_vc_hour24_path_time_line_instances"] = "ho-vc-hour24-path-time-line-instances"
                                        self._segment_path = lambda: "ho-vc-hour24-path-history" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory, ['number'], name, value)


                                    class HoVcHour24PathTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: ho_vc_hour24_path_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of  		 :py:class:`HoVcHour24PathTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances, self).__init__()

                                            self.yang_name = "ho-vc-hour24-path-time-line-instances"
                                            self.yang_parent_name = "ho-vc-hour24-path-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("ho-vc-hour24-path-time-line-instance", ("ho_vc_hour24_path_time_line_instance", PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.ho_vc_hour24_path_time_line_instance = YList(self)
                                            self._segment_path = lambda: "ho-vc-hour24-path-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances, [], name, value)


                                        class HoVcHour24PathTimeLineInstance(Entity):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path
                                            
                                            	PATH
                                            	**type**\:  :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path>`
                                            
                                            .. attribute:: fe_path
                                            
                                            	Far End PATH
                                            	**type**\:  :py:class:`FePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.FePath>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance, self).__init__()

                                                self.yang_name = "ho-vc-hour24-path-time-line-instance"
                                                self.yang_parent_name = "ho-vc-hour24-path-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("path", ("path", PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path)), ("fe-path", ("fe_path", PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.FePath))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None

                                                self.path = PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path()
                                                self.path.parent = self
                                                self._children_name_map["path"] = "path"

                                                self.fe_path = PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.FePath()
                                                self.fe_path.parent = self
                                                self._children_name_map["fe_path"] = "fe-path"
                                                self._segment_path = lambda: "ho-vc-hour24-path-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear24_hr_time'], name, value)


                                            class Path(Entity):
                                                """
                                                PATH
                                                
                                                .. attribute:: path_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:  :py:class:`PathESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathESs>`
                                                
                                                .. attribute:: path_es_rs
                                                
                                                	The number of Errored Seconds
                                                	**type**\:  :py:class:`PathEsRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathEsRs>`
                                                
                                                .. attribute:: path_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:  :py:class:`PathSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathSeSs>`
                                                
                                                .. attribute:: path_ses_rs
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:  :py:class:`PathSesRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathSesRs>`
                                                
                                                .. attribute:: path_e_bs
                                                
                                                	The number of Errored blocks
                                                	**type**\:  :py:class:`PathEBs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathEBs>`
                                                
                                                .. attribute:: path_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\:  :py:class:`PathUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathUaSs>`
                                                
                                                .. attribute:: path_bb_es
                                                
                                                	The number of background block errors
                                                	**type**\:  :py:class:`PathBbEs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathBbEs>`
                                                
                                                .. attribute:: path_bbe_rs
                                                
                                                	The number of background block errors
                                                	**type**\:  :py:class:`PathBbeRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathBbeRs>`
                                                
                                                .. attribute:: path_status
                                                
                                                	 status of the interface
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path, self).__init__()

                                                    self.yang_name = "path"
                                                    self.yang_parent_name = "ho-vc-hour24-path-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("path-e-ss", ("path_e_ss", PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathESs)), ("path-es-rs", ("path_es_rs", PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathEsRs)), ("path-se-ss", ("path_se_ss", PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathSeSs)), ("path-ses-rs", ("path_ses_rs", PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathSesRs)), ("path-e-bs", ("path_e_bs", PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathEBs)), ("path-ua-ss", ("path_ua_ss", PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathUaSs)), ("path-bb-es", ("path_bb_es", PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathBbEs)), ("path-bbe-rs", ("path_bbe_rs", PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathBbeRs))])
                                                    self._leafs = OrderedDict([
                                                        ('path_status', (YLeaf(YType.int32, 'path-status'), ['int'])),
                                                    ])
                                                    self.path_status = None

                                                    self.path_e_ss = PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathESs()
                                                    self.path_e_ss.parent = self
                                                    self._children_name_map["path_e_ss"] = "path-e-ss"

                                                    self.path_es_rs = PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathEsRs()
                                                    self.path_es_rs.parent = self
                                                    self._children_name_map["path_es_rs"] = "path-es-rs"

                                                    self.path_se_ss = PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathSeSs()
                                                    self.path_se_ss.parent = self
                                                    self._children_name_map["path_se_ss"] = "path-se-ss"

                                                    self.path_ses_rs = PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathSesRs()
                                                    self.path_ses_rs.parent = self
                                                    self._children_name_map["path_ses_rs"] = "path-ses-rs"

                                                    self.path_e_bs = PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathEBs()
                                                    self.path_e_bs.parent = self
                                                    self._children_name_map["path_e_bs"] = "path-e-bs"

                                                    self.path_ua_ss = PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathUaSs()
                                                    self.path_ua_ss.parent = self
                                                    self._children_name_map["path_ua_ss"] = "path-ua-ss"

                                                    self.path_bb_es = PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathBbEs()
                                                    self.path_bb_es.parent = self
                                                    self._children_name_map["path_bb_es"] = "path-bb-es"

                                                    self.path_bbe_rs = PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathBbeRs()
                                                    self.path_bbe_rs.parent = self
                                                    self._children_name_map["path_bbe_rs"] = "path-bbe-rs"
                                                    self._segment_path = lambda: "path"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path, ['path_status'], name, value)


                                                class PathESs(Entity):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathESs, self).__init__()

                                                        self.yang_name = "path-e-ss"
                                                        self.yang_parent_name = "path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "path-e-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathESs, ['data', 'threshold', 'tca_report'], name, value)


                                                class PathEsRs(Entity):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathEsRs, self).__init__()

                                                        self.yang_name = "path-es-rs"
                                                        self.yang_parent_name = "path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "path-es-rs"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathEsRs, ['data', 'threshold', 'tca_report'], name, value)


                                                class PathSeSs(Entity):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathSeSs, self).__init__()

                                                        self.yang_name = "path-se-ss"
                                                        self.yang_parent_name = "path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "path-se-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathSeSs, ['data', 'threshold', 'tca_report'], name, value)


                                                class PathSesRs(Entity):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathSesRs, self).__init__()

                                                        self.yang_name = "path-ses-rs"
                                                        self.yang_parent_name = "path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "path-ses-rs"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathSesRs, ['data', 'threshold', 'tca_report'], name, value)


                                                class PathEBs(Entity):
                                                    """
                                                    The number of Errored blocks
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathEBs, self).__init__()

                                                        self.yang_name = "path-e-bs"
                                                        self.yang_parent_name = "path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "path-e-bs"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathEBs, ['data', 'threshold', 'tca_report'], name, value)


                                                class PathUaSs(Entity):
                                                    """
                                                    The number of Unavailable Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathUaSs, self).__init__()

                                                        self.yang_name = "path-ua-ss"
                                                        self.yang_parent_name = "path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "path-ua-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathUaSs, ['data', 'threshold', 'tca_report'], name, value)


                                                class PathBbEs(Entity):
                                                    """
                                                    The number of background block errors
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathBbEs, self).__init__()

                                                        self.yang_name = "path-bb-es"
                                                        self.yang_parent_name = "path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "path-bb-es"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathBbEs, ['data', 'threshold', 'tca_report'], name, value)


                                                class PathBbeRs(Entity):
                                                    """
                                                    The number of background block errors
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathBbeRs, self).__init__()

                                                        self.yang_name = "path-bbe-rs"
                                                        self.yang_parent_name = "path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.str, 'data'), ['str'])),
                                                            ('threshold', (YLeaf(YType.str, 'threshold'), ['str'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "path-bbe-rs"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathBbeRs, ['data', 'threshold', 'tca_report'], name, value)


                                            class FePath(Entity):
                                                """
                                                Far End PATH
                                                
                                                .. attribute:: far_end_path_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: far_end_path_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: far_end_path_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: far_end_path_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.FePath, self).__init__()

                                                    self.yang_name = "fe-path"
                                                    self.yang_parent_name = "ho-vc-hour24-path-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('far_end_path_e_ss', (YLeaf(YType.uint32, 'far-end-path-e-ss'), ['int'])),
                                                        ('far_end_path_se_ss', (YLeaf(YType.uint32, 'far-end-path-se-ss'), ['int'])),
                                                        ('far_end_path_c_vs', (YLeaf(YType.uint32, 'far-end-path-c-vs'), ['int'])),
                                                        ('far_end_path_ua_ss', (YLeaf(YType.uint32, 'far-end-path-ua-ss'), ['int'])),
                                                    ])
                                                    self.far_end_path_e_ss = None
                                                    self.far_end_path_se_ss = None
                                                    self.far_end_path_c_vs = None
                                                    self.far_end_path_ua_ss = None
                                                    self._segment_path = lambda: "fe-path"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.FePath, ['far_end_path_e_ss', 'far_end_path_se_ss', 'far_end_path_c_vs', 'far_end_path_ua_ss'], name, value)


            class OpticsHistory(Entity):
                """
                OPTICS controller History performance data
                
                .. attribute:: optics_port_histories
                
                	Port performance data
                	**type**\:  :py:class:`OpticsPortHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory, self).__init__()

                    self.yang_name = "optics-history"
                    self.yang_parent_name = "periodic"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("optics-port-histories", ("optics_port_histories", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories))])
                    self._leafs = OrderedDict()

                    self.optics_port_histories = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories()
                    self.optics_port_histories.parent = self
                    self._children_name_map["optics_port_histories"] = "optics-port-histories"
                    self._segment_path = lambda: "optics-history"
                    self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory, [], name, value)


                class OpticsPortHistories(Entity):
                    """
                    Port performance data
                    
                    .. attribute:: optics_port_history
                    
                    	Port performance data
                    	**type**\: list of  		 :py:class:`OpticsPortHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories, self).__init__()

                        self.yang_name = "optics-port-histories"
                        self.yang_parent_name = "optics-history"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("optics-port-history", ("optics_port_history", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory))])
                        self._leafs = OrderedDict()

                        self.optics_port_history = YList(self)
                        self._segment_path = lambda: "optics-port-histories"
                        self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/optics-history/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories, [], name, value)


                    class OpticsPortHistory(Entity):
                        """
                        Port performance data
                        
                        .. attribute:: name  (key)
                        
                        	Port name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: optics_hour24_history
                        
                        	port current performance data
                        	**type**\:  :py:class:`OpticsHour24History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History>`
                        
                        .. attribute:: optics_second30_history
                        
                        	port current performance data
                        	**type**\:  :py:class:`OpticsSecond30History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History>`
                        
                        .. attribute:: optics_minute15_history
                        
                        	port current performance data
                        	**type**\:  :py:class:`OpticsMinute15History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory, self).__init__()

                            self.yang_name = "optics-port-history"
                            self.yang_parent_name = "optics-port-histories"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("optics-hour24-history", ("optics_hour24_history", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History)), ("optics-second30-history", ("optics_second30_history", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History)), ("optics-minute15-history", ("optics_minute15_history", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None

                            self.optics_hour24_history = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History()
                            self.optics_hour24_history.parent = self
                            self._children_name_map["optics_hour24_history"] = "optics-hour24-history"

                            self.optics_second30_history = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History()
                            self.optics_second30_history.parent = self
                            self._children_name_map["optics_second30_history"] = "optics-second30-history"

                            self.optics_minute15_history = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History()
                            self.optics_minute15_history.parent = self
                            self._children_name_map["optics_minute15_history"] = "optics-minute15-history"
                            self._segment_path = lambda: "optics-port-history" + "[name='" + str(self.name) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/optics-history/optics-port-histories/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory, ['name'], name, value)


                        class OpticsHour24History(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: optics_hour24_optics_histories
                            
                            	port 24 hour performance data
                            	**type**\:  :py:class:`OpticsHour24OpticsHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories>`
                            
                            .. attribute:: optics_hour24fec_histories
                            
                            	port current performance data
                            	**type**\:  :py:class:`OpticsHour24fecHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24fecHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History, self).__init__()

                                self.yang_name = "optics-hour24-history"
                                self.yang_parent_name = "optics-port-history"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("optics-hour24-optics-histories", ("optics_hour24_optics_histories", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories)), ("optics-hour24fec-histories", ("optics_hour24fec_histories", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24fecHistories))])
                                self._leafs = OrderedDict()

                                self.optics_hour24_optics_histories = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories()
                                self.optics_hour24_optics_histories.parent = self
                                self._children_name_map["optics_hour24_optics_histories"] = "optics-hour24-optics-histories"

                                self.optics_hour24fec_histories = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24fecHistories()
                                self.optics_hour24fec_histories.parent = self
                                self._children_name_map["optics_hour24fec_histories"] = "optics-hour24fec-histories"
                                self._segment_path = lambda: "optics-hour24-history"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History, [], name, value)


                            class OpticsHour24OpticsHistories(Entity):
                                """
                                port 24 hour performance data
                                
                                .. attribute:: optics_hour24_optics_history
                                
                                	port 24 hour optics performance data
                                	**type**\: list of  		 :py:class:`OpticsHour24OpticsHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories, self).__init__()

                                    self.yang_name = "optics-hour24-optics-histories"
                                    self.yang_parent_name = "optics-hour24-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("optics-hour24-optics-history", ("optics_hour24_optics_history", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory))])
                                    self._leafs = OrderedDict()

                                    self.optics_hour24_optics_history = YList(self)
                                    self._segment_path = lambda: "optics-hour24-optics-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories, [], name, value)


                                class OpticsHour24OpticsHistory(Entity):
                                    """
                                    port 24 hour optics performance data
                                    
                                    .. attribute:: number  (key)
                                    
                                    	channel number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: optics_hour24_optics_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`OpticsHour24OpticsTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory, self).__init__()

                                        self.yang_name = "optics-hour24-optics-history"
                                        self.yang_parent_name = "optics-hour24-optics-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([("optics-hour24-optics-time-line-instances", ("optics_hour24_optics_time_line_instances", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ])
                                        self.number = None

                                        self.optics_hour24_optics_time_line_instances = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances()
                                        self.optics_hour24_optics_time_line_instances.parent = self
                                        self._children_name_map["optics_hour24_optics_time_line_instances"] = "optics-hour24-optics-time-line-instances"
                                        self._segment_path = lambda: "optics-hour24-optics-history" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory, ['number'], name, value)


                                    class OpticsHour24OpticsTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: optics_hour24_optics_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of  		 :py:class:`OpticsHour24OpticsTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances, self).__init__()

                                            self.yang_name = "optics-hour24-optics-time-line-instances"
                                            self.yang_parent_name = "optics-hour24-optics-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("optics-hour24-optics-time-line-instance", ("optics_hour24_optics_time_line_instance", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.optics_hour24_optics_time_line_instance = YList(self)
                                            self._segment_path = lambda: "optics-hour24-optics-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances, [], name, value)


                                        class OpticsHour24OpticsTimeLineInstance(Entity):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lbc
                                            
                                            	LBC
                                            	**type**\:  :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Lbc>`
                                            
                                            .. attribute:: lbc_pc
                                            
                                            	LBC in percentage
                                            	**type**\:  :py:class:`LbcPc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.LbcPc>`
                                            
                                            .. attribute:: opt
                                            
                                            	OPT
                                            	**type**\:  :py:class:`Opt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Opt>`
                                            
                                            .. attribute:: opr
                                            
                                            	OPR
                                            	**type**\:  :py:class:`Opr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Opr>`
                                            
                                            .. attribute:: cd
                                            
                                            	Chromatic Dispersion
                                            	**type**\:  :py:class:`Cd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Cd>`
                                            
                                            .. attribute:: dgd
                                            
                                            	Differential group Delay
                                            	**type**\:  :py:class:`Dgd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Dgd>`
                                            
                                            .. attribute:: pmd
                                            
                                            	Polarization Mode Dispersion
                                            	**type**\:  :py:class:`Pmd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Pmd>`
                                            
                                            .. attribute:: osnr
                                            
                                            	Optical Signal to Noise Ratio
                                            	**type**\:  :py:class:`Osnr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Osnr>`
                                            
                                            .. attribute:: center_wavelength
                                            
                                            	Center Wavelength/Frequency
                                            	**type**\:  :py:class:`CenterWavelength <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.CenterWavelength>`
                                            
                                            .. attribute:: pdl
                                            
                                            	Polarization Dependent Loss
                                            	**type**\:  :py:class:`Pdl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Pdl>`
                                            
                                            .. attribute:: pcr
                                            
                                            	Polarization Change Rate
                                            	**type**\:  :py:class:`Pcr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Pcr>`
                                            
                                            .. attribute:: pn
                                            
                                            	Phase Noise
                                            	**type**\:  :py:class:`Pn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Pn>`
                                            
                                            .. attribute:: rx_sig_pow
                                            
                                            	Rx signal power
                                            	**type**\:  :py:class:`RxSigPow <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.RxSigPow>`
                                            
                                            .. attribute:: low_sig_freq_off
                                            
                                            	low freq sig off
                                            	**type**\:  :py:class:`LowSigFreqOff <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.LowSigFreqOff>`
                                            
                                            .. attribute:: ampli_gain
                                            
                                            	Ampli Gain
                                            	**type**\:  :py:class:`AmpliGain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.AmpliGain>`
                                            
                                            .. attribute:: ampli_gain_tilt
                                            
                                            	Ampli Gain Tilt
                                            	**type**\:  :py:class:`AmpliGainTilt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.AmpliGainTilt>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance, self).__init__()

                                                self.yang_name = "optics-hour24-optics-time-line-instance"
                                                self.yang_parent_name = "optics-hour24-optics-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("lbc", ("lbc", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Lbc)), ("lbc-pc", ("lbc_pc", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.LbcPc)), ("opt", ("opt", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Opt)), ("opr", ("opr", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Opr)), ("cd", ("cd", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Cd)), ("dgd", ("dgd", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Dgd)), ("pmd", ("pmd", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Pmd)), ("osnr", ("osnr", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Osnr)), ("center-wavelength", ("center_wavelength", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.CenterWavelength)), ("pdl", ("pdl", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Pdl)), ("pcr", ("pcr", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Pcr)), ("pn", ("pn", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Pn)), ("rx-sig-pow", ("rx_sig_pow", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.RxSigPow)), ("low-sig-freq-off", ("low_sig_freq_off", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.LowSigFreqOff)), ("ampli-gain", ("ampli_gain", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.AmpliGain)), ("ampli-gain-tilt", ("ampli_gain_tilt", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.AmpliGainTilt))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                    ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear24_hr_time = None
                                                self.sec30_support = None

                                                self.lbc = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Lbc()
                                                self.lbc.parent = self
                                                self._children_name_map["lbc"] = "lbc"

                                                self.lbc_pc = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.LbcPc()
                                                self.lbc_pc.parent = self
                                                self._children_name_map["lbc_pc"] = "lbc-pc"

                                                self.opt = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Opt()
                                                self.opt.parent = self
                                                self._children_name_map["opt"] = "opt"

                                                self.opr = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Opr()
                                                self.opr.parent = self
                                                self._children_name_map["opr"] = "opr"

                                                self.cd = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Cd()
                                                self.cd.parent = self
                                                self._children_name_map["cd"] = "cd"

                                                self.dgd = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Dgd()
                                                self.dgd.parent = self
                                                self._children_name_map["dgd"] = "dgd"

                                                self.pmd = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Pmd()
                                                self.pmd.parent = self
                                                self._children_name_map["pmd"] = "pmd"

                                                self.osnr = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Osnr()
                                                self.osnr.parent = self
                                                self._children_name_map["osnr"] = "osnr"

                                                self.center_wavelength = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.CenterWavelength()
                                                self.center_wavelength.parent = self
                                                self._children_name_map["center_wavelength"] = "center-wavelength"

                                                self.pdl = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Pdl()
                                                self.pdl.parent = self
                                                self._children_name_map["pdl"] = "pdl"

                                                self.pcr = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Pcr()
                                                self.pcr.parent = self
                                                self._children_name_map["pcr"] = "pcr"

                                                self.pn = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Pn()
                                                self.pn.parent = self
                                                self._children_name_map["pn"] = "pn"

                                                self.rx_sig_pow = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.RxSigPow()
                                                self.rx_sig_pow.parent = self
                                                self._children_name_map["rx_sig_pow"] = "rx-sig-pow"

                                                self.low_sig_freq_off = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.LowSigFreqOff()
                                                self.low_sig_freq_off.parent = self
                                                self._children_name_map["low_sig_freq_off"] = "low-sig-freq-off"

                                                self.ampli_gain = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.AmpliGain()
                                                self.ampli_gain.parent = self
                                                self._children_name_map["ampli_gain"] = "ampli-gain"

                                                self.ampli_gain_tilt = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.AmpliGainTilt()
                                                self.ampli_gain_tilt.parent = self
                                                self._children_name_map["ampli_gain_tilt"] = "ampli-gain-tilt"
                                                self._segment_path = lambda: "optics-hour24-optics-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                            class Lbc(Entity):
                                                """
                                                LBC
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Lbc, self).__init__()

                                                    self.yang_name = "lbc"
                                                    self.yang_parent_name = "optics-hour24-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.int32, 'minimum'), ['int'])),
                                                        ('average', (YLeaf(YType.int32, 'average'), ['int'])),
                                                        ('maximum', (YLeaf(YType.int32, 'maximum'), ['int'])),
                                                        ('minimum_threshold', (YLeaf(YType.int32, 'minimum-threshold'), ['int'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.int32, 'maximum-threshold'), ['int'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "lbc"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Lbc, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class LbcPc(Entity):
                                                """
                                                LBC in percentage
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.LbcPc, self).__init__()

                                                    self.yang_name = "lbc-pc"
                                                    self.yang_parent_name = "optics-hour24-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "lbc-pc"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.LbcPc, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class Opt(Entity):
                                                """
                                                OPT
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Opt, self).__init__()

                                                    self.yang_name = "opt"
                                                    self.yang_parent_name = "optics-hour24-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "opt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Opt, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class Opr(Entity):
                                                """
                                                OPR
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Opr, self).__init__()

                                                    self.yang_name = "opr"
                                                    self.yang_parent_name = "optics-hour24-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "opr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Opr, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class Cd(Entity):
                                                """
                                                Chromatic Dispersion
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Cd, self).__init__()

                                                    self.yang_name = "cd"
                                                    self.yang_parent_name = "optics-hour24-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.int32, 'minimum'), ['int'])),
                                                        ('average', (YLeaf(YType.int32, 'average'), ['int'])),
                                                        ('maximum', (YLeaf(YType.int32, 'maximum'), ['int'])),
                                                        ('minimum_threshold', (YLeaf(YType.int32, 'minimum-threshold'), ['int'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.int32, 'maximum-threshold'), ['int'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "cd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Cd, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class Dgd(Entity):
                                                """
                                                Differential group Delay
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Dgd, self).__init__()

                                                    self.yang_name = "dgd"
                                                    self.yang_parent_name = "optics-hour24-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "dgd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Dgd, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class Pmd(Entity):
                                                """
                                                Polarization Mode Dispersion
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Pmd, self).__init__()

                                                    self.yang_name = "pmd"
                                                    self.yang_parent_name = "optics-hour24-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "pmd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Pmd, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class Osnr(Entity):
                                                """
                                                Optical Signal to Noise Ratio
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Osnr, self).__init__()

                                                    self.yang_name = "osnr"
                                                    self.yang_parent_name = "optics-hour24-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "osnr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Osnr, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class CenterWavelength(Entity):
                                                """
                                                Center Wavelength/Frequency
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.CenterWavelength, self).__init__()

                                                    self.yang_name = "center-wavelength"
                                                    self.yang_parent_name = "optics-hour24-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "center-wavelength"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.CenterWavelength, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class Pdl(Entity):
                                                """
                                                Polarization Dependent Loss
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Pdl, self).__init__()

                                                    self.yang_name = "pdl"
                                                    self.yang_parent_name = "optics-hour24-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "pdl"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Pdl, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class Pcr(Entity):
                                                """
                                                Polarization Change Rate
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Pcr, self).__init__()

                                                    self.yang_name = "pcr"
                                                    self.yang_parent_name = "optics-hour24-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "pcr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Pcr, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class Pn(Entity):
                                                """
                                                Phase Noise
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Pn, self).__init__()

                                                    self.yang_name = "pn"
                                                    self.yang_parent_name = "optics-hour24-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "pn"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Pn, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class RxSigPow(Entity):
                                                """
                                                Rx signal power
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.RxSigPow, self).__init__()

                                                    self.yang_name = "rx-sig-pow"
                                                    self.yang_parent_name = "optics-hour24-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "rx-sig-pow"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.RxSigPow, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class LowSigFreqOff(Entity):
                                                """
                                                low freq sig off
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.LowSigFreqOff, self).__init__()

                                                    self.yang_name = "low-sig-freq-off"
                                                    self.yang_parent_name = "optics-hour24-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.int32, 'minimum'), ['int'])),
                                                        ('average', (YLeaf(YType.int32, 'average'), ['int'])),
                                                        ('maximum', (YLeaf(YType.int32, 'maximum'), ['int'])),
                                                        ('minimum_threshold', (YLeaf(YType.int32, 'minimum-threshold'), ['int'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.int32, 'maximum-threshold'), ['int'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "low-sig-freq-off"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.LowSigFreqOff, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class AmpliGain(Entity):
                                                """
                                                Ampli Gain
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.AmpliGain, self).__init__()

                                                    self.yang_name = "ampli-gain"
                                                    self.yang_parent_name = "optics-hour24-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "ampli-gain"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.AmpliGain, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class AmpliGainTilt(Entity):
                                                """
                                                Ampli Gain Tilt
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.AmpliGainTilt, self).__init__()

                                                    self.yang_name = "ampli-gain-tilt"
                                                    self.yang_parent_name = "optics-hour24-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "ampli-gain-tilt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.AmpliGainTilt, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                            class OpticsHour24fecHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: optics_hour24fec_history
                                
                                	port 24 hour fec performance data
                                	**type**\: list of  		 :py:class:`OpticsHour24fecHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24fecHistories.OpticsHour24fecHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24fecHistories, self).__init__()

                                    self.yang_name = "optics-hour24fec-histories"
                                    self.yang_parent_name = "optics-hour24-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("optics-hour24fec-history", ("optics_hour24fec_history", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24fecHistories.OpticsHour24fecHistory))])
                                    self._leafs = OrderedDict()

                                    self.optics_hour24fec_history = YList(self)
                                    self._segment_path = lambda: "optics-hour24fec-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24fecHistories, [], name, value)


                                class OpticsHour24fecHistory(Entity):
                                    """
                                    port 24 hour fec performance data
                                    
                                    .. attribute:: number  (key)
                                    
                                    	channel number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: optics_hour24fec_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`OpticsHour24fecTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24fecHistories.OpticsHour24fecHistory.OpticsHour24fecTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24fecHistories.OpticsHour24fecHistory, self).__init__()

                                        self.yang_name = "optics-hour24fec-history"
                                        self.yang_parent_name = "optics-hour24fec-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([("optics-hour24fec-time-line-instances", ("optics_hour24fec_time_line_instances", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24fecHistories.OpticsHour24fecHistory.OpticsHour24fecTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ])
                                        self.number = None

                                        self.optics_hour24fec_time_line_instances = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24fecHistories.OpticsHour24fecHistory.OpticsHour24fecTimeLineInstances()
                                        self.optics_hour24fec_time_line_instances.parent = self
                                        self._children_name_map["optics_hour24fec_time_line_instances"] = "optics-hour24fec-time-line-instances"
                                        self._segment_path = lambda: "optics-hour24fec-history" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24fecHistories.OpticsHour24fecHistory, ['number'], name, value)


                                    class OpticsHour24fecTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: optics_hour24fec_time_line_instance
                                        
                                        	port 15\-minute fec performance data
                                        	**type**\: list of  		 :py:class:`OpticsHour24fecTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24fecHistories.OpticsHour24fecHistory.OpticsHour24fecTimeLineInstances.OpticsHour24fecTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24fecHistories.OpticsHour24fecHistory.OpticsHour24fecTimeLineInstances, self).__init__()

                                            self.yang_name = "optics-hour24fec-time-line-instances"
                                            self.yang_parent_name = "optics-hour24fec-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("optics-hour24fec-time-line-instance", ("optics_hour24fec_time_line_instance", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24fecHistories.OpticsHour24fecHistory.OpticsHour24fecTimeLineInstances.OpticsHour24fecTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.optics_hour24fec_time_line_instance = YList(self)
                                            self._segment_path = lambda: "optics-hour24fec-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24fecHistories.OpticsHour24fecHistory.OpticsHour24fecTimeLineInstances, [], name, value)


                                        class OpticsHour24fecTimeLineInstance(Entity):
                                            """
                                            port 15\-minute fec performance data
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ec_bits
                                            
                                            	EC BITS
                                            	**type**\:  :py:class:`EcBits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24fecHistories.OpticsHour24fecHistory.OpticsHour24fecTimeLineInstances.OpticsHour24fecTimeLineInstance.EcBits>`
                                            
                                            .. attribute:: uc_words
                                            
                                            	UC WORDS
                                            	**type**\:  :py:class:`UcWords <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24fecHistories.OpticsHour24fecHistory.OpticsHour24fecTimeLineInstances.OpticsHour24fecTimeLineInstance.UcWords>`
                                            
                                            .. attribute:: pre_fec_ber
                                            
                                            	Pre FEC BER
                                            	**type**\:  :py:class:`PreFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24fecHistories.OpticsHour24fecHistory.OpticsHour24fecTimeLineInstances.OpticsHour24fecTimeLineInstance.PreFecBer>`
                                            
                                            .. attribute:: post_fec_ber
                                            
                                            	Post FEC BER
                                            	**type**\:  :py:class:`PostFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24fecHistories.OpticsHour24fecHistory.OpticsHour24fecTimeLineInstances.OpticsHour24fecTimeLineInstance.PostFecBer>`
                                            
                                            .. attribute:: q
                                            
                                            	Q
                                            	**type**\:  :py:class:`Q <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24fecHistories.OpticsHour24fecHistory.OpticsHour24fecTimeLineInstances.OpticsHour24fecTimeLineInstance.Q>`
                                            
                                            .. attribute:: qmargin
                                            
                                            	Q Margin
                                            	**type**\:  :py:class:`Qmargin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24fecHistories.OpticsHour24fecHistory.OpticsHour24fecTimeLineInstances.OpticsHour24fecTimeLineInstance.Qmargin>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24fecHistories.OpticsHour24fecHistory.OpticsHour24fecTimeLineInstances.OpticsHour24fecTimeLineInstance, self).__init__()

                                                self.yang_name = "optics-hour24fec-time-line-instance"
                                                self.yang_parent_name = "optics-hour24fec-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("ec-bits", ("ec_bits", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24fecHistories.OpticsHour24fecHistory.OpticsHour24fecTimeLineInstances.OpticsHour24fecTimeLineInstance.EcBits)), ("uc-words", ("uc_words", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24fecHistories.OpticsHour24fecHistory.OpticsHour24fecTimeLineInstances.OpticsHour24fecTimeLineInstance.UcWords)), ("pre-fec-ber", ("pre_fec_ber", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24fecHistories.OpticsHour24fecHistory.OpticsHour24fecTimeLineInstances.OpticsHour24fecTimeLineInstance.PreFecBer)), ("post-fec-ber", ("post_fec_ber", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24fecHistories.OpticsHour24fecHistory.OpticsHour24fecTimeLineInstances.OpticsHour24fecTimeLineInstance.PostFecBer)), ("q", ("q", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24fecHistories.OpticsHour24fecHistory.OpticsHour24fecTimeLineInstances.OpticsHour24fecTimeLineInstance.Q)), ("qmargin", ("qmargin", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24fecHistories.OpticsHour24fecHistory.OpticsHour24fecTimeLineInstances.OpticsHour24fecTimeLineInstance.Qmargin))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                    ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear24_hr_time = None
                                                self.sec30_support = None

                                                self.ec_bits = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24fecHistories.OpticsHour24fecHistory.OpticsHour24fecTimeLineInstances.OpticsHour24fecTimeLineInstance.EcBits()
                                                self.ec_bits.parent = self
                                                self._children_name_map["ec_bits"] = "ec-bits"

                                                self.uc_words = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24fecHistories.OpticsHour24fecHistory.OpticsHour24fecTimeLineInstances.OpticsHour24fecTimeLineInstance.UcWords()
                                                self.uc_words.parent = self
                                                self._children_name_map["uc_words"] = "uc-words"

                                                self.pre_fec_ber = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24fecHistories.OpticsHour24fecHistory.OpticsHour24fecTimeLineInstances.OpticsHour24fecTimeLineInstance.PreFecBer()
                                                self.pre_fec_ber.parent = self
                                                self._children_name_map["pre_fec_ber"] = "pre-fec-ber"

                                                self.post_fec_ber = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24fecHistories.OpticsHour24fecHistory.OpticsHour24fecTimeLineInstances.OpticsHour24fecTimeLineInstance.PostFecBer()
                                                self.post_fec_ber.parent = self
                                                self._children_name_map["post_fec_ber"] = "post-fec-ber"

                                                self.q = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24fecHistories.OpticsHour24fecHistory.OpticsHour24fecTimeLineInstances.OpticsHour24fecTimeLineInstance.Q()
                                                self.q.parent = self
                                                self._children_name_map["q"] = "q"

                                                self.qmargin = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24fecHistories.OpticsHour24fecHistory.OpticsHour24fecTimeLineInstances.OpticsHour24fecTimeLineInstance.Qmargin()
                                                self.qmargin.parent = self
                                                self._children_name_map["qmargin"] = "qmargin"
                                                self._segment_path = lambda: "optics-hour24fec-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24fecHistories.OpticsHour24fecHistory.OpticsHour24fecTimeLineInstances.OpticsHour24fecTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                            class EcBits(Entity):
                                                """
                                                EC BITS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24fecHistories.OpticsHour24fecHistory.OpticsHour24fecTimeLineInstances.OpticsHour24fecTimeLineInstance.EcBits, self).__init__()

                                                    self.yang_name = "ec-bits"
                                                    self.yang_parent_name = "optics-hour24fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ec-bits"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24fecHistories.OpticsHour24fecHistory.OpticsHour24fecTimeLineInstances.OpticsHour24fecTimeLineInstance.EcBits, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class UcWords(Entity):
                                                """
                                                UC WORDS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24fecHistories.OpticsHour24fecHistory.OpticsHour24fecTimeLineInstances.OpticsHour24fecTimeLineInstance.UcWords, self).__init__()

                                                    self.yang_name = "uc-words"
                                                    self.yang_parent_name = "optics-hour24fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "uc-words"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24fecHistories.OpticsHour24fecHistory.OpticsHour24fecTimeLineInstances.OpticsHour24fecTimeLineInstance.UcWords, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class PreFecBer(Entity):
                                                """
                                                Pre FEC BER
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24fecHistories.OpticsHour24fecHistory.OpticsHour24fecTimeLineInstances.OpticsHour24fecTimeLineInstance.PreFecBer, self).__init__()

                                                    self.yang_name = "pre-fec-ber"
                                                    self.yang_parent_name = "optics-hour24fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.maximum_tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "pre-fec-ber"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24fecHistories.OpticsHour24fecHistory.OpticsHour24fecTimeLineInstances.OpticsHour24fecTimeLineInstance.PreFecBer, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                            class PostFecBer(Entity):
                                                """
                                                Post FEC BER
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24fecHistories.OpticsHour24fecHistory.OpticsHour24fecTimeLineInstances.OpticsHour24fecTimeLineInstance.PostFecBer, self).__init__()

                                                    self.yang_name = "post-fec-ber"
                                                    self.yang_parent_name = "optics-hour24fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.maximum_tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "post-fec-ber"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24fecHistories.OpticsHour24fecHistory.OpticsHour24fecTimeLineInstances.OpticsHour24fecTimeLineInstance.PostFecBer, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                            class Q(Entity):
                                                """
                                                Q
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24fecHistories.OpticsHour24fecHistory.OpticsHour24fecTimeLineInstances.OpticsHour24fecTimeLineInstance.Q, self).__init__()

                                                    self.yang_name = "q"
                                                    self.yang_parent_name = "optics-hour24fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.maximum_tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "q"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24fecHistories.OpticsHour24fecHistory.OpticsHour24fecTimeLineInstances.OpticsHour24fecTimeLineInstance.Q, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                            class Qmargin(Entity):
                                                """
                                                Q Margin
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24fecHistories.OpticsHour24fecHistory.OpticsHour24fecTimeLineInstances.OpticsHour24fecTimeLineInstance.Qmargin, self).__init__()

                                                    self.yang_name = "qmargin"
                                                    self.yang_parent_name = "optics-hour24fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.maximum_tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "qmargin"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24fecHistories.OpticsHour24fecHistory.OpticsHour24fecTimeLineInstances.OpticsHour24fecTimeLineInstance.Qmargin, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                        class OpticsSecond30History(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: optics_second30_optics_histories
                            
                            	port current performance data
                            	**type**\:  :py:class:`OpticsSecond30OpticsHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories>`
                            
                            .. attribute:: optics_second30fec_histories
                            
                            	port current performance data
                            	**type**\:  :py:class:`OpticsSecond30fecHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30fecHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History, self).__init__()

                                self.yang_name = "optics-second30-history"
                                self.yang_parent_name = "optics-port-history"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("optics-second30-optics-histories", ("optics_second30_optics_histories", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories)), ("optics-second30fec-histories", ("optics_second30fec_histories", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30fecHistories))])
                                self._leafs = OrderedDict()

                                self.optics_second30_optics_histories = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories()
                                self.optics_second30_optics_histories.parent = self
                                self._children_name_map["optics_second30_optics_histories"] = "optics-second30-optics-histories"

                                self.optics_second30fec_histories = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30fecHistories()
                                self.optics_second30fec_histories.parent = self
                                self._children_name_map["optics_second30fec_histories"] = "optics-second30fec-histories"
                                self._segment_path = lambda: "optics-second30-history"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History, [], name, value)


                            class OpticsSecond30OpticsHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: optics_second30_optics_history
                                
                                	port 30\-second optics performance data
                                	**type**\: list of  		 :py:class:`OpticsSecond30OpticsHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories, self).__init__()

                                    self.yang_name = "optics-second30-optics-histories"
                                    self.yang_parent_name = "optics-second30-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("optics-second30-optics-history", ("optics_second30_optics_history", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory))])
                                    self._leafs = OrderedDict()

                                    self.optics_second30_optics_history = YList(self)
                                    self._segment_path = lambda: "optics-second30-optics-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories, [], name, value)


                                class OpticsSecond30OpticsHistory(Entity):
                                    """
                                    port 30\-second optics performance data
                                    
                                    .. attribute:: number  (key)
                                    
                                    	channel number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: optics_second30_optics_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`OpticsSecond30OpticsTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory, self).__init__()

                                        self.yang_name = "optics-second30-optics-history"
                                        self.yang_parent_name = "optics-second30-optics-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([("optics-second30-optics-time-line-instances", ("optics_second30_optics_time_line_instances", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ])
                                        self.number = None

                                        self.optics_second30_optics_time_line_instances = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances()
                                        self.optics_second30_optics_time_line_instances.parent = self
                                        self._children_name_map["optics_second30_optics_time_line_instances"] = "optics-second30-optics-time-line-instances"
                                        self._segment_path = lambda: "optics-second30-optics-history" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory, ['number'], name, value)


                                    class OpticsSecond30OpticsTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: optics_second30_optics_time_line_instance
                                        
                                        	port 30 second otn performance data
                                        	**type**\: list of  		 :py:class:`OpticsSecond30OpticsTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances, self).__init__()

                                            self.yang_name = "optics-second30-optics-time-line-instances"
                                            self.yang_parent_name = "optics-second30-optics-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("optics-second30-optics-time-line-instance", ("optics_second30_optics_time_line_instance", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.optics_second30_optics_time_line_instance = YList(self)
                                            self._segment_path = lambda: "optics-second30-optics-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances, [], name, value)


                                        class OpticsSecond30OpticsTimeLineInstance(Entity):
                                            """
                                            port 30 second otn performance data
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lbc
                                            
                                            	LBC
                                            	**type**\:  :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Lbc>`
                                            
                                            .. attribute:: lbc_pc
                                            
                                            	LBC in percentage
                                            	**type**\:  :py:class:`LbcPc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.LbcPc>`
                                            
                                            .. attribute:: opt
                                            
                                            	OPT
                                            	**type**\:  :py:class:`Opt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Opt>`
                                            
                                            .. attribute:: opr
                                            
                                            	OPR
                                            	**type**\:  :py:class:`Opr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Opr>`
                                            
                                            .. attribute:: cd
                                            
                                            	Chromatic Dispersion
                                            	**type**\:  :py:class:`Cd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Cd>`
                                            
                                            .. attribute:: dgd
                                            
                                            	Differential group Delay
                                            	**type**\:  :py:class:`Dgd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Dgd>`
                                            
                                            .. attribute:: pmd
                                            
                                            	Polarization Mode Dispersion
                                            	**type**\:  :py:class:`Pmd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Pmd>`
                                            
                                            .. attribute:: osnr
                                            
                                            	Optical Signal to Noise Ratio
                                            	**type**\:  :py:class:`Osnr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Osnr>`
                                            
                                            .. attribute:: center_wavelength
                                            
                                            	Center Wavelength/Frequency
                                            	**type**\:  :py:class:`CenterWavelength <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.CenterWavelength>`
                                            
                                            .. attribute:: pdl
                                            
                                            	Polarization Dependent Loss
                                            	**type**\:  :py:class:`Pdl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Pdl>`
                                            
                                            .. attribute:: pcr
                                            
                                            	Polarization Change Rate
                                            	**type**\:  :py:class:`Pcr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Pcr>`
                                            
                                            .. attribute:: pn
                                            
                                            	Phase Noise
                                            	**type**\:  :py:class:`Pn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Pn>`
                                            
                                            .. attribute:: rx_sig_pow
                                            
                                            	Rx signal power
                                            	**type**\:  :py:class:`RxSigPow <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.RxSigPow>`
                                            
                                            .. attribute:: low_sig_freq_off
                                            
                                            	low freq sig off
                                            	**type**\:  :py:class:`LowSigFreqOff <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.LowSigFreqOff>`
                                            
                                            .. attribute:: ampli_gain
                                            
                                            	Ampli Gain
                                            	**type**\:  :py:class:`AmpliGain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.AmpliGain>`
                                            
                                            .. attribute:: ampli_gain_tilt
                                            
                                            	Ampli Gain Tilt
                                            	**type**\:  :py:class:`AmpliGainTilt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.AmpliGainTilt>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance, self).__init__()

                                                self.yang_name = "optics-second30-optics-time-line-instance"
                                                self.yang_parent_name = "optics-second30-optics-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("lbc", ("lbc", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Lbc)), ("lbc-pc", ("lbc_pc", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.LbcPc)), ("opt", ("opt", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Opt)), ("opr", ("opr", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Opr)), ("cd", ("cd", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Cd)), ("dgd", ("dgd", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Dgd)), ("pmd", ("pmd", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Pmd)), ("osnr", ("osnr", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Osnr)), ("center-wavelength", ("center_wavelength", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.CenterWavelength)), ("pdl", ("pdl", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Pdl)), ("pcr", ("pcr", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Pcr)), ("pn", ("pn", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Pn)), ("rx-sig-pow", ("rx_sig_pow", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.RxSigPow)), ("low-sig-freq-off", ("low_sig_freq_off", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.LowSigFreqOff)), ("ampli-gain", ("ampli_gain", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.AmpliGain)), ("ampli-gain-tilt", ("ampli_gain_tilt", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.AmpliGainTilt))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                    ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear24_hr_time = None
                                                self.sec30_support = None

                                                self.lbc = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Lbc()
                                                self.lbc.parent = self
                                                self._children_name_map["lbc"] = "lbc"

                                                self.lbc_pc = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.LbcPc()
                                                self.lbc_pc.parent = self
                                                self._children_name_map["lbc_pc"] = "lbc-pc"

                                                self.opt = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Opt()
                                                self.opt.parent = self
                                                self._children_name_map["opt"] = "opt"

                                                self.opr = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Opr()
                                                self.opr.parent = self
                                                self._children_name_map["opr"] = "opr"

                                                self.cd = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Cd()
                                                self.cd.parent = self
                                                self._children_name_map["cd"] = "cd"

                                                self.dgd = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Dgd()
                                                self.dgd.parent = self
                                                self._children_name_map["dgd"] = "dgd"

                                                self.pmd = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Pmd()
                                                self.pmd.parent = self
                                                self._children_name_map["pmd"] = "pmd"

                                                self.osnr = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Osnr()
                                                self.osnr.parent = self
                                                self._children_name_map["osnr"] = "osnr"

                                                self.center_wavelength = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.CenterWavelength()
                                                self.center_wavelength.parent = self
                                                self._children_name_map["center_wavelength"] = "center-wavelength"

                                                self.pdl = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Pdl()
                                                self.pdl.parent = self
                                                self._children_name_map["pdl"] = "pdl"

                                                self.pcr = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Pcr()
                                                self.pcr.parent = self
                                                self._children_name_map["pcr"] = "pcr"

                                                self.pn = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Pn()
                                                self.pn.parent = self
                                                self._children_name_map["pn"] = "pn"

                                                self.rx_sig_pow = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.RxSigPow()
                                                self.rx_sig_pow.parent = self
                                                self._children_name_map["rx_sig_pow"] = "rx-sig-pow"

                                                self.low_sig_freq_off = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.LowSigFreqOff()
                                                self.low_sig_freq_off.parent = self
                                                self._children_name_map["low_sig_freq_off"] = "low-sig-freq-off"

                                                self.ampli_gain = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.AmpliGain()
                                                self.ampli_gain.parent = self
                                                self._children_name_map["ampli_gain"] = "ampli-gain"

                                                self.ampli_gain_tilt = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.AmpliGainTilt()
                                                self.ampli_gain_tilt.parent = self
                                                self._children_name_map["ampli_gain_tilt"] = "ampli-gain-tilt"
                                                self._segment_path = lambda: "optics-second30-optics-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                            class Lbc(Entity):
                                                """
                                                LBC
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Lbc, self).__init__()

                                                    self.yang_name = "lbc"
                                                    self.yang_parent_name = "optics-second30-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.int32, 'minimum'), ['int'])),
                                                        ('average', (YLeaf(YType.int32, 'average'), ['int'])),
                                                        ('maximum', (YLeaf(YType.int32, 'maximum'), ['int'])),
                                                        ('minimum_threshold', (YLeaf(YType.int32, 'minimum-threshold'), ['int'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.int32, 'maximum-threshold'), ['int'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "lbc"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Lbc, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class LbcPc(Entity):
                                                """
                                                LBC in percentage
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.LbcPc, self).__init__()

                                                    self.yang_name = "lbc-pc"
                                                    self.yang_parent_name = "optics-second30-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "lbc-pc"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.LbcPc, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class Opt(Entity):
                                                """
                                                OPT
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Opt, self).__init__()

                                                    self.yang_name = "opt"
                                                    self.yang_parent_name = "optics-second30-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "opt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Opt, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class Opr(Entity):
                                                """
                                                OPR
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Opr, self).__init__()

                                                    self.yang_name = "opr"
                                                    self.yang_parent_name = "optics-second30-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "opr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Opr, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class Cd(Entity):
                                                """
                                                Chromatic Dispersion
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Cd, self).__init__()

                                                    self.yang_name = "cd"
                                                    self.yang_parent_name = "optics-second30-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.int32, 'minimum'), ['int'])),
                                                        ('average', (YLeaf(YType.int32, 'average'), ['int'])),
                                                        ('maximum', (YLeaf(YType.int32, 'maximum'), ['int'])),
                                                        ('minimum_threshold', (YLeaf(YType.int32, 'minimum-threshold'), ['int'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.int32, 'maximum-threshold'), ['int'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "cd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Cd, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class Dgd(Entity):
                                                """
                                                Differential group Delay
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Dgd, self).__init__()

                                                    self.yang_name = "dgd"
                                                    self.yang_parent_name = "optics-second30-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "dgd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Dgd, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class Pmd(Entity):
                                                """
                                                Polarization Mode Dispersion
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Pmd, self).__init__()

                                                    self.yang_name = "pmd"
                                                    self.yang_parent_name = "optics-second30-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "pmd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Pmd, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class Osnr(Entity):
                                                """
                                                Optical Signal to Noise Ratio
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Osnr, self).__init__()

                                                    self.yang_name = "osnr"
                                                    self.yang_parent_name = "optics-second30-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "osnr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Osnr, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class CenterWavelength(Entity):
                                                """
                                                Center Wavelength/Frequency
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.CenterWavelength, self).__init__()

                                                    self.yang_name = "center-wavelength"
                                                    self.yang_parent_name = "optics-second30-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "center-wavelength"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.CenterWavelength, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class Pdl(Entity):
                                                """
                                                Polarization Dependent Loss
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Pdl, self).__init__()

                                                    self.yang_name = "pdl"
                                                    self.yang_parent_name = "optics-second30-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "pdl"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Pdl, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class Pcr(Entity):
                                                """
                                                Polarization Change Rate
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Pcr, self).__init__()

                                                    self.yang_name = "pcr"
                                                    self.yang_parent_name = "optics-second30-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "pcr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Pcr, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class Pn(Entity):
                                                """
                                                Phase Noise
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Pn, self).__init__()

                                                    self.yang_name = "pn"
                                                    self.yang_parent_name = "optics-second30-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "pn"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Pn, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class RxSigPow(Entity):
                                                """
                                                Rx signal power
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.RxSigPow, self).__init__()

                                                    self.yang_name = "rx-sig-pow"
                                                    self.yang_parent_name = "optics-second30-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "rx-sig-pow"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.RxSigPow, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class LowSigFreqOff(Entity):
                                                """
                                                low freq sig off
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.LowSigFreqOff, self).__init__()

                                                    self.yang_name = "low-sig-freq-off"
                                                    self.yang_parent_name = "optics-second30-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.int32, 'minimum'), ['int'])),
                                                        ('average', (YLeaf(YType.int32, 'average'), ['int'])),
                                                        ('maximum', (YLeaf(YType.int32, 'maximum'), ['int'])),
                                                        ('minimum_threshold', (YLeaf(YType.int32, 'minimum-threshold'), ['int'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.int32, 'maximum-threshold'), ['int'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "low-sig-freq-off"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.LowSigFreqOff, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class AmpliGain(Entity):
                                                """
                                                Ampli Gain
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.AmpliGain, self).__init__()

                                                    self.yang_name = "ampli-gain"
                                                    self.yang_parent_name = "optics-second30-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "ampli-gain"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.AmpliGain, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class AmpliGainTilt(Entity):
                                                """
                                                Ampli Gain Tilt
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.AmpliGainTilt, self).__init__()

                                                    self.yang_name = "ampli-gain-tilt"
                                                    self.yang_parent_name = "optics-second30-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "ampli-gain-tilt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.AmpliGainTilt, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                            class OpticsSecond30fecHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: optics_second30fec_history
                                
                                	port 30\-second fec performance data
                                	**type**\: list of  		 :py:class:`OpticsSecond30fecHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30fecHistories.OpticsSecond30fecHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30fecHistories, self).__init__()

                                    self.yang_name = "optics-second30fec-histories"
                                    self.yang_parent_name = "optics-second30-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("optics-second30fec-history", ("optics_second30fec_history", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30fecHistories.OpticsSecond30fecHistory))])
                                    self._leafs = OrderedDict()

                                    self.optics_second30fec_history = YList(self)
                                    self._segment_path = lambda: "optics-second30fec-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30fecHistories, [], name, value)


                                class OpticsSecond30fecHistory(Entity):
                                    """
                                    port 30\-second fec performance data
                                    
                                    .. attribute:: number  (key)
                                    
                                    	channel number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: optics_second30fec_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`OpticsSecond30fecTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30fecHistories.OpticsSecond30fecHistory.OpticsSecond30fecTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30fecHistories.OpticsSecond30fecHistory, self).__init__()

                                        self.yang_name = "optics-second30fec-history"
                                        self.yang_parent_name = "optics-second30fec-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([("optics-second30fec-time-line-instances", ("optics_second30fec_time_line_instances", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30fecHistories.OpticsSecond30fecHistory.OpticsSecond30fecTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ])
                                        self.number = None

                                        self.optics_second30fec_time_line_instances = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30fecHistories.OpticsSecond30fecHistory.OpticsSecond30fecTimeLineInstances()
                                        self.optics_second30fec_time_line_instances.parent = self
                                        self._children_name_map["optics_second30fec_time_line_instances"] = "optics-second30fec-time-line-instances"
                                        self._segment_path = lambda: "optics-second30fec-history" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30fecHistories.OpticsSecond30fecHistory, ['number'], name, value)


                                    class OpticsSecond30fecTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: optics_second30fec_time_line_instance
                                        
                                        	port sec\-30 fec performance data
                                        	**type**\: list of  		 :py:class:`OpticsSecond30fecTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30fecHistories.OpticsSecond30fecHistory.OpticsSecond30fecTimeLineInstances.OpticsSecond30fecTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30fecHistories.OpticsSecond30fecHistory.OpticsSecond30fecTimeLineInstances, self).__init__()

                                            self.yang_name = "optics-second30fec-time-line-instances"
                                            self.yang_parent_name = "optics-second30fec-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("optics-second30fec-time-line-instance", ("optics_second30fec_time_line_instance", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30fecHistories.OpticsSecond30fecHistory.OpticsSecond30fecTimeLineInstances.OpticsSecond30fecTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.optics_second30fec_time_line_instance = YList(self)
                                            self._segment_path = lambda: "optics-second30fec-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30fecHistories.OpticsSecond30fecHistory.OpticsSecond30fecTimeLineInstances, [], name, value)


                                        class OpticsSecond30fecTimeLineInstance(Entity):
                                            """
                                            port sec\-30 fec performance data
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ec_bits
                                            
                                            	EC BITS
                                            	**type**\:  :py:class:`EcBits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30fecHistories.OpticsSecond30fecHistory.OpticsSecond30fecTimeLineInstances.OpticsSecond30fecTimeLineInstance.EcBits>`
                                            
                                            .. attribute:: uc_words
                                            
                                            	UC WORDS
                                            	**type**\:  :py:class:`UcWords <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30fecHistories.OpticsSecond30fecHistory.OpticsSecond30fecTimeLineInstances.OpticsSecond30fecTimeLineInstance.UcWords>`
                                            
                                            .. attribute:: pre_fec_ber
                                            
                                            	Pre FEC BER
                                            	**type**\:  :py:class:`PreFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30fecHistories.OpticsSecond30fecHistory.OpticsSecond30fecTimeLineInstances.OpticsSecond30fecTimeLineInstance.PreFecBer>`
                                            
                                            .. attribute:: post_fec_ber
                                            
                                            	Post FEC BER
                                            	**type**\:  :py:class:`PostFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30fecHistories.OpticsSecond30fecHistory.OpticsSecond30fecTimeLineInstances.OpticsSecond30fecTimeLineInstance.PostFecBer>`
                                            
                                            .. attribute:: q
                                            
                                            	Q
                                            	**type**\:  :py:class:`Q <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30fecHistories.OpticsSecond30fecHistory.OpticsSecond30fecTimeLineInstances.OpticsSecond30fecTimeLineInstance.Q>`
                                            
                                            .. attribute:: qmargin
                                            
                                            	Q Margin
                                            	**type**\:  :py:class:`Qmargin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30fecHistories.OpticsSecond30fecHistory.OpticsSecond30fecTimeLineInstances.OpticsSecond30fecTimeLineInstance.Qmargin>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30fecHistories.OpticsSecond30fecHistory.OpticsSecond30fecTimeLineInstances.OpticsSecond30fecTimeLineInstance, self).__init__()

                                                self.yang_name = "optics-second30fec-time-line-instance"
                                                self.yang_parent_name = "optics-second30fec-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("ec-bits", ("ec_bits", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30fecHistories.OpticsSecond30fecHistory.OpticsSecond30fecTimeLineInstances.OpticsSecond30fecTimeLineInstance.EcBits)), ("uc-words", ("uc_words", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30fecHistories.OpticsSecond30fecHistory.OpticsSecond30fecTimeLineInstances.OpticsSecond30fecTimeLineInstance.UcWords)), ("pre-fec-ber", ("pre_fec_ber", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30fecHistories.OpticsSecond30fecHistory.OpticsSecond30fecTimeLineInstances.OpticsSecond30fecTimeLineInstance.PreFecBer)), ("post-fec-ber", ("post_fec_ber", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30fecHistories.OpticsSecond30fecHistory.OpticsSecond30fecTimeLineInstances.OpticsSecond30fecTimeLineInstance.PostFecBer)), ("q", ("q", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30fecHistories.OpticsSecond30fecHistory.OpticsSecond30fecTimeLineInstances.OpticsSecond30fecTimeLineInstance.Q)), ("qmargin", ("qmargin", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30fecHistories.OpticsSecond30fecHistory.OpticsSecond30fecTimeLineInstances.OpticsSecond30fecTimeLineInstance.Qmargin))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                    ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear24_hr_time = None
                                                self.sec30_support = None

                                                self.ec_bits = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30fecHistories.OpticsSecond30fecHistory.OpticsSecond30fecTimeLineInstances.OpticsSecond30fecTimeLineInstance.EcBits()
                                                self.ec_bits.parent = self
                                                self._children_name_map["ec_bits"] = "ec-bits"

                                                self.uc_words = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30fecHistories.OpticsSecond30fecHistory.OpticsSecond30fecTimeLineInstances.OpticsSecond30fecTimeLineInstance.UcWords()
                                                self.uc_words.parent = self
                                                self._children_name_map["uc_words"] = "uc-words"

                                                self.pre_fec_ber = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30fecHistories.OpticsSecond30fecHistory.OpticsSecond30fecTimeLineInstances.OpticsSecond30fecTimeLineInstance.PreFecBer()
                                                self.pre_fec_ber.parent = self
                                                self._children_name_map["pre_fec_ber"] = "pre-fec-ber"

                                                self.post_fec_ber = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30fecHistories.OpticsSecond30fecHistory.OpticsSecond30fecTimeLineInstances.OpticsSecond30fecTimeLineInstance.PostFecBer()
                                                self.post_fec_ber.parent = self
                                                self._children_name_map["post_fec_ber"] = "post-fec-ber"

                                                self.q = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30fecHistories.OpticsSecond30fecHistory.OpticsSecond30fecTimeLineInstances.OpticsSecond30fecTimeLineInstance.Q()
                                                self.q.parent = self
                                                self._children_name_map["q"] = "q"

                                                self.qmargin = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30fecHistories.OpticsSecond30fecHistory.OpticsSecond30fecTimeLineInstances.OpticsSecond30fecTimeLineInstance.Qmargin()
                                                self.qmargin.parent = self
                                                self._children_name_map["qmargin"] = "qmargin"
                                                self._segment_path = lambda: "optics-second30fec-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30fecHistories.OpticsSecond30fecHistory.OpticsSecond30fecTimeLineInstances.OpticsSecond30fecTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                            class EcBits(Entity):
                                                """
                                                EC BITS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30fecHistories.OpticsSecond30fecHistory.OpticsSecond30fecTimeLineInstances.OpticsSecond30fecTimeLineInstance.EcBits, self).__init__()

                                                    self.yang_name = "ec-bits"
                                                    self.yang_parent_name = "optics-second30fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ec-bits"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30fecHistories.OpticsSecond30fecHistory.OpticsSecond30fecTimeLineInstances.OpticsSecond30fecTimeLineInstance.EcBits, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class UcWords(Entity):
                                                """
                                                UC WORDS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30fecHistories.OpticsSecond30fecHistory.OpticsSecond30fecTimeLineInstances.OpticsSecond30fecTimeLineInstance.UcWords, self).__init__()

                                                    self.yang_name = "uc-words"
                                                    self.yang_parent_name = "optics-second30fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "uc-words"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30fecHistories.OpticsSecond30fecHistory.OpticsSecond30fecTimeLineInstances.OpticsSecond30fecTimeLineInstance.UcWords, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class PreFecBer(Entity):
                                                """
                                                Pre FEC BER
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30fecHistories.OpticsSecond30fecHistory.OpticsSecond30fecTimeLineInstances.OpticsSecond30fecTimeLineInstance.PreFecBer, self).__init__()

                                                    self.yang_name = "pre-fec-ber"
                                                    self.yang_parent_name = "optics-second30fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.maximum_tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "pre-fec-ber"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30fecHistories.OpticsSecond30fecHistory.OpticsSecond30fecTimeLineInstances.OpticsSecond30fecTimeLineInstance.PreFecBer, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                            class PostFecBer(Entity):
                                                """
                                                Post FEC BER
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30fecHistories.OpticsSecond30fecHistory.OpticsSecond30fecTimeLineInstances.OpticsSecond30fecTimeLineInstance.PostFecBer, self).__init__()

                                                    self.yang_name = "post-fec-ber"
                                                    self.yang_parent_name = "optics-second30fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.maximum_tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "post-fec-ber"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30fecHistories.OpticsSecond30fecHistory.OpticsSecond30fecTimeLineInstances.OpticsSecond30fecTimeLineInstance.PostFecBer, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                            class Q(Entity):
                                                """
                                                Q
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30fecHistories.OpticsSecond30fecHistory.OpticsSecond30fecTimeLineInstances.OpticsSecond30fecTimeLineInstance.Q, self).__init__()

                                                    self.yang_name = "q"
                                                    self.yang_parent_name = "optics-second30fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.maximum_tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "q"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30fecHistories.OpticsSecond30fecHistory.OpticsSecond30fecTimeLineInstances.OpticsSecond30fecTimeLineInstance.Q, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                            class Qmargin(Entity):
                                                """
                                                Q Margin
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30fecHistories.OpticsSecond30fecHistory.OpticsSecond30fecTimeLineInstances.OpticsSecond30fecTimeLineInstance.Qmargin, self).__init__()

                                                    self.yang_name = "qmargin"
                                                    self.yang_parent_name = "optics-second30fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.maximum_tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "qmargin"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30fecHistories.OpticsSecond30fecHistory.OpticsSecond30fecTimeLineInstances.OpticsSecond30fecTimeLineInstance.Qmargin, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                        class OpticsMinute15History(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: optics_minute15_optics_histories
                            
                            	port current performance data
                            	**type**\:  :py:class:`OpticsMinute15OpticsHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories>`
                            
                            .. attribute:: optics_minute15fec_histories
                            
                            	port current performance data
                            	**type**\:  :py:class:`OpticsMinute15fecHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15fecHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History, self).__init__()

                                self.yang_name = "optics-minute15-history"
                                self.yang_parent_name = "optics-port-history"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("optics-minute15-optics-histories", ("optics_minute15_optics_histories", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories)), ("optics-minute15fec-histories", ("optics_minute15fec_histories", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15fecHistories))])
                                self._leafs = OrderedDict()

                                self.optics_minute15_optics_histories = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories()
                                self.optics_minute15_optics_histories.parent = self
                                self._children_name_map["optics_minute15_optics_histories"] = "optics-minute15-optics-histories"

                                self.optics_minute15fec_histories = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15fecHistories()
                                self.optics_minute15fec_histories.parent = self
                                self._children_name_map["optics_minute15fec_histories"] = "optics-minute15fec-histories"
                                self._segment_path = lambda: "optics-minute15-history"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History, [], name, value)


                            class OpticsMinute15OpticsHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: optics_minute15_optics_history
                                
                                	port 15\-minute optics performance data
                                	**type**\: list of  		 :py:class:`OpticsMinute15OpticsHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories, self).__init__()

                                    self.yang_name = "optics-minute15-optics-histories"
                                    self.yang_parent_name = "optics-minute15-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("optics-minute15-optics-history", ("optics_minute15_optics_history", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory))])
                                    self._leafs = OrderedDict()

                                    self.optics_minute15_optics_history = YList(self)
                                    self._segment_path = lambda: "optics-minute15-optics-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories, [], name, value)


                                class OpticsMinute15OpticsHistory(Entity):
                                    """
                                    port 15\-minute optics performance data
                                    
                                    .. attribute:: number  (key)
                                    
                                    	channel number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: optics_minute15_optics_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`OpticsMinute15OpticsTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory, self).__init__()

                                        self.yang_name = "optics-minute15-optics-history"
                                        self.yang_parent_name = "optics-minute15-optics-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([("optics-minute15-optics-time-line-instances", ("optics_minute15_optics_time_line_instances", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ])
                                        self.number = None

                                        self.optics_minute15_optics_time_line_instances = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances()
                                        self.optics_minute15_optics_time_line_instances.parent = self
                                        self._children_name_map["optics_minute15_optics_time_line_instances"] = "optics-minute15-optics-time-line-instances"
                                        self._segment_path = lambda: "optics-minute15-optics-history" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory, ['number'], name, value)


                                    class OpticsMinute15OpticsTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: optics_minute15_optics_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of  		 :py:class:`OpticsMinute15OpticsTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances, self).__init__()

                                            self.yang_name = "optics-minute15-optics-time-line-instances"
                                            self.yang_parent_name = "optics-minute15-optics-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("optics-minute15-optics-time-line-instance", ("optics_minute15_optics_time_line_instance", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.optics_minute15_optics_time_line_instance = YList(self)
                                            self._segment_path = lambda: "optics-minute15-optics-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances, [], name, value)


                                        class OpticsMinute15OpticsTimeLineInstance(Entity):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lbc
                                            
                                            	LBC
                                            	**type**\:  :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Lbc>`
                                            
                                            .. attribute:: lbc_pc
                                            
                                            	LBC in percentage
                                            	**type**\:  :py:class:`LbcPc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.LbcPc>`
                                            
                                            .. attribute:: opt
                                            
                                            	OPT
                                            	**type**\:  :py:class:`Opt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Opt>`
                                            
                                            .. attribute:: opr
                                            
                                            	OPR
                                            	**type**\:  :py:class:`Opr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Opr>`
                                            
                                            .. attribute:: cd
                                            
                                            	Chromatic Dispersion
                                            	**type**\:  :py:class:`Cd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Cd>`
                                            
                                            .. attribute:: dgd
                                            
                                            	Differential group Delay
                                            	**type**\:  :py:class:`Dgd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Dgd>`
                                            
                                            .. attribute:: pmd
                                            
                                            	Polarization Mode Dispersion
                                            	**type**\:  :py:class:`Pmd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Pmd>`
                                            
                                            .. attribute:: osnr
                                            
                                            	Optical Signal to Noise Ratio
                                            	**type**\:  :py:class:`Osnr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Osnr>`
                                            
                                            .. attribute:: center_wavelength
                                            
                                            	Center Wavelength/Frequency
                                            	**type**\:  :py:class:`CenterWavelength <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.CenterWavelength>`
                                            
                                            .. attribute:: pdl
                                            
                                            	Polarization Dependent Loss
                                            	**type**\:  :py:class:`Pdl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Pdl>`
                                            
                                            .. attribute:: pcr
                                            
                                            	Polarization Change Rate
                                            	**type**\:  :py:class:`Pcr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Pcr>`
                                            
                                            .. attribute:: pn
                                            
                                            	Phase Noise
                                            	**type**\:  :py:class:`Pn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Pn>`
                                            
                                            .. attribute:: rx_sig_pow
                                            
                                            	Rx signal power
                                            	**type**\:  :py:class:`RxSigPow <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.RxSigPow>`
                                            
                                            .. attribute:: low_sig_freq_off
                                            
                                            	low freq sig off
                                            	**type**\:  :py:class:`LowSigFreqOff <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.LowSigFreqOff>`
                                            
                                            .. attribute:: ampli_gain
                                            
                                            	Ampli Gain
                                            	**type**\:  :py:class:`AmpliGain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.AmpliGain>`
                                            
                                            .. attribute:: ampli_gain_tilt
                                            
                                            	Ampli Gain Tilt
                                            	**type**\:  :py:class:`AmpliGainTilt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.AmpliGainTilt>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance, self).__init__()

                                                self.yang_name = "optics-minute15-optics-time-line-instance"
                                                self.yang_parent_name = "optics-minute15-optics-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("lbc", ("lbc", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Lbc)), ("lbc-pc", ("lbc_pc", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.LbcPc)), ("opt", ("opt", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Opt)), ("opr", ("opr", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Opr)), ("cd", ("cd", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Cd)), ("dgd", ("dgd", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Dgd)), ("pmd", ("pmd", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Pmd)), ("osnr", ("osnr", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Osnr)), ("center-wavelength", ("center_wavelength", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.CenterWavelength)), ("pdl", ("pdl", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Pdl)), ("pcr", ("pcr", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Pcr)), ("pn", ("pn", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Pn)), ("rx-sig-pow", ("rx_sig_pow", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.RxSigPow)), ("low-sig-freq-off", ("low_sig_freq_off", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.LowSigFreqOff)), ("ampli-gain", ("ampli_gain", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.AmpliGain)), ("ampli-gain-tilt", ("ampli_gain_tilt", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.AmpliGainTilt))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                    ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear24_hr_time = None
                                                self.sec30_support = None

                                                self.lbc = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Lbc()
                                                self.lbc.parent = self
                                                self._children_name_map["lbc"] = "lbc"

                                                self.lbc_pc = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.LbcPc()
                                                self.lbc_pc.parent = self
                                                self._children_name_map["lbc_pc"] = "lbc-pc"

                                                self.opt = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Opt()
                                                self.opt.parent = self
                                                self._children_name_map["opt"] = "opt"

                                                self.opr = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Opr()
                                                self.opr.parent = self
                                                self._children_name_map["opr"] = "opr"

                                                self.cd = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Cd()
                                                self.cd.parent = self
                                                self._children_name_map["cd"] = "cd"

                                                self.dgd = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Dgd()
                                                self.dgd.parent = self
                                                self._children_name_map["dgd"] = "dgd"

                                                self.pmd = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Pmd()
                                                self.pmd.parent = self
                                                self._children_name_map["pmd"] = "pmd"

                                                self.osnr = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Osnr()
                                                self.osnr.parent = self
                                                self._children_name_map["osnr"] = "osnr"

                                                self.center_wavelength = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.CenterWavelength()
                                                self.center_wavelength.parent = self
                                                self._children_name_map["center_wavelength"] = "center-wavelength"

                                                self.pdl = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Pdl()
                                                self.pdl.parent = self
                                                self._children_name_map["pdl"] = "pdl"

                                                self.pcr = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Pcr()
                                                self.pcr.parent = self
                                                self._children_name_map["pcr"] = "pcr"

                                                self.pn = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Pn()
                                                self.pn.parent = self
                                                self._children_name_map["pn"] = "pn"

                                                self.rx_sig_pow = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.RxSigPow()
                                                self.rx_sig_pow.parent = self
                                                self._children_name_map["rx_sig_pow"] = "rx-sig-pow"

                                                self.low_sig_freq_off = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.LowSigFreqOff()
                                                self.low_sig_freq_off.parent = self
                                                self._children_name_map["low_sig_freq_off"] = "low-sig-freq-off"

                                                self.ampli_gain = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.AmpliGain()
                                                self.ampli_gain.parent = self
                                                self._children_name_map["ampli_gain"] = "ampli-gain"

                                                self.ampli_gain_tilt = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.AmpliGainTilt()
                                                self.ampli_gain_tilt.parent = self
                                                self._children_name_map["ampli_gain_tilt"] = "ampli-gain-tilt"
                                                self._segment_path = lambda: "optics-minute15-optics-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                            class Lbc(Entity):
                                                """
                                                LBC
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Lbc, self).__init__()

                                                    self.yang_name = "lbc"
                                                    self.yang_parent_name = "optics-minute15-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.int32, 'minimum'), ['int'])),
                                                        ('average', (YLeaf(YType.int32, 'average'), ['int'])),
                                                        ('maximum', (YLeaf(YType.int32, 'maximum'), ['int'])),
                                                        ('minimum_threshold', (YLeaf(YType.int32, 'minimum-threshold'), ['int'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.int32, 'maximum-threshold'), ['int'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "lbc"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Lbc, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class LbcPc(Entity):
                                                """
                                                LBC in percentage
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.LbcPc, self).__init__()

                                                    self.yang_name = "lbc-pc"
                                                    self.yang_parent_name = "optics-minute15-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "lbc-pc"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.LbcPc, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class Opt(Entity):
                                                """
                                                OPT
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Opt, self).__init__()

                                                    self.yang_name = "opt"
                                                    self.yang_parent_name = "optics-minute15-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "opt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Opt, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class Opr(Entity):
                                                """
                                                OPR
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Opr, self).__init__()

                                                    self.yang_name = "opr"
                                                    self.yang_parent_name = "optics-minute15-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "opr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Opr, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class Cd(Entity):
                                                """
                                                Chromatic Dispersion
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Cd, self).__init__()

                                                    self.yang_name = "cd"
                                                    self.yang_parent_name = "optics-minute15-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.int32, 'minimum'), ['int'])),
                                                        ('average', (YLeaf(YType.int32, 'average'), ['int'])),
                                                        ('maximum', (YLeaf(YType.int32, 'maximum'), ['int'])),
                                                        ('minimum_threshold', (YLeaf(YType.int32, 'minimum-threshold'), ['int'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.int32, 'maximum-threshold'), ['int'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "cd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Cd, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class Dgd(Entity):
                                                """
                                                Differential group Delay
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Dgd, self).__init__()

                                                    self.yang_name = "dgd"
                                                    self.yang_parent_name = "optics-minute15-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "dgd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Dgd, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class Pmd(Entity):
                                                """
                                                Polarization Mode Dispersion
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Pmd, self).__init__()

                                                    self.yang_name = "pmd"
                                                    self.yang_parent_name = "optics-minute15-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "pmd"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Pmd, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class Osnr(Entity):
                                                """
                                                Optical Signal to Noise Ratio
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Osnr, self).__init__()

                                                    self.yang_name = "osnr"
                                                    self.yang_parent_name = "optics-minute15-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "osnr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Osnr, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class CenterWavelength(Entity):
                                                """
                                                Center Wavelength/Frequency
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.CenterWavelength, self).__init__()

                                                    self.yang_name = "center-wavelength"
                                                    self.yang_parent_name = "optics-minute15-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "center-wavelength"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.CenterWavelength, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class Pdl(Entity):
                                                """
                                                Polarization Dependent Loss
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Pdl, self).__init__()

                                                    self.yang_name = "pdl"
                                                    self.yang_parent_name = "optics-minute15-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "pdl"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Pdl, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class Pcr(Entity):
                                                """
                                                Polarization Change Rate
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Pcr, self).__init__()

                                                    self.yang_name = "pcr"
                                                    self.yang_parent_name = "optics-minute15-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "pcr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Pcr, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class Pn(Entity):
                                                """
                                                Phase Noise
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Pn, self).__init__()

                                                    self.yang_name = "pn"
                                                    self.yang_parent_name = "optics-minute15-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "pn"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Pn, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class RxSigPow(Entity):
                                                """
                                                Rx signal power
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.RxSigPow, self).__init__()

                                                    self.yang_name = "rx-sig-pow"
                                                    self.yang_parent_name = "optics-minute15-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "rx-sig-pow"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.RxSigPow, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class LowSigFreqOff(Entity):
                                                """
                                                low freq sig off
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.LowSigFreqOff, self).__init__()

                                                    self.yang_name = "low-sig-freq-off"
                                                    self.yang_parent_name = "optics-minute15-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.int32, 'minimum'), ['int'])),
                                                        ('average', (YLeaf(YType.int32, 'average'), ['int'])),
                                                        ('maximum', (YLeaf(YType.int32, 'maximum'), ['int'])),
                                                        ('minimum_threshold', (YLeaf(YType.int32, 'minimum-threshold'), ['int'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.int32, 'maximum-threshold'), ['int'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "low-sig-freq-off"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.LowSigFreqOff, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class AmpliGain(Entity):
                                                """
                                                Ampli Gain
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.AmpliGain, self).__init__()

                                                    self.yang_name = "ampli-gain"
                                                    self.yang_parent_name = "optics-minute15-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "ampli-gain"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.AmpliGain, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                                            class AmpliGainTilt(Entity):
                                                """
                                                Ampli Gain Tilt
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_min_thresh
                                                
                                                	minimunthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: configured_max_thresh
                                                
                                                	maximumthreshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.AmpliGainTilt, self).__init__()

                                                    self.yang_name = "ampli-gain-tilt"
                                                    self.yang_parent_name = "optics-minute15-optics-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('configured_min_thresh', (YLeaf(YType.str, 'configured-min-thresh'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('configured_max_thresh', (YLeaf(YType.str, 'configured-max-thresh'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                    ])
                                                    self.valid = None
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.configured_min_thresh = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.configured_max_thresh = None
                                                    self.maximum_tca_report = None
                                                    self._segment_path = lambda: "ampli-gain-tilt"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.AmpliGainTilt, ['valid', 'minimum', 'average', 'maximum', 'minimum_threshold', 'configured_min_thresh', 'minimum_tca_report', 'maximum_threshold', 'configured_max_thresh', 'maximum_tca_report'], name, value)


                            class OpticsMinute15fecHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: optics_minute15fec_history
                                
                                	port 15\-minute fec performance data
                                	**type**\: list of  		 :py:class:`OpticsMinute15fecHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15fecHistories.OpticsMinute15fecHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15fecHistories, self).__init__()

                                    self.yang_name = "optics-minute15fec-histories"
                                    self.yang_parent_name = "optics-minute15-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("optics-minute15fec-history", ("optics_minute15fec_history", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15fecHistories.OpticsMinute15fecHistory))])
                                    self._leafs = OrderedDict()

                                    self.optics_minute15fec_history = YList(self)
                                    self._segment_path = lambda: "optics-minute15fec-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15fecHistories, [], name, value)


                                class OpticsMinute15fecHistory(Entity):
                                    """
                                    port 15\-minute fec performance data
                                    
                                    .. attribute:: number  (key)
                                    
                                    	channel number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: optics_minute15fec_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`OpticsMinute15fecTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15fecHistories.OpticsMinute15fecHistory.OpticsMinute15fecTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15fecHistories.OpticsMinute15fecHistory, self).__init__()

                                        self.yang_name = "optics-minute15fec-history"
                                        self.yang_parent_name = "optics-minute15fec-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([("optics-minute15fec-time-line-instances", ("optics_minute15fec_time_line_instances", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15fecHistories.OpticsMinute15fecHistory.OpticsMinute15fecTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ])
                                        self.number = None

                                        self.optics_minute15fec_time_line_instances = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15fecHistories.OpticsMinute15fecHistory.OpticsMinute15fecTimeLineInstances()
                                        self.optics_minute15fec_time_line_instances.parent = self
                                        self._children_name_map["optics_minute15fec_time_line_instances"] = "optics-minute15fec-time-line-instances"
                                        self._segment_path = lambda: "optics-minute15fec-history" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15fecHistories.OpticsMinute15fecHistory, ['number'], name, value)


                                    class OpticsMinute15fecTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: optics_minute15fec_time_line_instance
                                        
                                        	port 15\-minute fec performance data
                                        	**type**\: list of  		 :py:class:`OpticsMinute15fecTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15fecHistories.OpticsMinute15fecHistory.OpticsMinute15fecTimeLineInstances.OpticsMinute15fecTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15fecHistories.OpticsMinute15fecHistory.OpticsMinute15fecTimeLineInstances, self).__init__()

                                            self.yang_name = "optics-minute15fec-time-line-instances"
                                            self.yang_parent_name = "optics-minute15fec-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("optics-minute15fec-time-line-instance", ("optics_minute15fec_time_line_instance", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15fecHistories.OpticsMinute15fecHistory.OpticsMinute15fecTimeLineInstances.OpticsMinute15fecTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.optics_minute15fec_time_line_instance = YList(self)
                                            self._segment_path = lambda: "optics-minute15fec-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15fecHistories.OpticsMinute15fecHistory.OpticsMinute15fecTimeLineInstances, [], name, value)


                                        class OpticsMinute15fecTimeLineInstance(Entity):
                                            """
                                            port 15\-minute fec performance data
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ec_bits
                                            
                                            	EC BITS
                                            	**type**\:  :py:class:`EcBits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15fecHistories.OpticsMinute15fecHistory.OpticsMinute15fecTimeLineInstances.OpticsMinute15fecTimeLineInstance.EcBits>`
                                            
                                            .. attribute:: uc_words
                                            
                                            	UC WORDS
                                            	**type**\:  :py:class:`UcWords <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15fecHistories.OpticsMinute15fecHistory.OpticsMinute15fecTimeLineInstances.OpticsMinute15fecTimeLineInstance.UcWords>`
                                            
                                            .. attribute:: pre_fec_ber
                                            
                                            	Pre FEC BER
                                            	**type**\:  :py:class:`PreFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15fecHistories.OpticsMinute15fecHistory.OpticsMinute15fecTimeLineInstances.OpticsMinute15fecTimeLineInstance.PreFecBer>`
                                            
                                            .. attribute:: post_fec_ber
                                            
                                            	Post FEC BER
                                            	**type**\:  :py:class:`PostFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15fecHistories.OpticsMinute15fecHistory.OpticsMinute15fecTimeLineInstances.OpticsMinute15fecTimeLineInstance.PostFecBer>`
                                            
                                            .. attribute:: q
                                            
                                            	Q
                                            	**type**\:  :py:class:`Q <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15fecHistories.OpticsMinute15fecHistory.OpticsMinute15fecTimeLineInstances.OpticsMinute15fecTimeLineInstance.Q>`
                                            
                                            .. attribute:: qmargin
                                            
                                            	Q Margin
                                            	**type**\:  :py:class:`Qmargin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15fecHistories.OpticsMinute15fecHistory.OpticsMinute15fecTimeLineInstances.OpticsMinute15fecTimeLineInstance.Qmargin>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15fecHistories.OpticsMinute15fecHistory.OpticsMinute15fecTimeLineInstances.OpticsMinute15fecTimeLineInstance, self).__init__()

                                                self.yang_name = "optics-minute15fec-time-line-instance"
                                                self.yang_parent_name = "optics-minute15fec-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("ec-bits", ("ec_bits", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15fecHistories.OpticsMinute15fecHistory.OpticsMinute15fecTimeLineInstances.OpticsMinute15fecTimeLineInstance.EcBits)), ("uc-words", ("uc_words", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15fecHistories.OpticsMinute15fecHistory.OpticsMinute15fecTimeLineInstances.OpticsMinute15fecTimeLineInstance.UcWords)), ("pre-fec-ber", ("pre_fec_ber", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15fecHistories.OpticsMinute15fecHistory.OpticsMinute15fecTimeLineInstances.OpticsMinute15fecTimeLineInstance.PreFecBer)), ("post-fec-ber", ("post_fec_ber", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15fecHistories.OpticsMinute15fecHistory.OpticsMinute15fecTimeLineInstances.OpticsMinute15fecTimeLineInstance.PostFecBer)), ("q", ("q", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15fecHistories.OpticsMinute15fecHistory.OpticsMinute15fecTimeLineInstances.OpticsMinute15fecTimeLineInstance.Q)), ("qmargin", ("qmargin", PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15fecHistories.OpticsMinute15fecHistory.OpticsMinute15fecTimeLineInstances.OpticsMinute15fecTimeLineInstance.Qmargin))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear30_sec_time', (YLeaf(YType.str, 'last-clear30-sec-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                    ('sec30_support', (YLeaf(YType.boolean, 'sec30-support'), ['bool'])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear24_hr_time = None
                                                self.sec30_support = None

                                                self.ec_bits = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15fecHistories.OpticsMinute15fecHistory.OpticsMinute15fecTimeLineInstances.OpticsMinute15fecTimeLineInstance.EcBits()
                                                self.ec_bits.parent = self
                                                self._children_name_map["ec_bits"] = "ec-bits"

                                                self.uc_words = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15fecHistories.OpticsMinute15fecHistory.OpticsMinute15fecTimeLineInstances.OpticsMinute15fecTimeLineInstance.UcWords()
                                                self.uc_words.parent = self
                                                self._children_name_map["uc_words"] = "uc-words"

                                                self.pre_fec_ber = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15fecHistories.OpticsMinute15fecHistory.OpticsMinute15fecTimeLineInstances.OpticsMinute15fecTimeLineInstance.PreFecBer()
                                                self.pre_fec_ber.parent = self
                                                self._children_name_map["pre_fec_ber"] = "pre-fec-ber"

                                                self.post_fec_ber = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15fecHistories.OpticsMinute15fecHistory.OpticsMinute15fecTimeLineInstances.OpticsMinute15fecTimeLineInstance.PostFecBer()
                                                self.post_fec_ber.parent = self
                                                self._children_name_map["post_fec_ber"] = "post-fec-ber"

                                                self.q = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15fecHistories.OpticsMinute15fecHistory.OpticsMinute15fecTimeLineInstances.OpticsMinute15fecTimeLineInstance.Q()
                                                self.q.parent = self
                                                self._children_name_map["q"] = "q"

                                                self.qmargin = PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15fecHistories.OpticsMinute15fecHistory.OpticsMinute15fecTimeLineInstances.OpticsMinute15fecTimeLineInstance.Qmargin()
                                                self.qmargin.parent = self
                                                self._children_name_map["qmargin"] = "qmargin"
                                                self._segment_path = lambda: "optics-minute15fec-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15fecHistories.OpticsMinute15fecHistory.OpticsMinute15fecTimeLineInstances.OpticsMinute15fecTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear30_sec_time', 'last_clear24_hr_time', 'sec30_support'], name, value)


                                            class EcBits(Entity):
                                                """
                                                EC BITS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15fecHistories.OpticsMinute15fecHistory.OpticsMinute15fecTimeLineInstances.OpticsMinute15fecTimeLineInstance.EcBits, self).__init__()

                                                    self.yang_name = "ec-bits"
                                                    self.yang_parent_name = "optics-minute15fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "ec-bits"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15fecHistories.OpticsMinute15fecHistory.OpticsMinute15fecTimeLineInstances.OpticsMinute15fecTimeLineInstance.EcBits, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class UcWords(Entity):
                                                """
                                                UC WORDS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15fecHistories.OpticsMinute15fecHistory.OpticsMinute15fecTimeLineInstances.OpticsMinute15fecTimeLineInstance.UcWords, self).__init__()

                                                    self.yang_name = "uc-words"
                                                    self.yang_parent_name = "optics-minute15fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('data', (YLeaf(YType.uint64, 'data'), ['int'])),
                                                        ('threshold', (YLeaf(YType.uint64, 'threshold'), ['int'])),
                                                        ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.data = None
                                                    self.threshold = None
                                                    self.tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "uc-words"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15fecHistories.OpticsMinute15fecHistory.OpticsMinute15fecTimeLineInstances.OpticsMinute15fecTimeLineInstance.UcWords, ['data', 'threshold', 'tca_report', 'valid'], name, value)


                                            class PreFecBer(Entity):
                                                """
                                                Pre FEC BER
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15fecHistories.OpticsMinute15fecHistory.OpticsMinute15fecTimeLineInstances.OpticsMinute15fecTimeLineInstance.PreFecBer, self).__init__()

                                                    self.yang_name = "pre-fec-ber"
                                                    self.yang_parent_name = "optics-minute15fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.maximum_tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "pre-fec-ber"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15fecHistories.OpticsMinute15fecHistory.OpticsMinute15fecTimeLineInstances.OpticsMinute15fecTimeLineInstance.PreFecBer, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                            class PostFecBer(Entity):
                                                """
                                                Post FEC BER
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15fecHistories.OpticsMinute15fecHistory.OpticsMinute15fecTimeLineInstances.OpticsMinute15fecTimeLineInstance.PostFecBer, self).__init__()

                                                    self.yang_name = "post-fec-ber"
                                                    self.yang_parent_name = "optics-minute15fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.maximum_tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "post-fec-ber"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15fecHistories.OpticsMinute15fecHistory.OpticsMinute15fecTimeLineInstances.OpticsMinute15fecTimeLineInstance.PostFecBer, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                            class Q(Entity):
                                                """
                                                Q
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15fecHistories.OpticsMinute15fecHistory.OpticsMinute15fecTimeLineInstances.OpticsMinute15fecTimeLineInstance.Q, self).__init__()

                                                    self.yang_name = "q"
                                                    self.yang_parent_name = "optics-minute15fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.maximum_tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "q"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15fecHistories.OpticsMinute15fecHistory.OpticsMinute15fecTimeLineInstances.OpticsMinute15fecTimeLineInstance.Q, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


                                            class Qmargin(Entity):
                                                """
                                                Q Margin
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\: str
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\: str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\: str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\: bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\: str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\: bool
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15fecHistories.OpticsMinute15fecHistory.OpticsMinute15fecTimeLineInstances.OpticsMinute15fecTimeLineInstance.Qmargin, self).__init__()

                                                    self.yang_name = "qmargin"
                                                    self.yang_parent_name = "optics-minute15fec-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('minimum', (YLeaf(YType.str, 'minimum'), ['str'])),
                                                        ('average', (YLeaf(YType.str, 'average'), ['str'])),
                                                        ('maximum', (YLeaf(YType.str, 'maximum'), ['str'])),
                                                        ('minimum_threshold', (YLeaf(YType.str, 'minimum-threshold'), ['str'])),
                                                        ('minimum_tca_report', (YLeaf(YType.boolean, 'minimum-tca-report'), ['bool'])),
                                                        ('maximum_threshold', (YLeaf(YType.str, 'maximum-threshold'), ['str'])),
                                                        ('maximum_tca_report', (YLeaf(YType.boolean, 'maximum-tca-report'), ['bool'])),
                                                        ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ])
                                                    self.minimum = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.minimum_threshold = None
                                                    self.minimum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.maximum_tca_report = None
                                                    self.valid = None
                                                    self._segment_path = lambda: "qmargin"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15fecHistories.OpticsMinute15fecHistory.OpticsMinute15fecTimeLineInstances.OpticsMinute15fecTimeLineInstance.Qmargin, ['minimum', 'average', 'maximum', 'minimum_threshold', 'minimum_tca_report', 'maximum_threshold', 'maximum_tca_report', 'valid'], name, value)


            class OcHistory(Entity):
                """
                OC controller History performance data
                
                .. attribute:: oc_port_histories
                
                	Port performance data
                	**type**\:  :py:class:`OcPortHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(PerformanceManagementHistory.Global.Periodic.OcHistory, self).__init__()

                    self.yang_name = "oc-history"
                    self.yang_parent_name = "periodic"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("oc-port-histories", ("oc_port_histories", PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories))])
                    self._leafs = OrderedDict()

                    self.oc_port_histories = PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories()
                    self.oc_port_histories.parent = self
                    self._children_name_map["oc_port_histories"] = "oc-port-histories"
                    self._segment_path = lambda: "oc-history"
                    self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OcHistory, [], name, value)


                class OcPortHistories(Entity):
                    """
                    Port performance data
                    
                    .. attribute:: oc_port_history
                    
                    	Port performance data
                    	**type**\: list of  		 :py:class:`OcPortHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories, self).__init__()

                        self.yang_name = "oc-port-histories"
                        self.yang_parent_name = "oc-history"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("oc-port-history", ("oc_port_history", PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory))])
                        self._leafs = OrderedDict()

                        self.oc_port_history = YList(self)
                        self._segment_path = lambda: "oc-port-histories"
                        self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/oc-history/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories, [], name, value)


                    class OcPortHistory(Entity):
                        """
                        Port performance data
                        
                        .. attribute:: name  (key)
                        
                        	Port name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: oc_hour24_history
                        
                        	port current performance data
                        	**type**\:  :py:class:`OcHour24History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History>`
                        
                        .. attribute:: oc_minute15_history
                        
                        	port current performance data
                        	**type**\:  :py:class:`OcMinute15History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory, self).__init__()

                            self.yang_name = "oc-port-history"
                            self.yang_parent_name = "oc-port-histories"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("oc-hour24-history", ("oc_hour24_history", PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History)), ("oc-minute15-history", ("oc_minute15_history", PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None

                            self.oc_hour24_history = PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History()
                            self.oc_hour24_history.parent = self
                            self._children_name_map["oc_hour24_history"] = "oc-hour24-history"

                            self.oc_minute15_history = PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History()
                            self.oc_minute15_history.parent = self
                            self._children_name_map["oc_minute15_history"] = "oc-minute15-history"
                            self._segment_path = lambda: "oc-port-history" + "[name='" + str(self.name) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/oc-history/oc-port-histories/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory, ['name'], name, value)


                        class OcHour24History(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: oc_hour24ocn_histories
                            
                            	port current performance data
                            	**type**\:  :py:class:`OcHour24ocnHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History, self).__init__()

                                self.yang_name = "oc-hour24-history"
                                self.yang_parent_name = "oc-port-history"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("oc-hour24ocn-histories", ("oc_hour24ocn_histories", PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories))])
                                self._leafs = OrderedDict()

                                self.oc_hour24ocn_histories = PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories()
                                self.oc_hour24ocn_histories.parent = self
                                self._children_name_map["oc_hour24ocn_histories"] = "oc-hour24ocn-histories"
                                self._segment_path = lambda: "oc-hour24-history"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History, [], name, value)


                            class OcHour24ocnHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: oc_hour24ocn_history
                                
                                	port 24 hour ocn performance data
                                	**type**\: list of  		 :py:class:`OcHour24ocnHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories, self).__init__()

                                    self.yang_name = "oc-hour24ocn-histories"
                                    self.yang_parent_name = "oc-hour24-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("oc-hour24ocn-history", ("oc_hour24ocn_history", PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory))])
                                    self._leafs = OrderedDict()

                                    self.oc_hour24ocn_history = YList(self)
                                    self._segment_path = lambda: "oc-hour24ocn-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories, [], name, value)


                                class OcHour24ocnHistory(Entity):
                                    """
                                    port 24 hour ocn performance data
                                    
                                    .. attribute:: number  (key)
                                    
                                    	channel number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: oc_hour24ocn_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`OcHour24ocnTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory, self).__init__()

                                        self.yang_name = "oc-hour24ocn-history"
                                        self.yang_parent_name = "oc-hour24ocn-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([("oc-hour24ocn-time-line-instances", ("oc_hour24ocn_time_line_instances", PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ])
                                        self.number = None

                                        self.oc_hour24ocn_time_line_instances = PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances()
                                        self.oc_hour24ocn_time_line_instances.parent = self
                                        self._children_name_map["oc_hour24ocn_time_line_instances"] = "oc-hour24ocn-time-line-instances"
                                        self._segment_path = lambda: "oc-hour24ocn-history" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory, ['number'], name, value)


                                    class OcHour24ocnTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: oc_hour24ocn_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of  		 :py:class:`OcHour24ocnTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances, self).__init__()

                                            self.yang_name = "oc-hour24ocn-time-line-instances"
                                            self.yang_parent_name = "oc-hour24ocn-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("oc-hour24ocn-time-line-instance", ("oc_hour24ocn_time_line_instance", PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.oc_hour24ocn_time_line_instance = YList(self)
                                            self._segment_path = lambda: "oc-hour24ocn-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances, [], name, value)


                                        class OcHour24ocnTimeLineInstance(Entity):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: section
                                            
                                            	SECTION
                                            	**type**\:  :py:class:`Section <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.Section>`
                                            
                                            .. attribute:: line
                                            
                                            	LINE
                                            	**type**\:  :py:class:`Line <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.Line>`
                                            
                                            .. attribute:: fe_line
                                            
                                            	FarEnd LINE
                                            	**type**\:  :py:class:`FeLine <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.FeLine>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance, self).__init__()

                                                self.yang_name = "oc-hour24ocn-time-line-instance"
                                                self.yang_parent_name = "oc-hour24ocn-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("section", ("section", PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.Section)), ("line", ("line", PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.Line)), ("fe-line", ("fe_line", PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.FeLine))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None

                                                self.section = PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.Section()
                                                self.section.parent = self
                                                self._children_name_map["section"] = "section"

                                                self.line = PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.Line()
                                                self.line.parent = self
                                                self._children_name_map["line"] = "line"

                                                self.fe_line = PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.FeLine()
                                                self.fe_line.parent = self
                                                self._children_name_map["fe_line"] = "fe-line"
                                                self._segment_path = lambda: "oc-hour24ocn-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear24_hr_time'], name, value)


                                            class Section(Entity):
                                                """
                                                SECTION
                                                
                                                .. attribute:: section_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:  :py:class:`SectionESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.Section.SectionESs>`
                                                
                                                .. attribute:: section_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:  :py:class:`SectionSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.Section.SectionSeSs>`
                                                
                                                .. attribute:: section_sef_ss
                                                
                                                	The number of Severely Errored Framing Seconds
                                                	**type**\:  :py:class:`SectionSefSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.Section.SectionSefSs>`
                                                
                                                .. attribute:: section_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:  :py:class:`SectionCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.Section.SectionCVs>`
                                                
                                                .. attribute:: section_status
                                                
                                                	 status of the interface
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.Section, self).__init__()

                                                    self.yang_name = "section"
                                                    self.yang_parent_name = "oc-hour24ocn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("section-e-ss", ("section_e_ss", PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.Section.SectionESs)), ("section-se-ss", ("section_se_ss", PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.Section.SectionSeSs)), ("section-sef-ss", ("section_sef_ss", PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.Section.SectionSefSs)), ("section-c-vs", ("section_c_vs", PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.Section.SectionCVs))])
                                                    self._leafs = OrderedDict([
                                                        ('section_status', (YLeaf(YType.int32, 'section-status'), ['int'])),
                                                    ])
                                                    self.section_status = None

                                                    self.section_e_ss = PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.Section.SectionESs()
                                                    self.section_e_ss.parent = self
                                                    self._children_name_map["section_e_ss"] = "section-e-ss"

                                                    self.section_se_ss = PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.Section.SectionSeSs()
                                                    self.section_se_ss.parent = self
                                                    self._children_name_map["section_se_ss"] = "section-se-ss"

                                                    self.section_sef_ss = PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.Section.SectionSefSs()
                                                    self.section_sef_ss.parent = self
                                                    self._children_name_map["section_sef_ss"] = "section-sef-ss"

                                                    self.section_c_vs = PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.Section.SectionCVs()
                                                    self.section_c_vs.parent = self
                                                    self._children_name_map["section_c_vs"] = "section-c-vs"
                                                    self._segment_path = lambda: "section"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.Section, ['section_status'], name, value)


                                                class SectionESs(Entity):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.Section.SectionESs, self).__init__()

                                                        self.yang_name = "section-e-ss"
                                                        self.yang_parent_name = "section"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "section-e-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.Section.SectionESs, ['data', 'threshold', 'tca_report'], name, value)


                                                class SectionSeSs(Entity):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.Section.SectionSeSs, self).__init__()

                                                        self.yang_name = "section-se-ss"
                                                        self.yang_parent_name = "section"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "section-se-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.Section.SectionSeSs, ['data', 'threshold', 'tca_report'], name, value)


                                                class SectionSefSs(Entity):
                                                    """
                                                    The number of Severely Errored Framing Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.Section.SectionSefSs, self).__init__()

                                                        self.yang_name = "section-sef-ss"
                                                        self.yang_parent_name = "section"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "section-sef-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.Section.SectionSefSs, ['data', 'threshold', 'tca_report'], name, value)


                                                class SectionCVs(Entity):
                                                    """
                                                    The number of Coding Violations
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.Section.SectionCVs, self).__init__()

                                                        self.yang_name = "section-c-vs"
                                                        self.yang_parent_name = "section"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "section-c-vs"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.Section.SectionCVs, ['data', 'threshold', 'tca_report'], name, value)


                                            class Line(Entity):
                                                """
                                                LINE
                                                
                                                .. attribute:: line_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:  :py:class:`LineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.Line.LineESs>`
                                                
                                                .. attribute:: line_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:  :py:class:`LineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.Line.LineSeSs>`
                                                
                                                .. attribute:: line_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:  :py:class:`LineCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.Line.LineCVs>`
                                                
                                                .. attribute:: line_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\:  :py:class:`LineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.Line.LineUaSs>`
                                                
                                                .. attribute:: line_fc_ls
                                                
                                                	The number of Failure counts Seconds
                                                	**type**\:  :py:class:`LineFcLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.Line.LineFcLs>`
                                                
                                                .. attribute:: line_status
                                                
                                                	 status of the interface
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.Line, self).__init__()

                                                    self.yang_name = "line"
                                                    self.yang_parent_name = "oc-hour24ocn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("line-e-ss", ("line_e_ss", PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.Line.LineESs)), ("line-se-ss", ("line_se_ss", PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.Line.LineSeSs)), ("line-c-vs", ("line_c_vs", PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.Line.LineCVs)), ("line-ua-ss", ("line_ua_ss", PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.Line.LineUaSs)), ("line-fc-ls", ("line_fc_ls", PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.Line.LineFcLs))])
                                                    self._leafs = OrderedDict([
                                                        ('line_status', (YLeaf(YType.int32, 'line-status'), ['int'])),
                                                    ])
                                                    self.line_status = None

                                                    self.line_e_ss = PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.Line.LineESs()
                                                    self.line_e_ss.parent = self
                                                    self._children_name_map["line_e_ss"] = "line-e-ss"

                                                    self.line_se_ss = PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.Line.LineSeSs()
                                                    self.line_se_ss.parent = self
                                                    self._children_name_map["line_se_ss"] = "line-se-ss"

                                                    self.line_c_vs = PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.Line.LineCVs()
                                                    self.line_c_vs.parent = self
                                                    self._children_name_map["line_c_vs"] = "line-c-vs"

                                                    self.line_ua_ss = PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.Line.LineUaSs()
                                                    self.line_ua_ss.parent = self
                                                    self._children_name_map["line_ua_ss"] = "line-ua-ss"

                                                    self.line_fc_ls = PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.Line.LineFcLs()
                                                    self.line_fc_ls.parent = self
                                                    self._children_name_map["line_fc_ls"] = "line-fc-ls"
                                                    self._segment_path = lambda: "line"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.Line, ['line_status'], name, value)


                                                class LineESs(Entity):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.Line.LineESs, self).__init__()

                                                        self.yang_name = "line-e-ss"
                                                        self.yang_parent_name = "line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "line-e-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.Line.LineESs, ['data', 'threshold', 'tca_report'], name, value)


                                                class LineSeSs(Entity):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.Line.LineSeSs, self).__init__()

                                                        self.yang_name = "line-se-ss"
                                                        self.yang_parent_name = "line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "line-se-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.Line.LineSeSs, ['data', 'threshold', 'tca_report'], name, value)


                                                class LineCVs(Entity):
                                                    """
                                                    The number of Coding Violations
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.Line.LineCVs, self).__init__()

                                                        self.yang_name = "line-c-vs"
                                                        self.yang_parent_name = "line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "line-c-vs"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.Line.LineCVs, ['data', 'threshold', 'tca_report'], name, value)


                                                class LineUaSs(Entity):
                                                    """
                                                    The number of Unavailable Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.Line.LineUaSs, self).__init__()

                                                        self.yang_name = "line-ua-ss"
                                                        self.yang_parent_name = "line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "line-ua-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.Line.LineUaSs, ['data', 'threshold', 'tca_report'], name, value)


                                                class LineFcLs(Entity):
                                                    """
                                                    The number of Failure counts Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.Line.LineFcLs, self).__init__()

                                                        self.yang_name = "line-fc-ls"
                                                        self.yang_parent_name = "line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "line-fc-ls"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.Line.LineFcLs, ['data', 'threshold', 'tca_report'], name, value)


                                            class FeLine(Entity):
                                                """
                                                FarEnd LINE
                                                
                                                .. attribute:: far_end_line_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:  :py:class:`FarEndLineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.FeLine.FarEndLineESs>`
                                                
                                                .. attribute:: far_end_line_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:  :py:class:`FarEndLineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.FeLine.FarEndLineSeSs>`
                                                
                                                .. attribute:: far_end_line_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:  :py:class:`FarEndLineCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.FeLine.FarEndLineCVs>`
                                                
                                                .. attribute:: far_end_line_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\:  :py:class:`FarEndLineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.FeLine.FarEndLineUaSs>`
                                                
                                                .. attribute:: far_end_line_fc_ls
                                                
                                                	The number of Failure counts Seconds
                                                	**type**\:  :py:class:`FarEndLineFcLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.FeLine.FarEndLineFcLs>`
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.FeLine, self).__init__()

                                                    self.yang_name = "fe-line"
                                                    self.yang_parent_name = "oc-hour24ocn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("far-end-line-e-ss", ("far_end_line_e_ss", PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.FeLine.FarEndLineESs)), ("far-end-line-se-ss", ("far_end_line_se_ss", PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.FeLine.FarEndLineSeSs)), ("far-end-line-c-vs", ("far_end_line_c_vs", PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.FeLine.FarEndLineCVs)), ("far-end-line-ua-ss", ("far_end_line_ua_ss", PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.FeLine.FarEndLineUaSs)), ("far-end-line-fc-ls", ("far_end_line_fc_ls", PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.FeLine.FarEndLineFcLs))])
                                                    self._leafs = OrderedDict()

                                                    self.far_end_line_e_ss = PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.FeLine.FarEndLineESs()
                                                    self.far_end_line_e_ss.parent = self
                                                    self._children_name_map["far_end_line_e_ss"] = "far-end-line-e-ss"

                                                    self.far_end_line_se_ss = PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.FeLine.FarEndLineSeSs()
                                                    self.far_end_line_se_ss.parent = self
                                                    self._children_name_map["far_end_line_se_ss"] = "far-end-line-se-ss"

                                                    self.far_end_line_c_vs = PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.FeLine.FarEndLineCVs()
                                                    self.far_end_line_c_vs.parent = self
                                                    self._children_name_map["far_end_line_c_vs"] = "far-end-line-c-vs"

                                                    self.far_end_line_ua_ss = PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.FeLine.FarEndLineUaSs()
                                                    self.far_end_line_ua_ss.parent = self
                                                    self._children_name_map["far_end_line_ua_ss"] = "far-end-line-ua-ss"

                                                    self.far_end_line_fc_ls = PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.FeLine.FarEndLineFcLs()
                                                    self.far_end_line_fc_ls.parent = self
                                                    self._children_name_map["far_end_line_fc_ls"] = "far-end-line-fc-ls"
                                                    self._segment_path = lambda: "fe-line"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.FeLine, [], name, value)


                                                class FarEndLineESs(Entity):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.FeLine.FarEndLineESs, self).__init__()

                                                        self.yang_name = "far-end-line-e-ss"
                                                        self.yang_parent_name = "fe-line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "far-end-line-e-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.FeLine.FarEndLineESs, ['data', 'threshold', 'tca_report'], name, value)


                                                class FarEndLineSeSs(Entity):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.FeLine.FarEndLineSeSs, self).__init__()

                                                        self.yang_name = "far-end-line-se-ss"
                                                        self.yang_parent_name = "fe-line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "far-end-line-se-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.FeLine.FarEndLineSeSs, ['data', 'threshold', 'tca_report'], name, value)


                                                class FarEndLineCVs(Entity):
                                                    """
                                                    The number of Coding Violations
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.FeLine.FarEndLineCVs, self).__init__()

                                                        self.yang_name = "far-end-line-c-vs"
                                                        self.yang_parent_name = "fe-line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "far-end-line-c-vs"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.FeLine.FarEndLineCVs, ['data', 'threshold', 'tca_report'], name, value)


                                                class FarEndLineUaSs(Entity):
                                                    """
                                                    The number of Unavailable Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.FeLine.FarEndLineUaSs, self).__init__()

                                                        self.yang_name = "far-end-line-ua-ss"
                                                        self.yang_parent_name = "fe-line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "far-end-line-ua-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.FeLine.FarEndLineUaSs, ['data', 'threshold', 'tca_report'], name, value)


                                                class FarEndLineFcLs(Entity):
                                                    """
                                                    The number of Failure counts Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.FeLine.FarEndLineFcLs, self).__init__()

                                                        self.yang_name = "far-end-line-fc-ls"
                                                        self.yang_parent_name = "fe-line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "far-end-line-fc-ls"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24ocnHistories.OcHour24ocnHistory.OcHour24ocnTimeLineInstances.OcHour24ocnTimeLineInstance.FeLine.FarEndLineFcLs, ['data', 'threshold', 'tca_report'], name, value)


                        class OcMinute15History(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: oc_minute15ocn_histories
                            
                            	port current performance data
                            	**type**\:  :py:class:`OcMinute15ocnHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History, self).__init__()

                                self.yang_name = "oc-minute15-history"
                                self.yang_parent_name = "oc-port-history"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("oc-minute15ocn-histories", ("oc_minute15ocn_histories", PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories))])
                                self._leafs = OrderedDict()

                                self.oc_minute15ocn_histories = PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories()
                                self.oc_minute15ocn_histories.parent = self
                                self._children_name_map["oc_minute15ocn_histories"] = "oc-minute15ocn-histories"
                                self._segment_path = lambda: "oc-minute15-history"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History, [], name, value)


                            class OcMinute15ocnHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: oc_minute15ocn_history
                                
                                	port 15\-minute ocn performance data
                                	**type**\: list of  		 :py:class:`OcMinute15ocnHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories, self).__init__()

                                    self.yang_name = "oc-minute15ocn-histories"
                                    self.yang_parent_name = "oc-minute15-history"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("oc-minute15ocn-history", ("oc_minute15ocn_history", PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory))])
                                    self._leafs = OrderedDict()

                                    self.oc_minute15ocn_history = YList(self)
                                    self._segment_path = lambda: "oc-minute15ocn-histories"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories, [], name, value)


                                class OcMinute15ocnHistory(Entity):
                                    """
                                    port 15\-minute ocn performance data
                                    
                                    .. attribute:: number  (key)
                                    
                                    	channel number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: oc_minute15ocn_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:  :py:class:`OcMinute15ocnTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory, self).__init__()

                                        self.yang_name = "oc-minute15ocn-history"
                                        self.yang_parent_name = "oc-minute15ocn-histories"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['number']
                                        self._child_classes = OrderedDict([("oc-minute15ocn-time-line-instances", ("oc_minute15ocn_time_line_instances", PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances))])
                                        self._leafs = OrderedDict([
                                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                        ])
                                        self.number = None

                                        self.oc_minute15ocn_time_line_instances = PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances()
                                        self.oc_minute15ocn_time_line_instances.parent = self
                                        self._children_name_map["oc_minute15ocn_time_line_instances"] = "oc-minute15ocn-time-line-instances"
                                        self._segment_path = lambda: "oc-minute15ocn-history" + "[number='" + str(self.number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory, ['number'], name, value)


                                    class OcMinute15ocnTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: oc_minute15ocn_time_line_instance
                                        
                                        	port 15\-minute ocn performance data
                                        	**type**\: list of  		 :py:class:`OcMinute15ocnTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances, self).__init__()

                                            self.yang_name = "oc-minute15ocn-time-line-instances"
                                            self.yang_parent_name = "oc-minute15ocn-history"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("oc-minute15ocn-time-line-instance", ("oc_minute15ocn_time_line_instance", PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance))])
                                            self._leafs = OrderedDict()

                                            self.oc_minute15ocn_time_line_instance = YList(self)
                                            self._segment_path = lambda: "oc-minute15ocn-time-line-instances"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances, [], name, value)


                                        class OcMinute15ocnTimeLineInstance(Entity):
                                            """
                                            port 15\-minute ocn performance data
                                            
                                            .. attribute:: number  (key)
                                            
                                            	History Index number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: section
                                            
                                            	SECTION
                                            	**type**\:  :py:class:`Section <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.Section>`
                                            
                                            .. attribute:: line
                                            
                                            	LINE
                                            	**type**\:  :py:class:`Line <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.Line>`
                                            
                                            .. attribute:: fe_line
                                            
                                            	FarEnd LINE
                                            	**type**\:  :py:class:`FeLine <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.FeLine>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\: bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\: str
                                            
                                            	**length:** 0..64
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance, self).__init__()

                                                self.yang_name = "oc-minute15ocn-time-line-instance"
                                                self.yang_parent_name = "oc-minute15ocn-time-line-instances"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['number']
                                                self._child_classes = OrderedDict([("section", ("section", PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.Section)), ("line", ("line", PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.Line)), ("fe-line", ("fe_line", PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.FeLine))])
                                                self._leafs = OrderedDict([
                                                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                                                    ('index', (YLeaf(YType.uint32, 'index'), ['int'])),
                                                    ('valid', (YLeaf(YType.boolean, 'valid'), ['bool'])),
                                                    ('timestamp', (YLeaf(YType.str, 'timestamp'), ['str'])),
                                                    ('last_clear_time', (YLeaf(YType.str, 'last-clear-time'), ['str'])),
                                                    ('last_clear15_min_time', (YLeaf(YType.str, 'last-clear15-min-time'), ['str'])),
                                                    ('last_clear24_hr_time', (YLeaf(YType.str, 'last-clear24-hr-time'), ['str'])),
                                                ])
                                                self.number = None
                                                self.index = None
                                                self.valid = None
                                                self.timestamp = None
                                                self.last_clear_time = None
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None

                                                self.section = PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.Section()
                                                self.section.parent = self
                                                self._children_name_map["section"] = "section"

                                                self.line = PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.Line()
                                                self.line.parent = self
                                                self._children_name_map["line"] = "line"

                                                self.fe_line = PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.FeLine()
                                                self.fe_line.parent = self
                                                self._children_name_map["fe_line"] = "fe-line"
                                                self._segment_path = lambda: "oc-minute15ocn-time-line-instance" + "[number='" + str(self.number) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance, ['number', 'index', 'valid', 'timestamp', 'last_clear_time', 'last_clear15_min_time', 'last_clear24_hr_time'], name, value)


                                            class Section(Entity):
                                                """
                                                SECTION
                                                
                                                .. attribute:: section_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:  :py:class:`SectionESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.Section.SectionESs>`
                                                
                                                .. attribute:: section_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:  :py:class:`SectionSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.Section.SectionSeSs>`
                                                
                                                .. attribute:: section_sef_ss
                                                
                                                	The number of Severely Errored Framing Seconds
                                                	**type**\:  :py:class:`SectionSefSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.Section.SectionSefSs>`
                                                
                                                .. attribute:: section_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:  :py:class:`SectionCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.Section.SectionCVs>`
                                                
                                                .. attribute:: section_status
                                                
                                                	 status of the interface
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.Section, self).__init__()

                                                    self.yang_name = "section"
                                                    self.yang_parent_name = "oc-minute15ocn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("section-e-ss", ("section_e_ss", PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.Section.SectionESs)), ("section-se-ss", ("section_se_ss", PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.Section.SectionSeSs)), ("section-sef-ss", ("section_sef_ss", PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.Section.SectionSefSs)), ("section-c-vs", ("section_c_vs", PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.Section.SectionCVs))])
                                                    self._leafs = OrderedDict([
                                                        ('section_status', (YLeaf(YType.int32, 'section-status'), ['int'])),
                                                    ])
                                                    self.section_status = None

                                                    self.section_e_ss = PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.Section.SectionESs()
                                                    self.section_e_ss.parent = self
                                                    self._children_name_map["section_e_ss"] = "section-e-ss"

                                                    self.section_se_ss = PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.Section.SectionSeSs()
                                                    self.section_se_ss.parent = self
                                                    self._children_name_map["section_se_ss"] = "section-se-ss"

                                                    self.section_sef_ss = PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.Section.SectionSefSs()
                                                    self.section_sef_ss.parent = self
                                                    self._children_name_map["section_sef_ss"] = "section-sef-ss"

                                                    self.section_c_vs = PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.Section.SectionCVs()
                                                    self.section_c_vs.parent = self
                                                    self._children_name_map["section_c_vs"] = "section-c-vs"
                                                    self._segment_path = lambda: "section"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.Section, ['section_status'], name, value)


                                                class SectionESs(Entity):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.Section.SectionESs, self).__init__()

                                                        self.yang_name = "section-e-ss"
                                                        self.yang_parent_name = "section"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "section-e-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.Section.SectionESs, ['data', 'threshold', 'tca_report'], name, value)


                                                class SectionSeSs(Entity):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.Section.SectionSeSs, self).__init__()

                                                        self.yang_name = "section-se-ss"
                                                        self.yang_parent_name = "section"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "section-se-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.Section.SectionSeSs, ['data', 'threshold', 'tca_report'], name, value)


                                                class SectionSefSs(Entity):
                                                    """
                                                    The number of Severely Errored Framing Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.Section.SectionSefSs, self).__init__()

                                                        self.yang_name = "section-sef-ss"
                                                        self.yang_parent_name = "section"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "section-sef-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.Section.SectionSefSs, ['data', 'threshold', 'tca_report'], name, value)


                                                class SectionCVs(Entity):
                                                    """
                                                    The number of Coding Violations
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.Section.SectionCVs, self).__init__()

                                                        self.yang_name = "section-c-vs"
                                                        self.yang_parent_name = "section"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "section-c-vs"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.Section.SectionCVs, ['data', 'threshold', 'tca_report'], name, value)


                                            class Line(Entity):
                                                """
                                                LINE
                                                
                                                .. attribute:: line_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:  :py:class:`LineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.Line.LineESs>`
                                                
                                                .. attribute:: line_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:  :py:class:`LineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.Line.LineSeSs>`
                                                
                                                .. attribute:: line_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:  :py:class:`LineCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.Line.LineCVs>`
                                                
                                                .. attribute:: line_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\:  :py:class:`LineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.Line.LineUaSs>`
                                                
                                                .. attribute:: line_fc_ls
                                                
                                                	The number of Failure counts Seconds
                                                	**type**\:  :py:class:`LineFcLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.Line.LineFcLs>`
                                                
                                                .. attribute:: line_status
                                                
                                                	 status of the interface
                                                	**type**\: int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.Line, self).__init__()

                                                    self.yang_name = "line"
                                                    self.yang_parent_name = "oc-minute15ocn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("line-e-ss", ("line_e_ss", PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.Line.LineESs)), ("line-se-ss", ("line_se_ss", PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.Line.LineSeSs)), ("line-c-vs", ("line_c_vs", PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.Line.LineCVs)), ("line-ua-ss", ("line_ua_ss", PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.Line.LineUaSs)), ("line-fc-ls", ("line_fc_ls", PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.Line.LineFcLs))])
                                                    self._leafs = OrderedDict([
                                                        ('line_status', (YLeaf(YType.int32, 'line-status'), ['int'])),
                                                    ])
                                                    self.line_status = None

                                                    self.line_e_ss = PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.Line.LineESs()
                                                    self.line_e_ss.parent = self
                                                    self._children_name_map["line_e_ss"] = "line-e-ss"

                                                    self.line_se_ss = PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.Line.LineSeSs()
                                                    self.line_se_ss.parent = self
                                                    self._children_name_map["line_se_ss"] = "line-se-ss"

                                                    self.line_c_vs = PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.Line.LineCVs()
                                                    self.line_c_vs.parent = self
                                                    self._children_name_map["line_c_vs"] = "line-c-vs"

                                                    self.line_ua_ss = PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.Line.LineUaSs()
                                                    self.line_ua_ss.parent = self
                                                    self._children_name_map["line_ua_ss"] = "line-ua-ss"

                                                    self.line_fc_ls = PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.Line.LineFcLs()
                                                    self.line_fc_ls.parent = self
                                                    self._children_name_map["line_fc_ls"] = "line-fc-ls"
                                                    self._segment_path = lambda: "line"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.Line, ['line_status'], name, value)


                                                class LineESs(Entity):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.Line.LineESs, self).__init__()

                                                        self.yang_name = "line-e-ss"
                                                        self.yang_parent_name = "line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "line-e-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.Line.LineESs, ['data', 'threshold', 'tca_report'], name, value)


                                                class LineSeSs(Entity):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.Line.LineSeSs, self).__init__()

                                                        self.yang_name = "line-se-ss"
                                                        self.yang_parent_name = "line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "line-se-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.Line.LineSeSs, ['data', 'threshold', 'tca_report'], name, value)


                                                class LineCVs(Entity):
                                                    """
                                                    The number of Coding Violations
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.Line.LineCVs, self).__init__()

                                                        self.yang_name = "line-c-vs"
                                                        self.yang_parent_name = "line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "line-c-vs"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.Line.LineCVs, ['data', 'threshold', 'tca_report'], name, value)


                                                class LineUaSs(Entity):
                                                    """
                                                    The number of Unavailable Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.Line.LineUaSs, self).__init__()

                                                        self.yang_name = "line-ua-ss"
                                                        self.yang_parent_name = "line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "line-ua-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.Line.LineUaSs, ['data', 'threshold', 'tca_report'], name, value)


                                                class LineFcLs(Entity):
                                                    """
                                                    The number of Failure counts Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.Line.LineFcLs, self).__init__()

                                                        self.yang_name = "line-fc-ls"
                                                        self.yang_parent_name = "line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "line-fc-ls"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.Line.LineFcLs, ['data', 'threshold', 'tca_report'], name, value)


                                            class FeLine(Entity):
                                                """
                                                FarEnd LINE
                                                
                                                .. attribute:: far_end_line_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:  :py:class:`FarEndLineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.FeLine.FarEndLineESs>`
                                                
                                                .. attribute:: far_end_line_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:  :py:class:`FarEndLineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.FeLine.FarEndLineSeSs>`
                                                
                                                .. attribute:: far_end_line_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:  :py:class:`FarEndLineCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.FeLine.FarEndLineCVs>`
                                                
                                                .. attribute:: far_end_line_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\:  :py:class:`FarEndLineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.FeLine.FarEndLineUaSs>`
                                                
                                                .. attribute:: far_end_line_fc_ls
                                                
                                                	The number of Failure counts Seconds
                                                	**type**\:  :py:class:`FarEndLineFcLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.FeLine.FarEndLineFcLs>`
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.FeLine, self).__init__()

                                                    self.yang_name = "fe-line"
                                                    self.yang_parent_name = "oc-minute15ocn-time-line-instance"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("far-end-line-e-ss", ("far_end_line_e_ss", PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.FeLine.FarEndLineESs)), ("far-end-line-se-ss", ("far_end_line_se_ss", PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.FeLine.FarEndLineSeSs)), ("far-end-line-c-vs", ("far_end_line_c_vs", PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.FeLine.FarEndLineCVs)), ("far-end-line-ua-ss", ("far_end_line_ua_ss", PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.FeLine.FarEndLineUaSs)), ("far-end-line-fc-ls", ("far_end_line_fc_ls", PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.FeLine.FarEndLineFcLs))])
                                                    self._leafs = OrderedDict()

                                                    self.far_end_line_e_ss = PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.FeLine.FarEndLineESs()
                                                    self.far_end_line_e_ss.parent = self
                                                    self._children_name_map["far_end_line_e_ss"] = "far-end-line-e-ss"

                                                    self.far_end_line_se_ss = PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.FeLine.FarEndLineSeSs()
                                                    self.far_end_line_se_ss.parent = self
                                                    self._children_name_map["far_end_line_se_ss"] = "far-end-line-se-ss"

                                                    self.far_end_line_c_vs = PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.FeLine.FarEndLineCVs()
                                                    self.far_end_line_c_vs.parent = self
                                                    self._children_name_map["far_end_line_c_vs"] = "far-end-line-c-vs"

                                                    self.far_end_line_ua_ss = PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.FeLine.FarEndLineUaSs()
                                                    self.far_end_line_ua_ss.parent = self
                                                    self._children_name_map["far_end_line_ua_ss"] = "far-end-line-ua-ss"

                                                    self.far_end_line_fc_ls = PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.FeLine.FarEndLineFcLs()
                                                    self.far_end_line_fc_ls.parent = self
                                                    self._children_name_map["far_end_line_fc_ls"] = "far-end-line-fc-ls"
                                                    self._segment_path = lambda: "fe-line"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.FeLine, [], name, value)


                                                class FarEndLineESs(Entity):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.FeLine.FarEndLineESs, self).__init__()

                                                        self.yang_name = "far-end-line-e-ss"
                                                        self.yang_parent_name = "fe-line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "far-end-line-e-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.FeLine.FarEndLineESs, ['data', 'threshold', 'tca_report'], name, value)


                                                class FarEndLineSeSs(Entity):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.FeLine.FarEndLineSeSs, self).__init__()

                                                        self.yang_name = "far-end-line-se-ss"
                                                        self.yang_parent_name = "fe-line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "far-end-line-se-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.FeLine.FarEndLineSeSs, ['data', 'threshold', 'tca_report'], name, value)


                                                class FarEndLineCVs(Entity):
                                                    """
                                                    The number of Coding Violations
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.FeLine.FarEndLineCVs, self).__init__()

                                                        self.yang_name = "far-end-line-c-vs"
                                                        self.yang_parent_name = "fe-line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "far-end-line-c-vs"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.FeLine.FarEndLineCVs, ['data', 'threshold', 'tca_report'], name, value)


                                                class FarEndLineUaSs(Entity):
                                                    """
                                                    The number of Unavailable Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.FeLine.FarEndLineUaSs, self).__init__()

                                                        self.yang_name = "far-end-line-ua-ss"
                                                        self.yang_parent_name = "fe-line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "far-end-line-ua-ss"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.FeLine.FarEndLineUaSs, ['data', 'threshold', 'tca_report'], name, value)


                                                class FarEndLineFcLs(Entity):
                                                    """
                                                    The number of Failure counts Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.FeLine.FarEndLineFcLs, self).__init__()

                                                        self.yang_name = "far-end-line-fc-ls"
                                                        self.yang_parent_name = "fe-line"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('data', (YLeaf(YType.uint32, 'data'), ['int'])),
                                                            ('threshold', (YLeaf(YType.uint32, 'threshold'), ['int'])),
                                                            ('tca_report', (YLeaf(YType.boolean, 'tca-report'), ['bool'])),
                                                        ])
                                                        self.data = None
                                                        self.threshold = None
                                                        self.tca_report = None
                                                        self._segment_path = lambda: "far-end-line-fc-ls"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(PerformanceManagementHistory.Global.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15ocnHistories.OcMinute15ocnHistory.OcMinute15ocnTimeLineInstances.OcMinute15ocnTimeLineInstance.FeLine.FarEndLineFcLs, ['data', 'threshold', 'tca_report'], name, value)

    def clone_ptr(self):
        self._top_entity = PerformanceManagementHistory()
        return self._top_entity

